;; -*- text -*- -*- coding: euc-jp -*-
;; Large size dictionary for SKK system
;; Copyright (C) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1997,
;;               1999, 2000, 2001, 2002
;;
;; Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
;; Hironobu Takahashi <takahasi@tiny.or.jp>,
;; Masahiro Doteguchi, Miki Inooka,
;; Yukiyoshi Kameyama <kameyama@kuis.kyoto-u.ac.jp>,
;; Akihiko Sasaki, Dai Ando, Junichi Okukawa,
;; Katsushi Sato and Nobuhiro Yamagishi
;;
;; Maintainer: SKK Development Team <skk@ring.gr.jp>
;; Version: $Id: SKK-JISYO.L,v 1.109 2002/04/30 19:36:14 obata Exp $
;; Keywords: japanese
;; Last Modified: $Date: 2002/04/30 19:36:14 $
;;
;; This dictionary is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either versions 2, or (at your option)
;; any later version.
;;
;; This dictionary is distributed in the hope that it will be useful
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with Daredevil SKK, see the file COPYING.  If not, write to the Free
;; Software Foundation Inc., 59 Temple Place - Suite 330, Boston,
;; MA 02111-1307, USA.
;;
;; okuri-ari entries.
をs /惜/
ゐr /居/
われらg /我等/
われしr /我知/
われr /我/
わるよi /悪酔/
わるがしこi /悪賢/
わるs /悪/
わるk /悪/惡/
わるi /悪/惡/
わるg /悪/
わりふt /割り振/
わりふr /割り振/割振/
わりびk /割引/
わりびi /割引/
わりつk /割り付/割付/
わりだs /割出/割り出/
わりこn /割り込/
わりこm /割込/割り込/
わりきt /割切/割り切/
わりきr /割切/割り切/
わりあてr /割当/
わりあt /割当/割り当/
わりあi /割合/割り合/
わりt /割/
わらw /笑/
わらu /笑/嗤/
わらt /笑/
わらk /笑/
わらi /笑/
わらh /笑/
わらe /笑/
わめk /喚/叫/
わびしi /侘/
わびs /侘/
わびr /侘/
わのr /輪乗/
わななk /戦慄/
わづらh /煩/
わだかまr /蟠/
わたりあるk /渡り歩/
わたりあるi /渡り歩/
わたしh /私/
わたt /渡/亘/
わたs /渡/
わたr /渡/亘/亙/航/渉/
わせだどおr /早稲田通/
わずらw /煩/
わずらu /患/煩/
わずらt /患/
わずらi /患/
わずk /僅/微/毫/
わすr /忘/
わざわi /災/禍/厄/
わけあw /分け合/
わけあu /分け合/
わけあt /分け合/
わけあo /分け合/
わけあi /分け合/
わけあe /分け合/
わけr /分/
わくぐm /枠組/
わきまe /弁/
わきづk /脇付/
わきたt /沸き立/
わきがたm /脇固/
わきあg /沸き上/
わかりやすk /判り易/理解り易/
わかがえt /若返/
わかがえr /若返/
わかt /判/分/解/觧/別/
わかs /若/
わかr /別/分/判/解/理解/觧/
わかk /若/
わかi /若/
わかc /解/
わt /割/
わs /和/
わr /割/
わk /分/沸/湧/訳/涌/
わi /湧/沸/
わg /我/
わb /詫/侘/
ろんz /論/
ろんj /論/
ろくがどr /録画撮/
ろくn /碌/
ろうをおs /労を惜/
ろうs /労/弄/聾/
れんらくいただk /連絡頂/
れんらくいただi /連絡頂/
れんらくいたs /連絡致/
れんきゅうあk /連休明/
れいぎただs /礼儀正/
れいn /例/
るいs /類/
りりs /凛々/凛凛/律々/
りようくだs /利用下/
りようs /利用/
りょこううかがi /旅行伺/
りょうほうもt /両方持/
りょうほうもc /両方持/
りょうほうとr /両方取/
りょうほうつかu /両方使/
りょうほうつかt /両方使/
りょうほうつかo /両方使/
りょうほうつかi /両方使/
りょうほうつかe /両方使/
りょうびらk /両開/
りょうひらk /両開/
りょうしょうくだs /了承下/
りょうかいs /了解/
りゅうこうおくr /流行遅/
りゃくs /略/
りづm /理詰/
りっs /律/
りだすk /利助/
りくつどおr /理屈通/
りきm /力/
りかいs /理解/
りs /利/
らうs /労/
よんd /読ん/
よわよわs /弱々/
よわすg /弱過/
よわt /弱/
よわs /弱/
よわr /弱/
よわm /弱/
よわk /弱/
よわi /弱/
よろしk /宜/
よろこんd /喜ん/
よろこn /喜/
よろこb /喜/慶/
よろs /宜/
よるおそk /夜遅/
よるおそi /夜遅/
よりそt /寄り添/
よりきt /寄り切/
よりきr /寄り切/
よめいr /嫁入/
よみはじm /読み始/
よみにくi /読み難/
よみなおs /読み直/
よみなr /読み慣/
よみとt /読取/読み取/
よみとr /読み取/読取/
よみとb /読み飛/
よみだs /読み出/読出/
よみすすm /読み進/
よみこn /読み込/読込/詠み込/
よみこm /読み込/読込/詠み込/
よみがえt /甦/蘇/蘓/
よみがえr /蘇/甦/蘓/
よみがe /蘇/蘓/
よみかえs /読み返/
よみかk /読み書/
よみかe /読み換/読み変/
よみおw /読み終/
よみおe /読み終/
よみあg /読み上/
よふかs /夜更/
よふk /夜更/
よびよs /呼び寄/
よびもどs /呼び戻/
よびとm /呼び止/
よびだs /呼出/呼び出/
よびたt /呼び立/
よびすt /呼び捨/
よびさm /呼び覚/
よびこn /呼び込/
よびこm /呼び込/
よびかw /呼び交/
よびかk /呼び掛/
よびおk /呼び起/
よびあつm /呼び集/
よばi /夜這/
よなおs /世直/
よどおs /夜通/
よどn /淀/澱/
よどm /澱/淀/
よとおr /四通/
よていどおr /予定通/
よづr /夜釣/
よっぱらt /酔っ払/
よっt /四/
よそほu /裝/
よそおu /装/裝/
よそおt /装/裝/
よそおi /装/裝/
よそおh /裝/
よそうどおr /予想通/
よそうs /予想/
よそu /装/
よそh /装/
よせがk /寄書/寄せ書/
よせあつm /寄せ集/
よすg /良過/
よじr /捩/
よごs /汚/
よごr /汚/
よこならb /横並/
よこどr /横取/
よことb /横跳/
よこづk /横付/
よこすべr /横滑/
よこくどおr /予告通/
よこぎt /横切/
よこぎr /横切/
よこがk /横書/
よこt /横/
よこs /寄越/遣/
よくばt /欲張/
よくばr /欲張/
よくs /浴/
よくb /欲/
よぎなk /余儀無/
よぎr /過/
よぎn /余儀/
ようよu /漸/
ようやk /漸/
ようだt /用立/
ようじんぶかk /用心深/
ようじんぶかi /用心深/
ようしゃねがu /容赦願/
ようしゃねがi /容赦願/
ようしゃくだs /容赦下/
よういs /用意/
よういn /容易/
よういd /容易/
ようs /要/擁/
ようn /様/陽/樣/
よいっぱr /宵っ張/
よいざm /酔醒/
よあるk /夜歩/
よあそb /夜遊/
よあk /夜明/
よz /攀/
よw /酔/醉/
よu /酔/醉/
よt /寄/酔/四/因/４/選/醉/依/拠/
よs /寄/良/善/
よr /寄/因/依/拠/選/撚/憑/縒/
よp /酔/
よn /読/呼/世/丗/讀/詠/
よm /読/呼/詠/讀/
よk /良/善/除/避/譱/好/
よj /攀/
よi /良/酔/善/好/譱/醉/佳/
よg /善/
よe /酔/醉/
よb /呼/喚/
よa /良/
ゆわk /湯沸/
ゆれうごi /揺れ動/
ゆるy /緩/
ゆるs /許/赦/
ゆるn /緩/
ゆるm /緩/弛/
ゆるk /緩/
ゆるi /緩/
ゆるg /揺/
ゆゆs /由々/由由/忌々/
ゆみけずr /弓削/
ゆびづかi /指使/
ゆびさs /指差/
ゆどおs /湯通/
ゆづr /讓/
ゆだn /委/
ゆたk /豊/豐/
ゆずりわたs /譲り渡/
ゆずりうk /譲り受/
ゆずt /譲/讓/
ゆずr /譲/讓/
ゆすぶr /揺振/
ゆすt /揺/
ゆさぶr /揺振/
ゆきわたt /行き渡/
ゆきわたr /行き渡/
ゆきまつr /雪祭/
ゆきなやn /行き悩/
ゆきなやm /行き悩/
ゆきどm /行き止/
ゆきどk /雪解/
ゆきとどk /行き届/
ゆきとどi /行き届/
ゆきづm /行き詰/
ゆきつk /行き付/
ゆきつi /行き付/
ゆきちがi /行き違/
ゆきだおr /行き倒/
ゆきすg /行き過/
ゆききd /行き来/
ゆきがk /行き掛/
ゆきかよu /行き通/
ゆきかよt /行き通/
ゆきかえr /行き帰/
ゆきかu /行き交/
ゆきかt /行き交/
ゆきおr /雪下/
ゆきあu /行き合/
ゆきあt /行き合/行き当/
ゆきあk /雪明/
ゆがn /歪/
ゆがm /歪/
ゆえn /故/
ゆうりn /有利/
ゆうめいすg /有名過/
ゆうびんきょくてつづk /郵便局手続/
ゆうそういたs /郵送致/
ゆうしょうあらそi /優勝争/
ゆうしゅうn /優秀/
ゆうぐr /夕暮/
ゆうきづk /勇気付/
ゆうs /有/
ゆいしょただs /由緒正/
ゆw /結/
ゆu /結/
ゆt /結/
ゆs /揺/搖/
ゆr /揺/搖/
ゆk /行/往/征/徃/逝/
ゆh /結/
ゆe /結/
ゆd /茹/
やんごとなs /止事無/
やわらかk /柔/
やわr /柔/和/軟/
やわi /柔/
やりこm /遣り込/
やむごとなs /止事無/
やみとりひk /闇取り引/
やみあがr /病み上/
やまもr /山盛/
やままw /山回/
やまのぼr /山登/
やまづm /山積/
やまそだt /山育/
やまごe /山越/
やまくずs /山崩/
やまあるk /山歩/
やまs /疾/疚/
やぶれr /殕/
やぶさk /吝/
やぶt /破/
やぶr /破/敗/
やぶi /破/
やはr /柔/軟/和/矢張/
やはi /柔/
やにさg /脂下/
やどさがs /宿探/
やどt /宿/
やどs /宿/
やどr /宿/
やとw /雇/
やとu /雇/傭/
やとt /雇/
やとi /雇/
やとh /雇/傭/
やとe /雇/
やつs /窶/
やつr /窶/
やっt /八/
やすものがi /安物買/
やすみあk /休み明/
やすすg /安過/
やすくにどおr /靖国通/
やすうけあi /安請け合/
やすうr /安売/
やすあがr /安上/
やすあg /安上/
やすs /易/安/
やすr /安/
やすn /休/
やすm /休/安/
やすk /安/易/
やすi /安/易/廉/
やじr /野次/
やしなw /養/
やしなu /養/豢/
やしなt /養/
やしなi /養/
やしなh /養/
やしなe /養/
やさしi /優し/
やさs /優/易/
やけこg /焼け焦/
やくわr /役割/
やくよk /厄除/
やくまわr /役回/
やくひんくさi /薬品臭/
やくばらi /厄払/
やくはらi /厄祓/
やくはらh /厄祓/
やくにたt /役に立/
やくづk /役付/
やくだt /役立/
やくだc /役立/
やくたt /役立/
やくそくどおr /約束通/
やくs /訳/譯/
やくn /役/
やきはらu /焼き払/
やきなまs /焼き鈍/
やきなおs /焼き直/
やきつk /焼き付/
やかまs /喧/
やうやu /漸/
やうやk /漸/
やt /演/八/
やs /痩/
やr /演/遣/殺/
やn /止/病/
やm /止/辞/病/辭/罷/已/熄/
やk /焼/妬/灼/燒/
やi /焼/妬/燒/
もんなs /文無/
もろk /脆/
もろi /脆/
もれだs /漏れ出/
もりつk /盛り付/
もりさg /盛り下/
もりこn /盛り込/
もりこm /盛り込/
もりあがr /盛り上/
もりあg /盛り上/盛上/
もらw /貰/
もらu /貰/
もらt /貰/
もらo /貰/
もらi /貰/
もらe /貰/
もよおs /催/
もようがe /模様替/
もよr /最寄/
もやu /舫/
ものわすr /物忘/
ものものs /物々/
ものもt /物持/
ものもc /物持/
ものたr /物足/
ものずk /物好/
ものすごk /物凄/
ものすごi /物凄/
ものしr /物知/
ものぐさi /懶/
ものがたt /物語/
ものがたr /物語/
ものかk /物書/
ものかi /物書/
ものおもi /物思/
ものおぼe /物覚/
ものおz /物怖/
ものおj /物怖/
ものうk /物憂/
ものうi /物憂/
ものうg /物憂/
ものいw /物言/
ものいr /物入/
ものいi /物言/
もぬk /蛻/
もどt /戻/
もどs /戻/
もどr /戻/
もとづk /基/
もとづi /基/
もとz /基/
もとr /戻/悖/
もとn /基/元/
もとm /求/
もとd /基/下/
もてあまs /持て余/
もてあそn /弄/
もてあそb /弄/玩/
もつr /縺/
もっぱr /専/專/
もっとm /最/尤/
もってかえr /持って帰/
もっt /以/
もぢr /捩/
もちはこb /持ち運/
もちなおs /持ち直/
もちつづk /持ち続/
もちだs /持ち出/
もちさr /持ち去/
もちこたe /持ち堪/
もちこs /持ち越/
もちこn /持ち込/持込/
もちこm /持ち込/持込/
もちぐさr /持ち腐/
もちかえt /持ち帰/
もちかえr /持ち帰/
もちかk /持ち掛/
もちいt /用い/
もちあるk /持ち歩/
もちあg /持ち上/
もちw /用/
もちi /用/
もだe /悶/
もたらs /齎/
もたr /凭/靠/
もたg /擡/
もじみとm /文字認/
もじまちがi /文字間違/
もじばk /文字化/
もじどおr /文字通/
もじおt /文字落/
もじおc /文字落/
もじr /捩/
もぐりこn /潜り込/
もぐりこm /潜り込/
もぐt /潜/
もぐr /潜/潛/濳/
もくろn /目論/
もくろm /目論/
もくs /黙/目/
もがk /藻掻/
もえあg /燃え上/
もうしわk /申し分/
もうしひらk /申し開/
もうしでt /申し出/
もうしでr /申し出/
もうしつk /申し付/
もうしたt /申し立/
もうしそe /申し添/
もうしこn /申し込/
もうしこm /申し込/
もうしおくr /申し遅/
もうしいr /申し入/
もうしあw /申し合/
もうしあg /申し上/
もうs /申/
もうk /設/儲/
もうd /詣/
もy /燃/
もt /持/盛/以/保/
もs /若/模/燃/
もr /盛/漏/洩/守/
もn /揉/
もm /揉/
もe /燃/萌/
もc /持/
めんばs /面罵/
めんどくさk /面倒臭/
めんどくさi /面倒臭/
めんどうくさi /面倒臭/
めんどうくさg /面倒臭/
めんくらu /面喰/
めんくらt /面喰/
めんくr /面喰/
めんきょとr /免許取/
めんz /免/
めんs /面/
めんj /免/
めりこm /減り込/
めもr /メモ/
めべr /目減/
めばe /芽生/
めどおs /目通/
めとr /娶/
めでたi /目出度/
めでt /目出/
めづらs /珍/珎/
めつk /目付/眼付/
めだt /目立/
めだc /目立/
めずらs /珍/珎/
めじろどおr /目白通/
めざわr /目障/
めざまs /目覚/
めざとi /目敏/
めざs /目指/目刺/
めざm /目覚/目醒/
めぐろどおr /目黒通/
めぐりめぐt /巡り巡/
めぐt /巡/
めぐr /巡/廻/繚/回/繞/
めぐn /恵/惠/
めぐm /恵/惠/
めくらまs /目眩/
めくらm /目眩/
めくばs /目配/
めくばr /目配/
めくr /捲/
めかくs /目隠/
めおs /目押/
めうつr /目移/
めいわくかk /迷惑掛/
めいじどおr /明治通/
めいうt /銘打/
めいz /命/銘/
めいt /滅入/
めいs /冥/
めいr /滅入/
めいj /命/銘/
めあわs /娶/
めあたらs /目新/
めあw /妻合/
めあt /目当/
めあk /目明/
めs /召/
めr /減/
めn /目/
めd /愛/目/賞/
むりn /無理/
むらg /群/叢/簇/
むねやk /胸焼/
むにきs /無に帰/
むなさわg /胸騒/
むなs /空/虚/
むづかs /難/
むづかr /憤/
むつかs /難/
むつm /睦/
むっt /六/
むちうt /鞭打/鞭/
むだづかi /無駄遣/無駄使/
むだn /無駄/
むだd /無駄/
むせかえr /蒸返/噎返/
むせb /咽/噎/
むずかs /難/
むずかr /憤/
むすびつk /結び付/
むすn /結/
むすb /結/掬/
むしばm /蝕/蠹/蠧/
むしとr /虫取/
むしくi /虫食/
むしあつs /蒸し暑/
むしあつi /蒸し暑/
むしs /無視/
むしr /寧/毟/
むさぼr /貪/
むごi /酷/惨/
むこu /向/
むくw /報/
むくu /報/
むくi /報/酬/
むかしなつk /昔懐/
むかしきk /昔聞/
むかしきi /昔聞/
むかえいr /迎え入/
むかu /対/向/
むかt /向/
むかi /向/
むかh /迎/対/邀/
むかe /迎/邀/
むt /六/
むs /蒸/咽/噎/
むr /群/蒸/
むk /向/剥/
むi /向/剥/
みわたs /見渡/
みわすr /見忘/
みわk /見分/
みょうn /妙/
みやぶr /見破/
みやびy /雅/
みやすk /見易/
みやすi /見易/
みむk /見向/
みみなr /耳馴/
みみざわr /耳障/
みまわs /見回/
みまわr /見回/
みまもt /見守/
みまもr /見守/
みまちがu /見間違/
みまちがi /見間違/
みまちがe /見間違/
みまかr /身罷/
みまいもうs /見舞申/
みまw /見舞/
みまu /見舞/
みまi /見舞/
みまh /見舞/
みぶるi /身震/
みぶr /身振/見振/
みひらk /見開/
みひらi /見開/
みばe /見栄/見映/
みはらs /見晴/
みはらi /未払/
みはなs /見放/
みはっt /見張/
みはじm /見始/
みはからi /見計/
みはかr /見計/
みはt /見張/
みはr /見張/見晴/瞠/
みのがs /見逃/
みのt /実/
みのr /実/稔/
みのg /見逃/
みねうt /峰打/
みぬk /見抜/
みぬi /見抜/
みにつk /身に付/
みにつi /身に付/
みにくk /醜/見難/
みにくi /醜/儖/見難/
みにいk /見に行/
みならw /見習/
みならu /見習/
みならt /見習/
みならi /見習/
みなすk /皆好/
みなぎr /漲/
みなおなz /皆同/
みなおなj /皆同/
みなおs /見直/
みなs /皆/看倣/見倣/見做/
みなr /見慣/見馴/
みとどk /見届/
みとがm /見咎/
みとおs /見通/
みとうs /見透/見通/
みとr /見惚/見蕩/
みとm /認/
みてとr /見て取/
みづらk /見辛/
みづらi /見辛/
みづくろi /身繕/
みづかr /自/
みつもt /見積/
みつもr /見積/
みつづk /見続/密漬/
みつけだs /見つけ出/見付け出/
みつくろu /見繕/
みつくろt /見繕/
みつくろh /見繕/
みつかr /見付か/
みつn /密/
みつm /見積/凝視/瞶/
みつk /見付/
みつi /貢/
みつg /貢/
みっt /三/
みぢかn /身近/
みちゆk /道行/
みちむk /道向/
みちびきだs /導き出/
みちびk /導/
みちびi /導/
みちがu /見違/
みだs /見出/乱/亂/
みだr /乱/淫/亂/妄/
みたt /見立/
みたs /満/充/
みそづk /味噌漬/
みそこn /見損/
みそいたm /味噌炒/
みそm /見初/
みせびらk /店開/
みせがまe /店構/
みずらi /見難/
みずみずs /瑞々/
みずまわr /水回/
みずまs /水増/
みずびたs /水浸/
みずだs /水出/
みずたまr /水溜/
みずくさi /水臭/
みずかr /自/
みずあらi /水洗/
みずあかとr /水垢取/
みずあb /水浴/
みすかs /見透/
みすt /見捨/
みすg /見過/
みすe /見据/視据/
みじかすg /短過/
みじかs /短/
みじかn /短/身近/
みじかm /短/
みじかk /短/
みじかi /短/身近/
みじm /慘/惨/
みじk /短/
みしr /見知/
みさだm /見定/
みごろs /見殺/
みごとかえr /見事返/
みこs /見越/
みこn /見込/
みこm /見込/
みぐるs /見苦/
みくらb /見比/
みくだs /見下/
みぎまわr /右回/
みぎどなr /右隣/
みぎぞろe /右揃/
みぎそろe /右揃/
みきわm /見極/
みきt /見切/
みきr /見切/
みきk /見聞/
みがわr /身代/
みがまe /身構/
みがk /磨/
みがi /磨/
みかぎt /見限/
みかぎr /見限/
みかえs /見返/
みかえr /見返/
みかk /見掛/
みおわr /見終/
みおぼe /見覚/
みおとs /見落/
みおとr /見劣/
みおくt /見送/
みおくr /見送/
みおw /見終/
みおt /見落/
みおr /見下/
みうしなu /見失/
みうしなt /見失/
みうしなi /見失/
みうごk /身動/見動/
みうr /身売/
みうk /見受/
みいだs /見出/
みいt /見入/
みいr /見入/魅入/
みあw /見合/
みあu /見合/
みあt /見当/見合/
みあk /見飽/
みあi /見合/
みあg /見上/
みz /見/
みy /見/観/
みw /見/身/
みu /見/
みt /見/満/観/三/診/充/視/滿/觀/看/盈/
みs /見/魅/観/視/
みr /見/観/診/視/觀/看/
みn /見/身/観/視/看/
みm /見/観/視/
みk /見/
みi /見/
みh /見/
みe /見/観/視/
みd /見/
みc /満/滿/見/
みa /見/
まんがずk /漫画好/
まんがかk /漫画描/
まゐr /參/
まわりこn /回り込/
まわりこm /回り込/
まわt /回/廻/囘/周/
まわs /回/周/廻/囘/
まわr /周/回/廻/巡/囘/
まるやk /丸焼/
まるめこn /丸め込/
まるめこm /丸め込/
まるみe /丸見/
まるなg /丸投/
まるだs /丸出/
まるm /丸/
まるk /丸/
まるi /丸/円/圓/槫/
まよいこn /迷い込/
まよいこm /迷い込/
まよw /迷/
まよu /迷/
まよt /迷/
まよk /魔除/
まよi /迷/
まよh /迷/
まよe /迷/
まやかs /瞞/
まもなk /間も無/
まもなi /間も無/
まもt /守/護/
まもr /守/護/防/
まみr /塗/
まみe /見/
まほうつかi /魔法使/
まぶs /眩/塗/
まびk /間引/
まばゆi /目映/眩/
まばたk /瞬/
まばr /疎/
まはs /回/廻/
まのあt /目の当/
まのb /間延/
まねt /真似/
まねr /真似/
まねk /招/
まねi /招/
まぬがr /免/
まぬかr /免/
まぬk /間抜/
まにあw /間に合/
まにあu /間に合/
まにあt /間に合/
まにあi /間に合/
まにあe /間に合/
まなざs /目差/
まなn /学/學/斈/
まなb /学/學/斈/
まどろm /微睡/
まどがk /窓掛/
まどかk /窓掛/
まどw /惑/
まどu /惑/悗/
まどi /惑/
まどh /惑/
まとはずr /的外/
まとw /纏/
まとu /纏/繚/
まとt /纏/
まとm /纏/纒/
まとh /纏/
まづi /不味/
まつまえづk /松前漬/
まつw /纏/
まつr /祭/奉/祀/
まつh /纏/
まっぷたt /真っ二/
まっとu /全/
まったk /全/
まっすg /真っ直/
まちはずr /街外/
まちのr /街乗/
まちどおs /待ち遠/
まちづくr /町作/
まちっがt /間違/
まちこg /待ち焦/
まちがw /間違/
まちがu /間違/
まちがt /間違/
まちがi /間違/
まちがe /間違/
まちかまe /待ち構/
まちかt /間違/
まちあわs /待ち合わ/待合/
まちあw /待合/待ち合/
まちあk /待ち明/
またたk /瞬/
またたi /瞬/
またぎk /又聞/
またi /跨/
またh /又/
またg /跨/
まぜがk /交ぜ書/
まずs /貧/
まずi /不味/マズ/
まじろg /瞬/
まじめすg /真面目過/
まじなi /呪/
まじきr /間仕切/
まじw /交/
まじt /混/
まじk /間近/
まじh /交/雑/
まじe /交/雑/
まざりあu /混ざり合/
まざりあt /混ざり合/
まさt /勝/優/
まさs /正/
まさr /勝/優/
まさn /正/
まことn /誠/
まけつづk /負け続/
まくr /捲/
まぎれこn /紛れ込/
まぎれこm /紛れ込/
まぎr /紛/
まきもどs /巻戻/巻き戻/
まきつk /巻き付/
まきこn /巻き込/
まきこm /巻き込/
まきかえs /巻き返/
まきおこs /巻き起/
まきあg /巻き上/
まがまがs /禍禍/兇々/禍々/
まがu /紛/擬/
まがt /曲/
まがr /曲/間借/彎/弯/枉/
まがi /擬/紛/
まがh /紛/
まかなw /賄/
まかなu /賄/
まかなh /賄/
まかなe /賄/
まかs /任/委/
まかr /罷/
まえむk /前向/
まえふr /前振/
まえづk /前付/
まえがk /前書/
まえおk /前置/
まえうr /前売/
まえいわi /前祝/
まうs /申/
まうk /設/儲/
まうd /詣/
まいこn /舞い込/
まいこm /舞い込/
まいあg /舞上/
まいt /参/參/
まいr /参/詣/參/
まあたらs /真新/目新/
まあi /間合/
まz /混/先/交/雑/
まw /舞/
まu /舞/
まt /待/舞/俟/
まs /増/摩/益/坐/在/
まn /間/倣/
まk /負/巻/蒔/撒/敗/卷/捲/撤/播/
まj /交/混/雑/
まi /舞/蒔/巻/散/撒/
まh /舞/
まg /曲/
まd /未/
まc /待/
ぼんおどr /盆踊/
ぼんあk /盆明/
ぼっs /没/
ぼうそうs /暴走/
ぼうえいs /防衛/
ぼk /呆/惚/暈/
ほんみょうおなz /本名同/
ほんみょうおなj /本名同/
ほんどおr /本通/
ほんとb /本飛/
ほんづかi /本使/
ほんすべr /本滑/
ほんw /本/
ほろよi /微酔/
ほろn /滅/
ほろb /滅/亡/
ほれこn /惚れ込/
ほれこm /惚れ込/
ほりぬk /掘り抜/
ほりだs /掘り出/
ほりさg /掘り下/
ほりかえs /掘り返/
ほめそやs /褒称/誉称/
ほまれおおk /誉大/
ほまr /誉/譽/
ほほばr /頬張/
ほほえn /微笑/
ほほえm /微笑/頬笑/
ほふr /屠/
ほのぐらi /仄暗/
ほのm /仄/
ほのk /仄/
ほねやすm /骨休/
ほねぐm /骨組/
ほねおr /骨折/
ほどよk /程良/
ほどよi /程良/
ほどとおk /程遠/
ほどとおi /程遠/
ほどこs /施/
ほどk /解/
ほとんd /殆/
ほとばしt /迸/
ほとばしr /迸/
ほとn /殆/
ほてt /火照/
ほてr /火照/
ほっs /欲/
ほだs /絆/
ほそながk /細長/
ほそながi /細長/
ほそぎr /細切/
ほそs /細/
ほそr /細/
ほそm /細/
ほそk /細/
ほそi /細/
ほじr /穿/
ほしふr /星降/
ほしi /欲し/欲/
ほころb /綻/
ほこt /誇/
ほこr /誇/
ほぐr /解/
ほがr /朗/朖/
ほかn /他/
ほおばr /頬張/
ほおt /放/
ほおr /放/
ほうりだs /放り出/
ほうりこn /放り込/
ほうりこm /放り込/
ほうむr /葬/
ほうふn /豊富/
ほうっt /放/
ほうこくいたs /報告致/
ほうz /焙/報/
ほうw /方/
ほうt /放/
ほうs /焙/
ほうr /放/抛/
ほうk /呆/
ほうj /報/焙/
ほうh /方/
ほうg /方/
ほt /掘/放/彫/
ほs /欲/乾/干/
ほr /掘/惚/彫/恍/愡/耄/
ほm /誉/褒/賞/襃/譽/
ほe /吠/咆/哮/
べんz /弁/
べんj /弁/
べつずr /別刷/
べつあつかi /別扱/
べつn /別/
べいこくぎらi /米国嫌/
べs /可/
べk /可/
へんにゅうs /編入/
へんそうくだs /返送下/
へんじくだs /返事下/
へんこういたs /変更致/
へんこうs /変更/
へんかんふくm /返還含/
へんかんg /変換/
へんかs /変化/
へんn /変/變/
へんd /変/
へりくだr /謙/遜/
へらs /減ら/
へつらu /諛/諂/
へつらh /諛/諂/
へだt /隔/
へたn /下手/
へこm /凹/
へいわn /平和/
へz /経/經/
へt /減/経/經/
へr /減/経/經/歴/
へn /経/經/
へm /経/
ぶんせつくぎr /文節区切/
ぶんかつs /分割/
ぶひんとr /部品取/
ぶどまr /歩留/
ぶじうごk /無事動/
ぶじうごi /無事動/
ぶかk /深/
ぶかi /深/
ぶあつk /ぶ厚/
ぶあつi /分厚/部厚/
ぶt /撃/打/撲/
ぶr /振/
ふんばt /踏ん張/
ふんばr /踏ん張/
ふんちがi /分遅/
ふんいきつたw /雰囲気伝/
ふんいきつたe /雰囲気伝/
ふんいきだs /雰囲気出/
ふんs /扮/
ふわたr /不渡/
ふろあg /風呂上/
ふれこn /触れ込/
ふれこm /触れ込/
ふるまu /振舞/振る舞/
ふるまt /振る舞/
ふるまi /振舞/振る舞/
ふるまh /振舞/
ふるまe /振舞/
ふるすg /古過/
ふるさとh /故郷/
ふるくさi /古臭/
ふるw /震/
ふるu /奮/揮/振/震/篩/
ふるt /奮/
ふるs /古/
ふるm /古/
ふるk /古/
ふるi /古/旧/震/舊/故/奮/振/
ふるh /揮/振/震/奮/篩/
ふるe /震/顫/
ふるb /古/
ふりわk /振り分/
ふりむk /振り向/
ふりむi /振り向/
ふりまわs /振り回/
ふりはらu /振り払/
ふりつk /振り付/
ふりだs /振り出/降り出/
ふりたs /振り足/
ふりこn /振り込/降り込/
ふりこm /振り込/振込/降り込/
ふりかえt /振り返/振返/
ふりかえr /振り返/
ふりかk /振り掛/
ふりかe /振り替/
ふゆやすm /冬休/
ふやs /殖や/増や/
ふむk /不向/
ふみたおs /踏み倒/
ふみこn /踏み込/
ふみこm /踏み込/
ふみきt /踏み切/
ふみきr /踏み切/
ふみいr /踏み入/
ふなr /不慣/
ふとどk /不届/
ふとt /太/
ふとs /太/
ふとr /太/
ふとm /太/
ふとk /太/
ふとi /太/
ふてくさr /ふて腐/
ふつかよi /二日酔/
ふつうn /普通/
ふっとn /吹っ飛/
ふっとb /吹っ飛/
ふちどr /縁取/
ふだんつかu /普段使/
ふだんつかt /普段使/
ふだんつかo /普段使/
ふだんつかi /普段使/
ふだんつかe /普段使/
ふたとおr /二通/
ふたたb /再/
ふたしk /不確/
ふたt /二/弍/
ふぞろi /不揃/
ふせi /防/
ふせg /防/拒/
ふしまわs /節回/
ふしぜんn /不自然/
ふしぎn /不思議/
ふざけr /巫山戯/
ふさわs /相応/
ふさi /塞/
ふさg /塞/鬱/
ふけt /耽/
ふけr /耽/
ふくざつすg /複雑過/
ふくs /服/復/覆/
ふくr /膨/脹/
ふくn /含/
ふくm /含/
ふきぬk /吹き抜/
ふきながs /吹き流/
ふきとおs /吹き通/
ふきとn /吹き飛/
ふきとb /吹き飛/
ふきつづk /吹き続/
ふきつk /吹き付/
ふきだs /噴き出/吹き出/
ふきこn /吹き込/
ふきこm /吹き込/
ふきかe /吹替/
ふきあg /吹き上/
ふがひなi /腑甲斐無/
ふがいなi /腑甲斐無/
ふかよm /深読/
ふかすg /深過/
ふかおi /深追/
ふかいr /深入/
ふかs /深/更/蒸/
ふかm /深/
ふかk /深/
ふかi /深/潭/
ふえふk /笛吹/
ふうじこm /封じ込/
ふうしゃがたm /風車固/
ふうぎt /封切/
ふうがわr /風変/
ふうz /封/
ふうs /諷/
ふうj /封/
ふあんていd /不安定/
ふy /増/殖/
ふt /振/降/
ふs /伏/付/臥/附/匐/
ふr /振/降/触/経/經/觝/觸/
ふn /踏/蹈/履/
ふm /踏/践/履/蹈/
ふk /吹/更/老/拭/深/葺/噴/
ふi /吹/拭/
ふe /増/殖/
びんじょうねあg /便乗値上/
びろi /広/
びょううt /鋲打/
びょううc /鋲打/
びみょうn /微妙/
びk /引/
ひんs /瀕/
ひろせどおr /広瀬通/
ひろすg /広過/
ひろいだs /拾い出/
ひろいあつm /拾い集/
ひろいあg /拾い上/
ひろw /拾/
ひろu /拾/広/
ひろt /拾/
ひろs /広/廣/
ひろo /拾/
ひろm /広/廣/
ひろk /広/廣/
ひろi /広/拾/弘/廣/
ひろg /広/拡/廣/擴/展/
ひろe /拾/
ひるやすm /昼休/
ひるすg /昼過/
ひるさg /昼下/
ひるがえt /翻/
ひるがえs /飜/翻/
ひるがえr /飜/翻/
ひるm /怯/
ひらめk /閃/
ひらづm /平積/
ひらきなおt /開き直/
ひらきなおr /開き直/
ひらあやまr /平謝/
ひらt /平/
ひらk /開/拓/
ひらi /開/
ひょうへんs /豹変/
ひょうばんわるk /評判悪/
ひょうばんわるi /評判悪/
ひょうばんよk /評判良/
ひょうばんよi /評判良/
ひょうばんどおr /評判通/
ひょうじょうゆたk /表情豊/
ひょうじs /表示/
ひょうしぬk /拍子抜/
ひょうぐm /表組/
ひょうs /表/評/
ひやかs /素見/
ひやs /冷/
ひやk /日焼/冷/
ひゃっぽゆずr /百歩譲/
ひもとk /紐解/繙/
ひまつぶs /暇潰/
ひまs /日増/
ひびわr /罅割/
ひびk /響/
ひびi /響/
ひねt /捻/
ひねr /捻/撚/拈/捫/陳/
ひにくr /皮肉/
ひなb /鄙/
ひどr /日取/
ひどk /非道/酷/
ひどi /酷/非道/
ひとりじm /一人占/
ひとりぐr /一人暮/
ひとりあるk /一人歩/
ひとよs /人寄/
ひとやすm /一休/
ひとみしr /人見知/
ひとふでがk /一筆書/
ひとにぎr /一握/
ひとなm /人並/
ひとどおr /人通/
ひととおr /一通/
ひととうr /一通/
ひとづきあi /人付き合/
ひとつづk /一続/
ひとちがi /人違/
ひとたたk /一叩/
ひとそろe /一揃/
ひとしr /人知/
ひとさわg /一騒/人騒/
ひとさがs /人捜/人探/
ひとごろs /人殺/
ひとごm /人込/人混/
ひとこいs /人恋/
ひとくぎr /一区切/
ひとくi /人喰/
ひとかかe /一抱/
ひとかi /人買/
ひとt /一/１/壱/弌/壹/1/
ひとs /等/均/斉/
ひとr /独/獨/孤/
ひとm /一/
ひでr /日照/
ひづk /日付/
ひつようn /必要/
ひっぱりだs /引っぱり出/
ひっぱりこn /引っ張り込/
ひっぱりこm /引っ張り込/
ひっぱt /引っ張/
ひっぱr /引っ張/引張/
ひったくr /引っ手繰/
ひっこぬi /引っこ抜/
ひっこしづかr /引越疲/
ひっこs /引越/引っ越/
ひっこn /引っ込/
ひっこm /引込/引っ込/
ひっかかt /引掛/
ひっかかr /引掛/
ひっかk /引っ掛/引っ掻/
ひだりまわr /左回/
ひだりきk /左利/左効/
ひたはしr /直走/
ひたかくs /直隠/
ひたt /浸/
ひたs /浸/漬/
ひたr /浸/
ひそy /秘/
ひそn /潜/潛/濳/
ひそm /潜/潛/濳/顰/
ひそk /秘/密/祕/
ひずn /歪/
ひずm /歪/
ひじょうn /非常/
ひしゃg /拉/
ひしめk /犇/
ひしm /犇/
ひしg /柆/
ひざまづk /跪/
ひざまづi /跪/
ひざまずk /跪/
ひざs /日射/日差/
ひさしぶr /久し振/
ひさs /久/尚/
ひさg /販/鬻/拉/
ひぐr /日暮/
ひくすg /低過/
ひくs /低/
ひくm /低/
ひくk /低/
ひくi /低/
ひきわたs /引き渡/
ひきわk /引き分/
ひきもどs /引き戻/
ひきまわs /引き回/
ひきはらt /引き払/
ひきぬk /引き抜/
ひきぬi /引き抜/
ひきとおs /引き通/
ひきとt /引き取/
ひきとr /引き取/引取/
ひきとm /引き止/
ひきつづk /引き続/引続/
ひきつづi /引き続/
ひきつr /引き攣/引き連/
ひきつk /引き付/
ひきつi /引き継/引継/
ひきつg /引き継/引継/
ひきだs /引出/引き出/
ひきたt /引き立/
ひきずりこn /引きずり込/
ひきずりこm /引きずり込/
ひきしめr /引き締め/
ひきしm /引締/
ひきさr /引き去/
ひきさk /引き裂/
ひきさg /引き下/
ひきこn /引き込/
ひきこm /引き込/
ひきかe /引き換/引き替/
ひきおとs /引き落/
ひきおk /引き起/惹き起/
ひきうk /引き受/
ひきあt /引き当/
ひきあg /引き上/
ひきw /率/
ひきi /率/
ひがえr /日帰/
ひがw /日替/日変/
ひがm /僻/
ひからb /乾涸/干涸/
ひかくてきあたらs /比較的新/
ひかt /光/
ひかr /光/
ひかe /控/
ひかc /光/
ひえこn /冷え込/
ひえこm /冷え込/
ひいd /秀/
ひあg /干上/乾上/
ひy /冷/
ひt /引/
ひs /比/秘/
ひr /干/
ひp /引/
ひm /秘/祕/
ひk /引/弾/挽/魅/曳/惹/彈/牽/索/退/碾/轢/
ひi /引/弾/挽/彈/索/
ひe /冷/
ぱt /張/
ぱr /張/
ばんごうづk /番号付/
ばんくるw /番狂/
ばらi /払/拂/
ばやi /早/
ばなr /離/
ばつぐんd /抜群/
ばっすいおわt /抜粋終/
ばっすいおわr /抜粋終/
ばちがi /場違/
ばたらk /働/
ばしt /走/
ばかよb /馬鹿呼/
ばかs /魅/
ばかr /許/
ばいちかk /倍近/
ばいちかi /倍近/
ばあいわk /場合分/
ばあt /場当/
ばs /馳/
ばr /化/
ばk /化/
ばi /這/
はんとしちかk /半年近/
はんとしちかi /半年近/
はんていがt /判定勝/
はんていがc /判定勝/
はんだづk /半田付/
はんそくまk /反則負/
はんぐm /版組/
はんえいs /反映/
はんs /反/
はれわたt /晴れ渡/
はれわたr /晴れ渡/
はるやすm /春休/
はるk /遥/遼/遙/
はりめぐr /張り巡/
はりつけr /貼り付け/
はりつk /貼り付/張り付/
はりつi /張り付/
はりだs /張り出/
はりこn /張り込/はり込/貼り込/
はりこm /張り込/はり込/貼り込/
はりかe /貼り替/
はりあわs /貼り合/
はりあw /貼り合/
はりあu /張り合/
はらへt /腹減/
はらへr /腹減/
はらばi /腹這/
はらだt /腹立/
はらたt /腹立/
はらぐろi /腹黒/
はらいもどs /払戻/
はらいだs /払出/
はらいさg /払い下/
はらいこn /払い込/
はらいこm /払込/払い込/
はらw /払/拂/
はらu /払/拂/祓/禳/掃/
はらt /払/拂/
はらo /払/拂/
はらm /孕/
はらi /払/拂/祓/
はらh /掃/払/拂/祓/
はらe /払/拂/
はよu /早/
はゆs /映/
はゆi /映/
はやすg /早過/速過/
はやがわr /早変/
はやがえr /早帰/
はやおくr /早送/
はやおk /早起/
はやt /流行/
はやs /速/早/囃/
はやr /流行/逸/早/
はやm /早/速/
はやk /早/速/疾/
はやi /早/速/疾/捷/
はめこm /嵌め込/
はみでr /はみ出/
はみだs /はみ出/
はみがk /歯磨/
はまべちかk /浜辺近/
はまべちかi /浜辺近/
はまちかk /浜近/
はまちかi /浜近/
はまt /嵌/
はまr /填/嵌/
はべr /侍/
はぶr /羽振/
はぶk /省/羽振/
はぶi /省/
はびこr /蔓延/
はばよs /幅寄/
はばひろk /幅広/
はばひろi /幅広/
はばかr /憚/
はばn /阻/
はばm /阻/難/
はねかえs /跳ね返/
はねかえr /跳ね返/
はねあg /跳ね上/
はなもt /鼻持/
はなびe /花冷/
はなばなs /華々/花々/華華/
はなはだs /甚/
はなはd /甚/堪/
はなつまm /鼻抓/
はなしだs /話出/
はなしこn /話し込/
はなしこm /話し込/
はなしがi /放し飼/
はなしあw /話し合/
はなしあu /話し合/
はなしあt /話し合/
はなしあo /話し合/
はなしあi /話し合/
はなしあe /話し合/
はなy /華/花/
はなt /放/
はなs /話/離/放/
はなr /離/放/
はどm /歯止/
はづs /外/
はづr /外/
はづm /勢/弾/彈/
はづk /辱/恥/
はつのr /初乗/
はつすべr /初滑/
はっぴょうもうs /発表申/
はっせいs /発生/
はっこうs /発行/
はっきs /発揮/
はっs /発/發/
はちあw /鉢合/
はだざむk /肌寒/
はだざむi /肌寒/
はださむi /肌寒/
はだk /開/
はたらk /働/
はたらi /働/
はたたk /羽撃/
はたs /果/
はたk /叩/
はせいs /派生/
はずかしm /辱/
はずかs /恥ずか/
はずs /外/
はずr /外/
はずn /弾/
はずm /弾/彈/勢/機/
はずk /辱/恥/
はすうきりあg /端数切上/
はじm /始/初/甫/創/
はじk /弾/
はじi /弾/
はしをr /端折/
はしわたs /橋渡/
はしりだs /走り出/
はしりこn /走り込/
はしりこm /走り込/
はしょr /端折/
はしぞm /箸初/
はしおr /端折/
はしt /走/赱/奔/
はしr /走/奔/赱/迸/
はざわr /歯触/
はさみこn /挟み込/
はさみこm /挟み込/
はさn /挟/夾/挾/
はさm /挟/夾/挾/
はごたe /歯応/
はこびこn /運び込/
はこびこm /運び込/
はこn /運/
はこb /運/
はげまs /励ま/
はげs /激/烈/劇/
はげn /励/勵/
はげm /励/勵/
はぐくm /育/毓/
はぐr /逸/
はくs /博/
はぎr /歯切/
はきだs /掃き出/吐き出/はき出/
はきだi /掃き出/
はがゆi /齒痒/
はがs /剥/
はがr /剥/
はかりしr /計り知/
はかりうr /量り売/
はかばかs /捗々/
はかなm /果無/
はかなi /儚/果敢無/果無/
はかどr /捗/
はかt /計/図/測/圖/
はかr /計/図/測/企/量/謀/圖/諮/
はおt /羽織/
はおr /羽織/
はいりこn /入り込/
はいりこm /入り込/
はいちがe /配置換/
はいしゃてつづk /廃車手続/
はいt /入/這入/
はいs /排/廃/拝/配/
はいr /入/這入/
はいn /入/
はあくd /把握/
はz /恥/耻/爆/羞/
はy /生/映/榮/
はw /歯/齒/這/
はu /這/匍/
はt /果/張/貼/這/
はs /発/馳/發/
はr /晴/張/貼/腫/膨/脹/
はn /跳/食/撥/
はm /食/嵌/
はk /吐/履/掃/帚/菷/刷/捌/穿/着/佩/帶/掃除/
はj /恥/羞/耻/
はi /吐/履/這/掃/
はg /剥/禿/
はe /生/映/暎/栄/榮/
はd /恥/耻/愧/慙/羞/
はb /羽/
のろけr /惚気/
のろw /呪/
のろu /呪/咒/詛/
のろt /呪/
のろi /呪/鈍/
のりづk /糊付/
のりつg /乗り継/
のりだs /乗り出/
のりこn /乗り込/
のりこm /乗り込/
のりこe /乗り越/
のりくn /乗り組/
のりきt /乗り切/
のりきr /乗り切/
のりかe /乗り換/乗換/
のりおくr /乗り遅/
のりいr /乗り入/
のみほs /飲み干/
のみすg /飲み過/
のみこn /飲み込/
のみこm /飲込/飲み込/
のみあk /飲む明/
のぼt /登/昇/上/
のぼs /逆上/上/
のぼr /登/昇/上/騰/
のびなやn /伸び悩/
のばなs /野放/
のばs /延/
ののしr /罵/
ののs /罵/
のっとt /乗っ取/則/
のっとr /乗っ取/則/
のちn /後/
のたまu /宣/曰/
のたまt /宣/曰/
のたまi /宣/曰/
のたまh /宣/曰/
のぞn /望/臨/
のぞm /望/臨/
のぞk /除/覗/覘/臨/
のぞi /除/覗/
のこt /残/殘/
のこs /残/遺/殘/
のこr /残/殘/遺/
のこn /残/
のこc /残/
のきなm /軒並/
のがs /逃/迯/
のがr /逃/迯/逸/遁/
のt /載/乗/乘/
のs /載/乗/乘/熨/伸/
のr /乗/載/乘/伸/
のn /飲/呑/飮/
のm /飲/呑/飮/嚥/
のk /乗/退/載/
のg /逃/迯/
のb /述/延/伸/陳/
ねんごr /懇/
ねんおs /念押/
ねんいr /念入/
ねんz /念/
ねんj /念/
ねりこm /練り込/
ねらw /狙/
ねらu /狙/
ねらt /狙/
ねらo /狙/
ねらi /狙/
ねらe /狙/
ねもこr /懇;「ねんごろ」の古い形/
ねむりこn /眠り込/
ねむりこm /眠り込/
ねむt /眠/
ねむs /眠/
ねむr /眠/睡/
ねむk /眠/
ねむi /眠/
ねまわs /根回/
ねぼk /寝惚/寝呆/
ねぶかk /根深/
ねぶかi /根深/
ねぶr /舐/
ねびk /値引/
ねびi /値引/
ねばりづよi /粘り強/
ねばt /粘/
ねばr /粘/
ねばk /粘/
ねづよk /根強/
ねづよi /根強/
ねづk /根付/
ねっちゅうs /熱中/
ねっしんd /熱心/
ねっs /熱/
ねちがe /寝違/
ねだr /強請/
ねたm /妬/
ねずみとr /鼠取/
ねすごs /寝過/
ねすg /寝過/
ねじふs /捻じ伏/
ねじr /捻/捩/
ねじk /拗/
ねざs /根差/
ねさg /値下/
ねころg /寝転/
ねころb /寝転/
ねこずk /猫好/
ねこn /寝込/
ねこm /寝込/
ねぐるs /寝苦/
ねくずr /値崩/
ねぎらu /犒/
ねぎらi /犒/
ねぎt /値切/
ねぎr /値切/
ねがえt /寝返/
ねがえr /寝返/
ねがいでt /願い出/
ねがいさg /願い下/
ねがw /願/
ねがu /願/
ねがt /願/
ねがi /願/
ねがh /願/
ねがe /願/
ねえs /姉/
ねうt /値打/
ねうc /値打/
ねいr /寝入/
ねあがr /値上/
ねあk /寝明/
ねあg /値上/
ねz /寝/寢/捻/捩/
ねy /寝/寢/
ねt /寝/練/寢/
ねs /寝/
ねr /寝/練/錬/寢/粘/煉/
ねn /寝/寢/
ねm /寝/寢/睨/
ねk /寝/根/
ねj /捻/捩/
ねc /寝/
ぬるm /微温/
ぬるi /微温/温/
ぬりつぶs /塗り潰/
ぬりこn /塗り込/
ぬりこm /塗り込/
ぬめr /滑/
ぬのうr /布売/
ぬすn /盗/盜/
ぬすm /盗/盜/
ぬけだs /抜け出/
ぬぐu /拭/
ぬぐt /拭/
ぬぐo /拭/
ぬぐi /拭/
ぬぐe /拭/
ぬくm /温/
ぬくi /温/
ぬきとおs /貫き通/
ぬきでt /抜き出/
ぬきだs /抜き出/
ぬきずr /抜き刷/
ぬきさs /抜き差/
ぬきうt /抜き打/抜き撃/
ぬきn /抽/擢/
ぬかr /泥濘/
ぬw /抜/
ぬu /縫/
ぬt /塗/縫/
ぬr /塗/濡/
ぬk /抜/脱/拔/貫/
ぬi /抜/脱/縫/拔/貫/
ぬg /脱/
にんめいs /任命/
にんきうすk /人気薄/
にんきうすi /人気薄/
にわk /俄/
にらn /睨/
にらm /眈/睨/
にゅうりょくまt /入力待/
にゅうりょくまc /入力待/
にゅうしゅつりょくh /入出力/
にほんじんずk /日本人好/
にほんじんごのm /日本人好/
にほんごまz /日本語混/
にほんごまj /日本語混/
にほんごふきかe /日本語吹替/
にほんごうt /日本語打/
にほんごうc /日本語打/
にぶt /鈍/
にぶs /鈍/
にぶr /鈍/
にぶk /鈍/
にぶi /鈍/
にはじm /煮始/
になw /担/
になu /担/擔/
になt /担/擔/
になi /担/擔/
になe /担/
にとおr /二通/
につm /煮詰/
にちしゅくやすm /日祝休/
にじr /躙/
にじn /滲/
にじm /滲/
にごt /濁/
にごs /濁/
にごr /濁/
にこy /柔/和/
にこn /煮込/
にこm /煮込/
にげまわt /逃げ回/
にげまわr /逃げ回/
にげまどu /逃げ惑/
にげまどt /逃げ惑/
にげだs /逃げ出/
にげさr /逃げ去/
にげこn /逃げ込/
にげこm /逃げ込/
にげきt /逃げ切/
にげきr /逃げ切/
にげかくr /逃げ隠/
にげかえt /逃げ帰/
にげかえr /逃げ帰/
にげおくr /逃げ遅/
にげおt /逃げ落/
にげうs /逃げ失/
にくにくs /憎々/
にくづk /肉付/
にくおどr /肉踊/
にくt /憎/
にくs /難/憎/
にくr /憎/
にくn /憎/
にくm /憎/
にくk /難/憎/
にくi /難/憎/
にぎわu /賑/
にぎはh /賑/
にぎy /賑/
にぎw /賑/
にぎt /握/
にぎr /握/
にがs /逃/苦/
にがm /苦/
にがk /苦/
にがi /苦/
にかよu /似通/
にかよt /似通/
におw /匂/臭/
におu /匂/臭/
におi /匂/臭/
におe /匂/
にえきr /煮え切/
にいt /兄/
にいs /兄/
にあw /似合/
にあu /似合/
にあt /似合/
にあi /似合/
にy /煮/
にt /似/煮/
にs /似/
にr /煮/似/
にn /似/
にk /煮/似/
にg /逃/迯/
にe /煮/
なんばんづk /南蛮漬/
なんなn /垂/
なんなk /難無/
なんとおr /何通/
なんt /何/
なんr /何/
なんk /何/
なんd /何/
なわばr /縄張/
なれなれs /馴々/
なりゆk /成り行/
なりふr /形振/
なりたt /成り立/成立/
なりかw /成り変/成り代/
ならべかe /並べ変/並べ替/並べ換/
ならびかe /並び換/
ならづk /奈良漬/
ならw /習/
ならu /習/倣/肄/
ならt /習/倣/
ならs /均/
ならo /習/
ならn /並/竝/列/
ならi /習/倣/
ならh /習/
ならe /習/
ならb /並/竝/列/
なやn /悩/惱/
なやm /悩/惱/
なめらk /滑/
なめs /鞣/
なめr /滑/
なみはずr /並み外/
なみのr /波乗/
なみうt /波打/
なまやさs /生易/
なまやk /生焼/
なまめかしk /艶かし/
なまめかしi /艶かし/
なまめk /艶/
なまめi /艶/
なまぬるi /生温/
なまにe /生煮/
なまなまs /生生/生々/
なまじろs /生白/
なまじろk /生白/
なまじろi /生白/
なまじi /憖/
なまじh /憖/
なまごろs /生殺/
なまぐさk /生臭/
なまぐさi /生臭/腥/
なまがわk /生乾/
なまえまk /名前負/
なまえつk /名前付/
なまあたたk /生暖/
なまt /訛/
なまr /鈍/訛/譌/
なまm /生/
なまk /怠/懶/
なほs /治/直/
なぶr /嬲/嫐/
なびk /靡/
なはs /話/
なのt /名乗/名宣/
なのr /名乗/名告/名宣/
なにひとt /何一/
なにげなi /何気無/
なにげn /何気/
なにかんがe /何考/
なにw /何/
なにm /何/
なにk /何/
なにg /何/
ななt /七/
ななm /斜/
なづけt /名付け/
なづm /泥/
なづk /名付/
なつやすm /夏休/
なつむk /夏向/
なつまつr /夏祭/
なつかs /懐/懷/
なつk /懐/懷/
なっとくいただk /納得頂/
なっとくいただi /納得頂/
なっとくいk /納得行/
なっとくs /納得/
なだかk /名高/
なだかi /名高/
なだt /名立/
なだr /傾/雪崩/
なだm /宥/
なぞらu /擬/准/凖/
なぞらh /擬/准/凖/
なぞらe /擬/准/準/
なぞとk /謎解/
なずらu /擬/准/凖/
なずらh /擬/准/凖/
なずm /泥/
なすr /擦/
なじr /詰/
なじn /馴染/
なじm /馴染/
なしとg /成し遂/
なざs /名指/
なさけなs /情無/
なさけなi /情無/情け無/
なさk /情/
なごy /和/
なごr /名残/
なごn /和/
なごm /和/
なげやr /投げ遣/
なげつk /投げ付/
なげだs /投げ出/
なげこn /投げ込/
なげこm /投げ込/
なげうt /抛/擲/
なげいr /投げ入/
なげあg /投げ上/
なげk /嘆/歎/慨/
なげi /嘆/慨/
なぐりこn /殴り込/
なぐりこm /殴り込/
なぐさm /慰/
なぐt /殴/毆/撲/
なぐr /殴/毆/擲/撲/
なきねいr /泣き寝入/
なきだs /泣き出/
なきあk /泣き明/
ながれだs /流れ出/
ながれこn /流れ込/
ながれこm /流れ込/
ながれあるk /流れ歩/
ながらh /存/
ながもt /長持/
ながもc /長持/
ながびk /長引/
ながびi /長引/
ながつづk /長続/
ながすぎr /長過/
ながすg /長過/
ながしこn /流し込/
ながしこm /流し込/
ながいこうえんどおr /長居公園通/
ながいk /長生/
ながt /長/
ながs /流/長/
ながr /流/長/乍/永/存/
ながm /眺/長/
ながk /長/永/
ながi /長/永/
ながb /長/
なかよs /仲良/
なかよk /仲良/
なかまはずr /仲間外/
なかまいr /仲間入/
なかぬk /中抜/
なかだt /仲立/
なかだc /仲立/
なかr /勿/
なかn /中/
なかb /半/
なおっt /直/
なおt /直/治/
なおs /直/治/癒/
なおr /直/治/
ないまz /綯い交/
なz /撫/
なu /綯/
なt /鳴/成/
なs /無/成/為/做/爲/生/
なr /慣/鳴/成/馴/生/爲/為/
なo /綯/
なm /並/嘗/竝/舐/
なk /泣/無/亡/鳴/失/成/哭/啾/啼/嚶/涕/
なi /無/泣/鳴/綯/凪/亡/啼/
なh /綯/
なg /投/薙/凪/
なe /萎/痿/
なd /撫/名/
どろくさs /泥臭/
どろくさk /泥臭/
どろくさi /泥臭/
どもr /吃/
どなりこn /怒鳴り込/
どなりこm /怒鳴り込/
どなt /怒鳴/
どなr /怒鳴/
どしゃぶr /土砂降/
どしゃくづr /土砂崩/
どくづk /毒突/
どくけs /毒消/
どおs /遠/
どおr /通/
どうせきs /同席/
どうじn /同時/
どうぐだt /道具立/
どうきづk /動機付/
どうあg /胴上/
どうz /動/
どうr /通/
どうj /動/
どあi /度合/
どr /取り/録/
どm /止/
とんがr /尖/
とろk /蕩/盪/
とりわすr /取り忘/
とりわk /取り分/
とりよs /取り寄/
とりやm /取り止/
とりもなおs /取りも直/
とりもどs /取り戻/
とりむすn /取り結/
とりむすb /取り結/
とりみだs /取り乱/
とりまわs /取り回/
とりまとm /取り纏/
とりまz /取り混/
とりまk /取り巻/
とりまi /取り巻/
とりひk /取引/取り引/
とりはらw /取り払/
とりはらu /取り払/
とりはらt /取り払/
とりはらo /取り払/
とりはらi /取り払/
とりはらe /取り払/
とりはずs /取り外/
とりはこn /取り運/
とりはこb /取り運/
とりはかr /取り計/
とりのぞk /取り除/取除/
とりのぞi /取り除/
とりのこs /取り残/
とりにg /取り逃/
とりなおs /取り直/録り直/
とりなs /取り成/執り成/
とりつくろu /取り繕/
とりつくろt /取り繕/
とりつくs /取り尽/
とりつk /取り付/取付/
とりつi /取り付/取り次/
とりつg /取り次/
とりちがe /取り違/
とりちr /取り散/
とりだs /取り出/取出/
とりたt /取り立/
とりそろe /取り揃/
とりそこn /取り損/
とりすm /取り澄/
とりしらb /取調/取り調/
とりしまr /取り締ま/
とりしきt /取り仕切/
とりしきr /取り仕切/
とりしm /取り締/取締/
とりさt /取り去/
とりさr /取り去/
とりさg /取り下/
とりこわs /取り壊/
とりこs /取り越/
とりこn /取り込/
とりこm /取り込/
とりけs /取り消/取消/
とりくずs /取り崩/
とりくn /取り組/
とりくm /取り組/取組/
とりきm /取り決/
とりかわs /取り交/取交/
とりかたm /取り固/
とりかこn /取り囲/
とりかこm /取り囲/
とりかえs /取り返/
とりかw /取り交/取交/
とりかk /取り掛/
とりかe /取り換/取り替/
とりおさe /取り抑/
とりおこなw /執り行/
とりおこなu /執り行/
とりおこなt /執り行/
とりおこなo /執り行/
とりおこなi /執り行/
とりおこなe /執り行/
とりおk /取り置/
とりおi /取り置/
とりうr /取り得/
とりいそi /取り急/
とりいそg /取り急/
とりいr /取り入/取入/
とりあらそu /取り争/
とりあらそt /取り争/
とりあつかw /取り扱/
とりあつかu /取り扱/取扱/
とりあつかt /取り扱/
とりあつかo /取り扱/
とりあつかi /取り扱/取扱/
とりあつかe /取り扱/
とりあつm /取り集/
とりあw /取り合/
とりあu /取り合/
とりあt /取り合/
とりあo /取り合/
とりあi /取り合/
とりあg /取り上/
とりあe /取り敢/取り合/
とらw /捕/囚/
とらh /囚/捉/捕/
とらe /捉/捕/把/
ともばたらk /共働/
ともなw /伴/
ともなu /伴/
ともなt /伴/
ともなi /伴/
ともなh /伴/
ともだおr /共倒/
ともえなg /巴投/
ともs /灯/燈/点/
ともr /燈/灯/点/
ともn /共/伴/
とむらu /弔/訪/
とまりこn /泊まり込/
とまりこm /泊まり込/
とまどu /戸惑/
とまどt /戸惑/戸迷/
とまどi /戸惑/
とまt /止/泊/佇/
とまr /泊/止/停/留/
とぼs /乏/
とぼk /惚/恍/
とほのk /遠退/
とほs /通/徹/
とほi /遠/
とぶらh /弔/訪/
とびまわr /飛び回/
とびのr /飛び乗/
とびのk /飛び退/
とびぬk /飛び抜/
とびでt /飛び出/
とびでr /飛び出/
とびちt /飛び散/
とびちr /飛び散/
とびだs /飛び出/
とびこs /飛び越/
とびこn /飛び込/
とびこm /飛び込/
とびかu /飛び交/
とびかt /飛び交/
とびかi /飛び交/
とびいr /飛び入/
とばs /飛/
となりあw /隣合/
となりあu /隣合/
となりあt /隣り合/
となr /隣/鄰/
となh /唱/称/
となe /唱/称/稱/
とどろk /轟/軣/
とどまt /滞/
とどこおt /滞/滯/
とどこおr /滞/滯/
とどけでt /届け出/
とどけでr /届け出/
とどm /留/止/畄/停/
とどk /届/屆/
とどi /届/屆/
ととのえr /整/
ととのw /整/
ととのu /整/調/
ととのt /整/
ととのi /整/
ととのh /整/斉/調/
ととのe /整/調/
とつi /嫁/
とつg /嫁/
とってかえs /取って返/
とっしんs /突進/
とっかe /取っ替/
とだe /途絶/
とじこn /綴じ込/
とじこm /閉じ込/綴じ込/
とじm /戸締/
としよr /年寄/
としこs /年越/
としあk /年明/
とざs /鎖/閉/
とげとげs /刺刺/
とけこn /溶け込/
とけこm /溶け込/
とくべつあつかi /特別扱/
とくべつn /特別/
とくばらi /特払/
とくちょうづk /特徴付/
とくn /特/
とぎれr /途切れ/
とぎr /途切/
ときはなt /解き放/
ときあk /説き明/解き明/
ときn /時/
とがt /尖/
とがr /尖/
とがm /咎/
とおりぬk /通り抜/
とおりすi /通り過/
とおまわs /遠回/
とおまわr /遠回/
とおまk /遠巻/
とおぼe /遠吠/
とおのk /遠の/遠退/
とおすg /遠過/
とおざかt /遠ざか/
とおz /遠/
とおt /通/
とおs /通/遠/徹/
とおr /通/
とおn /遠/
とおm /遠/
とおk /遠/
とおi /遠/
とおc /通/
とうろくs /登録/
とうひょうてつづk /投票手続/
とうとs /尊/
とうとi /貴/尊/
とうとb /尊/貴/
とうぜんn /当然/
とうすg /遠過/
とうじつうr /当日売/
とうじすでn /当時既/
とうこういたs /投稿致/
とうこうs /投稿/
とうけつs /凍結/
とうきょううm /東京生/
とうz /投/
とうt /通/
とうs /通/父/
とうr /通/
とうj /投/
といなおs /問直/
といあわs /問合/問い合わ/
といあw /問い合/問合/
とz /閉/閇/綴/
とw /問/
とu /問/
とt /取/撮/採/録/盗/脱/捕/
とr /取/撮/採/捕/録/執/摂/秉/脱/盗/
とp /取/
とn /飛/富/冨/翔/跳/
とm /止/泊/留/停/富/冨/畄/
とk /解/溶/説/觧/疾/融/熔/鎔/
とj /閉/綴/閇/
とi /問/解/説/觧/研/
とh /問/
とg /遂/研/磨/砥/
とe /問/
とd /綴/閉/
とb /飛/跳/翔/
でんちぎr /電池切/
でんげんぬk /電源抜/
でんげんぎr /電源切/
でんげんいr /電源入/
でんきさらあらi /電気皿洗/
でやすk /出易/
でやすi /出易/
でむかe /出迎/
でむk /出向/
でむi /出向/
でまわt /出回/
でまわr /出回/
でばらu /出払/
でばらt /出払/
でばらi /出払/
ではじm /出始/
ではいr /出入/
でにくk /出難/
でなおs /出直/
でてゆk /出て行/
でてきt /出て来/
でつづk /出続/
でつくs /出尽/
でっぱt /出張/
でたt /出立/
でそろu /出揃/
でそろt /出揃/
でそろi /出揃/
ですg /出過/
でくw /出喰/出食/
できばe /出来栄/出来映/
できなi /出来無/
できあg /出来上/
できz /出来/
できt /出来/
できs /出来/
できr /出来/
できn /出来/
できm /出来/
でかせg /出稼/
でかk /出掛/
でおくr /出遅/
でいr /出入/
であるk /出歩/
であるi /出歩/
であw /出逢/出合/出会/
であu /出逢/出会/出合/
であt /出逢/出会/
であi /出会/出逢/
であe /出会/出逢/出合/
でz /出/
でy /出/
でt /出/
でs /出/
でr /出/
でp /出/
でn /出/
でm /出/
でk /出/
でd /出/
でa /出/
てんぷいたs /添付致/
てんとr /点取/
てんじもうs /展示申/
てんかいs /展開/
てんz /転/
てんj /転/
てをだs /手を出/
てわたs /手渡/
てりこn /照り込/
てりこm /照り込/
てりかえs /照り返/
てらしあw /照し合/
てらu /衒/
てらs /照/
てらh /衒/
てやわらk /手柔/
てもどr /手戻/
てもt /手持/
てもc /手持/
てまわs /手回/
てまどt /手間取/
てまどr /手間取/
てぶr /手振/
てびk /手引/
てばやk /手早/
てばやi /手早/
てばなs /手放/手離/
てはじm /手始/
てぬk /手抜/
てにはいr /手に入/
てにいr /手に入/
てなおs /手直/
てどr /手取/
てとりあしとr /手取り足取/
てとr /手取/
てづくr /手作/
てづm /手詰/
てつやあk /徹夜明/
てつづk /手続/手続き/
てつだw /手伝/
てつだu /手伝/
てつだt /手伝/
てつだo /手伝/
てつだi /手伝/
てつだe /手伝/
てっとりばやk /手っ取り早/
てっとりばやi /手っ取り早/
てっとr /手っ取/
てっs /徹/
てぢかn /手近/
てちがi /手違/
てだすk /手助/
てだt /手立/手出/
てだr /手練/
てざわr /手触/
てざs /手差/
てさぐr /手探/
てさs /手差/
てごわs /手強/
てごわk /手強/
てごわi /手強/
てごたh /手應/
てごたe /手應/
てこずr /梃摺/
てきびs /手厳/
てきとうn /適当/
てきs /適/
てきn /的/
てがたk /手堅/
てがたi /手堅/
てがかr /手掛/
てがk /手書/手掛/手懸/
ておくr /手遅/
ておt /手落/
ておs /手押/
ておc /手落/
ていせいいたs /訂正致/
ていしいたs /停止致/
ていぎづk /定義付/
ていきょうs /提供/
ていs /呈/挺/締/訂/
ていr /手入/
てあらk /手粗/
てあらi /手洗/
てあつk /手厚/
てあつi /手厚/
てあt /手当/
てあi /手合/
てあg /手上/
てr /照/
てn /手/
てm /手/
てg /手/
てd /手/
づらi /辛/
づよk /強/
づよi /強/
づたi /伝/
づくr /作/造/做/
づかi /遣/使/
づr /連/
づm /積/
づk /付/漬/突/
つんざk /劈/
つれもどs /連れ戻/
つれてきt /連れて来/
つれだt /連れ立/
つれだs /連れ出/
つれこn /連れ込/
つれこm /連れ込/
つるs /吊/
つるm /連/
つりこn /釣り込/
つりこm /釣り込/
つりあw /釣合/
つりあu /釣合/釣り合/
つりあi /釣合/
つりあg /釣上/釣り上/
つりあe /釣合/
つらぬきとおs /貫き通/
つらぬk /貫/
つらぬi /貫/
つらs /辛/
つらn /連/列/
つらk /辛/
つらi /辛/
つよs /強/
つよm /強/
つよk /強/
つよi /強/
つよg /強/
つもt /積/
つもr /積/
つめたi /冷/
つめこn /詰め込/
つめこm /詰め込/
つめあw /詰め合/
つめt /冷/
つめr /詰/
つむg /紡/
つみぶかk /罪深/
つみこn /積み込/
つみこm /積み込/
つみかさn /積み重/積重/
つみあg /積上/積み上/
つまびk /爪弾/
つまづk /躓/
つまt /詰/
つまs /約/
つまr /詰/
つまm /撮/摘/抓/
つぼm /窄/蕾/
つぶやk /呟/
つぶやi /呟/
つぶひとt /粒一/
つぶs /潰/
つぶr /潰/瞑/
つひe /潰/費/幣/
つのt /募/
つのr /募/
つねr /抓/
つねn /常/
つなぎこm /繋ぎ込/
つなぎかe /継ぎ換/
つながt /繋/
つなi /継/繋/繼/
つなg /繋/継/繼/
つどu /集/
つどt /集/
つどi /集/
つどh /集/
つとn /夙/
つとm /勤/務/努/勉/
つづt /綴/
つづr /綴/
つづm /約/
つづk /続/續/
つづi /続/續/
つつみこn /包み込/
つつみこm /包み込/
つつまs /慎/
つつぬk /筒抜/
つつしn /謹/慎/愼/
つつしm /慎/鎮/謹/愼/鎭/
つつs /謹/慎/
つつn /包/
つつm /包/
つつk /突/突突/
つっぷs /突っ伏/
つっぱしt /突っ走/
つっぱしr /突っ走/
つっぱt /突っ張/
つっぱr /突っ張/突張/
つっぱn /突っ撥/
つっつk /突っ突/
つったt /突っ立/
つっこn /突込/突っ込/突っこ/
つっこm /突っ込/
つっきr /突っ切/
つっかk /突っ掛/
つっかh /支/閊/
つっかe /支/閊/
つちかw /培/
つちかu /培/
つちかt /培/
つだw /伝/
つだu /伝/傳/
つだi /伝/傳/
つたなi /拙/
つたw /伝/傳/
つたu /伝/傳/
つたt /伝/傳/
つたi /伝/
つたh /伝/傳/
つたe /伝/傳/
つずr /綴/
つこうまつr /仕/
つこu /使/
つけわすr /付け忘/
つけたs /付け足/
つけこn /付け込/漬け込/
つけこm /付け込/漬け込/
つけくわe /付け加/
つけかe /付け替/
つけあg /付け上/
つぐなu /償/
つぐなi /償/
つぐm /噤/
つくろu /繕/
つくろh /繕/
つくりなおs /作り直/
つくりだs /作り出/
つくりこn /作り込/
つくりあg /作り上/
つくらh /繕/
つくt /作/做/創/造/
つくs /尽/殲/殱/盡/
つくr /作/創/造/做/
つくn /捏/
つくc /作/
つぎこn /つぎ込/
つぎこm /つぎ込/
つぎn /次/
つきまとu /付き纏/
つきはじm /月始/月初/
つきとおs /突き通/
つきとm /突き止/
つきとb /突き飛/
つきつk /突き付/
つきだs /突き出/
つきそt /付き添/
つきおとs /突き落/
つきおくr /月遅/
つきあw /突き合/付き合/
つきあu /付き合/付合/
つきあt /付き合/突き当/
つきあo /付き合/
つきあk /月明/
つきあi /付き合/
つきあg /突き上/
つがu /番/
つがi /番/
つがh /番/
つかまつr /仕/
つかさどt /司/
つかさどr /司/掌/
つかうまつr /仕/
つかいわk /使い分/
つかいやすs /使い易/
つかいやすi /使い易/
つかいはじm /使い始/
つかいはt /使い果/
つかいにくi /使い難/
つかいづらi /使い辛/
つかいつk /使い尽/
つかいだs /使い出/
つかいすt /使い捨/
つかいこn /使い込/
つかいこm /使い込/
つかいおw /使い終/
つかいおe /使い終/
つかw /使/遣/
つかu /使/遣/
つかt /使/遣/
つかr /疲/
つかo /使/
つかn /掴/把/束/
つかm /捕/掴/把/捉/攫/
つかi /使/遣/遺/
つかh /遣/仕/使/支/閊/
つかe /使/仕/支/障/閊/
つかc /使/
つうほうs /通報/
つうz /通/
つうj /通/
ついやs /費/費や/
ついy /費/
ついn /対/遂/
ついe /潰/費/幣/
ついb /啄/
つt /突/釣/吊/
つr /連/釣/吊/攣/貫/
つn /積/詰/接/摘/
つm /詰/積/摘/
つk /付/着/尽/突/漬/点/使/尾/衝/憑/就/附/盡/點/築/撞/搗/
つi /着/付/突/継/憑/次/就/附/繼/支/点/
つg /告/継/次/接/嗣/椄/繼/
ぢs /持/
ちんがs /賃貸/
ちりばm /鏤/
ちょくせんみとおs /直線見通/
ちょくせついk /直接行/
ちょうどよk /丁度良/
ちょうどよi /丁度良/
ちょうしわるk /調子悪/
ちょうしわるi /調子悪/
ちょうしよk /調子良/
ちょうしよi /調子良/
ちょうしおt /調子落/
ちょうしおc /調子落/
ちょうけs /帳消/
ちょうz /長/
ちゅうもんとr /注文取/
ちゅうしs /中止/
ちゅうこうr /中古売/
ちゅうがえr /宙返/
ちゅうかんあたr /中間辺/
ちゅうおうよs /中央寄/
ちゅうおうどおr /中央通/
ちゅういぶかk /注意深/
ちゅういぶかi /注意深/
ちゅういs /注意/
ちゅうs /沖/注/註/冲/
ちゃづk /茶漬/
ちゃくばらi /着払/
ちゃくm /茶汲/
ちゃかs /茶化/茶加/
ちまよu /血迷/
ちまよt /血迷/
ちばしt /血走/
ちばしr /血走/
ちぬr /血塗/
ちなn /因/
ちなm /因/
ちぢみこn /縮み込/
ちぢみこm /縮み込/
ちぢみあg /縮み上/
ちぢr /縮/
ちぢn /縮/
ちぢm /縮/
ちちおやごろs /父親殺/
ちじm /縮/
ちこu /近/
ちぎr /契/千切/
ちがw /違/
ちがu /違/交/
ちがt /違/
ちがi /違/
ちがh /違/交/
ちがe /違/
ちからもt /力持/
ちからもc /力持/
ちからまかs /力任/
ちからづよs /力強/
ちからづよk /力強/
ちからづよi /力強/
ちからつk /力尽/
ちからぞe /力添/
ちかよt /近寄/
ちかよs /近寄/
ちかよr /近寄/
ちかづk /近付/
ちかづi /近付/
ちかすg /近過/
ちかu /誓/盟/
ちかt /誓/
ちかs /近/親/
ちかk /近/
ちかi /近/誓/
ちかh /誓/盟/
ちかg /近/
ちかe /誓/
ちかd /近/
ちいさn /小さ/
ちいさk /小/
ちいs /小/
ちt /散/
ちr /散/
ちg /血/
ちb /禿/
だんどr /段取/
だんとr /段取/
だんづk /段付/
だんちがi /段違/
だんせいむk /男性向/
だんぐm /段組/
だんくm /段組/
だんz /断/
だんj /断/
だれm /誰/
だれk /誰/
だれg /誰/
だるi /怠/
だよr /便/
だまりこn /黙り込/
だまりこm /黙り込/
だまt /黙/默/
だまs /騙/
だまr /黙/默/
だぶr /ダブ/
だっs /脱/
だしあu /出し合/
だしあt /出し合/
だきこn /抱き込/
だきこm /抱き込/
だきあt /抱き合/
だおs /倒/
だいめいわすr /題名忘/
だいめいどおr /題名通/
だいぶちがu /大分違/
だいびk /代引/
だいひょうてきn /代表的/
だいたいおなz /大体同/
だいたいおなj /大体同/
だいすk /大好/
だいきらi /大嫌/
だいがくがえr /大学帰/
だいs /題/
だt /立/建/
だs /出/堕/
だm /溜/澑/
だk /抱/
だi /抱/
だc /立/
たんじゅんn /単純/
たんいじかんあt /単位時間当/
たんn /単/單/
たをr /手折/
たをm /撓/
たわむr /戯/戲/
たわm /撓/
たわk /戯/
たれながs /垂れ流/
たれこn /垂れ込/
たれこm /垂れ込/
たるm /弛/
たらs /誑/
たよt /頼/
たよr /頼/便/
たゆたu /揺蕩/
たゆたh /揺蕩/
たゆm /弛/
たやすi /容易/
たもt /保/
たもc /保/
ためらu /躊躇/猶豫/
ためらh /躊躇/猶豫/
ためしずr /試し刷/
ためこn /溜め込/
ためs /試/
ためn /為/爲/
ためd /為/
たむろs /屯/
たむk /手向/
たまわt /賜/
たまわr /賜/承/
たまつk /玉突/
たまだs /玉出/
たまげr /魂消/
たまぎr /弾切/魂消/
たまきt /玉木/
たまw /賜/
たまu /給/賜/
たまt /溜/澑/
たまr /溜/堪/澑/
たまh /給/賜/
たまe /給/
たべつくs /食べ尽/
たべかk /食べ掛/
たべt /食べ/
たべr /食べ/
たぶらk /誑/
たふとi /貴/尊/
たふs /倒/
たふr /倒/斃/
たびなr /旅慣/
たびだt /旅立/
たびかさn /度重/
たばなs /手放/
たばさm /手挾/
たばかr /謀/
たばn /束/
たはむr /戲/
たのみこn /頼み込/
たのみこm /頼み込/
たのしm /楽/
たのs /楽/愉/樂/
たのn /頼/
たのm /頼/恃/
たにまわr /谷回/
たどりつk /辿り着/辿りつ/
たどりつi /辿り着/辿りつ/
たどt /辿/到/
たどr /辿/到/
たとh /喩/譬/
たとe /例/喩/譬/
たでくu /蓼食/
たてまつr /奉/
たてなおs /立て直/
たてとおs /立て通/
たてつづk /立て続/
たてつk /盾突/楯突/建付/
たてぐm /縦組/
たてがk /縦書/
たてかk /立て掛/
たてかe /立て替/
たづさh /攜/携/
たづn /尋/訊/訪/
たっとi /貴/尊/
たっとb /貴/尊/
たっせいs /達成/
たっs /達/逹/
たちよt /立寄/立ち寄/
たちよr /立寄/
たちよm /立ち読/
たちなおt /立ち直/
たちなおr /立ち直/
たちどおs /立ち通/
たちどm /立ち止/
たちとおs /立ち通/
たちさr /立ち去/
たちさg /立ち下/
たちこm /立ち籠/
たちきt /断ち切/裁ち切/
たちきr /断ち切/裁ち切/
たちうt /太刀打/
たちいr /立ち入/
たちあげr /立ち上げ/
たちあw /立会/
たちあu /立合/立ち会/立ち合/
たちあt /立ち合/
たちあi /立合/立会/
たちあg /立ち上/起ち上/立上/
たちあe /立会/
ただよw /漂/
ただよu /漂/
ただよt /漂/
ただよi /漂/
ただよh /漂/
ただたんn /只単/
ただt /直/
ただs /正/但/匡/質/糺/
ただr /爛/糜/
ただc /直/
たたみこn /畳み込/
たたみこm /畳み込/
たたづm /佇/
たたずm /侘/佇/
たたきつk /叩きつ/
たたきだs /叩き出/
たたきこm /叩き込/
たたかw /戦/闘/戰/鬪/
たたかu /闘/戦/斗/戰/鬪/
たたかt /闘/戦/戰/鬪/
たたかi /戦/闘/戰/鬪/
たたかh /戰/鬪/
たたかe /戦/戰/闘/
たたえr /湛/
たたt /祟/
たたr /祟/崇/
たたm /疊/畳/疉/疂/
たたk /叩/敲/
たたi /叩/
たたh /称/湛/
たたe /讃/賛/称/湛/
たそがr /黄昏/
たずさわt /携/
たずさわr /携/
たずさw /携/攜/
たずさe /携/攜/
たずn /尋/訪/訊/
たすk /助/扶/
たしょうちがu /多少違/
たしょうちがt /多少違/
たしょうちがi /多少違/
たしょうちがe /多少違/
たしょうたかk /多少高/
たしょうたかi /多少高/
たしょうおくr /多少遅/
たしなm /嗜/窘/
たしあw /足し合/
たしk /確/慥/
たけなわn /闌/酣/
たけしたどおr /竹下通/
たけs /猛/
たけr /猛/哮/
たけk /猛/
たぐu /比/類/
たぐt /手繰/
たぐr /手繰/
たぐi /類/
たぐh /比/類/
たくわe /蓄/畜/貯/
たくらn /企/
たくらm /企/
たくまs /逞/
たくはh /蓄/貯/
たくs /託/
たくr /綰/
たくm /巧/
たぎr /滾/
たがやs /耕/畊/畉/
たがu /違/
たがi /互/
たがh /違/
たがe /違/
たかをくくr /高を括/
たからさがs /宝探/
たかぶr /昂ぶ/亢ぶ/昂/
たかなt /高鳴/
たかなr /高鳴/
たかすg /高過/
たかs /高/
たかr /集/
たかn /高/
たかm /高/
たかk /高/
たかi /高/
たおれr /殕/
たおしこm /倒し込/
たおy /嫋/
たおs /倒/
たおr /倒/斃/手折/
たえがたi /耐え難/
たうe /田植/
たいへんよk /大変良/
たいへんよi /大変良/
たいへんもうs /大変申/
たいへんおそk /大変遅/
たいへんおそi /大変遅/
たいさくしr /対策知/
たいおうづk /対応付/
たいおうしきr /対応仕切/
たいおうs /対応/
たいあたr /体当/
たいあt /体当/
たいs /対/大/對/
たいr /平/
たy /絶/
たt /立/経/建/断/起/発/絶/斷/發/經/裁/
たs /足/達/逹/
たr /足/垂/埀/
たn /他/
たm /溜/貯/矯/澑/
たk /炊/焚/長/闌/
たi /炊/焚/
たh /他/堪/耐/
たe /耐/絶/堪/
たc /立/断/斷/経/建/
たb /食/
ぞんじあg /存じ上/
ぞんz /存/
ぞんj /存/
ぞろe /揃/
ぞくs /属/
ぞくn /俗/
ぞi /沿/
ぞe /添/
そんざいs /存在/
そんz /損/
そんs /存/
そんj /損/
そろw /揃/
そろu /揃/
そろt /揃/
そろi /揃/
そろh /揃/
そろe /揃/
そろc /揃/
そらんz /諳/
そらんj /諳/
そめこn /染め込/
そめこm /染め込/
そむk /背/叛/
そむi /背/
そぼt /濡/
そぶr /素振/
そびe /聳/
そばだt /峙/
そねm /嫉/妬/猜/
そなえつk /備え付/
そなw /備/
そなh /供/具/備/
そなe /備/供/具/
そとむk /外向/
そとまわr /外回/
そとづk /外付/
そとつk /外付/
そだt /育/毓/
そだc /育/毓/
そそのかs /唆/嗾/
そそぎこn /注ぎ込/
そそぎこm /注ぎ込/
そそi /注/
そそg /注/灌/
そしr /詆/謗/讒/誹/
そこなw /損/
そこなu /損/害/
そこなt /損/
そこなh /損/
そこしr /底知/
そこあg /底上/
そこn /損/害/
そぐw /似/
そぐu /似/
そくs /則/即/促/
そうろu /候/
そうりょうちゃくばらi /送料着払/
そうめいs /聡明/
そうめいd /聡明/
そうふいただk /送付頂/
そうふいたs /送付致/
そうとうn /相当/
そうていs /想定/
そうだんくだs /相談下/
そうぞうs /騒々/
そうz /総/
そうs /奏/
そうj /総/
そあくn /粗悪/
そw /沿/添/
そu /沿/添/副/
そt /沿/添/剃/
そr /剃/反/逸/其/
そn /其/素/
そm /初/染/
そi /沿/添/
そh /沿/添/副/
そg /削/殺/
そe /添/沿/副/
ぜんぶもt /全部持/
ぜんぜんよn /全然読/
ぜんぜんよm /全然読/
ぜんぜんみt /全然見/
ぜんきょくとおs /全曲通/
ぜんk /前/
ぜひきk /是非聞/
ぜにうしなi /銭失/
ぜったいよk /絶対良/
ぜったいいk /絶対行/
ぜっくs /絶句/
ぜっs /絶/
ぜいぬk /税抜/
ぜいこm /税込/
せんもんかむk /専門家向/
せんまいどおs /千枚通/
せんまいづk /千枚漬/
せんびk /線引/
せんなi /詮無/
せんたくばさm /洗濯挟/
せんたくs /選択/
せんぞがえr /先祖帰/
せんさいn /繊細/
せんかたなi /詮方無/
せんz /煎/先/
せんs /僭/
せんj /煎/先/
せわずk /世話好/
せわs /忙/
せめこn /攻め込/
せめこm /攻め込/
せめg /鬩/
せますg /狭過/
せまt /迫/
せまs /狭/狹/
せまr /迫/逼/
せまk /狭/狹/
せまi /狭/狹/
せばm /狭/狹/
せはs /忙/
せつめいしょどおr /説明書通/
せつめいs /説明/
せつぞくs /接続/
せつn /切/
せつk /責付/
せっていまちがi /設定間違/
せっていs /設定/
せっつk /責付/
せっしょくs /接触/
せっきんs /接近/
せっきょくてきn /積極的/
せっきょうたr /説教垂/
せっきょうくさk /説教臭/
せっきょうくさi /説教臭/
せっs /接/
せちがらi /世知辛/
せせらわらu /嘲笑/
せきにんもt /責任持/
せきにんとt /責任取/
せきにんとr /責任取/
せきとm /せき止/
せきたt /急き立/
せきがe /席替/
せおいこn /背負い込/
せおいこm /背負込/背負い込/
せおu /背負/
せおt /背負/
せおi /背負/
せおe /背負/
せうs /抄/
せいりけんとr /整理券取/
せいびs /整備/
せいちょうs /成長/
せいせいs /生成/
せいしんてきn /精神的/
せいげんつk /制限付/
せいかくs /正確/
せいかくn /正確/
せいs /制/
せt /競/
せs /接/
せr /競/迫/糶/
せm /責/攻/
せk /急/堰/塞/
せi /急/
せg /背/
ずるi /狡/
ずぶとk /図太/
ずぶとi /図太/
ずつk /頭突/
ずうずうs /図々/
ずいぶんふるi /随分古/
ずr /刷/
ずm /済/濟/
ずk /好/付/
すんぶんちがw /寸分違/
すわりこn /座り込/
すわりこm /座り込/
すわt /座/坐/
すわr /座/坐/
すれちがu /擦れ違/
するどs /鋭/
するどk /鋭/
するどi /鋭/
すりよr /擦り寄/摩り寄/
すりむk /擦り剥/擦剥/
すりむi /擦剥/
すりへr /磨り減/
すりぬk /擦り拔/
すりつぶs /摺り潰/磨り潰/
すりこn /刷り込/
すりこm /摺り込/摩り込/刷り込/
すりくだk /擂り碎/
すりきr /摺り切/摩り切/
すりかe /すり替/摩り替/
すもぐr /素潜/
すみこn /住み込/
すみこm /住み込/
すみくr /住み暮/
すみy /速/
すまh /住ま/
すぼm /窄/
すべりこn /滑り込/
すべりこm /滑り込/
すべt /全/滑/総/總/
すべr /滑/辷/
すぶr /素振/
すばらs /素晴/
すばやs /素早/
すばやk /素早/素速/
すばやi /素早/
すばr /素晴/
すなわt /即/則/
すなわc /即/
すなどr /漁/
すどまr /素泊/
すどおs /素通/
すどおr /素通/
すでn /既/
すてさt /捨て去/
すてさr /捨て去/
すてきr /捨て切/
すてきd /素敵/
すてがたi /捨て難/
すてr /捨て/
すづk /酢漬/
すだt /巣立/
すたr /廃/頽/廢/
すずs /涼/凉/
すずn /涼/
すずm /涼/凉/
すすr /啜/
すすn /進/
すすm /進/勧/薦/勸/
すすk /煤/
すすg /啌/漱/濯/雪/
すじちがi /筋違/
すじr /捩/
すさn /荒/
すさm /凄/荒/進/遊/
すさb /荒/進/遊/
すごもr /巣篭/
すごすg /凄過/
すごs /過/凄/
すごm /凄/
すごk /凄/
すごi /凄/
すこぶr /頗/
すこy /健/
すこs /少/
すぐr /優/秀/勝/選/
すぐn /直/
すくなk /少/少な/
すくなi /少/少な/寡/
すくいだs /救い出/
すくw /救/掬/
すくu /救/掬/匡/抄/巣喰/済/巣く/
すくt /救/掬/巣喰/
すくo /救/
すくn /少/竦/
すくm /竦/窘/
すくi /救/掬/
すくh /掬/救/済/抄/
すくe /救/
すぎn /過ぎ/
すきとおt /透き通/
すきとおr /透き通/
すきこn /漉き込/
すきこm /漉き込/
すがすがs /清々/
すがr /縋/
すかs /賺/透/
すえながk /末長/末永/
すえおk /据置/据え置/
すうねんたt /数年経/
すうねんたc /数年経/
すいだs /吸い出/
すいこn /吸い込/
すいこm /吸い込/
すいあg /吸い上/
すあg /素揚/
すw /吸/喫/据/
すu /吸/喫/
すt /捨/吸/刷/棄/喫/
すr /刷/擦/摺/擂/為/剃/摩/磨/掏/爲/
すp /酸/
すn /済/住/棲/澄/拗/濟/
すm /済/住/澄/棲/栖/澂/濟/清/
すk /好/透/梳/耡/空/漉/鋤/抄/剥/
すi /吸/済/空/透/喫/酸/濟/好/
すg /過/直/
すe /据/吸/饐/
すb /総/統/總/
じょうほうくだs /情報下/
じょうせきどおr /定石通/
じょうけんづk /条件付/
じょうz /乗/乘/
じょうs /城/
じょうn /上/状/
じょうj /乗/乘/
じゆうさんかd /自由参加/
じゆうd /自由/
じゅんばんまt /順番待/
じゅんばんまc /順番待/
じゅんz /準/殉/凖/
じゅんn /順/
じゅんj /準/凖/
じゅつごよb /述語呼/
じゅくs /熟/
じゅうらいどおr /従来通/
じゅうぶんn /十分/
じゅうぶんd /十分/
じゅうなんn /柔軟/
じゅうだいn /重大/
じゅうじがたm /十字固/
じゅn /得/
じゃらs /戯/
じゃっかんことn /若干異/
じむてづづk /事務手続/
じばk /字化/
じてんしゃのr /自転車乗/
じてんd /時点/
じつn /実/
じつh /実/
じっこうs /実行/
じだいおくr /時代遅/
じしょひk /辞書引/
じさg /字下/
じこt /事故/
じこm /仕込/
じきはずr /時期外/
じかんぎr /時間切/
じかんおくr /時間遅/
じかn /直/
じあまr /字余/
じs /辞/侍/持/
じr /焦/
じn /死/
じg /字/
しんぴてきn /神秘的/
しんぴてきd /神秘的/
しんぱいなs /心配無/
しんぱいなi /心配無/
しんちょうs /新調/
しんじんぶかk /信心深/
しんじんぶかi /信心深/
しんじゅくどおr /新宿通/
しんじt /信じ/
しんじr /信じ/
しんしんぶかk /信心深/
しんしんぶかi /信心深/
しんしんともn /心身共/
しんこうs /進行/
しんけんd /真剣/
しんきくさk /心気臭/辛気臭/
しんきくさi /心気臭/辛気臭/
しんz /信/死ん/
しんn /真/
しんj /信/死ん/
しをr /萎/
しわがr /嗄/
しわk /仕分/
しわi /吝/
しろぬk /白抜/
しろうとかんがe /素人考/
しろk /白/
しろi /白/
しるs /記/著/示/印/誌/徴/標/
しりぞk /退/斥/
しりぞi /退/
しりごm /尻込/
しりあu /知り合/
しりあt /知り合/
しりあi /知り合/
しりあe /知り合/
しらべr /調べ/
しらじらs /白々/
しらs /報/知ら/
しらm /白/
しらk /白/
しらb /調/
しようくだs /使用下/
しようs /使用/
しようd /使用/
しょりs /処理/
しょっきあらi /食器洗/
しょじs /所持/
しょしんしゃむk /初心者向/
しょげr /悄気/
しょくs /食/
しょきばらi /暑気払/
しょきかs /初期化/
しょうろうながs /精霊流/
しょうめいずm /証明済/
しょうめいs /証明/
しょうぶづよi /勝負強/
しょうぶつよk /勝負強/
しょうどうがi /衝動買/
しょうだt /章立/
しょうじょまんがずk /少女漫画好/
しょうぎだおs /将棋倒/
しょうがつやすm /正月休/
しょうかいいただk /紹介頂/
しょうかいいたs /紹介致/
しょうz /生/
しょうs /称/抄/証/
しょうj /生/
しょu /背負/
しょt /背負/
しょs /処/
しょh /背負/
しゅつりょくs /出力/
しゅくs /祝/
しゅうりがk /修理書/
しゅうかんおくr /週間遅/
しゅうあk /週明/
しゅt /主/
しゃれt /洒落/
しゃべt /喋/
しゃべr /喋/諜/
しゃちほこばr /鯱張/
しゃこいr /車庫入/
しゃがr /嗄/
しめだs /締め出/
しめくくr /締め括/
しめきt /締め切/
しめきr /締切/締め切/
しめいs /指名/
しめt /湿/
しめs /示/湿/濕/
しめr /湿/濕/
しめp /湿/濕/
しむk /仕向/
しみこn /染み込/
しみこm /染み込/
しみいt /染み入/
しみいr /染み入/
しみr /沁/
しまu /仕舞/終/了/
しまt /了/仕舞/
しまr /閉/
しまi /終/
しぼりこn /絞り込/
しぼりこm /絞り込/
しぼt /絞/
しぼr /絞/搾/
しぼm /萎/凋/
しぶだよr /支部便/
しぶt /渋/澁/澀/
しぶs /渋/
しぶr /渋/澁/
しぶk /渋/澁/澀/
しぶi /渋/澁/澀/
しびr /痺/
しばらk /暫/
しばたk /瞬/
しばt /縛/
しばs /暫/
しばr /縛/暫/凍/
しはらw /支払/
しはらu /支払/
しはらt /支払/
しはらi /支払/
しはらe /支払/
しのびこn /忍び込/
しのびこm /忍び込/
しのばずどおr /不忍通/
しのn /忍/
しのi /凌/
しのg /凌/
しのb /偲/忍/
しにくi /為難/爲難/
しなぞろi /品揃/
しなぞろe /品揃/
しなさだm /品定/
しなぎr /品切/
しながe /品換/
しなおs /仕直/
しなu /撓/
しなr /撓/
しなh /撓/
しなb /萎/
しとm /仕留/爲留/
してきどおr /指摘通/
してきs /指摘/
していs /指定/
しづらi /仕辛/
しづr /垂/埀/
しづm /沈/鎭/靜/
しつりょうあたr /質量当/
しつけr /躾/
しっとぶかi /嫉妬深/
しっかr /確/
しっs /失/
しちめんどうくさi /七面倒臭/
しだr /垂/
したよs /下寄/
したまわt /下回/
したまわr /下回/
したばたらk /下働/
したどr /下取/
したとr /下取/
したつk /下付/
したたt /滴/
したたr /舌足/滴/
したたm /認/
したしらb /下調/
したしm /親し/親/
したざわr /舌触/
したがw /従/从/從/
したがu /従/順/从/啝/從/随/
したがt /従/从/從/順/
したがk /下書/
したがi /従/从/從/順/
したがh /従/順/随/從/
したがe /従/从/從/随/
したうt /舌打/
したうk /下請/
したw /慕/
したu /慕/
したt /仕立/慕/
したs /親/
したn /下/
したk /下/
したh /慕/
しぜんn /自然/
しずみこn /沈み込/
しずみこm /沈み込/
しずけs /靜け/
しずr /垂/
しずn /沈/
しずm /沈/静/鎮/靜/沒/鎭/
しずk /静/靜/
しじょうむk /市場向/
しじどおr /指示通/
ししんかえs /私信返/
しさs /示唆/
しごk /扱/
しこr /凝/痼/
しこn /仕込/
しこm /仕込/
しげt /茂/楙/
しげr /茂/繁/楙/
しげm /茂/
しげk /繁/
しけr /湿気/
しぐr /時雨/
しくn /仕組/
しくm /仕組/
しきわm /爲極/
しきりなおs /仕切り直/
しきはm /爲極/
しきつm /敷き詰/
しきt /仕切/
しきr /仕切/頻/
しからしm /然らし/
しかたなk /仕方無/
しかたなi /仕方無/
しかしながr /乍/
しかくi /四角/
しかえs /仕返/
しかt /叱/
しかs /而/然/併/
しかr /叱/然/
しかn /爲兼/
しかm /顰/
しかk /仕掛/
しおほs /爲果/
しおづk /塩漬/
しおくr /仕送/爲送/
しおおs /爲果/
しおr /萎/
しおk /仕置/爲置/
しいれr /仕入れ/
しいたg /虐/
しいs /弑/
しいr /仕入/
しあわs /幸/倖/仕合/
しあがt /仕上が/
しあいおw /試合終/
しあu /為合/爲合/
しあg /仕上/
しt /知/
しs /死/資/執/失/悉/齒/
しr /知/調/
しn /死/知/
しm /占/締/閉/染/絞/〆/沁/閇/緊/浸/凍/滲/
しk /敷/如/及/若/
しi /強/敷/誣/
しh /強/誣/
ざいせきs /在籍/
ざr /戯/
さんびょうしそろt /三拍子揃/
さんはいしこm /山廃仕込/
さんせいいたs /賛成致/
さんしょうくだs /参照下/
さんしゅうくだs /参集下/
さんかてつづk /参加手続/
さんかくだs /参加下/
さんかいたs /参加致/
さんかs /参加/
さんz /参/
さんs /産/
さんj /参/
さわぎだs /騒ぎ出/
さわy /爽/
さわt /触/障/觸/
さわr /触/障/觸/
さわi /騒/騷/
さわg /騒/騷/
さらあらi /皿洗/
さらu /濬/復習/攫/浚/渫/
さらs /晒/曝/暴/
さらn /更/
さらk /曝/
さらh /浚/復習/渫/
さらe /渫/浚/
さめr /寤/
さむs /寒/
さむk /寒/
さむi /寒/
さむg /寒/
さみs /淋/寂/
さまよu /彷/さ迷/
さまたg /妨/防/碍/
さまざまn /様々/
さまがw /様変/
さまs /冷/醒/
さぼt /サボ/
さぶらu /候/
さびs /寂/淋/寞/寥/
さびr /寂/
さばk /捌/裁/
さばi /裁/
さとがえr /里帰/
さとうづk /砂糖漬/
さとt /悟/
さとs /悟/説/諭/訓/
さとr /悟/
さとi /慧/
さっちs /察知/
さっそくためs /早速試/
さっs /察/
さだm /定/
さだk /定/
さそいこn /誘い込/
さそいこm /誘い込/
さそw /誘/
さそu /誘/哘/
さそt /誘/
さそo /誘/
さそi /誘/
さそe /誘/
さずk /授/
さすらu /流離/
さしもどs /差し戻/
さしむk /差し向/
さしまわs /差し回/
さしひかe /差し控/差控/
さしひk /差し引/
さしひi /差し引/
さしはさn /差し挟/
さしはさm /差し挟/
さしのぼt /差し上/差し昇/
さしのぼr /差し上/差し昇/
さしのb /差し延/
さしぬi /刺し縫/
さしとおs /刺し通/
さしとm /差し止/
さしでg /差し出/
さしづm /差し詰/
さしつかw /差し遣/
さしつかe /差し支/差支/
さしちがe /差し違/刺し違/
さしだs /差出/指し出/差し出/
さしたt /差し立/
さしせまt /差し迫/
さしせまr /差し迫/
さしずm /差し詰/
さししめs /指し示/
さしさわt /差し障/
さしさわr /差障/差し障/
さしころs /刺し殺/
さしこn /差し込/射し込/
さしこm /差し込/射し込/指し込/
さしかw /差し交/
さしかk /差し掛/
さしかe /差し替/挿し替/
さしおs /差し押/
さしおk /差し置/
さしおi /差し置/
さしいそg /差し急/
さしいr /差し入/挿し入/
さしあw /差し合/
さしあt /差し当/
さしあg /差し上/
ささやk /囁/
ささy /細/
ささg /捧/
ささe /支/
さげすm /蔑/貶/
さけずk /酒好/
さけn /叫/
さけb /叫/
さぐりあi /探り合/
さぐt /探/
さぐr /探/
さくづk /作付/
さくせいてつづk /作成手続/
さくせいいたs /作成致/
さくせいs /作成/
さきよm /先読/
さきものがi /先物買/
さきまわr /先回/
さきぶr /先触/
さきばらi /先払/
さきばしt /先走/
さきばしr /先走/
さきのb /先延/
さきどr /先取/
さきだt /先立/
さきだc /先立/
さきがk /先駆/
さきおくr /先送/
さきうt /先打/
さきn /先/
さきg /先/
さがしまわr /探し回/
さがしだs /探し出/
さがt /下/
さがs /探/捜/搜/
さがr /下/
さかもr /酒盛/
さかまk /逆巻/
さかのぼt /遡/
さかのぼr /遡/逆昇/逆のぼ/泝/溯/
さかなy /魚/
さかだt /逆立/
さかs /逆/賢/
さかr /逆/盛/
さかn /盛/
さかe /栄/盛/榮/
さえわたr /さえ渡/冴え渡/
さえずr /哢/囀/
さえぎt /遮/
さえぎr /峺/遮/
さいわi /幸/
さいはt /最果/
さいなm /呵/嘖/
さいこうn /最高/
さいげんs /再現/
さいきんいそがs /最近忙/
さいかいs /再開/
さいs /際/
さいn /際/
さt /去/
さs /差/指/刺/察/射/剌/溂/螫/鎖/挿/注/点/捺/插/然/
さr /去/然/
さm /覚/醒/冷/覺/褪/
さk /避/咲/裂/割/
さi /咲/裂/割/削/
さg /下/差/提/
さe /冴/冱/
さb /錆/荒/寂/
ごろうz /御覧/
ごろうj /御覧/
ごろn /頃/
ごれんらくねがu /御連絡願/
ごれんらくねがi /御連絡願/
ごれんらくいただk /御連絡戴/御連絡頂/
ごれんらくいただi /御連絡戴/御連絡頂/
ごりようくだs /御利用下/ご利用下/
ごりかいくだs /御理解下/
ごりかいいただk /御理解頂/
ごりおs /ゴリ押/
ごらんくだs /御覧下/
ごようしゃくだs /御容赦下/
ごまかs /胡麻化/誤魔化/
ごのm /好/
ごとうひょうくだs /御投票下/
ごとs /若/如/
ごとn /毎/
ごとk /如/
ごちゅういくだs /御注意下/
ごぞんz /御存/
ごぞんj /御存/
ごしようくだs /御使用下/
ごしどうねがi /御指導願/
ごしどうくだs /御指導下/
ごしてきくだs /御指摘下/
ござi /御座/
ごさんしょうくだs /御参照下/
ごさんかくだs /御参加下/
ごきょうりょくくだs /御協力下/
ごきょうじゅねがi /御教授願/
ごきょうじゅくだs /御教授下/
ごきょうじねがi /御教示願/
ごきょうじくだs /御教示下/
ごきょうじいただk /御教示頂/
ごきょうじいただi /御教示頂/
ごきたいくだs /御期待下/
ごかつようくだs /御活用下/
ごかくにんくだs /御確認下/
ごえんりょくだs /御遠慮下/
ごうじょっぱr /強情っ張/
ごいっぽうねがu /御一報願/
ごいっぽうねがi /御一報願/
ごいっぽうくだs /御一報下/
ごいちどくくだs /御一読下/
ごあんないもうs /御案内申/
ごあんしんくだs /御安心下/
ごs /越/期/伍/
ごk /極/
ごe /越/
こんぽんてきn /根本的/
こんばんh /今晩/
こんねんどかぎr /今年度限/
こんにちh /今日/
こんかいはじm /今回初/
こわばr /強張/
こわs /壊/怖/毀/壞/恐/
こわr /壊/毀/壞/
こわk /恐/怖/小分/
こわi /恐/怖/強/
こわg /怖/恐/
こわb /硬/
ころしあi /殺し合/
ころげこn /転げ込/
ころげこm /転げ込/
ころがりこn /転がり込/
ころがりこm /転がり込/
ころs /殺/
ころn /転/轉/
ころg /転/轉/
ころb /転/轉/
こりかたm /凝り固/
こらe /怺/堪/
こもt /籠/
こもr /籠/隠/篭/子守/
こみだs /小見出/
こみいt /混み入/
こまわr /小回/
こまねk /拱/
こまぬk /拱/
こまつかi /小間使/
こまぎr /細切/小間切/
こまかi /細か/
こまt /困/
こまr /困/
こまn /困/
こまk /細/
こまi /細/
こまc /困/
こぼt /毀/
こぼs /零/毀/
こぼr /溢/零/
こほr /凍/氷/
こぶr /小降/小振/
こばしr /小走/
こばn /拒/
こばm /拒/
このn /好/
このm /好/
こどもむk /子供向/
こどもづr /子供連/
ことわt /断/斷/
ことわr /断/斷/
ことほg /言祝/寿/
ことばどおr /言葉通/
ことばづかi /言葉遣/言葉使/
ことばあそb /言葉遊/
ことはじm /事始/
ことなt /異/
ことなr /異/
こととh /言問/
ことづt /言伝/言傳/
ことづk /託/言付/
ことたr /言葉足/事足/
ことずk /託/
ことごとk /尽/盡/悉/
ことかk /事欠/
ことw /断/斷/
ことn /異/殊/
こづかi /小遣/
こづr /子連/
こづk /小突/
こづi /小突/
こだわt /拘/
こだわr /拘/
こだかi /小高/
こたh /堪/答/應/
こたe /答/応/堪/應/
こぞt /挙/
こぞr /挙/
こそだt /子育/
こそg /刮/
こすからi /狡辛/
こすt /擦/
こすr /擦/錯/
こすi /狡/
こじんてきn /個人的/
こじs /誇示/
こじr /抉/拗/
こしらh /拵/
こしらe /拵/
こしづk /腰付/
こしくだk /腰砕/
こしかk /腰掛/
こざかs /小賢/
こごろs /子殺/
こごr /凝/
こごm /屈/
こごe /凍/
こころよk /快/
こころよi /快/
こころゆるs /心許/
こころやさs /心優/
こころもとなi /心許無/
こころもt /心持/
こころもc /心持/
こころまt /心待/
こころまc /心待/
こころぼそk /心細/
こころぼそi /心細/
こころひk /心魅/
こころのこr /心残/
こころづよk /心強/
こころづよi /心強/
こころづかi /心遺/心使/心遣/
こころざs /志/
こころぐるs /心苦/
こころがまe /心構/
こころがk /心掛/
こころおだy /心穏/
こころおk /心置/
こころあたたm /心温/
こころあたr /心当/
こころあt /心当/
こころm /試/
こころh /心/
こころg /心/
ここのt /九/
ここちよs /心地良/
ここちよk /心地良/
ここちよi /心地良/心地好/
ここn /個々/
こきょうさがs /故郷探/
こきみよi /小気味良/
こきざm /小刻/
こきおr /扱き下/
こがらs /木枯/
こがs /焦/
こがr /焦/木枯/
こかs /転/倒/
こおりつi /凍り付/
こおりけずr /氷削/
こおt /凍/
こおr /凍/氷/
こえだs /声出/
こえかk /声掛/
こえt /超/
こうりょs /考慮/
こうむt /蒙/被/
こうむr /被/蒙/
こうべそだt /神戸育/
こうべそだc /神戸育/
こうべうm /神戸生/
こうねんはなr /光年離/
こうにゅういたs /購入致/
こうだいn /広大/
こうそくなr /高速慣/
こうそくn /高速/
こうせいn /公正/
こうごうs /神々/
こうげきs /攻撃/
こうきゅうとr /高給取/
こうz /高/講/嵩/考/構/
こうj /講/高/効/構/效/嵩/考/
こうb /香/
こいねがはk /希/
こいs /恋/戀/
こz /来/
こy /来/來/徠/肥/
こw /請/
こu /乞/請/買/斯/恋/戀/
こt /凝/
こs /越/漉/濃/濾/鼓/超/
こr /来/凝/懲/來/徠/樵/此/
こn /込/来/混/此/來/徠/捏/
こm /込/混/籠/篭/
こk /濃/扱/痩/放/
こi /濃/来/漕/來/徠/乞/請/
こh /乞/請/戀/
こg /焦/漕/扱/
こe /越/超/肥/踰/
こd /子/小/
こb /媚/
げんつk /原付/
げんだいかなづかi /現代仮名遣/
げんさくどおr /原作通/
げんz /減/
げんs /減/
げんn /現/
げんj /減/
げぎらi /毛嫌/
げきs /激/
げs /解/觧/
げr /蹴/
けんとうちがi /見当違/
けんとうs /検討/
けんしょうずm /検証済/
けんいづk /権威付/
けんz /献/
けわu /化粧/
けわs /険/峻/險/
けりとb /蹴飛/
けむt /煙/
けむr /煙/烟/
けむi /煙/
けみs /閲/
けぶかk /毛深/
けぶかi /毛深/
けぶr /煙/烟/
けぶi /煙/
けはh /化粧/
けなs /貶/
けなm /毛並/
けどr /気取/
けとb /蹴飛/
けづr /削/梳/
けっていてきn /決定的/
けっていづk /決定付/
けっていいたs /決定致/
けっていs /決定/
けっしゅうs /結集/
けっこうおおk /結構大/
けっs /決/
けちr /蹴散/
けだるi /気怠/
けだかk /気高/
けだかi /気高/
けたちがi /桁違/
けたちがh /桁違/
けずt /削/
けずr /削/梳/
けしかr /怪しか/
けしかk /嗾/
けがs /汚/涜/穢/
けがr /汚/穢/
けおs /気圧/
けいじs /掲示/
けいこくs /警告/
けいけんゆたk /経験豊/
けいけんs /経験/
けいきづk /景気付/
けいかいn /軽快/
けいえいs /経営/
けあg /蹴上/
けt /蹴/
けs /消/決/
けr /蹴/
ぐるs /苦/
ぐちr /愚痴/
ぐずr /愚図/
ぐさr /腐/
ぐあi /具合/
ぐm /組/
ぐi /食/
くんよm /訓読/
くんづk /君付/
くわわt /加/
くわだt /企/
くわw /加/
くわs /詳/加/
くわk /区分/
くわe /加/咥/銜/
くろびかr /黒光/
くろぬr /黒塗/
くろすg /黒過/
くろk /黒/
くろi /黒/梍/玄/
くれなずm /暮れ泥/
くるめk /眩/
くるしまぎr /苦し紛/
くるw /狂/
くるu /狂/
くるt /狂/
くるs /苦/
くるo /狂/
くるm /包/
くるi /狂/
くるh /狂/
くりひろg /繰り広/
くりのb /繰延/
くりだs /繰り出/
くりこs /繰り越/
くりこn /繰り込/
くりこm /繰り込/
くりかえs /繰り返/繰返/
くりあw /繰り合/
くりあg /繰上/繰り上/
くらすg /暗過/
くらいどr /位取/
くらいづk /位付/
くらいつk /食らい付/
くらいつi /食らい付/
くらいこn /食らい込/
くらいこm /食らい込/
くらいs /位/
くらu /喰ら/
くらt /食/
くらs /暮/暗/
くらm /晦/眩/暗/
くらk /暗/
くらi /暗/位/暝/眛/昏/冥/
くらe /喰ら/
くらb /比/較/競/
くゆr /燻/
くやs /悔/口惜/
くやm /悔/
くもゆk /雲行/
くもt /曇/
くもr /曇/
くみとr /汲み取/
くみたてr /組み立て/
くみたt /組み立/組立/
くみこn /組み込/
くみこm /組込/組み込/
くみかw /酌み交/
くみかe /組替/
くみあわs /組合/組み合わ/組み合/
くみあw /組み合/組合/
くみs /与/與/
くぼn /窪/
くぼm /窪/凹/
くべつs /区別/
くびがたm /首固/
くびr /縊/括/
くばt /配/
くばr /配/
くはh /加/銜/
くどk /口説/
くどi /口説/諄/
くづほr /頽/
くづs /崩/
くつろg /寛/
くつがへs /覆/
くつがへr /覆/
くつがえs /覆/
くつがえr /覆/
くっt /食/
くっs /屈/
くちをs /口惜/
くちばしt /口走/
くちばしr /口走/
くちなおs /口直/
くちどr /口取/
くちだs /口出/
くちずさm /口遊/
くちごm /口籠/
くちぎたなi /口穢/
くちおs /口惜/
くちあt /口当/
くだt /下/
くだs /下/降/
くだr /下/降/
くだk /砕/碎/
くだi /砕/
くずおr /頽/
くずs /崩/
くずr /崩/
くすりづk /薬漬/
くすぶr /燻ぶ/燻/
くすぐt /擽/
くすぐr /擽/
くすg /擽/
くじk /挫/
くじi /挫/
くしざs /串刺/
くしけづr /梳/
くしけずr /梳/
くさわk /草分/
くさふかk /草深/
くさふかi /草深/
くさかr /草刈/
くさt /腐/
くさs /臭/
くさr /腐/鏈/
くさk /臭/
くさi /臭/
くぐt /潜/
くぐr /潛/潜/
くくt /括/
くくr /括/
くぎづk /釘付/
くぎt /区切/
くぎr /区切/
くうきいr /空気入/
くいちがu /食い違/
くいちがt /食い違/
くいちがi /喰い違/食い違/
くいちr /食い散/
くいたr /食い足/
くいこn /食い込/喰い込/
くいこm /喰い込/食い込/
くいあらたm /悔い改/
くいあr /食い荒/
くy /悔/
くw /食/喰/
くu /食/喰/
くt /食/喰/朽/
くs /屈/
くr /来/繰/暮/食/喰/呉/來/徠/眩/
くo /食/
くn /組/苦/汲/
くm /組/汲/酌/
くi /食/悔/喰/
くh /食/
くg /絎/
くe /喰/食/
くc /朽/喰/
ぎんz /吟/
ぎろんずk /議論好/
ぎらi /嫌/
ぎょうぎょうs /仰々/仰仰/
ぎゅうじr /牛耳/
ぎゃっこうs /逆行/
ぎゃくもどr /逆戻/
ぎゃくむk /逆向/
ぎゃくまわr /逆回/
ぎゃくびk /逆引/
ぎゃくじょうs /逆上/
ぎゃくじゅうじがたm /逆十字固/
ぎゃくn /逆/
ぎむづk /義務付/
ぎs /擬/
ぎr /切/斬/
ぎm /決/
きんちょうs /緊張/
きんz /禁/
きんj /禁/
きをつk /気を付/
きわどi /際疾/
きわだt /極立/際立/
きわm /極/究/窮/
きわd /際/
きれこn /切れ込/
きれこm /切れ込/
きりんかんどおr /希林館通/
きりわk /切り分/
きりひらk /切開/
きりはなs /切離/切り離/
きりはr /切り貼/
きりぬk /切り抜/
きりぬi /切り抜/
きりなおs /切り直/
きりどおs /切り通/
きりとおs /切り通/
きりとt /切り取/
きりとr /切取/切り取/
きりづk /切り漬/
きりつm /切り詰/
きりだs /切り出/
きりすt /切り捨/切捨/
きりさk /切り裂/斬り裂/
きりかえs /切り返/
きりかえr /切り換え/
きりかw /切り替/切替/
きりかe /切り替/切り換/切替/切換/
きりおとs /切り落/
きりうr /切り売/
きりあg /切り上/
きらめk /煌/
きらw /嫌/
きらu /嫌/
きらt /嫌/
きらm /煌/
きらi /嫌/
きらh /嫌/
きらb /燦/
きよらかn /清らか/
きよs /清/
きよr /清/
きよm /浄/清/
きよk /清/
きよi /清/
きょぜつs /拒絶/
きょくりょくさk /極力避/
きょうりょくたまわr /協力賜/
きょうりょくくだs /協力下/
きょうみぶかk /興味深/
きょうみぶかi /興味深/
きょうだいn /強大/
きょうじゅくだs /教授下/
きょうじくだs /教示下/
きょうしゅくs /恐縮/
きょうかしょどおr /教科書通/
きょうz /興/
きょうs /供/
きょうn /今日/
きょうm /今日/
きょうj /興/
きょうh /今日/
きゅうしょげr /急所蹴/
きゅうしゅうs /吸収/
きゅうs /窮/
きゅうn /急/
きやすm /気休/
きやすk /気安/
きやすi /気安/
きゃくあつかi /客扱/
きもちわるs /気持ち悪/
きもちわるi /気持ち悪/気持悪/
きもちよi /気持ち良/
きもだめs /肝試/
きもいr /肝煎/
きもt /気持/
きもc /気持/
きめつk /決め付/
きめこn /決め込/
きめこm /木目込/決め込/
きむづかs /気難/
きむずかs /気難/
きみわるi /気味悪/
きまぐr /気紛/
きまt /決/
きまr /極/決/
きぼういたs /希望致/
きぶくr /着脹/
きふよm /棋譜読/
きびしi /厳し/
きびs /厳/嚴/
きばr /気張/気晴/
きはどi /際疾/
きはz /気恥/
きはm /窮/
きのうs /機能/
きのr /気乗/
きにいt /気に入/
きにいr /気に入/
きなr /着慣/
きどおs /着通/
きどうs /起動/
きどt /気取/
きどr /気取/
きていどおr /規定通/
きづかu /気遣/
きづかi /気遣/
きづk /気付/築/気附/
きづi /気付/築/
きつk /気付/キツ/
きっs /喫/
きちがi /気違/
きたなs /汚/
きたなk /汚/
きたなi /汚/穢/
きたいどおr /期待通/
きたいくだs /期待下/
きたいs /期待/
きたs /来/來/
きたr /来/來/
きたn /汚/
きたe /鍛/
きそづk /基礎付/
きそくただs /規則正/
きそいあu /競い合/
きそw /競/
きそu /競/竸/
きそt /競/
きそo /競/
きそi /競/
きそh /競/
きそe /競/
きずつk /傷付/
きずt /傷/
きずk /気付/築/
きずi /築/
きじよm /記事読/
きしょくわるk /気色悪/
きしょくわるi /気色悪/
きしょうむずかs /気性難/
きしちかk /岸近/
きしr /軋/轢/
きしn /軋/
きしm /軋/
きざs /兆/
きざn /刻/
きざm /刻/
きさいs /記載/
きこn /着込/
きこm /着込/
きけんn /危険/
きくばr /気配/
ききわk /聞き分/
ききよi /聴き良/
ききやすi /聞き易/
ききのg /聞き逃/
ききにくi /聞き難/
ききとおs /聞き通/
ききとt /聞き取/
ききとr /聞き取/
ききだs /聞き出/効き出/
ききこn /聞き込/
ききこm /聞き込/
ききぐるs /聞き苦/
ききおぼe /聞き覚/
ききいt /聞き入/聴き入/
ききいr /聞き入/
きがまe /気構/
きがつk /気が附/気が付/
きがつi /気が付/気が附/
きがかr /気掛/
きがn /気兼/
きがe /着替/
きかざt /着飾/
きかざr /着飾/
きかe /着換/
きおくちがi /記憶違/
きおくr /気後/
きおw /気負/
きおu /気負/
きおt /気負/
きえさt /消え去/
きえさr /消え去/
きいろk /黄色/
きいろi /黄色/
きあいはいr /気合入/
きあいいr /気合入/
きあi /気合/
きz /着/気/氣/
きy /消/
きw /気/氣/
きt /来/切/着/斬/來/徠/著/
きs /来/記/着/期/帰/來/徠/歸/皈/
きr /切/着/斬/鑽/著/来/
きn /気/来/着/機/氣/著/
きm /決/来/気/來/决/徠/氣/窮/極/着/
きk /聞/効/聴/訊/利/尋/着/切/效/聽/
きi /聞/効/聴/尋/訊/效/聽/利/
きh /気/氣/
きg /気/氣/
きe /消/
きd /気/氣/
きc /切/来/
がんばt /頑張/
がんばr /頑張/
がらi /辛/
がまんできn /我慢出来/
がまんづよk /我慢強/
がまんづよi /我慢強/
がとu /難/
がっしょうづくr /合掌造/
がっこうがえr /学校帰/
がっきつなg /楽器繋/
がたs /難/
がたk /難/
がたi /難/
がぞうとr /画像取/
がさn /重/
がけくずr /崖崩/
がかr /係/
がえんz /肯/
がえんj /肯/
がえs /返/
がえr /帰/歸/皈/
がえn /肯/
がいじんえらb /外人選/
がいs /害/概/
がw /代/
がt /勝/
がr /刈/
がk /書/駆/
がi /買/
がe /替/換/
かんれんづk /関連付/
かんれんz /関連/
かんれんs /関連/
かんれんd /関連/
かんりょういたs /完了致/
かんりがe /管理換/
かんべんねがu /勘弁願/
かんべんねがi /勘弁願/
かんばt /頑張/
かんばs /芳/
かんねんs /観念/
かんとくはじm /監督始/
かんづm /缶詰/
かんちがi /勘違/感違/
かんだかk /甲高/
かんだかi /甲高/疳高/
かんたんすg /簡単過/
かんせいs /完成/
かんすうよb /関数呼/
かんじょうてきすg /感情的過/
かんじまz /漢字混/
かんじとr /感じ取/
かんしんs /感心/
かんしゃいたs /感謝致/
かんしゃs /感謝/
かんしちどおr /環七通/
かんげいいたs /歓迎致/
かんけいs /関係/
かんぐt /勘繰/
かんぐr /勘繰/
かんきわm /感極/
かんがみr /鑑み/
かんがえだs /考え出/
かんがえすg /考え過/
かんがえこn /考え込/
かんがえこm /考え込/
かんがえあw /考え合/
かんがm /鑑/鑒/
かんがh /考/
かんがe /考/攷/
かんいr /缶入/
かんz /感/
かんs /関/冠/關/
かんj /感/
かんg /勘/
かんd /勘/感/
かわばたどおr /川端通/
かわぞi /川沿/
かわくだr /川下/
かわきr /皮切/
かわいs /可愛/可哀/
かわいr /可愛/
かわいk /可愛/
かわいi /可愛/
かわいg /可愛/
かわt /変/變/
かわs /交/躱/
かわr /代/変/換/替/變/
かわk /乾/喝/渇/
かわi /可愛/乾/喝/
かろy /軽/輕/
かろu /辛/
かろn /軽/
かれんn /可憐/
かれr /彼/涸/
かれh /彼/
かれg /彼/
かるがるs /軽々/
かるs /軽/輕/
かるk /軽/輕/
かるi /軽/輕/
かりとt /刈り取/
かりとr /刈取/刈り取/
かりだs /狩り出/借り出/駆り出/
かりたt /駆り立/
かりずm /借り住/仮住/
かりこn /狩り込/刈り込/
かりこm /狩り込/刈り込/
かりきt /借り切/
かりきr /借り切/
かりうk /借り受/
かりいr /借り入/刈り入/
かりあつm /駆り集/
かりあg /借り上/刈り上/
かりn /仮/
からみあu /絡み合/
からまわr /空回/
からs /辛/
からp /空/
からn /絡/
からm /絡/辛/搦/
からk /辛/
からi /辛/鹹/
からg /絡/紮/
かよw /通/
かよu /通/
かよt /通/
かよo /通/
かよi /通/
かよe /通/
かゆs /痒/
かゆm /痒/
かゆk /痒/
かゆi /痒/癢/
かゆg /痒/
かもs /醸/釀/
かむr /被/
かみあt /噛み合/
かまびすs /喧/
かまw /構/
かまu /構/
かまt /構/
かまi /構/
かまh /構/
かまe /構/
かへr /歸/皈/
かぶt /被/
かぶs /被/
かぶr /被/
かばu /庇/
かはs /交/
かのうn /可能/
かねもうk /金儲/
かねもt /金持/
かねもc /金持/
かねばらi /金払/
かねづかi /金遣/
かねそなe /兼ね備/
かねあw /兼ね合/
かねあi /兼ね合/兼合/
かねt /予/
かねr /兼/
かならz /必/
かなづかi /仮名遣/
かなしばr /金縛/
かなぎr /金切/
かなきr /金切/
かなw /叶/敵/適/
かなu /叶/敵/適/
かなt /叶/適/
かなs /悲/哀/愛/
かなe /叶/
かなd /奏/
かどk /角/
かていs /仮定/
かつt /嘗/
かつi /担/
かつg /担/擔/
かつe /餓/
かっこうよk /格好良/
かちこs /勝ち越/
かたわr /傍/
かたりあk /語り明/
かたよt /偏/片寄/
かたよr /偏/片寄/
かたむk /傾/
かたむi /傾/
かたべr /片減/
かたびらk /片開/
かたひらk /片開/
かたどおr /型通/
かたどt /象/
かたどr /象/模/
かたづくr /形作/
かたづk /片付/型付/
かたづi /片付/
かたつk /型付/
かたたたk /肩叩/
かたすg /硬過/
かたじけなi /忝/辱/
かたこr /肩凝/
かたぐるs /堅苦/
かたくるs /堅苦/
かたがw /肩代/
かたかk /肩掛/
かたおもi /片想/片思/
かたえびがたm /片海老固/
かたいr /肩入/
かたt /語/
かたs /固/堅/難/硬/
かたr /語/騙/
かたm /固/傾/硬/
かたk /固/堅/難/硬/
かたi /固/難/堅/硬/
かたd /片/
かぞくづr /家族連/
かぞえいr /数え入/
かぞえあg /数え上/
かぞe /数/數/
かぜとおs /風通/
かぜあt /風当/
かせi /稼/
かせg /稼/
かずすくn /数少/
かずしr /数知/
かずかぎりなk /数限り無/
かずおおk /数多/
かずおおi /数多/
かずあt /数当/
かずk /被/
かすがどおr /春日通/
かすt /掠/
かすr /擦/掠/
かすn /霞/
かすm /霞/掠/
かすk /微/幽/
かじょうがk /箇条書/
かじt /齧/噛/
かじr /噛/囓/齧/
かしまs /姦/
かしづk /傳/
かしつk /貸し付/
かしだs /貸し出/貸出/
かしずk /傅/
かしこs /賢/
かしこm /畏/
かしこk /賢/
かしこi /賢/
かしきt /貸し切/
かしきr /貸し切/
かしかr /貸し借/
かしi /傾/
かしg /傾/
かざりたt /飾り立/
かざt /飾/餝/
かざs /翳/
かざr /飾/錺/餝/
かさねあw /重ね合/
かさなりあt /重なり合/
かさなt /重な/
かさn /重/
かさm /嵩/
かこつk /託/
かこくn /苛酷/
かこいこn /囲い込/
かこいこm /囲い込/
かこw /囲/
かこu /囲/圍/
かこt /喞/囲/
かこn /囲/圍/
かこm /囲/圍/
かこi /囲/
かこe /囲/圍/
かげきすg /過激過/
かげr /翳/陰/
かけめぐt /駆け巡/
かけまわr /駆け回/
かけひk /駆引/
かけどおs /駆け通/
かけつけt /駆け付け/
かけだs /駆けだ/
かけこn /駆け込/
かけこm /駆け込/
かけr /翔/
かぐわs /馨/香/
かくりs /隔離/
かくほs /確保/
かくのごとk /斯くの如/
かくのうs /格納/
かくにんねがi /確認願/
かくにんくだs /確認下/
かくにんおよb /確認及/
かくにんs /確認/
かくていs /確定/
かくづk /格付/
かくちょうたかk /格調高/
かくちょうたかi /格調高/
かくだいs /拡大/
かくs /隠/隱/匿/画/
かくr /隠/隱/
かぎt /限/
かぎr /限/
かきわすr /書き忘/
かきわk /かき分/掻き分/書き分/
かきよごs /書き汚/
かきやすk /書き易/
かきやすi /書き易/
かきもどs /書き戻/書戻/
かきもうs /下記申/
かきもr /書き漏/
かきまz /かき混/掻き混/
かきはじm /書き始/
かきのこs /書き残/
かきぬk /書き抜/
かきぬi /書き抜/
かきならb /書き並/
かきなおs /書き直/
かきなr /かき鳴/掻き鳴/
かきとどm /書き留/
かきとt /書き取/
かきとr /書き取/
かきとb /書き飛/
かきつらn /書き連/
かきつづt /書き綴/
かきつづr /書き綴/
かきつづk /書き続/
かきつたe /書き伝/
かきつくs /書き尽/
かきつk /書き尽/書き付/
かきちr /書き散/
かきだs /書き出/書出/かき出/掻き出/
かきたt /書き立/
かきたs /書き足/
かきぞm /書き初/
かきそんz /書き損/
かきそんj /書き損/
かきそこn /書き損/
かきそe /書き添/
かきすt /書き捨/かき捨/掻き捨/
かきしるs /書き記/
かきこn /書き込/書込/
かきこm /書き込/書込/
かきけs /かき消/掻き消/
かきくわe /書き加/
かきくだs /書き下/
かきくずs /書き崩/
かきかえr /書き換え/
かきかe /書換/書き換/書き替/書き変/
かきおろs /書下/描き下ろ/
かきおよn /書き及/
かきおよb /書き及/
かきおさm /書き納/
かきおくt /書き送/
かきおくr /書き送/
かきおt /書き落/
かきおr /書き下/
かきおk /書き起/書き置/
かきうつs /書き写/
かきいr /書き入/
かきあらわs /書き表/
かきあらたm /書き改/
かきあやまt /書き誤/
かきあやまr /書き誤/
かきあつm /かき集/掻き集/
かきあg /書き上/
かがやk /輝/耀/
かがやi /輝/
かがn /屈/
かがm /屈/
かかわt /拘/
かかわr /拘/関/係/
かかりつk /掛かり付/
かかりすg /掛り過/
かかえこn /抱え込/
かかえこm /抱え込/
かかw /関/係/關/
かかt /掛/係/
かかr /係/掛/罹/
かかg /掲/
かかe /抱/
かおみしr /顔見知/
かおまk /顔負/
かおつk /顔付/
かおだt /顔立/
かおあわs /顔合/
かおあw /顔合/
かおt /薫/
かおr /香/薫/馨/
かえりざk /返り咲/
かえりm /省/顧/
かえt /帰/返/変/却/卻/變/歸/皈/
かえs /返/帰/還/孵/歸/皈/
かえr /帰/返/換/替/歸/皈/還/
かえn /帰/
かえc /帰/歸/皈/
かいまみy /垣間見/
かいまみt /垣間見/
かいまみr /垣間見/
かいまみn /垣間見/
かいまみm /垣間見/
かいほうs /解放/
かいなおs /買い直/
かいどくd /買い得/
かいとういただk /回答頂/
かいとういただi /回答頂/
かいとt /買い取/
かいとr /買取/買い取/
かいだs /買い出/
かいたs /買い足/
かいせんたt /回線断/
かいせつs /開設/
かいせいてつづk /改姓手続/
かいじょうえらb /会場選/
かいしゃがえr /会社帰/
かいしm /買占/
かいさいいたs /開催致/
かいこn /買い込/
かいこm /買い込/
かいけつs /解決/
かいぐi /買い食/
かいがんまわr /海岸回/
かいがんちかk /海岸近/
かいがんちかi /海岸近/
かいがいs /甲斐甲斐/
かいかぶr /買い被/
かいかe /買い換/
かいt /解/觧/
かいs /介/解/会/會/觧/
かあs /母/
かw /変/買/代/換/替/交/變/飼/
かu /買/飼/交/書/支/
かt /買/勝/掛/飼/且/駆/苅/刈/交/驅/克/
かs /貸/課/化/科/淅/
かr /借/苅/刈/枯/狩/仮/駆/嗄/涸/驅/貸/
かo /買/飼/
かn /兼/噛/彼/
かm /噛/咬/嚼/
かk /書/掛/欠/描/駆/賭/掻/架/画/駈/懸/買/畫/缺/翔/驅/繋/斯/闕/舁/
かi /書/買/描/飼/画/欠/掻/畫/缺/交/嗅/
かh /替/換/交/支/飼/代/買/變/
かg /嗅/
かe /変/換/替/買/代/帰/飼/變/歸/皈/易/返/
かc /勝/買/
おんよm /音読/
おんなだいすk /女大好/
おんなぎらi /女嫌/
おんがえs /恩返/
おわらi /お笑/
おわたs /お渡/
おわすr /お忘/
おわかr /お別/
おわかi /お若/
おわt /終/
おわs /御座/在/
おわr /終/終わ/
おろそk /疎/
おろs /卸/下/
おろk /愚/
おれまがr /折れ曲/
おれいもうs /御礼申/
おりまg /折り曲/
おりなs /織り成/
おりたたn /折畳/
おりたたm /折畳/折り畳/
おりこn /折り込/織り込/
おりこm /折込/織込/折り込/織り込/
おりかえs /折り返/折返/
おりs /折/
およろこb /お慶/
およぎこn /泳ぎ込/
およぎこm /泳ぎ込/
およn /及/
およm /御読/
およi /泳/
およg /泳/游/
およb /及/
おやすm /お休/
おもんばかr /慮/
おもむk /赴/趣/
おもむi /赴/
おもみづk /重み付/
おもはy /面映/
おもねr /阿/
おもてむk /表向/
おもてどおr /表通/
おもてだt /表立/
おもすぎr /重過ぎ/
おもすg /重過/
おもしろu /面白/
おもしろs /面白/
おもしろk /面白/
おもしろi /面白/
おもしろg /面白/
おもぐるs /重苦/
おもくるs /重苦/
おもおもs /重々/
おもいつk /思い付/
おもいつi /思い付/
おもいだs /思い出/
おもいたt /思い立/
おもいしr /思い知/
おもいこn /思い込/
おもいこm /思い込/
おもいきt /思い切/
おもいきr /思い切/
おもいおk /思い起/
おもいうk /思い浮/
おもいあg /思い上/
おもw /思/
おもu /思/想/
おもt /思/重/御持/お持/
おもs /重/
おもr /重/
おもo /思/
おもn /主/重/
おもm /重/
おもk /重/
おもi /思/重/想/
おもh /思/想/
おもe /思/想/
おもc /御持/思/お持/
おめn /御目/
おみまi /御見舞/
おまt /お待/
おぼしめs /思召/
おぼえなおs /覚え直/
おぼえこn /覚え込/
おぼえこm /覚え込/
おぼw /憶/
おぼt /覚/
おぼs /覚/思/
おぼr /溺/
おぼe /覚/憶/覺/
おほh /被/覆/
おぶu /負/
おびやk /脅/
おびただs /夥/
おびe /怯/脅/
おひとよs /御人好/
おひさs /御久/お久/
おののk /戦/
おのずかr /自/
おのずt /自/
おのずk /自/
おのz /自/
おのr /己/
おねがi /お願/御願/
おなz /同/
おなj /同/
おどろk /驚/
おどろi /驚/
おどりこn /踊り込/
おどりこm /踊り込/
おどりあk /踊り明/
おどt /踊/踴/
おどs /脅/縅/
おどr /踊/躍/踴/
おどk /脅/
おとろe /衰/
おとなu /訪/
おとなs /大人/
おとどk /御届/お届/
おとだs /音出/
おとずr /訪/
おとしいr /陥/陷/
おとしm /貶/
おとぎr /音切/
おとz /訪/
おとt /劣/
おとs /落/
おとr /劣/
おてあg /お手上/
おつかr /お疲/
おつかi /お使/
おっしゃr /仰/
おっしゃi /仰/
おちつk /落着/落ち着/
おちつi /落ち着/落着/
おちこn /落ち込/
おちこm /落ち込/
おちいt /陥/
おちいr /陥/陷/
おちあu /落ち合/
おちあt /落ち合/
おちあo /落ち合/
おちr /落/堕ち/墜ち/落ち/
おちi /陥/
おだやk /穏/
おだy /穏/穩/
おだt /煽/
おたずn /お尋/
おたけb /雄叫/
おたがi /御互/お互/
おぞまs /悍/鈍/悍ま/
おぞm /悍/鈍/
おそろs /恐/
おそれいr /恐れ入/
おそれr /怐/
おそw /教/襲/
おそu /襲/
おそt /襲/
おそs /遅/遲/
おそr /恐/畏/怖/臆/憶/惧/虞/
おそm /遅/
おそk /遅/遲/
おそi /遅/襲/遲/
おそh /襲/
おしよs /押し寄/
おしながk /お品書/
おしとおs /押し通/
おしつk /押し付/
おしだs /押し出/
おしたおs /押し倒/
おしすすm /推し進/
おしこn /押し込/
おしこm /押し込/
おしえこn /教え込/
おしえこm /教え込/
おしうr /押し売/
おしあk /押し開/
おしr /御知/お知/
おしe /教/
おさなs /幼/
おさなk /幼/
おさなi /幼/
おさっs /御察/
おさえこn /押さえ込/
おさえこm /押さえ込/
おさm /収/治/納/修/收/
おさe /抑/押/圧/壓/
おごそk /厳/嚴/
おごr /傲/奢/驕/
おこのm /お好/
おこなw /行/
おこなu /行/
おこなt /行/
おこなo /行/
おこなi /行/
おこなh /行/
おこなe /行/
おこたt /怠/
おこたr /怠/
おこがましk /烏滸がまし/
おこがましi /烏滸がまし/
おこt /怒/起/興/
おこs /起/遣/起こ/興/
おこr /怒/起/興/
おこn /行/怒/
おこc /怒/
おくりなおs /送り直/
おくりとどk /送り届/
おくりだs /送り出/
おくりこm /送り込/
おくりかえs /送り返/
おくゆk /奥行/
おくぶかs /奥深/
おくぶかk /奥深/
おくふかk /奥深/
おくふかi /奥深/
おくt /送/贈/
おくs /臆/奥/
おくr /送/遅/贈/後/遲/
おくc /送/
おぎなw /補/
おぎなu /補/
おぎなt /補/
おぎなo /補/
おぎなi /補/
おぎなe /補/
おきわすr /置き忘/
おきびk /置き引/
おきぬk /起き抜/
おきにいr /お気に入/
おきなおs /起き直/
おきてやぶr /掟破/
おきづk /お気付/
おきだs /起き出/
おきたt /起き立/
おきざr /置き去/
おきがk /置き掛/
おきかえt /置き換え/
おきかえr /置き換え/
おきかw /置き換/置き変/置き代/
おきかe /置き換/置換/
おきあg /起き上/
おきk /御聞/お聞/
おがn /拝/
おがm /拝/拜/
おかえr /お帰/
おかs /犯/可笑/冒/侵/奇/
おおわらi /大笑/
おおよろこb /大喜/
おおよs /凡/
おおもうk /大儲/
おおむn /概/
おおみだs /大見出/
おおまわr /大回/
おおまちがi /大間違/
おおまk /大負/
おおばんぶるまi /大盤振舞/大盤振る舞/
おおどおr /大通/
おおづm /大詰/
おおちがi /大違/
おおすぎt /大過ぎ/
おおすg /多過/
おおしe /御教/お教/
おおさわg /大騒/
おおぐi /大食/
おおくr /御送/お送/
おおきすg /大き過/
おおがk /大掛/
おおうk /大受/
おおいそがs /大忙/
おおいそg /大急/
おおあばr /大暴/
おおあt /大当/
おおz /大/応/應/
おおw /覆/
おおu /覆/奄/多/被/蔽/
おおt /覆/被/
おおs /多/仰/夛/
おおr /大/
おおm /多/大/夛/
おおk /大/多/夛/
おおj /応/應/
おおi /多/大/覆/夛/
おおh /被/覆/
おおg /大/
おうぼくだs /応募下/
おうばんぶるまi /椀飯振舞/椀飯振る舞/
おうこうs /横行/
おうz /応/應/
おうj /応/應/
おいわi /お祝/
おいはらu /追い払/
おいはらt /追い払/
おいはらi /追い払/
おいぬk /追い抜/
おいぬi /追い抜/
おいつm /追い詰/
おいつk /追い付/
おいつi /追い付/
おいだs /追い出/追出/
おいたt /生い立/追い立/
おいしげt /生い茂/
おいしげr /生い茂/
おいこs /追い越/
おいこn /追い込/老い込/
おいこm /追い込/老い込/
おいかk /追い掛/
おいt /於/
おいs /美味/
おあi /御会/
おz /怖/
おw /終/追/負/
おu /追/負/
おt /落/追/折/負/堕/墜/墮/織/居/
おs /押/推/惜/圧/壓/
おr /降/折/居/下/織/
おp /追/
おo /追/
おm /追/
おk /起/置/於/追/落/惜/怒/擱/
おj /怖/
おi /置/追/負/於/老/生/
おh /負/追/
おe /終/負/追/
おd /怖/
おc /落/
おb /帯/帶/
えんりょねがいi /遠慮願/
えんりょくだs /遠慮下/
えんむすb /縁結/
えんばらi /円払/
えんどおk /縁遠/
えんきr /縁切/
えんz /演/
えんj /演/
えらびだs /選び出/
えらs /偉/
えらn /選/
えらk /偉/
えらi /偉/
えらb /選/
えびがたm /海老固/
えづk /餌付/
えつk /絵付/
えだわかr /枝分/
えだわk /枝分/
えだがr /枝刈/
えだかr /枝刈/
えぐt /抉/
えぐr /刔/抉/
えがたi /得難/
えがk /描/
えがi /描/
えかk /絵描/
えいきょうあたe /影響与/
えいz /映/
えz /得/
えy /得/
えt /得/
えs /得/
えr /得/選/獲/
えn /得/
えm /得/笑/
うんわるk /運悪/
うんわるi /運悪/
うわむk /上向/
うわまわt /上回/
うわまわr /上回/
うわのs /上乗/
うわづm /上積/
うわさどおr /噂通/
うわがk /上書/
うわかk /上書/
うわt /浮/
うわm /上/
うろおぼe /空覚/
うれえr /慯/
うれu /愁/憂/
うれs /嬉/
うれi /愁/憂/
うれe /憂/愁/
うるわs /麗/
うるさk /煩/
うるさi /五月蝿/煩/騒/
うるおu /潤/
うるおs /潤/
うるm /潤/
うりとb /売り飛/
うりだs /売り出/
うりこn /売り込/
うりこm /売り込/
うりきr /売り切/
うりあg /売上/
うらやまs /羨/
うらやm /羨/
うらなu /占/卜/
うらなt /占/
うらなi /占/卜/
うらなg /裏投/
うらなe /占/
うらどおr /裏通/
うらどr /裏取/
うらづk /裏付/
うらぎt /裏切/
うらぎr /裏切/
うらがえt /裏返/
うらがえs /裏返/
うらかえs /裏返/
うらうt /裏打/
うらうc /裏打/
うらn /恨/
うらm /恨/怨/
うらd /裏/
うやまu /敬/
うやうやs /恭/
うめこn /埋め込/
うめこm /埋め込/埋込/
うめk /呻/
うみだs /生み出/
うまれつk /生まれ付/
うまれつi /生まれ付/
うまれかw /生まれ変/
うまれおt /生まれ落/
うまのr /馬乗/
うまs /旨/巧/
うまr /生/
うまm /旨/
うまk /上手/旨/巧/
うまi /旨/上手/巧/美味/
うばいさr /奪い去/
うばw /奪/
うばu /奪/
うばt /奪/
うばo /奪/
うばi /奪/
うばe /奪/
うのm /う飲/鵜飲/鵜呑/
うぬぼr /己惚/自惚/
うなだr /項垂/
うなずk /頷/
うなずi /頷/
うながs /促/
うなt /唸/
うなs /魘/
うなr /唸/
うとn /疎/
うとm /疎/
うとk /疎/踈/
うとi /疎/踈/
うでぐm /腕組/
うでがたm /腕固/
うでおs /腕押/
うつむk /俯/
うつぶs /俯/
うつくs /美/
うつt /移/写/映/遷/冩/寫/暎/
うつs /移/写/映/冩/寫/暎/
うつr /移/写/映/遷/伝染/冩/寫/暎/虚/
うっとうs /欝陶/鬱陶/
うってかわt /打って変/
うったe /訴/
うちよs /打ち寄/
うちやぶt /打ち破/討ち破/
うちやぶr /打ち破/討ち破/
うちほろb /討ち滅/
うちはらu /打ち払/
うちはらt /打ち払/
うちはなs /打ち放/
うちぬk /打ち抜/
うちぬi /打ち抜/
うちながm /打ち眺/
うちなおs /打ち直/
うちなr /打ち鳴/
うちどm /打ち止/
うちとおs /打ち通/
うちとt /打ち取/
うちとr /打ち取/
うちとk /打ち解/
うちつk /打ち付/
うちだs /打ち出/
うちたt /打ち立/
うちじn /討ち死/
うちこわs /打ち壊/
うちころs /打ち殺/
うちこn /打ち込/
うちこm /打込/打ち込/
うちけs /打ち消/
うちくだk /打ち砕/
うちくだi /打ち砕/
うちくずs /打ち崩/
うちきt /打ち切/
うちきr /打ち切/
うちかt /打ち勝/
うちかk /打ち掛/
うちおt /打ち落/
うちおr /打ち下/
うちいr /討ち入/
うちあわs /打合/
うちあw /打ち合/打合/
うちあk /打ち明/
うちあg /打ち上/
うたがw /疑/
うたがu /疑/
うたがt /疑/
うたがi /疑/
うたがe /疑/
うたいだs /歌い出/
うたいあk /歌い明/
うたw /歌/謳/唄/謡/
うたu /歌/唄/唱/謌/謳/謠/謡/
うたt /歌/唄/唱/謌/謡/謳/詠/
うたo /唄/歌/謳/謡/
うたi /歌/謌/謳/唄/謡/
うたe /歌/謌/唄/謡/
うそぶk /嘯/
うせつまt /右折待/
うせつまc /右折待/
うずまk /渦巻/
うずたかk /堆/
うずたかi /堆/
うずくまr /踞/蹲/
うずくm /蹲/
うずk /疼/
うすわらi /薄笑/
うすよごr /薄汚/
うすぐらk /薄暗/
うすぐらi /薄暗/
うすぎたなi /薄汚/
うすぎr /薄切/
うすきみわるk /薄気味悪/
うすきみわるi /薄気味悪/
うすs /薄/
うすr /薄/
うすm /薄/
うすk /薄/
うすi /薄/
うしろむk /後向/後ろ向/
うしろづk /後ろ付/
うしなw /失/
うしなu /失/喪/
うしなt /失/
うしなi /失/
うしおi /牛追/
うしr /後/
うしn /失/
うさんくさi /胡散臭/
うごめk /蠢/蠕/
うごきはじm /動き始/
うごきだs /動き出/
うごk /動/
うごi /動/
うけわたs /受渡/受け渡/
うけもどs /受け戻/
うけもt /受け持/受持/
うけながs /受け流/
うけとt /受け取/受取/
うけとr /受け取/受取/
うけとm /受け止/
うけつk /受け付/受付/
うけつi /受け継/
うけつg /受け継/
うけたまわt /承/
うけたまわr /承/
うけたまw /受け賜/
うけおw /請け負/
うけおu /請け負/請負/
うけおt /請け負/
うけおo /請け負/
うけおi /請け負/
うけおe /請け負/
うけうr /請け売/受け売/
うけいr /受け入/受入/
うけあw /請け合/受け合/
うけあu /請け合/受け合/
うけあt /請け合/受け合/
うけあo /請け合/受け合/
うけあi /請合/請け合/受け合/
うけあe /請け合/受け合/
うきぼr /浮き彫/
うきだs /浮き出/
うきたt /浮き立/
うきしずm /浮き沈/
うきがs /浮貸/
うきうk /浮き浮/
うきあしだt /浮足立/
うきあg /浮き上/
うががi /伺/
うがt /穿/窄/鑿/
うかがw /伺/窺/
うかがu /伺/窺/覘/
うかがt /伺/窺/
うかがo /伺/
うかがi /伺/窺/覘/
うかがe /伺/窺/
うかr /合格/
うかn /浮/
うかb /浮/
うえよs /上寄/
うえつk /植え付/上付/
うえこn /植え込/
うえこm /植え込/
うえd /上/
ういういs /初々/
うz /埋/
うw /植/
うt /打/売/撃/射/討/撲/搏/攴/攵/賣/
うs /失/憂/
うr /売/得/熟/賣/
うn /産/生/膿/
うm /埋/生/産/倦/膿/
うk /受/浮/請/憂/
うi /浮/憂/
うe /飢/植/
うc /打/射/討/撃/売/
いんしょうぶかk /印象深/
いんしょうぶかi /印象深/
いわu /祝/
いわt /祝/
いわr /謂/
いわk /曰/
いわi /祝/
いろわk /色分/
いろどr /彩/
いろづかi /色使/
いろづk /色付/
いろづi /色付/
いろちがi /色違/
いろだs /色出/
いろこk /色濃/
いろあs /色褪/
いろあi /色合/
いれわすr /入れ忘/
いれなおs /入れ直/
いれこn /入れ込/
いれこm /入れ込/
いれかw /入れ替/入れ換/
いれかe /入れ替/入れ換/
いりみだr /入り乱/
いりこn /入り込/
いりこm /入り込/
いりくn /入り組/
いりくm /入り組/
いらだたしi /苛立たし/
いらだt /苛立/
いらだc /苛立/
いらいらしi /苛苛し/
いらu /苛/弄/
いらh /苛/弄/
いらd /苛/
いやしm /卑し/
いやs /卑/癒/
いやn /嫌/
いやg /嫌/
いやd /嫌/
いみぶかk /意味深/
いみぶかi /意味深/
いみづk /意味付/
いみきらu /忌み嫌/
いみs /意味/
いまわs /忌/
いましばらk /今暫/
いましm /戒/誡/
いまいまs /忌々/
いまd /未/
いぶかs /訝/
いぶかr /訝/
いぶs /燻/
いぶr /燻/
いばt /威張/
いばr /威張/
いのちもe /命燃/
いのちとr /命取/
いのちごi /命乞/
いのこr /居残/
いのt /祈/
いのr /祈/
いねむr /居眠/
いならn /居並/
いならb /居並/
いななk /嘶/
いなおt /居直/
いなおr /居直/
いなm /否/
いなk /否/
いどn /挑/
いどm /挑/
いとなn /営/營/
いとなm /営/營/
いとw /厭/
いとu /厭/
いとs /愛/
いとi /厭/
いでたt /出で立/
いてつk /凍てつ/凍て付/
いつわr /偽/僞/
いつづk /居続/
いつくしm /慈/
いつくs /慈/
いつt /五/
いつk /居着/
いっぱんn /一般/
いっそうおいs /一層美味/
いっそうs /一掃/
いっしょn /一緒/
いっしむくi /一矢報/
いっきよm /一気読/
いっかつs /一括/
いっt /言/行/
いっs /逸/
いちりんざs /一輪挿/
いちやづk /一夜漬/
いちもんなs /一文無/
いちばんちかk /一番近/
いちばんちかi /一番近/
いちばんすk /一番好/
いちはやk /一早/
いちとr /位置取/
いちづk /位置付/
いちずk /位置付/
いちじるs /著/
いちぎm /位置決/
いちおs /一押/
いちs /位置/
いだk /抱/
いだi /抱/
いたわr /労/
いたばさm /板狭/
いただk /頂/戴/
いただi /頂/戴/
いたずらn /徒/
いたいたs /痛々/
いたw /労/
いたt /至/到/
いたs /致/痛/
いたr /至/到/致/
いたn /痛/悼/傷/
いたm /痛/炒/傷/悼/愴/慯/
いたk /痛/
いたi /痛/
いたg /痛/
いそがs /忙/
いそs /勤/
いそi /急/
いそg /急/忙/
いずr /何/
いすわt /居座/
いすわr /居座/
いじわるk /意地悪/
いじわるi /意地悪/
いじょうn /異常/
いじっぱr /意地っ張/
いじt /弄/
いじs /維持/
いじr /弄/
いじm /苛/
いじk /弄/
いしなg /石投/
いしとr /石取/
いしづくr /石造/
いしぐm /石組/
いしきs /意識/
いざなu /誘/
いざなt /誘/
いざなi /誘/
いざr /躄/
いさぎよk /潔/
いさぎよi /潔/
いさかi /諍/
いさn /勇/
いさm /諌/勇/
いこうs /移行/
いこu /憩/憇/
いこn /鋳込/
いこm /鋳込/
いこi /憩/憇/
いけn /不可/
いくとおr /幾通/
いくt /幾/
いくr /幾/
いぎもうs /異義申/
いぎぶかi /意義深/
いきわたt /行き渡/
いきわたr /行き渡/
いきわかr /生き別/
いきまk /息巻/
いきまi /息巻/
いきのこt /生き残/
いきのこr /生き残/
いきのb /生き延/
いきぬk /息抜/
いきなやn /行き悩/
いきなやm /行き悩/
いきながr /生き長/
いきどおr /憤/
いきどm /行き止/
いきとどk /行き届/
いきとどi /行き届/
いきづかi /息使/息遣/
いきづm /息詰/行き詰/
いきつづk /生き続/
いきつk /行き付/
いきつi /行き付/
いきちがu /行き違/
いきちがi /行き違/
いきだおr /行き倒/
いきすg /行き過/
いきごn /意気込/
いきごm /意気込/
いきぐるs /息苦/
いきぎr /息切/
いきがk /行き掛/
いきかよu /行き通/
いきかえt /生き返/
いきかえr /生き返/行き帰/
いきかu /行き交/
いきかt /行き交/
いきおいづk /勢い付/
いきおいづi /勢い付/
いきおいこn /勢い込/
いきおいこm /勢い込/
いきおi /勢/
いきうつs /生き写/
いきうm /生き埋/
いきいk /生き生/
いきあu /行き合/
いきあt /行き当/行き合/
いがいt /意外/
いがいn /意外/
いがいd /意外/
いかおなz /以下同/
いかおなj /以下同/
いかt /怒/
いかr /怒/忿/
いかn /以下/何如/如何/
いかg /如何/
いえどm /雖/
いいわたs /言い渡/
いいわすr /言い忘/
いいわk /言い分/
いいよt /言い寄/
いいよr /言い寄/
いいもr /言い漏/
いいまわs /言い回/
いいまぎr /言い紛/
いいまk /言い負/
いいふるs /言い古/
いいふくm /言い含/
いいふr /言い触/
いいひろm /言い広/
いいひらk /言い開/
いいはなt /言い放/
いいはt /言い張/
いいはr /言い張/
いいのこs /言い残/
いいのがr /言い逃/
いいぬk /言い抜/
いいならw /言い習/
いいなおs /言い直/
いいとおs /言い通/
いいつたe /言い伝/
いいつくs /言い尽/
いいつk /言い付/
いいだs /言い出/
いいそこn /言い損/
いいそe /言い添/
いいすg /言い過/
いいしr /言い知/
いいこm /言い籠/
いいけs /言い消/
いいきt /言い切/
いいきr /言い切/
いいきk /言い聞/
いいがたi /言い難/
いいかえs /言い返/
いいかえr /言い替え/
いいかk /言い掛/
いいかe /言い換/言い替/
いいおよn /言い及/
いいおよb /言い及/
いいおとs /言い落/
いいおくt /言い送/
いいおくr /言い送/
いいおk /言い置/
いいおi /言い置/
いいあるk /言い歩/
いいあるi /言い歩/
いいあらわs /言い表/
いいあらたm /言い改/
いいあらそw /言い争/
いいあらそu /言い争/
いいあらそt /言い争/
いいあらそo /言い争/
いいあらそe /言い争/
いいあやまt /言い誤/
いいあやまr /言い誤/
いいあu /言い合/
いいあt /言い当/言い合/
いいあo /言い合/
いいあi /言い合/
いいあe /言い合/
いあわs /居合/
いあw /居合/
いあu /居合/
いz /居/
いy /癒/居/
いw /言/云/
いu /言/云/謂/
いt /言/行/入/居/射/云/炒/煎/凍/要/
いs /逸/
いr /入/居/要/煎/射/容/炒/鑄/淹/言/鋳/
いo /言/
いn /居/要/言/
いm /居/忌/
いk /行/生/活/逝/言/往/
いi /言/良/云/可/好/
いh /云/言/
いe /言/癒/云/
いd /出/
いc /言/行/
あんないもうs /案内申/
あんないいたs /案内致/
あんぜんd /安全/
あんしんくだs /安心下/
あんしんs /安心/
あんz /案/
あんj /案/
あんd /編ん/
あわれm /憐/
あわだt /泡立/粟立/
あわただs /慌/
あわせもt /合わせ持/
あわおどr /阿波踊/
あわt /慌/
あわs /合/併/
あわr /憐/哀/閔/
あわk /淡/
あわi /淡/
あるきまわr /歩き回/
あるきだs /歩き出/
あるk /歩/
あるi /歩/或/
ありがとu /有難/
ありがたk /有難/
ありがたi /有難/
ありうr /有り得/
あらわs /表/現/著/
あらわr /現/表/
あらたn /新/
あらたm /改/更/
あらそu /争/爭/
あらそt /争/爭/
あらそi /争/爭/
あらそe /競/
あらすg /粗過/
あらけずr /荒削/
あらがu /抗/争/爭/諍/
あらがo /抗/争/爭/諍/
あらがk /荒書/
あらがi /抗/争/爭/諍/
あらがe /抗/争/爭/諍/
あらかじm /予/豫/
あらいながs /洗い流/
あらいだs /洗い出/
あらあらs /荒々/
あらz /非/
あらw /表/現/洗/
あらu /洗/
あらt /新/洗/
あらs /粗/
あらr /荒/
あらp /荒/
あらo /洗/
あらk /荒/粗/
あらj /非/
あらi /洗/荒/粗/麁/
あらg /荒/
あらe /洗/
あらb /荒/
あゆみよr /歩み寄/
あゆn /歩/
あゆm /歩/
あやまt /誤/謝/過/
あやまr /誤/謝/
あやまc /過/誤/
あやつt /操/
あやつr /操/
あやu /危/
あやs /怪/妖/恠/
あやb /危/
あめふr /雨降/
あみかk /網掛/
あみあg /編み上/
あまやどr /雨宿/
あまもr /雨漏/
あまねk /遍/普/
あまっさe /剰/
あまずp /甘酸/
あまくだr /天下/
あまぎごe /天城越/
あまy /甘/
あまt /余/餘/甘/
あまs /甘/余/餘/
あまr /余/餘/
あまn /甘/
あまm /甘/
あまk /甘/
あまi /甘/
あまe /甘/
あぶなs /危/
あぶなk /危/
あぶなi /危/
あぶなg /危/
あぶt /焙/
あぶr /炙/炮/焙/溢/
あぶn /危/
あふr /溢/
あびs /浴/
あばr /暴/
あばk /暴/
あばi /暴/
あなねらi /穴狙/
あなどt /侮/
あなどr /侮/
あなうm /穴埋/
あともどr /後戻/
あとまわs /後回/
あとばらi /後払/
あとづk /後付/
あとすこs /後少/
あとかたづk /後片付/後片づ/
あとおs /後押/
あとd /後/
あてはまr /当て嵌/
あてはm /当て嵌/
あてながk /宛て名書/
あてこn /当て込/
あてこm /当て込/
あてt /宛/
あつらh /誂/
あつらe /誂/
あつまr /集/集ま/
あつぐるs /暑苦/
あつくるs /暑苦/
あつぎr /厚切/
あつかw /扱/
あつかu /扱/
あつかt /扱/
あつかo /扱/
あつかi /扱/
あつかe /扱/
あつu /暑/
あつs /暑/厚/熱/
あつm /集/厚/纂/蒐/輯/聚/
あつk /厚/暑/熱/篤/扱/
あつi /厚/暑/熱/
あつg /暑/
あったk /暖/
あだうt /仇打/
あたらs /新/
あたまだs /頭出/
あたまがk /頭書/
あたまうt /頭打/
あたたかi /暖/
あたたm /暖/温/
あたたk /暖/温/
あたu /能/
あたt /当/中/辺/
あたr /辺/当/新/中/邊/邉/
あたh /与/
あたe /与/與/
あそんd /遊ん/
あそびほうk /遊び惚/
あそびあk /遊び明/
あそn /遊/
あそb /遊/游/
あせにぎr /汗握/
あせt /焦/
あせr /焦/
あずかt /与/
あずk /預/
あじちがi /味違/
あじだs /味出/
あじけなi /味気無/
あじけs /味消/
あじきなi /味気無/
あじw /味/
あしまわs /足回/
あしまわr /足回/
あしぶm /足踏/
あしふm /足踏/
あしなr /足慣/
あしなm /足並/
あしどr /足取/
あしとr /足取/
あしでまとi /足手纏/
あししげk /足繁/
あしk /悪/惡/
あざやk /鮮/
あざむk /欺/
あざけr /嘲/
あざy /鮮/
あさはやk /朝早/
あさはやi /朝早/
あさづk /浅漬/
あさすg /浅過/
あさぐろi /浅黒/
あさがえr /朝帰/
あさおk /朝起/
あさいr /浅煎/
あさt /漁/
あさs /浅/
あさr /漁/
あさk /浅/淺/
あさi /浅/淺/
あこがr /憧/
あこu /赤/
あげt /上/
あけわたs /明け渡/
あけくれr /明け暮れ/
あぐm /倦/
あくめいたかk /悪名高/
あくめいたかi /悪名高/
あくみょうだかi /悪名高/
あきらm /諦/
あきらk /明/
あきやすm /秋休/
あきばr /秋晴/
あきなu /賈/商/
あきr /明/呆/煥/顕/
あがりこn /上がり込/
あがりこm /上がり込/
あがなu /購/贖/
あがなi /贖/購/
あがt /上/
あがr /上/
あがm /崇/
あかるi /明/
あからm /赧/
あかs /證/赤/
あかr /明/灯/赤/
あかp /赤/
あかn /赤/
あかk /赤/紅/
あかi /赤/紅/赫/
あおむk /仰向/
あおばどおr /青葉通/
あおじろs /青白/
あおじろk /青白/
あおじろi /青白/
あおt /煽/
あおr /煽/
あおp /青/
あおk /青/蒼/
あおi /青/蒼/碧/仰/
あおg /仰/
あえt /敢/
あえg /喘/
あいようs /愛用/
あいまt /相俟/
あいはんs /相反/
あいのr /相乗/
あいなr /相成/
あいつらn /相連/
あいつi /相次/
あいつg /相次/
あいたいs /相対/
あいしあw /愛し合/
あいしあu /愛し合/
あいしあt /愛し合/
あいしあo /愛し合/
あいしあi /愛し合/
あいしあe /愛し合/
あいさつがわr /挨拶代/
あいことn /相異/
あいかわr /相変/
あいかw /相変/
あいうt /相討/
あいいr /相容/
あいs /愛/
あいi /相/
あw /合/会/併/逢/會/遭/
あu /合/会/逢/遭/遇/會/
あt /当/会/合/有/宛/蓬/逢/遭/會/當/充/該/
あs /悪/褪/惡/
あr /有/荒/在/或/
あo /合/会/會/
あn /編/
あm /編/
あk /空/開/明/飽/厭/倦/飫/
あi /合/会/空/悪/開/逢/遭/相/會/
あh /合/會/
あg /上/挙/揚/擧/
あe /会/合/逢/敢/遭/會/和/
あb /浴/
;; okuri-nasi entries.
! /！/感嘆符/
!! /！！/
!= /≠/
" /″/“/”/〃/
# /#1/#3/#2/＃/#0/#4/
#% /#1％/
#) /#1）/
#,# /#1，#1/#1、#1/
#-# /#1〜#1/#1-#1/
#-#-# /#1−#1−#1/
#. /#1．/
#.# /#1．#1/#0月#0日/
#/# /#0月#0日/#1／#1/#1月#1日/
#:# /#1：#1/
#F /#1Ｆ/
#cm /#1ｃｍ/
#copy /#0部/
#d /#0日/
#f /#0階/#1Ｆ/#1階/
#feet /(skk-gadget-units-conversion "feet" (string-to-number (car skk-num-list)) "cm")/
#fu /#9歩/
#g /#0G/#1ギガ/
#gatu /#1月/
#gatu#niti /#1月#1日/
#giga /#1ギガ/
#gin /#9銀/
#gyoku /#9玉/
#h /#0時間/#1時/#0時/
#h#m /#0時#0分/
#hi /#9飛/
#hisha /#9飛車/
#hu /#9歩/
#inch /#1インチ/(skk-gadget-units-conversion "inch" (string-to-number (car skk-num-list)) "cm")/(skk-gadget-units-conversion "inch" (string-to-number (car skk-num-list)) "feet")/
#ji /#1時/
#k /#0金/
#ka /#1日/
#kaku /#9角/
#kei /#9桂/
#kg /1#ｋｇ/
#kin /#9金/
#kyou /#9香/
#m /#0Mbytes/#1ｍ/#0月/
#m# /#0月#0日/
#m#d /#0月#0日/
#mega /#1メガ/
#mei /#1名/
#mile /(skk-gadget-units-conversion "mile" (string-to-number (car skk-num-list)) "km")/(skk-gadget-units-conversion "mile" (string-to-number (car skk-num-list)) "yard")/
#min /#0分/
#mm /#1ｍｍ/#2ｍｍ/
#narigin /#9成銀/
#narikei /#9成桂/
#narikyou /#9成香/
#nen /#1年/
#nichi /#1日/
#page /#0 ページ/#0ページ/#1ページ/
#room /#0部屋/
#ryu /#9龍/
#ryuu /#9竜/
#t /#1ｔ/#0坪/
#to /#9と/
#uma /#9馬/
#x# /(skk-times)/
#y /#0年/
#y#m#d /#0年#0月#0日/
#yard /(skk-gadget-units-conversion "yard" (string-to-number (car skk-num-list)) "cm")/(skk-gadget-units-conversion "yard" (string-to-number (car skk-num-list)) "feet")/
#yen /#1円/#0円/
#、# /#1、#1/
#、#てん /#1、#1点/
#、#にち /#1、#1日/
#、#にん /#1、#1人/
#、#ねん /#1、#1年/
#、#ふん /#1、#1分/
#、#まい /#1、#1枚/
#、#まん /#1、#1万/
#。 /#1．/
#。# /#1．#1/#1.#1/
#。#。# /#1．#1．#1/
#。#にん /#1．#1人/
#。#めが /#1.#1Mbyte/
#：# /#1：#1/
#ー# /#1―#1/
#い /#0位/#1位/
#えん /#1円/#0円/#0えん/
#おうふく /#1往復/
#おく /#1億/
#おく#せんまん /#1億#1千万/
#おくねんまえ /#3億年前/
#か /#1日/#1価/#0日/
#かい /#1回/#0回/#1階/#0階/#2階/#4階/#3回/#1Ｆ/#3階/
#かいせい /#0回生/#1回生/#3回生/
#かいせん /#0回線/#1回戦/
#かいはつ /#3開発/
#かいめ /#0回目/#3回目/
#かかん /#1日間/
#かげつ /#1ヶ月/#0 ヶ月/#0ヶ月/#3ヶ月/#0カ月/
#かこく /#0カ国/#2カ国/
#かしょ /#0箇所/#1ヶ所/#1個所/#0ヶ所/#0カ所/#2カ所/
#かじょう /#2カ条/
#かねん /#0カ年/
#かめ /#1日目/
#から# /#1〜#1/
#からむ /#1カラム/
#かん /#1巻/
#がい /#0階/#1階/
#がつ /#0月/#1月/#2月/#3月/
#がつ#か /#1月#1日/#0月#0日/
#がつ#にち /#1月#1日/#0月#0日/#2月#1日/#2月#2日/
#がつごう /#0月号/#3月号/#1月号/
#がつちゅう /#0月中/
#がつまつ /#1月末/
#がめん /#1画面/
#き /#3期/#1期/#0機/#0期/
#きょく /#1曲/
#きろ /#1キロ/#2キロ/#1Km/#1kbyte/#1kg/#1Ｋ/#1ｋ/
#きろばいと /#1kb/#1kbytes/
#きん /#9金/
#ぎが /#1Ｇ/
#ぎょう /#0行/#1行/#2行/
#ぎょうめ /#0行目/#1行目/
#くみ /#1組/
#ぐらむ /#1グラム/
#けいとう /#0系統/#1系統/
#けた /#3桁/#1桁/#2桁/#0桁/
#けん /#0 件/#0件/#1件/#1軒/#3間/#3軒/
#けんめ /#1軒目/
#げんそく /#1原則/
#げんめ /#1限目/
#こ /#0個/#1個/#3個/
#こう /#0項/#0校/#1項/
#こうかんけい /#0項関係/
#こま /#0コマ/#1コマ/
#ご /#0語/#1語/
#ごう /#4号/#1号/#1號/#2號/#3號/#2号/
#ごうかん /#0号館/#1号館/
#ごうき /#1号機/
#ごうしつ /#4号室/
#ごうしゃ /#0号車/#1号車/
#ごうせん /#0号線/
#さい /#0歳/#1才/#1歳/#2歳/#3歳/
#さつ /#1冊/#3冊/#0冊/
#さつめ /#3冊目/
#し /#0氏/
#しあい /#0試合/
#しつ /#0室/#1室/
#しゃ /#1者/
#しゅ /#3種/#0種/#1種/
#しゅう /#1週/
#しゅうかん /#1週間/#0週間/#3週間/
#しゅうかんご /#0週間後/
#しゅうねん /#1周年/#3周年/
#しゅるい /#0種類/#1種類/#2種類/
#しょう /#1章/#0章/
#しょう#せつ /#1章#1節/
#しょく /#1色/#0色/
#しん /#0進/#1進/#3進/
#しんすう /#0進数/#1進数/#3進数/
#しんほう /#0進法/#1進法/#3進法/
#しんぽう /#4進法/
#じ /#0時/#1時/#2時/#0次/#3次/#1次/#3時/#0字/
#じ#ふん /#0時#0分/#1時#1分/
#じ#ぷん /#0時#0分/
#じかい /#1次会/#3次会/
#じかん /#0時間/#1時間/#2時間/#3時間/
#じかんはん /#1時間半/
#じげん /#1次元/#0次元/
#じごろ /#0時頃/
#じはん /#1時半/#0時半/
#じみゃく /#3次脈/
#じゅう /#1重/#3重/#0重/
#じょ /#2女/
#じょう /#3畳/#0条/#0畳/#0乗/#1畳/
#すう /#1数/
#すうか /#3数花/
#すうせい /#1数性/
#すてっぷ /#1ステップ/
#すん /#2寸/
#せいき /#0世紀/#1世紀/
#せいりょく /#3勢力/
#せだい /#1世代/
#せだいめ /#3世代目/
#せっと /#1セット/
#せつ /#1節/
#せん /#1千/
#せんえん /#1千円/
#せんち /#1cm/#1センチ/
#せんまん /#3千万/
#そう /#1漕/#3層/#0相/#0層/
#そうさ /#1走査/
#ぞく /#1属/
#だい /#0台/#0代/#1台/#3代/#3題/#0題/#1代/#3台/
#だいめ /#3台目/
#だん /#3段/#0段/
#だんかい /#1段階/
#だんぐみ /#0段組み/
#だんめ /#1段目/#0段目/
#ち /#0値/
#ちっぷ /#1チップ/
#ちょうめ /#1丁目/#0丁目/#2丁目/#3丁目/
#つ /#1つ/#0つ/#2つ/#3つ/
#つう /#1通/#0通/
#つうめ /#1通目/
#つき /#3月/#0月/
#つぼ /#1坪/
#つめ /#1つ目/
#てん /#0点/#1点/
#とう /#1等/#0頭/
#とうしん /#1頭身/
#とおり /#1通り/
#ど /#1度/#3度/#0度/
#どめ /#1度目/#3度目/#4度目/
#にち /#1日/#0日/#3日/
#にちかん /#3日間/#0日間/
#にちぶん /#1日分/
#にん /#0人/#1人/#3人/
#にんぐみ /#1人組/
#にんぶん /#0人分/#1人分/
#にんめ /#3人目/
#ねん /#1年/#0年/#3年/
#ねん#がつ#にち /#0年#0月#0日/#1年#1月#1日/
#ねんかん /#0年間/#1年間/
#ねんご /#3年後/
#ねんせい /#0年生/#3年生/#1年生/
#ねんど /#0年度/#1年度/#2年度/
#ねんはん /#0年半/
#ねんまえ /#3年前/#1年前/
#ねんめ /#0年目/#1年目/
#はいめ /#杯目/
#はく /#0泊/#1泊/#0拍/#3泊/
#はく#か /#3泊#3日/
#はこ /#1箱/
#ばい /#1倍/#1杯/#3倍/
#ばいすう /#1倍数/
#ばいと /#1バイト/#0バイト/
#ばん /#3晩/#1番/#0番/#2番/
#ばんだい /#0番台/
#ばんち /#0番地/
#ばんめ /#0番目/#1番目/#4番目/#3番目/
#ぱーせんと /#1％/
#ぱく /#0拍/#0泊/
#ひき /#1匹/
#ひゃくねん /#3百年/
#びっと /#1ビット/
#びょう /#0秒/#1秒/#3秒/
#びょうし /#1拍子/
#びん /#1便/
#ぴょう /#1票/
#ふくろ /#1袋/
#ふん /#1分/#0分/#3分/
#ふん#びょう /#1分#1秒/
#ぶ /#0部/#3部/
#ぶもん /#0部門/
#ぶんかつ /#3分割/
#ぶんや /#0分野/
#ぷん /#0分/#1分/
#へるつ /#1Hz/
#へん /#0編/#1片/#0辺/#1編/
#ぺーじ /#1ページ/
#ほん /#0本/#1本/#4本/#3本/
#ほんだて /#1本立て/
#ぼん /#1本/#2本/#0本/
#ぽん /#1本/#0本/
#まい /#1枚/#0枚/#2枚/#3枚/
#まいぶん /#0枚分/
#まいめ /#2枚目/
#まん /#1万/#0万/
#まんえん /#1万円/#0万円/
#まんねん /#3万年/
#みり /#1mm/
#めーとる /#1メートル/
#めい /#0名/#1名/
#めが /#1Mbyte/#1メガ/
#めん /#1面/
#もじ /#1文字/#0文字/#3文字/
#もじめ /#0文字目/#1文字目/#3文字目/
#もん /#1問/
#り /#1人/
#りーる /#1リール/#リール/
#りん /#1輪/
#りんか /#3輪花/
#れつ /#0裂/#1裂/#0列/
#れつめ /#3列目/
#れん /#0連/
#れんきゅう /#1連休/
#れんぱい /#1連敗/
#ろばん /#0路盤/
#わ /#0話/#1話/
#わり /#0割/#3割/#1割/
#わりびき /#1割り引き/#1割引/#3割引/
$ /＄/¢/£/
% /％/‰/パーセント/
& /＆/アンド/アンパサンド/
' /′/‘/’/アポストロフィ/
'' /″/”/
( /（/［/『/【/〔/
(#) /（#2）/
(#)#-# /（#1）#1-#1/
) /）/］/』/】/
* /＊/※/×/
+ /＋/╋/┼/┿/╂/
+- /±/
, /，/、/
- /―/ー/−/━/ … /─/〜/マイナス/‐/
-- /―/
--- /――/―/
-> /→/
-| /┤/┫/
. /．/・/…/。/
.# /．#1/
.. /‥/
... /…/・・・/……/
...... /……/
/ /／/÷/
/= /≠/
0 /０/
1 /一/１/壱/弌/壹/
10 /十/
100 /百/
1000 /千/
109 /１０９/
15 /十五/
17 /十七/
2 /２/二/弍/
20 /二十/
3 /三/３/
3.5 /３．５/
3dots /・・・/
3f /３Ｆ/
3star /★ ★ ★/
4 /４/四/
4.0.3 /４．０．３/
4.3bsd /４．３ＢＳＤ/
4f /４Ｆ/
5 /５/五/
6 /６/六/
7 /７/七/
77 /七十七銀行/
8 /８/八/
8mm /８ｍｍ/
9 /９/九/
: /：/：―）/…/:-)/:^)/
:- /÷/
< /〈/＜/《/←/⊂/
<- /←/
<-> /⇔/
<< /《/≪/
<= /≦/
<=> /⇔/
<> /≠/◇/
<か /課/化/
<がた /型/
<く /区/
<くん /君/
<けん /県/
<ご /後/
<さま /様/
<し /市/氏/
<しつ /室/
<すう /数/
<せい /性/製/
<せん /線/
<せんせい /先生/
<てい /邸/
<てき /的/
<てん /点/
<と /都/
<どの /殿/
<は /派/
<はい /杯/
<ばん /版/
<ふ /府/
<ぶ /部/
<ぶん /文/
<まち /町/
<めい /名/
<よう /用/
= /〓/≡/＝/
=: /≒/
=> /》/⇒/
=| /〒/
> /〉/＞/→/》/⇒/≫/
>= /≧/
>> /》/≫/
>あん /案/
>いき /域/
>いち /市/
>いろ /色/
>いん /員/
>えき /駅/
>えん /園/
>おやかた /親方/
>おん /音/
>か /下/化/科/課/可/
>かい /回/界/会/
>かく /核/
>かた /型/方/
>かん /感/間/艦/館/観/官/管/
>が /絵/画/
>がい /街/外/
>がた /型/
>がわ /側/
>き /器/機/
>きゅう /級/
>きょく /局/
>く /区/
>くみ /組/
>くん /君/
>ぐみ /組/組み/
>ぐん /郡/群/
>け /家/
>けい /系/型/
>けん /研/県/権/圏/
>こ /個/
>こく /国/
>ご /後/語/
>ごう /号/
>ごと /毎/
>ごろ /頃/
>さ /差/
>さき /先/
>さく /策/
>さま /様/
>ざい /剤/
>し /市/氏/誌/師/子/
>しき /式/
>した /下/
>しつ /室/
>しゃ /者/
>しゅう /集/州/
>しょ /書/所/
>しょう /症/証/省/
>じ /時/
>じてん /辞典/
>じゅう /中/
>じゅつ /術/
>じゅん /順/
>じょう /上/状/場/
>じん /陣/人/
>すう /数/
>ず /図/
>せい /制/性/生/製/
>せん /線/
>せんせい /先生/
>ぜんたい /全体/
>そう /層/相/槽/奏/
>そく /則/
>ぞく /族/
>たい /帯/隊/
>たち /達/
>だい /台/大/代/
>だいがく /大学/
>だん /談/団/
>ち /値/地/
>ちゅう /中/注/
>ちょう /町/長/調/
>つい /対/
>つう /通/
>つき /付き/
>てい /邸/
>てき /的/
>てん /点/
>と /都/
>とう /等/
>ど /度/
>どう /道/
>どうし /同士/
>どの /殿/
>ない /内/
>など /等/
>のう /能/
>は /派/
>はい /杯/
>はば /幅/
>はん /藩/半/班/版/
>ばい /倍/
>ばん /版/盤/
>ひ /比/
>ひょう /表/票/
>ひん /品/
>び /日/
>ふ /府/
>ふう /風/
>ぶ /部/
>ぶつ /物/
>ぶん /分/文/
>へん /編/
>べつ /別/
>べん /弁/
>ほう /法/
>まい /枚/
>まえ /前/
>まち /町/
>むら /村/
>め /目/
>めい /名/
>めん /面/
>もく /目/
>もと /元/
>や /屋/
>やく /訳/
>よう /用/
>よく /翼/
>らん /欄/
>りつ /率/
>りょう /料/量/
>りょく /力/
>るい /類/
>れい /例/
>れき /歴/
>ろく /録/
>ろん /論/
>わ /羽/
>わき /脇/
? /？/
?か /化/科/課/下/可/
?かい /会/回/
?かん /感/
?く /区/
?こ /個/
?ご /後/語/
?さ /差/
?さき /先/
?し /子/市/氏/
?しゃ /者/
?しょ /書/
?じ /時/
?じょう /上/
?じん /人/
?ず /図/
?せい /性/
?ち /値/
?ちゅう /中/
?てき /的/
?てん /点/
?ど /度/
?ない /内/
?はん /版/
?ひ /比/
?ひん /品/
?ぶ /部/
?まえ /前/
?めい /名/
?もと /元/
?や /屋/
?よう /用/
?りつ /率/
@ /＠/
A /Ａ/Å/
ACM /Abstract Control Model;USB/
AIDS /エイズ/後天性免疫不全症候群/
ALFEE /アルフィー/
AND /論理積/
AP /アプリケーション/
Adam /アダム/
Alpha /Α/
America /アメリカ/
April /エイプリル/
Arbeit /アルバイト/
Atena /アテナ/
Audrey /オードリー/
Australia /オーストラリア/
B-spline /Ｂ−スプライン/
BBQ /バーベキュー/
BGM /ＢＧＭ/
BKK /バンコク/
Bach /バッハ/
Barbara /バーバラ/
Barium /バリウム/
Bartholin's-glands /バルトリン腺/
Benedict /ベネディクト/
Benz /ベンツ/
Berkeley /バークレー/
Beryl /ベリル/
Beta /Β/
Bezier /ベジエ/
Biff /ビフ/
Bonjours /ボンジュール/
Booby /ブービー/
Box /□/
Brown /ブラウン/
Budapest /ブダペスト/
C /Ｃ/
CD /ＣＤ/コンパクト・ディスク/Compact Disk/
CDC /Communication Device Class;USB/
CISC /複雑命令セット計算機/Complex Instruction Set Computer/
CM /ＣＭ/
CORBA /Common Object Request Broker Architecture;アプリケーションを異なる言語・プロセス・OS間で動作させるための規格。プログラミング言語がCORBAを利用するためにIDLを使う。OMGが策定した。/
CS /コミュニケーションサーバ/
CTC /伊藤忠テクノサイエンス/
Caesar /カエサル/シーザー/
Calbee /カルビー/
Camille /カミーユ/
Carter /カーター/
Chanel /シャネル/
Charlie /チャーリー/
Chi /Χ/
Chlamydia /クラミジア/
Christ /キリスト/
Christmas /クリスマス/
Claire /クレール/
Claudel /クローデル/
Constantine /コンスタンチン/
Crea /クレア/
DB /データベース/ＤＢ/
DBA /データベース管理者/
DBMS /dbms/
DOM /Document Object Model;W3C/
DTD /Document Type Definition;XMLドキュメントのデータ構造を定めたもの。/
Daffy /ダフィー/
Dagger /ダガー/
Delta /Δ/
Deutschlant /ドイツ/独逸/
Diamond /◇/
Dick /ディック/
Disney /ディズニー/
Edinburgh /エディンバラ/
Edward /エドワード/
Egypt /エジプト/
Elizabeth /エリザベス/
Epsilon /Ε/
Eskimo /エスキモー/
Esquimau /エスキモー/
Eta /Η/
Europa /ヨーロッパ/
Eve /イブ/
Evil /エビル/
F /Ｆ/
FAX /ＦＡＸ/
FEN /極東放送/Far East Network/
FSF /Free Software Foundation/
Fourier /フーリエ/
Franken /フランケン/
Frankenstein /フランケンシュタイン/
G /Ｇ/
GHQ /総司令部/連合国軍総司令部/General Headquarters/
GUI /グラフィカルユーザインタフェース/ＧＵＩ/
GW /ゲートウェイ/
Gamma /Γ/
George /ジョージ/
Giants /ジャイアンツ/
Giraffu /ジラフ/
Goddard /ゴダール/
Greek /Α/Β/Γ/Δ/Ε/Ζ/Η/Θ/Ι/Λ/Κ/Μ/Ν/Ξ/Ο/Π/Φ/Σ/Ρ/Χ/Τ/Υ/Ω/Ψ/
Grimm /グリム/
Guile /ガイル/
HP /ヒューレット・パッカード/
HTML /Hyper Text Markup Language;W3C/
Harmoniodeon /ハルモニオデオン/
Harvard /ハーバード/
Henry /ヘンリー/
Hudson /ハドソン/波怒村/
Hungarian /ハンガリアン/
Hungary /ハンガリー/
IBM /ＩＢＭ/アイ・ビー・エム/日本アイ・ビー・エム株式会社/
ICU /国際基督教大学/
IDFT /逆離散フーリエ変換/
IDL /Interface Definition Language;CORBAオブジェクトをコールするために必要な情報を提供する。/
ISO /国際標準化機構/
Indian /インディアン/
Internet /インターネット/
Iota /Ι/
Itriangle /▽/
JICC /ＪＩＣＣ出版/
JIP /ＪＩＰ/日本電子計算/
JISU /ＪＩＳＵ/日本工業標準調査会/
Jadeite /ジェダイト/
James /ジェームス/
Jamiroquai /ジャミロクワイ;ミュージシャン/
Jane /ジェーン/
Jenny /ジェニー/
Jimmy /ジミー/
Joe /ジョー/
John /ジョン/
Julian /ジュリアン/
Julie /ジュリー/
Jupiter /ジュピター/
Kappa /Κ/
Katze /カッツェ/
Kiki /キキ/
Knuth /クヌース/
Kodak /コダック/
Kunzite /クンツァイト/
L /£/Ｌ/
LD /ＬＤ/
LPF /ローパス・フィルタ/
Lagrange /ラグランジュ/
Lambda /Λ/λ/
Laura /ローラ/
Lebesgue /ルベーグ/
Lilliput /リリパット/
Linus /ライナス/
Lolita /ロリータ/
London /ロンドン/
Los_Angeles /ロサンゼルス/
Lucy /ルーシー/
Lynch /リンチ/
M /Ｍ/
ML /メイリングリスト/メーリングリスト/
MO /ＭＯ/
MPT /マルチポートトランシーバー/
MSA /ＭＳＡ/マイクロソフトウェア　アソシエイツ/マイクロソフトウェアアソシエイツ/日米相互防衛援助協定/Micro Software Associates/
MTU /ＭＴＵ/
Macaroni /マカロニ/
Mach /マッハ/
Manhattan /マンハッタン/
Marcica /マーシカ/
Marie /マリ/マリー/
Mario /マリオ/
Mars /マーズ/
Martha /マーサ/
Martin /マーティン/
Mary /メアリ/
Melby /メルビー/
Mercury /マーキュリー/メルクリウス/
Miami /マイアミ/
Michael /マイケル/
Mickey /ミッキー/
Microsoft /マイクロソフト/
Milky /ミルキー/
Minerva /ミネルヴァ/
Motorola /モトローラ/
Mu /Μ/
NEC /日本電気/ＮＥＣ/
NFS /Network File System/
NG /ＮＧ/
NHK /ＮＨＫ/
NRT /成田/
NTT /日本電信電話/
NY /ニューヨーク/
Nausicaa /ナウシカ/
Nephrite /ネフライト/
Neuman /ノイマン/フォン・ノイマン/ヤーノッシュ・フォン・ノイマン/
Newsweek /ニューズウィーク/
Nijmegen /ナイメヘン/
Norman /ノルマン/
Norway /ノルウェー/
Nu /Ν/
OA /ＯＡ/
OK /ＯＫ/
OMG /the Object Management Group;CORBA策定のためのフレームワークを提供するために組織された。/(concat "http:\057\057www.omg.org\057")/
OR /オペレーションズリサーチ/論理和/
OS /オペレーティングシステム/ＯＳ/
Olympic /オリンピック/
Omega /Ω/
Omicron /Ο/
Oo /◎/
PC /ＰＣ/
POA /Portable Object Adapter/
PS /P.S./
Palabora /パラボーラ/
Patty /パティ/
Peanuts /ピーナッツ/
Peter /ピーター/ピョートル/ペーター/
Phi /Φ/
Philips /フィリップス/
Pi /Π/
Polaroid /ポラロイド/
Psi /Ψ/
Q /Ｑ/
R /Ｒ/
R246 /２４６号線/玉川通り/厚木街道/国道２４６号線/
RDB /関係データベース/
RE /正規表現/
RISC /限定命令セット計算機/Restricted Instruction Set Computer/
RPC /Remote Procedure Call/
RPG /ロールプレイングゲーム/
RSI /反復運動過多損傷/Repetitive Strain Injury/
RT /ＲＴ/
Rana /ラナ/
Rho /Ρ/
Richard /リチャード/
Ritchie /リッチー/
Robert /ロバート/ロベルト/
Robin /ロビン/
Rose /ローズ/
Russia /А/Б/В/Г/Д/Е/Ё/Ж/З/И/Й/К/Л/М/Н/О/П/Р/С/Т/У/Ф/Х/Ц/Ч/Ш/Щ/Ъ/Ы/Ь/Э/Ю/Я/
SAX /The Simple API for event-based XML parsing/
SFO /サンフランシスコ/
SPA /製造小売業;繊研新聞社のデスク山崎光弘氏が翻案した略語/Specality Store Retailer of Private Label Apparel/
Sailormoon /セーラームーン/
Saint /聖/
Sally /サリー/
Sandy /サンディー/
Sappho /サッフォー/
Scotch /スコッチ/
Sheena /シーナ/
Sibip /シビップ/
Sigma /Σ/
Singapore /シンガポール/
Sony /ソニー/
Square /□/
Stallman /ストールマン/
Suesan /スーザン/
Sweden /スウェーデン/
Sylpheed /シルフィード/
T /Ｔ/
TA /ターミナルアダプタ/
TBJ /東京防衛軍/
TDL /東京ディズニーランド/
TV /テレビ/ＴＶ/
Tau /Τ/
Theta /θ/Θ/
Ti /Ｔｉ/
Tiananmen /天安門/
Tibet /チベット/
Toppe /トッピー/
Toronto /トロント/
Turing /チューリング/
UNIX /ＵＮＩＸ/
US /ＵＳ/
Unisys /ユニシス/
Upsilon /Υ/
Valentine /バレンタイン/
Vega /ベガ/
Venus /ビーナス/ビィーナス/
Versailles /ベルサイユ/ヴェルサイユ/
Vietnum /ベトナム/
W /Ｗ/
W3C /The World Wide Web Consortium/
WG /ワーキンググループ/
WS /ワークステーション/ＷＳ/
WW1 /第一次世界大戦/歐州大戰/
WW2 /太平洋戦争/大東亜戰爭/第二次世界大戦/
Watson /ワトソン/
X /Ｘ/
XEROX /ゼロックス/
XML /Extensible Markup Language/
XTP /ＸＴＰ/
Xi /Ξ/
YHP /横河ヒューレット・パッカード/
Yapoos /ヤプーズ/
Zeta /Ζ/
Zoisite /ゾイサイト/
[ /［/【/『/〔/
[] /□/
\ /＼/
\/ /∨/
] /］/】/』/〕/
]] /』/
^ /↑/∧/
^^ /↑/
^v /↓/
_ /＿/　/
` /‘/
`` /“/
a /Ａ/A/ａ/Ａ型/エー/
a4 /Ａ４/
aaai /ＡＡＡＩ/
abc /ＡＢＣ/
abduction /アブダクション/
abec /アベック/
abgata /ＡＢ型/
ability /アビリティ/
abnormal /アブノーマル/
abort /アボート/
about /アバウト/
abroad /ＡＢｒｏａｄ/
abstract /アブストラクト/抽象/
abstraction /アブストラクション/
ac /ＡＣ/
academia /アカデミア/
academic /アカデミック/
academy /アカデミー/
accelerando /アチェレランド/
accelerator /アクセラレータ/アクセル/
accent /アクセント/
accept /アクセプト/
acceptable /アクセプタブル/
access /アクセス/
accessor /アクセサ/
accessory /アクセサリ/アクセサリー/
accesstime /アクセスタイム/
accident /アクシデント/
accidentally /アクシデンタリ/
accordion /アコーディオン/
account /アカウント/
accountability /アカンタビリティ/
accounting /アカウンティング/
accoustic /アクースティック/
ace /エース/ＡＣＥ/
acid /アシッド/
acm /米国計算機学会/ＡＣＭ/
acount /アカウント/
acryl /アクリル/
action /アクション/
activate /アクティベート/
active /アクティブ/アクティヴ/
activity /アクティビティ/
actor /アクター/
actual /アクチュアル/
actuality /アクチュアリティ/
actualtime /アクチュアルタイム/
ad /ＡＤ/アド/
ada /Ada/
adac /アドバンスド・データ・コントロールズ/
adaptation /アダプテーション/
adapter /アダプタ/アダプター/
adaptive /アダプティヴ/
adaptor /アダプタ/
adc /Ａ／Ｄコンバータ/ＡＤＣ/
add /アッド/
addessability /アドレッサビリティ/
address /アドレス/
addressing /アドレッシング/アドレシング/
adhoc /アドホック/
adlib /アドリブ/
admin /アドミン/
administer /アドミニスター/
administration /アドミニストレーション/
administrator /アドミニストレータ/
admission /アドミッション/
admittance /アドミタンス/
adobe /Ａｄｏｂｅ/
adopter /アダプタ/
adpcm /ADPCM法/
adt /抽象データ型/ADT(Abstruct Data Type)/
adult /アダルト/
advance /アドバンス/
advanced /アドバンスド/アドバンスト/
advantage /アドバンテージ/
adventure /アドベンチャー/
advertisement /アド/
advice /アドバイス/アドヴァイス/
advise /アドバイス/
adviser /アドバイザー/アドバイザ/
advisor /アドヴァイザー/
advisory /アドバイザリ/アドバイサリ/アドヴァイザリ/
aerobics /エアロビクス/
aerodynamics /エアロダイナミクス/
aerogramme /エアログラム/
affine /アフィン/
africa /アフリカ/
afro /アフロ/
after /アフター/
aftercare /アフターケア/
afterfive /アフターファイブ/
afternoon /アフタヌーン/
agata /Ａ型/
age /エージ/
agenda /アジェンダ/会議事項/
agent /エージェント/エイジェント/
aggregate /アグリゲート/
aggressive /アグレッシブ/
aging /エージング/
agit /アジト/
agitpunkt /アジト/
agribusiness /アグリビジネス/
agriculture /アグリカルチャー/
ahead /アヘッド/
ai /ＡＩ/人工知能/AI/
aid /エイド/
aids /ＡＩＤＳ/エイズ/後天性免疫不全症候群/
aiexpert /ＡＩエキスパート/
air /エア/
aircheck /エアチェック/
aircon /エアコン/
airmail /エアメール/
aist /奈良先端科学技術大学院大学/奈良先端/
akapella /ア・カペラ/アカペラ/
akcl /ＡＫＣＬ/AKCL/AKCL(Austin Kyoto Common Lisp)/
alarm /アラーム/
albeit /アルバイト/
album /アルバム/
alcohol /アルコール/
alcove /アルコーブ/
aleph /アレフ/
alfee /アルフィー/
alfred /アルフレッド/
algol /アルゴル/
algorithm /アルゴリズム/算法/
alias /エイリアス/エーリアス/エリアス/ａｌｉａｓ/
alice /アリス/
alien /エイリアン/
align /アライン/
alignment /アラインメント/アライメント/
all /オール/∀/
allback /オールバック/
allegro /アレグロ/
allergy /アレルギ/アレルギー/
allied /アライド/
alligator /アリゲーター/
allinone /オールインワン/
allnight /オールナイト/
allocate /アロケート/
allocation /アロケーション/割り当て/
allocator /アロケータ/
allpass /オールパス/
alminium /アルミニウム/
almond /アーモンド/
alone /アローン/アロン/
alpen /アルペン/
alpha /α/アルファ/
alphabet /アルファベット/
alphatron /アルファトロン/
alpine /アルパイン/
alt /ａｌｔ/アルト/
alternate /オルタネイト/
alternative /オルタナティヴ/
alto /アルト/
am /ＡＭ/
ama /アマ/
amadeus /アマデウス/
amalg /Ц/
amateur /アマチュア/
amazon /アマゾン/
ambivalence /アンビバレンス/
amen /Ａ面/
amenity /アメニティ/
america /アメリカ/亜米利加/メリケン/
ameteur /アマチュア/
amethyst /紫石英/紫水晶/アメジスト/
amnesty /アムネスティ/
amoeba /アメーバ/
amop /ＡＭＯＰ/AMOP(the Art of the Metaobject Protocol)/
amortization /アモチゼーション/
amount /アマウント/
amp /アンプ/アンプリファイア/
amsterdam /アムステルダム/
amulet /ａｍｕｌｅｔ/
amusement /アミューズメント/
ana /ＡＮＡ/
anachronism /アナクロ/
anaheim /アナハイム/
analizer /アナライザ/
analizing /アナライジング/
analog /アナログ/
analogue /アナログ/
analogy /アナロジー/
analysis /アナリシス/
analyst /アナリスト/
analyzer /アナライザー/アナライザ/
anarchy /アナーキー/
anc /アクティブノイズコントロール/
anchor /アンカー/
anchorman /アンカーマン/
and /∧/ＡＮＤ/かつ/＆/および/アンド/&/
andes /アンデス/
angel /エンジェル/
angeles /エンジェルス/
angle /∠/アングル/
angstrom /Å/オングストローム/
anima /アニマ/
animation /アニメーション/
anime /アニメ/
animism /アニミズム/
anketo /アンケート/
anklet /アンクレット/
ann /ＡＮＮ/アン/
annealing /アニーリング/
annex /ＡＮＮＥＸ/アネックス/
annotation /アノテーション/
announce /アナウンス/
announcement /アナウンスメント/
announcer /アナウンサー/
anntena /アンテナ/
ano /アノ/
anode /アノード/
anonymous /アノニマス/
anritsu /アンリツ/
ansi /ａｎｓｉ/ANSI/ＡＮＳＩ/
answer /アンサ/
antenna /アンテナ/
anthology /アンソロジー/
anti /アンチ/
antique /アンティーク/
antithese /アンチテーゼ/
any /何か/
ao /(concat "and" (make-string 1 47) "or")/
ap /ＡＰ/アクセスポイント/
apart /アパート/
aphorism /アフォリズム/
api /ＡＰＩ/
apo /アポ/
apollo /アポロ/
apparel /アパレル/
appeal /アピール/
append /アペンド/ａｐｐｅｎｄ/
appendix /アペンディックス/付録/
appi /安比/
apple /アップル/Ａｐｐｌｅ/
applet /アプレット/
appli /アプリ/
application /アプリケーション/アプリケイション/応用/
applicationcontext /アプリケーションコンテキスト/
applicationmodal /アプリケーションモーダル/
apply /アプライ/
appoint /アポイント/
appointment /アポイントメント/
apprication /アプリケーション/
approach /アプローチ/
approx /〜/
aqua /アクア/
aquacise /アクアサイズ/
aquafresh /アクアフレッシュ/
aquamarine /アクアマリン/藍玉/
ar /人工現実感/
arab /アラブ首長国連邦/アラブ/
arabia /アラビア/
arbeit /アルバイト/バイト/
arbiter /アービタ/
arbitor /アービター/
arbitrage /アービトラージ/
arbitration /アービトレーション/
arc /アーク/
arcade /アーケード/
arch /アーチ/
architecture /アーキテクチャ/アーキテクチャー/
archive /アーカイブ/アーカイヴ/
archiver /アーカイバ/
area /エリア/域/空間/
arena /アリーナ/
argo /アルゴ/
argument /引数/アーギュメント/
aria /アリア/
aristotle /アリストテレス/
arity /アリティ/
arm /アーム/
armacology /アロマコロジー/
armor /アーマー/
army /アーミー/
aromatherapy /アロマセラピー/
around /アラウンド/
arp /ａｒｐ/
arpegio /アルペジオ/
arrange /アレンジ/
arrangement /アレンジメント/
arranger /アレンジャー/
array /アレイ/配列/アレー/
arrow /→/←/↑/↓/⇒/⇔/
art /ＡＲＴ/アート/
article /アーティクル/
articulate /アーティキュレイト/
artist /アーティスト/
arts /アーツ/
as /ＡＳ/
asbestos /アスベスト/
ascii /アスキー/ASCII/ＡＳＣＩＩ/アスキ−/
asia /アジア/亜細亜/
asic /ＡＳＩＣ/
asimov /アシモフ/アジモフ/
asistance /アシスタンス/
aspect /アスペクト/
asphalt /アスファルト/
assemble /アセンブル/
assembler /アセンブラ/
assembly /アセンブリ/
assert /アサート/
asset /アセット/遺産/
assign /アサイン/割り当て/
assignment /アサインメント/代入/
assistant /アシスタント/
assoc /アソック/
associates /アソシエイツ/
association /アソシエーション/
associative /アソシアティブ/アソシエイティブ/
astec /ＡＳＴＥＣ/アステック/
astem /京都高度技術研究所/アステム/
asterisk /アスタリスク/
astroscope /アストロスコープ/
asymmetry /アシンメトリー/
at /＠/アット/ＡＴ/アト/
atari /アタリ/
atelier /アトリエ/
athena /Ａｔｈｅｎａ/Athena/
athletic /アスレチック/
athome /アットホーム/
atkins /アトキンス/
atm /ＡＴＭ/自動現金取り扱い機/自動預貯金機/
atok /Ａｔｏｋ/ATOK/
atom /アトム/原子式/
atomic /アトミック/
atopie /アトピー/
atp /ＡＴＰ/
atr /ＡＴＲ/
att /ＡＴ＆Ｔ/
attach /アタッチ/
attack /アタック/
attention /アテンション/
attenuator /アッテネータ/
attraction /アトラクション/
attractive /アトラクティブ/
attractor /アトラクター/アトラクタ/
attribute /アトリビュート/属性/
auction /オークション/
audio /オーディオ/
audiology /オージオロジ/
audition /オーディション/
auditorium /オーディトリアム/
auger /オーガ/
austin /オースチン/
australia /オーストラリア/
authoring /オーサリング/
authority /オーソリティ/
authorize /オーソライズ/
auto /オート/
autobacks /オートバックス/
autobike /オートバイ/
autofact /ＡＵＴＯＦＡＣＴ/
autoload /オートロード/
automa /オートマ/
automata /オートマトン/
automatic /オートマチック/
automation /オートメーション/
automaton /オートマトン/
automount /オートマウント/
autoraise /オートレイズ/
av /ＡＶ/
availability /アベイラビリティ/
available /使用可能/利用可能/
aval /アバール/
average /アベレージ/
avr /ＡＶＲ/
award /アワード/
awk /ａｗｋ/ＡＷＫ/
ax /ＡＸ/
axe /アクス/アックス/
axiom /公理/
axon /Ａｘｏｎ/
b /Ｂ/B/ベータ/β/
b# /Ｂ#1/
b-spline /Ｂ−スプライン/
babs /バブス/
baby /ベイビー/ベビー/ベイビィ/
bach /Ｂａｃｈ/バッハ/
back /バック/
backano /バックアノ/
backband /バックバンド/
backbone /バックボーン/
backchain /バックチェイン/
backend /バックエンド/
backfire /バックファイア/
backgammon /バックギャモン/
background /バックグラウンド/背景/
backing /バッキング/
backlog /バックログ/
backmirror /バックミラー/
backnumber /バックナンバー/
backpack /バックパック/
backpacker /バックパッカー/
backpropagation /バックプロパゲーション/
backquote /バッククオート/
backslash /＼/バックスラッシュ/
backspace /バックスペース/
backtrace /バックトレース/
backtrack /バックトラック/
backtracking /バックトラッキング/
backup /バックアップ/
backward /バックワード/
bacteria /バクテリア/
bad /バド/
badge /バッジ/
badminton /バドミントン/
baffle /バッフル/バフル/
bag /バッグ/
bagdad /バグダッド/
baka /バカ/
balance /バランス/
balancing /バランシング/
balcony /バルコニー/
ball /ボール/
ballad /バラード/
ballard /バラード/
ballet /バレエ/
bam /ＢＡＭ/
banana /バナナ/
band /バンド/The Band/Ｔｈｅ Ｂａｎｄ/
bandana /バンダナ/
bandman /バンドマン/
bandpass /バンドパス/
bandscore /バンドスコア/
bandwidth /バンド幅/
bang /バン/
bangkok /バンコク/
bank /バンク/
bankbutton /バンクボタン/
banking /バンキング/
banner /バナー/
bar /バー/−/‖/｜/ｂａｒ/(make-string (- fill-column 1) ?-)/
barbara /バーバラ/
barber /バーバー/
barcode /バーコード/
bare /ベア/
bargain /バーゲン/
baricade /バリケード/
barium /バリウム/
baroque /バロック/
barrier /バリア/
barrior /バリア/
barron /バロン/
base /ベース/基底/
baseball /ベースボール/
baseline /ベースライン/
basename /ベースネーム/
bash /バッシュ/
basic /ベーシック/
basis /基礎/
basket /バスケット/
bass /ベース/バス/
bassist /ベーシスト/
bassoon /バスーン/
bat /バット/
batch /バッチ/
batchfile /バッチファイル/
batchsize /バッチサイズ/
bath /バス/
batman /バットマン/
batsu /×/
batter /バッター/
battery /バッテリ/バッテリー/
batting /バッティング/
battle /バトル/
baud /ボー/
baudrate /ボーレート/
bay /ベイ/
bayes /ベイズ/
bayesian /ベイジアン/
baz /ｂａｚ/
bazar /バザー/
bbc /BBC/
bbs /ＢＢＳ/
bc /ＢＣ/
bd /ＢＤ/
bday /バースディ/
bdd /二分決定グラフ/
beach /ビーチ/
beagle /ビーグル/
beaker /ビーカー/
beam /ビーム/
beat /ビート/ｂｅａｔ/
beatles /ビートルズ/
beauty /ビューティ/
because /∵/
bed /ベッド/
beef /ビーフ/
beem /ビーム/
beep /ビープ/
beer /ビール/ビア/麦酒/
beerken /ビール券/
beethoven /ベートーヴェン/ベートーベン/
begin /−−−−−−−−−−−−−−−ここから−−−−−−−−−−−−−−−/ビギン/===================== ここから ====================/BEGIN--cut here--cut here/
beginner /ビギナー/
beginners /ビギナーズ/
behind /ビハインド/
beit /バイト/
belgium /ベルギー/
bell /ベル/
bellcore /ベルコア/
bellken /Ｂｅｌｌ研/
belt /ベルト/
bem /境界要素法/ベム/
bench /ベンチ/
benchmark /ベンチマーク/
benchmarktask /ベンチマーク・タスク/
bend /ベンド/
bender /ベンダー/ベンダ/
bending /ベンディング/
benedict /ベネディクト/
benson /ベンソン/
berkeley /バークレー/
berkley /バークレイ/バークレー/
berlin /ベルリン/
bessel /ベッセル/
best /ベスト/
bestalbum /ベストアルバム/
bestseller /ベストセラー/
bestten /ベストテン/
beta /β/ベータ/β版/
better /ベター/
betty /ベティ/
bex /ＢＥＸ/
bezier /ベジエ/
bg /ＢＧ/バックグラウンド/
bgata /Ｂ型/
bgm /ＢＧＭ/
bianca /ビアンカ/
bias /バイアス/
bib /参考文献/
bible /バイブル/
bibtex /BibTeX/
bid /ビッド/
bidding /ビディング/
biff /ビフ/
big /ビッグ/
bigband /ビッグバンド/
bigblue /ビッグブルー/
bigendian /ビッグエンディアン/
bigmac /ビッグマック/
bigtex /BigTeX/
bike /バイク/オートバイ/
bikini /ビキニ/
bilingual /バイリンガル/
bill /ビル/
bim /境界積分法/
bin /ビン/バイナリ/
binary /バイナリ/バイナリー/
binarydump /バイナリダンプ/
binaural /バイノーラル/
bind /バインド/ＢＩＮＤ/
binder /バインダ/
binding /バインディング/ビンディング/
binoche /ビノシュ/
bio /バイオ/ｂｉｏ/
bios /ＢＩＯＳ/
biotope /ビオトープ;野生生物の生育場所。ギリシャ語のBIO(生物)とTOP(場所)の合成語/
bird /バード/トリ/
birthday /バースディ/
bishop /ビショップ/
bison /Bison/
bit /ビット/ｂｉｔ/
bit-field /ビットフィールド/
bite /バイト/
bitfield /ビット場/ビットフィールド/
bitimage /ビットイメージ/
bitmap /ビットマップ/
bitnet /ｂｉｔｎｅｔ/ビットネット/BITNET/
bizerre /ビザール/
black /ブラック/
blackbox /ブラックボックス/
blackhole /ブラックホール/
blackmagic /ブラックマジック/
blackrider /ブラックライダー/
blade /ブレード/
blain /ブレーン/
blank /ブランク/
blaster /ブラスター/
bldg /ビル/
blind /ブラインド/
blindtouch /ブラインドタッチ/
blink /ブリンク/
block /ブロック/
blockdiagram /ブロックダイアグラム/
blocking /ブロッキング/
blouse /ブラウス/
blow /ブロー/
blowser /ブラウザ/
blue /ブルー/
bluebacks /ブルーバックス/
blueberry /ブルーベリー/
blueday /ブルーデイ/
blueglass /ブルーグラス/
bluenote /ＢｌｕｅＮｏｔｅ/
blues /ブルース/ブルーズ/
bluewave /ブルーウェーブ/
blushup /ブラッシュアップ/
bm /ＢＭ/
bnews /ｂｎｅｗｓ/
bnf /BNF(Backus-Naur Form)/
board /ボード/
boardlevel /ボードレベル/
boat /ボート/
bob /ボブ/
bochum /ボッフム/
body /ボディ/ボデー/
bodybuil /ボディビル/
bodycon /ボディコン/
bohm /ベーム/
boiled /ボイルド/
boiler /ボイラー/ボイラ/
boke /ボケ/
bold /ボールド/
boltzmann /ボルツマン/
bomb /ボム/
bomber /ボンバー/
bondage /ボンデージ/
bone /ボーン/
bonnet /ボンネット/
bonus /ボーナス/
booby /ブービー/
boogie /ブギー/ブギ/
book /ブック/Book/
booker /ブッカー/
booking /ブッキング/
bookmart /ブックマート/
books /ブックス/
bool /ブール/
boole /ブール/
boolean /ブーリアン関数/ブーリアン/
boom /ブーム/
boost /ブースト/
boot /ブート/
booth /ブース/
boots /ブーツ/
bootstrap /ブートストラップ/
bord /ボード/
borden /ボーデン/
border /ボーダー/
bore /ボア/
borel /ボレル/
borland /ボーランド/
boss /ボス/
boston /ボストン/ボストン大学/
bot /⊥/
bottle /ボトル/
bottleneck /ボトルネック/
bottom /ボトム/⊥/下/底/
bottomline /ボトムライン/
bottomup /ボトムアップ/
boundary /バウンダリ/
bounding /バウンディング/
bouquet /ブーケ/
bourbon /バーボン/
boutique /ブティック/
bowl /ボウル/
bowling /ボーリング/ボウリング/
box /ボックス/□/■/
boxer /ボクサー/
boxing /ボクシング/
boxp /ボックス／ポインタ/
boy /ボーイ/
boyer /ボイヤー/
boyish /ボーイッシュ/
bps /ｂｐｓ/
bq /“/
brace /ブレース/
bracket /ブラケット/
brahms /ブラームス/
brain /ブレイン/ブレーン/
brake /ブレーキ/
branch /ブランチ/
brand /ブランド/
brandy /ブランデー/
brass /ブラス/
brassband /ブラスバンド/
brazil /ブラジル/
break /ブレーク/ブレイク/ブレーキ/
breakdown /ブレークダウン/
breaker /ブレーカー/ブレーカ/
breaking /ブレーキング/
breakpoint /ブレークポイント/ブレイクポイント/
breath /ブレス/
brian /ブライアン/
bridal /ブライダル/
bridge /ブリッジ/
bridgestone /ブリジストン/
bridging /ブリッジング/
british /イギリス/
broad /ブロード/
broadcast /ブロードキャスト/
bronze /ブロンズ/
brother /ブラザー/
brothers /ブラザーズ/
brouter /ブルータ/
brow /ブロウ/
brown /ブラウン/
browse /ブラウズ/
browser /ブラウザ/
browsing /ブラウジング/
browzer /ブラウザ/
brunswick /ブランズウィック/
brush /ブラシ/
brushup /ブラッシュアップ/
bs /ＢＳ/(concat "B\057S")/Ｂ／Ｓ/Balance Sheet/貸借対照表;財務諸表の1つ/
bsd /ＢＳＤ/BSD/
bsd# /(concat "BSD\057#0")/
bsdi /BSDI/
btron /ＢＴＲＯＮ/
bubble /バブル/
bubbly /バブリー/
bubbule /バブル/
bucket /バケツ/バケット/
buffer /バッファ/バッファー/作業域/
buffered /バッファード/
bufferin /バファリン/
buffering /バッファリング/
buffle /バッフル/
bug /バグ/
bugfix /バグフィクス/バグフィックス/
buggy /バギー/
buglist /バグリスト/
bugreport /バグレポート/
buil /ビル/
build /ビルド/
builder /ビルダ/ビルダー/
buildin /ビルドイン/
building /ビルディング/ビル/ビルヂング/
built-in /ビルトイン/
builtin /ビルトイン/
bulk /バルク/
bull /ブル/
bulldozer /ブルドーザ/
bulletin /ブリテン/
bulletinboard /ブレティンボード/
bump /バンプ/
bumper /バンパー/
buncher /バンチャ/
bundle /バンドル/
bundling /バンドリング/
bureau /ビューロー/
burger /バーガー/
burma /ビルマ/
burner /バーナー/
burst /バースト/
bus /バス/
buserror /Ｂｕｓ Ｅｒｒｏｒ/
bush /ブッシュ/
bushbaby /ブッシュベイビー/
business /ビジネス/
businessman /ビジネスマン/
busmaster /バスマスタ/
busy /ビジー/ビジィ/
butter /バター/
butterfly /バタフライ/
butterworth /バタワース/
button /ボタン/
buzzer /ブザー/
by /バイ/ｂｙ/
bye /バイ/
bypass /バイパス/
bypath /バイパス/
byte /バイト/Ｂｙｔｅ/
byte-compile /バイトコンパイル/
byte-compiler /バイトコンパイラ/
bytecode /バイトコード/
bytecompile /バイトコンパイル/
bytecompiler /バイトコンパイラ/
c /Ｃ/C/Ｃ言語/℃/ｃ/
c++ /Ｃ＋＋/C++/
cabaret /キャバレー/
cabbage /キャベツ/
cabin /キャビン/
cabinet /キャビネット/
cable /ケーブル/
cachable /キャッシャブル/
cache /キャッシュ/
caching /キャッシング/
cad /ＣＡＤ/CAD/
cadam /ＣＡＤＡＭ/
caddie /キャディ/キャディー/
caddy /キャディ/
cadence /ケイデンス/
cady /キャディー/
cae /ＣＡＥ/
caesar /カエサル/シーザー/
cage /ケージ/
cai /ＣＡＩ/
cake /ケーキ/
calbee /カルビー/
calculus /カルキュラス/
caldina /カルディナ/
calendar /カレンダー/カレンダ/
calender /カレンダ/
calibration /キャリブレーション/
california /カルフォルニア/カリフォルニア/
call /コール/
callback /コールバック/
caller /呼出し側/
callose /カロース/
callsign /コールサイン/
callus /カルス/
calorie /カロリー/
calpis /カルピス/
caltech /カルテック/
camber /キャンバー/
cambridge /ケンブリッジ/
camera /カメラ/
cameraman /カメラマン/
camp /キャンプ/
campaign /キャンペーン/
campus /キャンパス/
canada /カナダ/
canasta /カナスタ/
cancel /キャンセル/
canceler /キャンセラ/
cancellation /キャンセレーション/
canceller /キャンセラ/
candle /キャンドル/
candy /キャンディ/
canne /カンヌ/
cannon /キャノン/
canon /キャノン/キヤノン/カノン/
canonical /カノニカル/
canopus /カノープス/
canvas /キャンバス/
cap /∩/キャップ/
capa /キャパ/
capability /ケーパビリティ/
capacitance /キャパシタンス/
capacity /キャパシティ/
capcom /カプコン/
capital /キャピタル/
capsule /カプセル/
captain /キャプテン/
caption /キャプション/
capture /キャプチャー/取込/キャプチャ/
car /カー/ｃａｒ/
caramel /キャラメル/
carbon /カーボン/
carboxyl /カルボキシル/
carburetor /キャブレター/キャブ/
card /カード/
cardigan /カーディガン/
cardioid /カーディオイド/
cardreader /カードリーダ/
cards /トランプ/
cardwindow /カードウインドー/
care /ケア/
career /キャリア/
careless /ケアレス/
cargo /カーゴ/
carib /カリブ/
carina /カリーナ/
carlos /カルロス/
carlton /カールトン/
carnegie /カーネギーメロン大学/カーネギー/
carnival /カーニバル/
carp /カープ/
carpenter /カーペンター/
carpet /カーペット/
carriage /キャリッジ/
carrier /キャリア/
carrot /キャロット/
carry /カレー/キャリー/
carstereo /カーステレオ/
carte /カルテ/
carter /カーター/
cartesian /カルテジアン/
cartridge /カートリッジ/
cartrige /カートリッジ/
cascade /カスケード/
case /ケース/ＣＡＳＥ/CASE/
casebycase /ケースバイケース/
casette /カセット/
cash /キャッシュ/
cashe /キャッシュ/
casino /カジノ/
casio /カシオ/
casiopea /カシオペア/
casl /CASL/
cassette /カセット/
cast /キャスト/
caster /キャスター/
castle /キャッスル/
casual /カジュアル/
cat /ｃａｔ/ネコ/キャット/カット/
catalog /カタログ/
catalogue /カタログ/
catalyst /カタリスト/
catch /キャッチ/
catcher /キャッチャー/
categorical /カテゴリカル/
categorize /カテゴライズ/
category /カテゴリー/カテゴリ/範疇/
caterpillar /キャタピラ/
cathereine /キャサリン/
catholic /カトリック/
cats /キャッツ/
cbssony /ＣＢＳＳｏｎｙ/
cc /ｃｃ/ＣＣ/カーボンコピー/
ccr /CCR(Creedence Clearwater Revival)/
cctu /大型計算機センター/
cd /ＣＤ/コンパクトディスク/CD/キャッシュディスペンサー/
cdb /Command Description Block/
cdot /・/
cdots /…/
cdr /ｃｄｒ/
cdrom /ＣＤ−ＲＯＭ/CD-ROM/
cds /ＣｄＳ/
celery /セロリ/
celica /セリカ/
cell /セル/
cellar /セルラー/
cellinstance /セルインスタンス/
cello /チェロ/
cellulose /セルロース/
cent /セント/¢/
center /センター/センタ/
centering /センタリング/
centi /センチ/
centre /センター/
century /センチュリー/
cepheus /ケフェウス/
cepstral /ケプストラル/
cepstrum /ケプストラム/
ceramic /セラミック/
certification /サーティフィケーション/
cesp /CESP/CESP(Common Extended Self-contained Prolog)/
cf /ＣＦ/
cg /ＣＧ/コンピュータ・グラフィックス/
ch /ｃｈ/チャンネル/チャネル/
chain /チェーン/チェイン/
chair /チェア/
challenge /チャレンジ/
challengealbe /チャレンジブル/
challenger /チャレンジャー/
challenging /チャレンジング/
chalmers /チャルマース/
chamber /チャンバー/
chameleon /カメレオン/
champion /チャンピォン/チャンピオン/
championship /チャンピオンシップ/
chan /チャン/
chance /チャンス/
change /チェンジ/
changer /チェンジャー/
channel /チャネル/チャンネル/
chaos /カオス/
chaotic /カオス的/
chapter /チャプター/
char /キャラ/キャラクタ/
chara /キャラ/
character /キャラクタ/キャラクター/
charge /チャージ/
charger /チャージャー/
chari /チャリ/
charity /チャリティ/
charleston /チャールストン/
charlie /チャーリー/
charm /チャーム/ＣＨＡＲＭ/
charming /チャーミング/
chart /チャート/
charter /チャーター/チャータ/
chartfile /チャートファイル/
chassis /シャーシ/
chat /チャット/
cheap /チープ/
cheaper /チーパー/
chebyshev /チェビチェフ/
chech /チェコ/
check /チェック/
checker /チェッカー/チェッカ/
checkerplayer /チェッカープレイヤー/
checkers /チェッカーズ/
checkin /チェックイン/チェック・イン/
checking /チェッキング/
checkmate /チェックメイト/
checkout /チェックアウト/チェック・アウト/
checkpoint /チェックポイント/
checksum /チェックサム/
cheek /チーク/
cheer /チア/
cheese /チーズ/
cheesecake /チーズケーキ/
chef /シェフ/
cheko /チェコ/
chemical /ケミカル/
cheque /チェック/
cherry /チェリー/
chess /チェス/
chi /χ/
chicago /シカゴ/
chicken /チキン/
chief /チーフ/
child /チャイルド/子/
chiller /チラー/
chime /チャイム/
chimera /キマイラ/キメラ/
china /チャイナ/
chinese /チャイニーズ/
chip /チップ/
choco /チョコ/
chocolate /チョコレート/
choice /チョイス/
choke /チョーク/
choking /チョーキング/
chombo /チョンボ/
chonbo /チョンボ/
chop /チョップ/
chopin /ショパン/
chopper /チョッパー/
chord /コード/
chordname /コードネーム/
chorus /コーラス/
christ /キリスト/クライスト/
christamas /クリスマス/
christian /クリスチャン/
christmas /クリスマス/
chro /クロ/
chunk /チャンク/
church /チャーチ/
chute /シュート/
ci /ＣＩ/チェックイン/
cinema /シネマ/
cinnamon /シナモン/
circle /サークル/○/◎/●/
circuit /サーキット/
circumscribe /サーカムスクライブ/
circumscription /サーカムスクリプション/
circus /サーカス/
cisc /ＣＩＳＣ/CISC/
citizen /シチズン/
city /シティ/
civic /シビック/
cl /ｃｏｍｍｏｎ−ｌｉｓｐ/Common Lisp/
claidha /クレイダ/
claim /クレーム/
clamp /クランプ/
clampmeter /クランプメーター/
clash /クラシュ/クラッシュ/
class /クラス/
classic /クラシック/
classiclife /クラシックライフ/
classification /クラスフィケーション/分類/
classifier /クラシファイア/
classmate /クラスメイト/
clause /クローズ/
clavinova /クラビノーバ/
clean /クリーン/
cleaner /クリーナー/
cleaning /クリーニング/
cleanup /クリーンアップ/
clear /クリア/
click /クリック/
clickable /クリッカブル/
client /クライアント/
clim /ＣＬＩＭ/
climax /クライマックス/
clime /クライム/
clinic /クリニック/
clint /クリント/
clip /クリップ/
clipboard /クリップボード/
clipping /クリッピング/
clisp /CLISP/
clock /クロック/
clone /クローン/
clos /ＣＬＯＳ/CLOS(Common Lisp Object System)/CLOS/
close /クローズ/
closed /クローズド/
closer /クローザ/
closet /クローゼット/
closeup /クローズアップ/
closure /クロージャ/閉包/
cltl# /ＣＬｔＬ#1/CLtL#0/
club /クラブ/倶楽部/
clue /クルー/
cluster /クラスタ/クラスター/
clustering /クラスタリング/
clutch /クラッチ/
clx /ＣＬＸ/CLX(Common Lisp X Interface)/CLX/
cm /ＣＭ/ｃｍ/Ｃｍ/コマーシャル/センチ/センチメートル/
cmdline /コマンドライン/
cmos /ＣＭＯＳ/
cmu /ＣＭＵ/カーネギーメロン大学/CMU/
cmucl /ＣＭＵ−ＣＬ/ＣＭＵＣＬ/CMU-CL/
cnews /ｃｎｅｗｓ/
co /コ/株式会社/
co2 /ＣＯ2/
coach /コーチ/
coart /コート/
coaster /コースター/
coat /コート/
cobol /COBOL/ＣＯＢＯＬ/
cocacola /コカコーラ/
cocaine /コカイン/
cockpit /コックピット/
coco /ＣｏＣｏ/
cocoa /ココア/
coconut /ココナツ/
cocostore /ＣｏＣＯストア/
coda /コーダ/
code /コード/
codebooks /コードブックス/
codeka /コード化/
codeless /コードレス/
codeset /コードセット/
codesign /コデザイン/
coding /コーディング/
coffee /コーヒー/珈琲/
cohen /コーヘン/
coherence /コヒーレンス/
coherency /コヒレンシ/コヒーレンシ/
coherent /コヒーレント/
coil /コイル/
coin /コイン/
coincidence /コインシデンス/
cola /コーラ/
cold /コールド/:-'|/:-~)/
collect /コレクト/
collectcall /コレクトコール/
collection /コレクション/
collector /コレクタ/コレクター/
college /カレッジ/
collision /コリージョン/コリジョン/
colon /コロン/
color /カラー/色/
colorado /コロラド/
colorbox /カラーボックス/
colorful /カラフル/
colormap /カラーマップ/
colour /カラー/
colt /ＣＯＬＴ/
columbia /コロンビア/
columella /コルメラ/
column /コラム/カラム/
com /コン/
comb /コム/
combi /コンビ/
combination /コンビネーション/
combinator /コンビネータ/
combo /コンボ/
comeback /カムバック/
comedian /コメディアン/
comedy /コメディー/喜劇/
comic /コミック/
comical /コミカル/
comics /コミックス/
comiket /コミケ/コミ/
comma /コンマ/，/、/カンマ/
command /コマンド/
commander /コマンダー/
commandline /コマンドライン/
commandlineoption /コマンドラインオプション/
comment /コメント/
commentout /コメントアウト/
commerce /コマース/
commercial /コマーシャル/
commissioner /コミッショナー/
commit /コミット/
commitment /コミットメント/
committee /コミッティ/
committer /コミッター/コミッタ/
commodore /コモドール/
common /Ｃｏｍｍｏｎ−Ｌｉｓｐ/コモン/共通/
commu /コミ/
communicate /コミュニケート/
communication /コミュニケーション/
communicator /コミュニケーター/
communist /コミュニスト/共産主義者/
community /コミュニティ/
comp /コンプ/ｃｏｍｐ/
compa /コンパ/
compact /コンパクト/
compaction /コンパクション/
companion /コンパニオン/
comparator /コンパレータ/
compati /コンパチ/
compatibility /コンパチビリティ/コンパチ/
compatible /コンパチブル/コンパチ/互換/
compe /コンペ/
compilation /コンピレイション/コンピ/
compile /コンパイル/
compileoption /コンパイルオプション/
compiler /コンパイラ/コンパイラー/
complete /コンプリート/
completion /コンプリーション/
complex /コンプレックス/ＣＯＭＰＬＥＸ/
compo /コンポ/
component /コンポーネント/
compose /コンポーズ/
composer /コンポーザ/コンポーザー/
composite /コンポジット/
compound /コンパウンド/
compress /コンプレス/
compression /コンプレッション/
compressor /コンプレッサ/
compuserve /コンピューサーブ/
computation /コンピュテーション/
computer /コンピュータ/コンピューター/
computer-science /コンピュータサイエンス/
computer-software /コンピュータソフトウェア/
computermusic /コンピュータミュージック/
computervision /コンピュータービジョン/コンピュータビジョン/
computing /コンピューティング/
comtec /コムテック/
concealer /コンシーラー/
concentrator /コンセントレーター/コンセントレータ/
concept /コンセプト/
concert /コンサート/
concerthall /コンサートホール/
concerto /コンチェルト/
concise /簡明な/
concorde /コンコルド/
concrete /コンクリート/
concurrency /コンカレンシー/
concurrent /コンカレント/
condenser /コンデンサー/コンデンサ/
condition /コンディション/
conductance /コンダクタンス/
conductor /コンダクタ/
cones /コーンズ/
conference /コンファレンス/
config /コンフィギュレーション/コンフィグ/
configuration /コンフィギュレーション/コンフィグレーション/
configure /コンフィギュア/
conflict /コンフリクト/競合/衝突/
confocal /コンフォーカル/
conic /コニック/
connect /コネクト/接続/
connecter /コネクタ/
connection /コネクション/
connectionism /コネクショニズム/
connectionist /コネクショニスト/
connectionistmodel /コネクショニストモデル/
connectivity /コネクティビティ/
connector /コネクタ/
cons /コンス/ｃｏｎｓ/
conscell /コンスセル/
consensus /コンセンサス/
consent /コンセント/
conservatory /コンセルヴァトーリ/
consider /コンシダー/
consistency /コンシステンシ/
console /コンソール/
consortium /コンソーシアム/
const-prog /構成的プログラミング/
constant /コンスタント/
construct /コンストラクト/
constructor /コンストラクタ/構築子/
consult /コンサルト/
consultant /コンサルタント/
consultation /コンサルテーション/
consulting /コンサルティング/
consume /コンシューム/
consumer /コンシュマー/
contac /コンタック/
contact /コンタクト/
container /コンテナ/
content /コンテント/
contents /コンテンツ/
contest /コンテスト/
context /コンテキスト/コンテクスト/
continuation /コンティニュエーション/継続/
continue /コンティニュー/
contour /コンター/コンタ/
contract /コントラクト/
contraction /コントラクション/
contrast /コントラスト/
contrib /ｃｏｎｔｒｉｂ/
contribution /コントリビューション/
control /コントロール/制御/
controler /コントローラ/
controller /コントローラ/
conveni /コンビニ/
convenience /コンビニエンス/
convention /コンベンション/コンヴェンション/
conventional /コンヴェンショナル/コンベンショナル/
conversion /コンバージョン/コンヴァージョン/変換/
convert /コンヴァート/コンバート/変換/
converter /コンバータ/
convertor /コンバータ/
convolution /コンヴォリューション/
convolve /コンヴォルヴ/
cook /クック/コック/
cookie /クッキー/
cooking /クッキング/
cooky /クッキー/
cool /クール/
coolbox /クールボックス/
cooler /クーラー/
coolerbox /クーラーボックス/
coop /コープ/
cooperate /コーポレート/
coordinate /座標/コーディネート/
coordinator /コーディネーター/コーディネータ/
cop /コップ/
copier /コピア/
copper /カッパー/
coprocessor /コプロセッサ/
coprod /Ц/
copy /コピー/
copyback /コピーバック/
copymap /コピーマップ/
copyonwrite /コピーオンライト/
copyright /コピーライト/
cord /コード/
core /コア/
coredump /コアダンプ/
coretime /コアタイム/
coriolis /コリオリ/
cork /コルク/
corn /コーン/
cornell /コーネル/
corner /コーナー/┘/└/┐/┌/┓/┏/┛/┗/
cornflakes /コーンフレーク/
corns /コーンズ/
corolla /カローラ/
corona /コロナ/
corpus /コーパス/
correct /正確な/
correlation /コリレーション/
cos /コサイン/
cosine /コサイン/
cosmo /コスモ/
cosmos /コスモス/
cost /コスト/
coucou /クク/
counselor /カウンセラー/
count /カウント/
countdown /カウントダウン/
counter /カウンタ/カウンター/
counterpropagation /カウンタープロパゲーション/
country /カントリー/
couple /カップル/
coupling /カップリング/
coupon /クーポン/
cource /コース/
course /コース/
court /コート/
cov /共分散/
cover /カバー/
coverage /カバレッジ/カバレージ/
cp /構成的プログラミング/コストパフォーマンス/
cps /ＣＰＳ/CPS(Continuation-Passing Style)/
cpu /中央処理装置/ＣＰＵ/CPU/
cr /ＣＲ/CR/
crack /クラック/
cracker /クラッカー/
cracking /クラッキング/
craft /クラフト/
crane /クレーン/
crash /クラッシュ/
cray /クレイ/
crayon /クレヨン/
crazy /クレイジー/
cream /クリーム/
create /クリエート/クリエイト/
creative /クリエイティヴ/
credit /クレジット/
creditcard /クレジットカード/
crimson /クリムゾン/
cripper /クリッパー/
critical /クリティカル/
croissant /クロワッサン/
cross /クロス/×/┼/╋/┿/╂/
crosspost /クロスポスト/
crosstalk /クロストーク/
crossword /クロスワード/
crown /クラウン/
crt /ＣＲＴ/
cruise /クルーズ/
cruiser /クルーザー/
crush /クラッシュ/
cry /(concat "(\073_\073)")/
crystal /クリスタル/水晶/
cs /コンピュータソフトウェア/ＣＳ/control-sequence/コントロールシーケンス/コンピュータサイエンス/コミュニケーションサーバ/コミュニケーションサーバー/
csh /ｃｓｈ/
csk /ＣＳＫ/
ct /ＣＴ/
ctc /伊藤忠テクノサイエンス/
cuba /キューバ/
cube /キューブ/
cue /キュー/
cug /ＣＵＧ/
cult /カルト/
culture /カルチャー/
cup /カップ/コップ/∩/∪/
cupple /カップル/
curl /カール/
curling /カーリング/
curot /キュロット/
currect /カレント/
currency /カレンシ/
current /カレント/
curriculum /カリキュラム/
curry /カレー/カリー/
currying /カリー化/
curses /カーセス/
cursor /カーソル/カーサ/
cursorkey /カーソルキー/
curtain /カーテン/
curve /カーヴ/カーブ/
cusco /クスコ/
cushion /クッション/
custom /カスタム/
customer /カスタマー/カスタマ/
customizable /カスタマイザブル/
customization /カスタマイゼーション/
customize /カスタマイズ/カスタム化/
customized /カスタマイズド/
customizer /カスタマイザ/
cut /カット/------------------------( C U T   H E R E )---------------------------/-------------------- ここから --------------------/CUT/切り取り/---- cut here --------------------------------------------------/------------------------CUT-HERE---------------------------/------------>8------------ C U T   H E R E ------------>8------------/
cute /キュート/
cuticle /クチクラ/
cutie /キューティー/
cutoff /カットオフ/
cutter /カッター/
cutting /カッティング/
cuty /キューティー/
cyber /サイバー/
cybernetics /サイバネティクス/
cyberpunk /サイバーパンク/
cyborg /サイボーグ/
cycle /サイクル/
cyclic /サイクリック/
cyclo /サイクロ/
cyclotron /サイクロトロン/
cylindar /シリンダー/
cylinder /シリンダ/シリンダー/
cymbal /シンバル/
cynnamon /シナモン/
cyric /サイクロトロンＲＩ/
d /Ｄ/ｄ/∂/
d# /Ｄ#1/
d1 /Ｄ１/
d3 /Ｄ３/
dB /デシベル/
da /↓/ＤＡ/
dac /Ｄ／Ａ変換/Ｄ／Ａコンバータ/ＤＡＣ/
daemon /デーモン/
dagger /†/‡/ダガー/
dahl /ダール/
daikei /大型計算機センター/
daisy /Ｄａｉｓｙ/デイジー/
damage /ダメージ/
damper /ダンパー/
dance /ダンス/
dancer /ダンサー/
dancing /ダンシング/
dark /ダーク/
darpa /ＤＡＲＰＡ/
dart /ダート/
darwin /ダーウィン/
dasein /ダーザイン/
dash /ダッシュ/―/
dashv /┤/
dat /ＤＡＴ/
data /データ/データー/
database /データベース/ＤＢ/
databasesystem /データベース・システム/
datafile /データファイル/
dataflow /データフロー/
dataglove /データグローブ/
datagram /データグラム/
datalink /データリンク/
dataobject /データオブジェクト/
datapack /データパック/
dataserver /データサーバー/
dataset /データセット/
datasheet /データシート/
datashow /データショウ/
datastore /データストア/
datatype /データタイプ/
date /デート/
datebase /データベース/
davinci /ダヴィンチ/ダ・ヴィンチ/
davis /デービス/
day /ディ/デイ/デー/
db /データベース/ＤＢ/
dbms /データベース管理システム/DBMS/
dc /ＤＣ/直流/
dce /ＤＣＥ/
dcircle /◎/
dcl /ＤＣＬ/
ddagger /‡/
ddb /演繹データベース/文書データベース/
de /デ/ド/
dead /デッド/
deadline /デッドライン/
deadlock /デッドロック/
deal /ディール/
dealer /ディーラー/ディーラ/
deallocate /デアロケイト/
deamon /デーモン/
death /デス/
debug /デバッグ/ディバッグ/
debugger /デバッガ/ディバッガ/デバッガー/
debugging /デバッギング/
debussy /ドビュッシー/
debut /デビュー/
dec /ＤＥＣ/DEC/
decay /ディケイ/
decca /デッカ/
decimal /十進数/
decision /デシジョン/
deck /デッキ/デック/
decnet /ＤＥＣｎｅｔ/ＤＥＣＮＥＴ/
decode /デコード/復号化/
decoder /デコーダー/デコーダ/
decoding /デコーディング/
deconvolution /デコンボリューション/
decorate /デコレート/
decoration /デコレーション/
decrement /デクリメント/
dectalk /ＤＥＣｔａｌｋ/
deep /ディープ/
defacto /デファクト/
default /デフォルト/ディフォルト/ディフォールト/省略/デファルト/
defaultresourcefile /デフォルトリソースファイル/
defect /ディフェクト/
defence /ディフェンス/
defender /ディフェンダー/
define /デファイン/
degrade /デグレード/
delay /ディレイ/ディレー/
delayed /ディレイド/
delayline /ディレイライン/
delete /デリート/
delft /デルフト/
delicate /デリケート/
delimiter /デリミタ/
delivery /デリバリー/
delta /δ/デルタ/
deltarule /δルール/
deluxe /デラックス/
dema /デマ/
demacs /Ｄｅｍａｃｓ/
demand /デマンド/
demension /ヂメンジョン/
demerit /デメリット/
demo /デモ/デモ版/
democracy /デモクラシー/
demonstration /デモンストレーション/
demonstrator /デモンストレータ/
demorgan /ド・モルガン/
demotape /デモテープ/
denied /拒否された/
denmark /デンマーク/
denotational /デノテーショナル/
denver /デンヴァー/
depart /デパート/
depend /ディペンド/
dependency /ディペンデンシ/
depo /デポ/
deposerver /デポサーバー/
deposit /デポジット/
dequeue /デキュー/
derived /デライブド/
desc /記述子/
describe /ディスクライブ/
descripter /記述子/
descriptor /ディスクリプタ/記述子/
desert /デザート/
design /デザイン/
designer /デザイナー/
desk /デスク/
desktop /デスクトップ/
destination /デスティネーション/ディスティネーション/デスティネイション/
destroy /デストロイ/破壊する/
destroyer /デストロイヤー/破壊者/
destructor /ディストラクタ/デストラクタ/消滅子/
det /行列式/
detach /デタッチ/
detect /ディテクト/発見する/
detector /ディテクタ/
detroit /デトロイト/
deutch /ドイツ/
deutsch /ドイツ語/ドイツ/
develop /デベロップ/
developer /デベロッパー/デベロッパ/
device /デバイス/デヴァイス/
devicedriver /デバイスドライバー/デバイスドライバ/
devil /デビル/
devo /ＤＥＶＯ/
df /ＤＦ/
dg /ＤＧ/
dia /◇/ダイヤ/
diagnosis /ダイアグノーシス/
diagram /ダイアグラム/
dial /ダイアル/ダイヤル/
dialin /ダイアルイン/
dialing /ダイアリング/
dialog /ダイアログ/
dialogue /ダイアログ/
dialup /ダイアルアップ/
diamond /ダイアモンド/◇/◆/ダイヤモンド/ダイヤ/金剛石/
diatone /ダイアトーン/
diatonic /ダイアトニック/
dictionary /ディクショナリ/辞書/
diesel /ディーゼル/
diet /ダイエット/
diff /ディフ/
differential /デフ/ディファレンシャル/
digest /ダイジェスト/
digital /ディジタル/デジタル/Digital/
dijkstra /ダイクストラ/
dilation /ダイレーション/
dilemma /ジレンマ/
dimension /ディメンション/ディメンジョン/
dining /ダイニング/
dinner /ディナー/
diode /ダイオード/
dip /ディップ/
dipole /ダイポール/
dir /ディレクトリ/ディレクトリー/
dirac /ディラク/
direct /ダイレクト/
directive /ディレクティブ/
directmail /ダイレクトメール/
director /ディレクター/
directory /ディレクトリ/ディレクトリィ/ディレクトリー/デイレクトリー/
dirichlet /ディリクレ/
dirt /ダート/
dirty /ダーティ/
dis /ディス/
disable /ディスエーブル/ディゼーブル/
disassemble /ディスアセンブル/
disc /ディスク/
discard /ディスカード/
discman /ディスクマン/
disco /ディスコ/
discommunication /ディスコミュニケーション/
disconnect /ディスコネクト/
discount /ディスカウント/
discrimination /ディスクリミネーション/
discriminator /ディスクリミネータ/
discuss /ディスカス/
discussion /ディスカッション/
dish /ディッシュ/
disk /ディスク/DISK/
diskette /ディスケット/
diskless /ディスクレス/
diskman /ディスクマン/
disney /ディズニー/
disneyland /ディズニーランド/
dispatch /ディスパッチ/
dispatcher /ディスパッチャ/
dispencer /ディスペンサ/
displacement /ディスプレイスメント/
display /ディスプレイ/ディスプレー/
distance /ディスタンス/
distortion /ディストーション/
distribution /ディストリビューション/
distributor /ディストリビュータ/
dithering /ディザリング/
div /÷/
diving /ダイヴィング/ダイビング/
dj /ＤＪ/
dma /ＤＭＡ/DMA/Direct Memory Access/
dna /ＤＮＡ/ＤＮＡ分子/
dns /ＤＮＳ/
do /ｄｏ/
doc /ドキュメント/
dock /ドック/
docment /ドキュメント/
docter /博士課程/ドクター/
doctor /ドクター/博士課程/
doctorcheck /ドクターチェック/
document /ドキュメント/文書/ドキュメント /
documentation /ドキュメンテーション/
dodge /ドッジ/
doek /ズック/
dog /ドッグ/
dogfight /ドッグファイト/
dolby /ドルビー/
dolbysurround /ドルビーサラウンド/
doll /ドル/
dollar /ドル/＄/ダラー/
dolphin /イルカ/ドルフィン/
domain /ドメイン/ドメーン/
domani /ドマーニ/
dome /ドーム/
dominant /ドミナント/
dominion /ドミニオン/
domino /ドミノ/
dood /演繹オジェクト指向データベース/
door /ドア/
doorbell /ドアベル/
doors /ドアーズ/
doppler /ドップラ/
dorian /ドリアン/
dortmund /ドルトムント/
dos /ＤＯＳ/DOS/
dot /ドット/./．/・/
dots /…/‥/.../... /
dotted /ドッティド/
double /ダブル/
doubleclick /ダブルクリック/
doublecount /ダブルカウント/
doughnut /ドーナツ/
doughnuts /ドーナツ/
down /ダウン/↓/
downarrow /↓/
download /ダウンロード/
downsampling /ダウンサンプリング/
downto /↓/
downtown /ダウンタウン/
dozen /ダース/
dpd /ＤＰＤ/
dpi /ｄｐｉ/
dq /ドラクエ/
dracula /ドラキュラ/
draft /ドラフト/
drag /ドラッグ/
dragging /ドラッギング/
dragon /ドラゴン/
drain /ドレイン/ドレン／ベント/ドレン/
drake /ドレーク/
dram /ＤＲＡＭ/
drama /ドラマ/
dramatic /ドラマティック/
dramaturgie /ドラマツルギー/
drastic /ドラスティック/
draw /ドロー/
drawer /ドロワ/
drawers /ズロース/
drawing /ドローイング/
dream /ドリーム/
dress /ドレス/
dressing /ドレッシング/
dribble /ドリブル/
drier /ドライヤー/
drift /ドリフト/
drill /ドリル/
drink /ドリンク/
drip /ドリップ/
drive /ドライブ/ドライヴ/
driven /ドリブン/
driver /ドライバ/ドライバー/ドライヴァ/
drocer /ドローサー/
dron /Ｄ論/
drop /ドロップ/
drug /ドラッグ/
drum /ドラム/
drummer /ドラマー/
drumming /ドラミング/
drumset /ドラムセット/
drumsolo /ドラムソロ/
drunker /ドランカー/
dry /ドライ/
dryad /ドライアド/ドリアード/
dsp /ＤＳＰ/ディジタル信号処理/
dt /減衰時間/
dte /DTE/
dtp /ＤＴＰ/
dual /デュアル/
dub /ダブ/
dubbing /ダビング/
dubble /ダブル/
duct /ダクト/
duet /デュエット/
dumb /ダム/
dummy /ダミー/
dummyhead /ダミーヘッド/だみーへっど/
dump /ダンプ/
dumper /ダンパー/
dungeon /ダンジョン/
dunk /ダンク/
dunlop /ダンロップ/
duo /デュオ/
duplex /デュプレクス/
duplicate /デュープリケート/デュプリケート/デュプリケイト/
dupulicate /デュプリケート/
duration /デュレイション/
duskin /ダスキン/
dvi /ｄｖｉ/
dvm /分散仮想記憶/
dvvm /大域的仮想仮想記憶/
dwarf /ドワーフ/
dylan /Ｄｙｌａｎ/ディラン/Dylan/Dylan(Dynamic language)/
dyna /ＤＹＮＡ/
dynabook /ダイナブック/
dynamic /ダイナミック/
dynamics /ダイナミクス/ダイナミックス/
dynamism /ダイナミズム/
dynamite /ダイナマイト/
dynamo /ダイナモ/
dystal /ＤＹＳＴＡＬ/
e /Ｅ/ｅ/
ear /イア/イヤー/
earphone /イアフォン/イヤフォン/
earring /イアリング/
earth /アース/
eason /イーソン/
east /Ｅａｓｔ/イースト/
eastwood /イーストウッド/
easy /イージー/
easyorder /イージーオーダー/
eb /ＥＢ/
ec /ＥＣ/
eccentric /エキセントリック/
echo /エコー/
echoback /エコーバック/
ecip /情報処理教育センター/
ecology /エコロジー/
economist /エコノミスト/
economy /エコノミー/
ed /ｅｄ/ＥＤ/エド/
edbeta /ＥＤベータ/
edge /エッジ/
edinburgh /エディンバラ/
edit /エディット/エディト/編集/
edition /エディション/
editor /エディタ/エディター/
edward /エドワード/
edwin /エドウィン/
effect /エフェクト/
effector /エフェクター/エフェクタ/
effects /エフェクツ/
ega /ＥＧＡ/
egg /ｅｇｇ/エッグ/
egoism /エゴイズム/
egoist /エゴイスト/
egypt /エジプト/
eight /エイト/
einstein /アインシュタイン/
eis /ＥＩＳ/
eisa /ＥＩＳＡ/
eject /イジェクト/
elec /エレキ/
electone /エレクトーン/
electric /エレクトリック/
electrical /エレクトリカル/
electro /エレクトロ/
electron /エレクトロン/
electronic /エレクロニック/
electronics /エレクトロニクス/
elegant /エレガント/
elegie /エレジー/
element /エレメント/
elemental /エレメンタル/
elementary /エレメンタリー/
elevator /エレベーター/
eleven /イレブン/
elf /エルフ/
elisp /ｅｌｉｓｐ/EmacsLisp/
elite /エリート/
elk /ｅｌｋ/Elk/
elocution /エロキューション/
elvis /エルビス/
emacs /Ｅｍａｃｓ/ｅｍａｃｓ/Emacs/イーマックス/
emacslisp /EmacsLisp/
email /電子メイル/E-mail/電子メール/
emblem /エンブレム/
emboss /エンボス/
emotion /エモーション/
emphasis /強調/
empty /エンプティー/エンプティ/
emulate /エミュレート/イミュレート/
emulation /エミュレーション/
emulator /エミュレータ/エミュレーター/イミュレイタ/イミュレータ/
emurate /エミュレート/
emurater /エミュレータ/
enable /イネーブル/
enableware /イネーブルウェア/
enamel /エナメル/
enbug /エンバグ/
encapsulate /カプセル化/
encapsulation /エンカプセレーション/エンカプシュレーション/
encapsulator /エンカプスレータ/
enclosure /エンクロージャ/
encode /エンコード/符号化/
encoder /エンコーダー/エンコーダ/
encoding /エンコーディング/
encore /アンコール/
encount /エンカウント/
encounter /エンカウンター/
encyclopedia /エンサイクロペディア/百科事典/
end /エンド/−−−−−−−−−−−−−−−ここまで−−−−−−−−−−−−−−−/===================== ここまで ====================/END--cut here--cut here/
endian /エンディアン/
ending /エンディング/
endless /エンドレス/
endorphin /エンドルフィン/
endpoint /エンドポイント/
enduser /エンドユーザ/
energish /エネルギッシュ/
energy /エネルギー/エナジー/
engine /エンジン/
engineer /エンジニア/
engineering /エンジニアリング/
england /イギリス/イングランド/
englar /エングラー/
english /イングリッシュ/イギリス/英吉利/
enhance /エンハンス/
enhanced /エンハンスド/
enjoy /エンジョイ/
enquete /アンケート/
enqueue /エンキュー/
ensemble /アンサンブル/
entailment /→/
enter /エンター/
enterprise /エンタープライズ/
entertainer /エンターティナー/
entertainment /エンターテインメント/
entity /エンティティ/
entrepreneur /アントレプレナー/
entropy /エントロピー/
entry /エントリ/エントリー/
envelope /エンベロープ/
eof /EOF/
eos /ＥＯＳ/
epi /エピ/
epic /ｅｐｉｃ/
epicurean /エピキュリアン/
epilogue /エピローグ/
epipolar /エピポーラ/
episode /エピソード/
epoch /エポック/
epock /エポック/
epsilon /ε/イプシロン/∋/∈/
epson /エプソン/
eq /＝/≡/
equal /＝/イコール/
equality /イクアリティ/
equalizer /イコライザ/
equity /エクイティ/
equiv /⇔/≡/
erector /エレクター/
ergode /エルゴード/
erica /エリカ/
eros /エロス/
erotic /エロティック/
eroticism /エロチシズム/
err /エラー/
error /エラー/エラーメッセージ/
errorcheck /エラーチェック/
errordialog /エラー・ダイアログ/
errormessage /エラーメッセージ/
errorsignal /エラーシグナル/
es /ＥＳ/
esc /ｅｓｃ/エスケープ/
escalate /エスカレート/
escalator /エスカレータ/エスカレーター/
escape /エスケープ/
escargot /エスカルゴ/
escher /エッシャー/
escort /エスコート/
esher /エッシャー/
eskimo /エスキモー/
esp /ESP/
esquimau /エスキモー/
essay /エッセィ/エッセイ/
essence /エッセンス/
essential /エッセンシャル/
establishment /設立/
estrogen /エストロゲン/
eta /η/
ether /イーサ/
etherboard /イーサーボード/
ethernet /イーサネット/
ethiopia /エチオピア/
ethnic /エスニック/
etiquette /エチケット/
etl /電総研/電子技術総合研究所/
etude /エチュード/
euc /ＥＵＣ/ｅｕｃ/
euclid /ユークリッド/
euler /オイラー/
eunos /ユーノス/
eurasip /ＥＵＲＡＳＩＰ/
europa /欧州/欧羅巴/歐州/歐羅巴/
europe /ヨーロッパ/欧州/欧羅巴/歐州/歐羅巴/
evaluate /評価する/
evaluator /エバリュエータ/
eve /イヴ/イブ/
even /イーブン/
evening /イブニング/
event /イベント/イヴェント/
eventhandler /イベントハンドラ/
ever /エバー/
evergreen /エバーグリーン/
evil /エビル/
evolution /発展/
ew /─/━/
ewi /ＥＷＩ/
ewn /┷/┴/┻/┸/
ews /ＥＷＳ/エンジニアリング・ワークステーション/ワークステーション/┯/┬/┳/┰/
ex /∃/ＥＸ/
exceed /エクシード/
excelan /エクセラン/
excellent /エクセレント/
exception /例外/
exchange /エクスチェンジ/
exciting /エキサイティング/
exclamation /感嘆符/
exec /実行/
exective /エグゼクティブ/
execute /エグゼキュート/
executive /エクゼクティブ/
exercise /Ｅｘｅｒｃｉｓｅ/エクササイズ/
exhibition /エキシビジョン/
exist /∃/
exists /∃/
exit /イグジット/
exp /エクスポネンシャル/
expand /拡張/イクスパンド/
expander /エクスパンダ/
expert /エキスパート/
expertsystem /エキスパート・システム/
expiration /エクスパイレーション/
expire /エクスパイア/
expo /エキスポ/
exponential /エクスポネンシャル/
export /エクスポート/エキスポート/
expose /エクスポーズ/
express /エクスプレス/
expression /式/イクスプレッション/
extender /エクステンダ/
extension /エクステンション/
extent /エクステント/
external /エクスターナル/
extra /エキストラ/エクストラ/
extract /エキス/
eye /アイ/
eyebrow /アイブロウ/
eyeliner /アイライナー/
eyeshadow /アイシャドウ/
f /Ｆ/ｆ/周波数/
f1 /Ｆ１/１／ｆゆらぎ/
f8 /Ｆ８/
fa /ＦＡ/
faa /ＦＡＡ/
face /フェース/フェイス/(concat "(\073_\073)")/(concat "(^_^\073)")/(_o_)/:-(/:-</:-B/:-P/X-(/
facom /ファコム/
facsimile /ファクシミリ/
fact /ファクト/
factor /ファクター/
fade /フェード/
fader /フェイダー/
fail /フェイル/失敗/
failure /フェイリュア/
faint /フェイント/
fair /フェアー/フェア/
false /誤/偽/
fame /Ｆａｍｅ/
famicom /ファミコン/
famicon /ファミコン/
family /ファミリー/ファミリ/
familyrestaurant /ファミリーレストラン/
fan /ファン/
fanclub /ファンクラブ/
fanin /ファンイン/
fanout /ファンアウト/
fantasic /ファンタジック/
fantasy /ファンタジー/
faq /ＦＡＱ/
faraday /ファラデー/
fashion /ファッション/
fashionable /ファッショナブル/
fast /ファースト/ファスト/
fastfood /ファストフード/
fatal /フェイタル/
fault /フォールト/フォルト/
faulttolerance /フォールトトレランス/
faulttolerancy /フォルトトレランシ/
faure /フォーレ/
fax /ファクシミリ/ファックス/Ｆａｘ/ファクス/FAX/
fazzy /ファジィ/
fb /フレームバッファ/
fc /ＦＣ/
fd /フロッピーディスク/FD/
fddi /ＦＤＤＩ/
fe /ＦＥ/
feasibility /フィージビリティ/
feature /フィーチャー/フィーチャ/
feed /フィード/
feedback /フィードバック/
feeder /フィーダ/
feedforward /フィードフォワード/
feel /フィール/
feeling /フィーリング/
feet /フィート/
feferman /フェファーマン/
feller /フェラー/
fellowship /フェローシップ/
fem /有限要素法/
feminism /フェミニズム/
fen /ＦＥＮ/
fence /フェンス/
fender /フェンダー/
fep /ＦＥＰ/フロントエンドプロセッサ/
ferry /フェリー/
fes /フェス/
festiva /フェスティヴァ/
festival /フェスティバル/
fet /ＦＥＴ/電界効果トランジスタ/
fetch /フェッチ/
fetishism /フェティシズム/
fever /フィーバー/
feynman /ファインマン/
ff /font-family/
fft /ＦＦＴ/高速フーリエ変換/
fg /フォアグラウンド/
fiance /フィアンセ/
fiancee /フィアンセ/
fiber /ファイバー/ファイバ/
fibonacci /フィボナッチ/
fiction /フィクション/
field /フィールド/
fieldmap /フィールドマップ/
fifo /先入れ先出し/ＦＩＦＯ/
fight /ファイト/
fighter /ファイター/
figure /フィギュア/フィギュアー/
file /ファイル/
filehandle /ファイルハンドル/
filemenu /ファイル・メニュー/
filename /ファイルネーム/ファイル名/
filepointer /ファイルポインタ/
filer /ファイラー/ファイラ/
fileserver /ファイルサーバー/
fileset /ファイルセット/
filesystem /ファイルシステム/
filing /ファイリング/
fill /フィル/
fillet /フィレット/
fillin /フィルイン/
film /フィルム/
filter /フィルター/フィルタ/
filterbank /フィルタバンク/
filtered /フィルタード/
filtering /フィルタリング/
final /ファイナル/
finalize /ファイナライズ/
finance /ファイナンス/
finder /ファインダ/ＦＩＮＤＥＲ/
finesse /フィネス/
finger /フィンガー/
fingering /フィンガリング/
finish /フィニッシュ/
finland /フィンランド/
fire /ファイア/
firewall /ファイアウォール/
firm /ファーム/
firmware /ファームウェア/
first /ファースト/１ｓｔ/第1要素/
firstclass /ファースト・クラス/
firstname /ファーストネーム/
fish /フィッシュ/
fisher /フィッシャー/
fit /フィット/
fitness /フィットネス/
fitting /フィッティング/
fix /フィックス/フィクス/修正/
fixed /フィクスト/
fizz /フィズ/
fj /ｆｊ/
flag /フラグ/
flail /フレイル/
flake /フレーク/
flame /フレーム/
flange /フランジ/
flap /フラップ/
flash /フラッシュ/
flat /フラット/♭/
flatter /フラッタ/
flavor /フレイヴァー/Ｆｌａｖｏｒ/Flavor/
flex /フレックス/
flexible /フレキシブル/柔軟な/
flight /フライト/
flip /フリップ/
flipflop /フリップフロップ/フリップロップ/
flipper /フリッパー/
float /フロート/浮動小数点数/
floating /フローティング/浮動小数点数/
floor /フロアー/フロア/
floorplan /フロアプラン/
flop /フロップ/
floppy /フロッピィ/フロッピー/フロッピ/
floppydisk /フロッピィディスク/
florida /フロリダ/
flow /フロー/
flowchart /フローチャート/フロウチャート/
flower /フラワー/
flowgraph /フローグラフ/
floyd /フロイド/
flush /フラッシュ/
flute /フルート/
flutter /フラッタ/
fly /ハエ/フライ/
flying /フライング/
flying-pan /フライパン/
fm /ＦＭ/
fmr /ＦＭＲ/
fns /ＦＮＳ/
focus /フォーカス/
focusmode /フォーカスモード/
fodor /フォドー/
fog /フォグ/
foghorn /フォグホーン/
fold /フォールド/
folder /フォルダ/フォルダー/
folding /フォールディング/
folk /フォーク/
folkdance /フォークダンス/
follow /フォロウ/フォロー/
follower /フォロワー/
font /フォント/
fontlist /フォントリスト/
fontpath /フォントパス/
fontserver /フォントサーバー/
fontset /フォントセット/
foo /ｆｏｏ/
food /フード/
foods /フーズ/
fool /フール/
fools /フールズ/
foot /フット/
football /フットボール/
footer /フッタ/
footnote /¶/
footprint /フットプリント/
footwork /フットワーク/
for /ｆｏｒ/
forall /∀/
force /フォース/
forcus /フォーカス/
ford /フォード/
fore /フォア/
foreground /フォアグラウンド/
forest /フォレスト/
fork /フォーク/ｆｏｒｋ/
form /フォーム/
formal /フォーマル/形式的/
formalize /フォーマライズ/
formant /ホルマント/
format /フォーマット/形式/
formation /フォーメーション/
formatstring /フォーマットストリング/
formatter /フォーマッタ/
formatting /フォーマッティング/
formula /論理式/
forte /フォルテ/ＦＯＲＴＥ/
fortran /ＦＯＲＴＲＡＮ/
forum /フォーラム/
forval /フォーバル/
forward /フォワード/
forwarder /フォーワーダ/
forwarding /フォワーディング/
forword /フォワード/
foul /ファール/
foundation /ファウンデーション/ファンデーション/
fourball /フォアボール/
fourier /フーリエ/
fox /フォックス/
fractal /フラクタル/
fragment /フラグメント/
fragmentation /フラグメンテーション/
frame /フレーム/フレイム/
framebuffer /フレームバッファ/
framework /フレームワーク/
franc /フラン/
france /フランス/仏蘭西/佛蘭西/
franchise /フランチャイズ/
francisco /フランシスコ/
franken /フランケン/
frankenstein /フランケンシュタイン/
franz /Ｆｒａｎｚ/ｆｒａｎｚ/
fraser /フレーザー/
freak /フリーク/
free /フリー/
free-software /フリーソフトウェア/
freedial /フリーダイアル/
freehand /フリーハンド/
freelist /フリーリスト/
freepage /フリーページ/
freesoft /フリーソフト/
freesoftware /フリーソフトウェア/フリーソフトウエア/
freeware /フリーウェア/
freeze /フリーズ/
frege /フレーゲ/
french /フレンチ/フランス語/
fresco /Fresco/
fresh /フレッシュ/
fret /フレット/
fretless /フレットレス/
fri /金/
fried /フライド/
friedchicken /フライドチキン/
friend /フレンド/
friendly /フレンドリ/
from /━ここから━/━━━━━ここから━━━━━/(concat "----- ここから ----- ここから ----- ここから ----- ここから -----\n")/
front /フロント/
frontend /フロントエンド/
frontglass /フロントガラス/
frontier /フロンティア/
frown /⌒/
fruit /フルート/フルーツ/
fruits /フルーツ/
frustration /フラストレーション/
fry /フライ/
fsf /Free Software Foundation/FSF/
ft /ＦＴ/
ftp /ｆｔｐ/ftp/FTP/
fuji /フジ/
fujitsu /富士通/
fujitv /フジテレビ/
full /フル/一杯/
full-time /フルタイム/
fullinstall /フルインストール/
fullname /フルネーム/
fullpath /フルパス/
fullrange /フルレンジ/
fullscore /フルスコア/
fulltime /フルタイム/
fun /ファン/
function /ファンクション/機能/関数/
functional /汎関数/
functionkey /ファンクションキー/
fund /ファンド/
funk /ファンク/
funky /ファンキー/
fuse /ヒューズ/
fusion /フュージョン/
future /フューチャ/フューチャー/
fuzzy /ファジー/ファジィ/
fw /周波数荷重/ＦＷ/
g /Ｇ/ｇ/
g-theory /Ｇ−理論/
ga /遺伝的アルゴリズム/ＧＡ/
gacchan /ガッチャン/
gadget /ガジェット/
gag /ギャグ/
gain /ゲイン/
gal /ギャル/
gala /ギャラ/
galaxy /ギャラクシー/
gallery /ギャラリー/
galley /ゲラ/
gamble /ギャンブル/
gambler /ギャンブラー/
game /ゲーム/ＧＡＭＥ/
gamecenter /ゲームセンター/
gamer /ゲーマー/
gamest /ゲーメスト/
gamma /γ/γ版/
gammon /ギャモン/
gang /ギャング/
gap /ギャップ/
garage /ガレージ/
garbage /ガーベージ/ガベージ/ガーベッジ/
garden /ガーデン/
garfield /ガーフィールド/
garnet /ガーネット/
gas /ガス/瓦斯/ガソリン/
gasoline /ガソリン/
gate /ゲート/
gatearray /ゲートアレイ/
gateway /ゲートウェイ/
gather /ギャザー/
gauge /ゲージ/
gauss /ガウス/
gaussian /ガウシアン/
gawk /ｇａｗｋ/
gay /ゲイ/
gb /ＧＢ/ＧＢｙｔｅ/
gc /ガーベッジ・コレクション/グラフィク・コンテキスト/
gcc /ｇｃｃ/Gcc/
gcl /GCL/
ge /≧/
gear /ギヤ/ギア/
gel /ゲル/ジェル/
geller /ゲラー/
general /ジェネラル/
generalist /ジェネラリスト/
generate /ジェネレート/
generator /ジェネレータ/
generic /ジェネリック/
genesis /ＧＥＮＥＳＩＳ/
genetic /ジェネティック/
geneticalgorithms /ジェネティックアルゴリズム/
geneticsystem /ジェネティックシステム/
genom /ゲノム/
genome /ゲノム/
genre /ジャンル/
gentleman /ゼントルマン/
gentzen /ゲンツェン/
geometry /ジオメトリ/
geomtory /ジオメトリ/
geopotential /ジオポテンシャル/
george /ジョージ/
georgemason /ジョージ・メイソン大学/
georgia /ジョージア/
geq /≧/
german /ドイツ/
germany /ドイツ/
gestalt /ゲシュタルト/
get /ゲット/得る/
gfp /最大不動点/
gg /≫/
ghc /ＧＨＣ/
ghost /ゴースト/
giants /ジャイアンツ/
gif /ＧＩＦ/
gift /ギフト/
giga /ギガ/
gile /ガイル/
gina /ＧＩＮＡ/ｇｉｎａ/GINA(the Generic Interactive Application)/
giraffu /ジラフ/
girl /ガール/
girls /ガールズ/
gks /ＧＫＳ/
glass /グラス/ガラス/硝子/
glasswool /グラスウール/
glenn /グレン/
glider /グライダー/
global /グローバル/
globaldatafile /グローバルデータファイル/
globalmemory /グローバルメモリ/
glove /グローヴ/
glue /グルー/
glyph /グリフ/
gmd /GMD(German National Research Center for Computer Science)/
gmdh /ＧＭＤＨ/
gmt /ＧＭＴ/グリニッジ標準時/GMT/
gmw /ＧＭＷ/
gnome /ノーム/
gnp /ＧＮＰ/
gnu /ＧＮＵ/GNU/
gnus /Ｇｎｕｓ/ｇｎｕｓ/GNUS/Gnus/
go /ゴー/
goal /ゴール/
goddard /ゴッダード/
godel /ゲーデル/
godzilla /ゴジラ/
goedel /ゲーデル/
gold /ゴールド/
goldberg /ゴールドバーグ/ゴールドベルグ/
golden /ゴールデン/
goldenweek /ゴールデンウィーク/
golf /ゴルフ/
golfer /ゴルファー/
gom /ゴム/
gong /ゴング/
good /グッド/グー/
good-bye /グッド・バイ/
goods /グッズ/
goodyear /グッドイアー/
gordon /ゴードン/
goro /ＧＯＲＯ/
gosign /ゴーサイン/
gossip /ゴシップ/
goteborg /イェテボリ/
gothenburg /イェテボリ/
gothic /ゴシック/
gould /グールド/
gourmet /グルメ/
gp /ＧＰ/
gpan /Ｇパン/
gpl /GPL/
gps /ＧＰＳ/
grab /グラブ/
grace /グレース/ＧＲＡＣＥ/
grade /グレード/
gradeup /グレイドアップ/グレードアップ/
gradient /グラディエント/
gradius /グラディウス/
graduate /大学院生/
gram /グラム/
grammar /グラマー/
grand /グランド/
grandpiano /グランドピアノ/
grandprix /グランプリ/
granular /グラニュラー/
grape /グレープ/
grapefruits /グレープフルーツ/
graph /グラフ/
graphic /グラフィック/グラフィク/
graphica /グラフィカ/
graphical /グラフィカル/
graphicalinterface /グラフィカル・インターフェイス/
graphics /グラフィックス/グラフィクス/
graphmatching /グラフマッチング/
grapple /グラップル/
gray /グレイ/
grayout /グレイアウト/
grb /ＧＲＢ/
great /グレート/
greece /ギリシア/
greek /α/β/γ/δ/ε/ζ/η/θ/λ/μ/ι/κ/ν/ξ/ρ/π/ο/σ/φ/χ/τ/υ/ψ/ω/ギリシャ/
green /グリーン/
greenwich /グリニッジ/
grey /グレイ/グレー/
grid /グリッド/
griffin /グリフィン/
grimm /グリム/
grip /グリップ/
gripper /グリッパー/
groove /グルーヴ/
ground /グラウンド/グランド/
group /グループ/
grouping /グルーピング/
groupingeffect /グルーピング・エフェクト/
groupware /グループウェア/
growing /グローイング/
gs /ＧＳ/ghostscript/
gsis /情報科学研究科/
gt /＞/
guam /グァム/
guard /ガード/
guardian /ガーディアン/
guest /ゲスト/
gui /ＧＵＩ/GUI/グラフィカルユーザインターフェース/
guidance /ガイダンス/
guide /ガイド/
guideline /ガイドライン/
guile /ガイル/
guitar /ギター/
guitaramp /ギターアンプ/
guitarist /ギタリスト/
guitarmagazine /ギターマガジン/
guitarsynth /ギターシンセ/
gum /ゴム/ガム/
gun /ガン/
gunner /ガンナー/
gunnm /銃夢/
gustav /グスタフ/
gut /ガット/
guts /ガッツ/
gw /ＧＷ/ゴールデンウィーク/ゲートウェイ/GateWay/
gym /ジム/
gypsy /ジプシー/
gyro /ジャイロ/
h /Ｈ/エッチ/
h# /平成#0年度/平成#0年/
h#.#.# /平成#0年#0月#0日/
hack /ハック/
hacker /ハッカー/
hacking /ハッキング/
hadamard /アダマール/
hair /ヘア/
half /ハーフ/
hall /ホール/
hambacker /ハムバッカー/
hamburg /ハンブルグ/
hamburger /ハンバーガー/
hamilton /ハミルトン/
hammer /ハンマー/ハンマ/
hamming /ハミング/
hand /ハンド/
handbook /ハンドブック/
handkerchief /ハンカチーフ/ハンカチ/
handle /ハンドル/
handler /ハンドラ/
handling /ハンドリング/
handoff /ハンドオフ/
hands /ハンズ/
handshake /ハンドシェイク/
handy /ハンディ/
hang /ハング/
hanger /ハンガー/
hangul /ハングル/
hangup /ハングアップ/
hankel /ハンケル/
hanning /ハニング/
hanoi /ハノイ/
happening /ハプニング/
happiness /ＨＡＰＰＩＮＥＳＳ/
happy /ハッピー/
happyend /ハッピーエンド/
happytalking /ハッピートーキング/
hard /ハード/ハードウェア/
hardcopy /ハードコピー/
hardcover /ハードカバー/
harddisk /ハードディスク/
hardle /ハードル/
hardlink /ハードリンク/
hardrock /ハードロック/
hardware /ハードウェア/
hardwiring /ハードワイアリング/
harmonize /ハーモナイズ/
harmony /ハーモニー/
harp /ハープ/
harpy /ハーピー/ハルピュイア/
harrier /ハリヤー/
harrop /ハロップ/
harry /ハリー/
harvard /ハーバード/
harvester /ハーベスタ/
hash /ハッシュ/
hat /ハット/
hatch /ハッチ/
hatchback /ハッチバック/
hawaii /ハワイ/
hawk /ホーク/
hazard /ハザード/
hd /ＨＤ/ハードディスク/
hdtv /ＨＤＴＶ/
head /ヘッド/
header /ヘッダ/ヘッダー/
headerfile /ヘッダファイル/ヘッダーファイル/
heading /ヘッディング/
headphone /ヘッドホン/ヘッドフォン/
heal /ヒール/
health /ヘルス/
healthcheck /ヘルスチェック/
healthy /ヘルシー/
heap /ヒープ/
hear /ヒア/
hearing /ヒアリング/
heart /ハート/ハツ/
heat /ヒート/
heater /ヒーター/
heavy /ヘビー/
hebrew /ヘブライ/
hedge /ヘッジ/
heel /ヒール/
height /高さ/ハイト/
heights /ハイツ/
helical /ヘリカル/
helicopter /ヘリコプター/
helium /ヘリウム/
hello /ハロー/
helmet /ヘルメット/
helmholtz /ヘルムホルツ/
help /ヘルプ/
helpdesk /ヘルプデスク/
helper /ヘルパ/ヘルパー/
henry /ヘンリー/
herb /ハーブ/
herbrand /エルブラン/
here /ヒア/
herman /エルマン/
hermit /エルミット/
hero /ヒーロー/
heroine /ヒロイン/
hertz /ヘルツ/
hetero /ヘテロ/ヘテロジニアス/
heterogeneous /ヘテロジニアス/
heuristic /ヒューリスティック/
heuristics /ヒューリスティクス/
hex /十六進数/
hexard /ヘキサード/
hh /ＨＨ/
hi /ハイ/ヒューマンインターフェース/
hi8 /Ｈｉ８/
hiband /ＨｉＢａｎｄ/
hide /ハイド/非表示/
hiding /ハイディング/
hie /境界積分方程式/
high /ハイ/
highend /ハイエンド/
highlight /ハイライト/
highschool /ハイスクール/
hightech /ハイテク/
highvision /ハイビジョン/
highway /ハイウェイ/
hihat /ハイハット/
hiking /ハイキング/
hilbert /ヒルベルト/
hilevel /ハイレベル/
hilight /ハイライト/
hilite /ハイライト/
hill /ヒル/
hilton /ヒルトン/
him /境界積分法/
hinet /ＨＩＮＥＴ/
hint /ヒント/
hip /ヒップ/
hireso /ハイレゾ/
histogram /ヒストグラム/
history /ヒストリ/ヒストリー/
hit /ヒット/
hitchcock /ヒッチコック/
hitom /ハイタム/
hitter /ヒッター/
hivision /ハイビジョン/
hmv /ＨＭＶ/
hoare /ホーア/
hobbit /ホビット/Ｈｏｂｂｉｔ/
hockey /ホッケー/
hoe /ホー/
hold /ホールド/
holder /ホルダー/ホルダ/
hole /ホール/
holiday /ホリデイ/ホリデー/
holland /オランダ/
holmes /ホームズ/
hologram /ホログラム/
holographic /ホログラフィック/
holography /ホログラフィー/
holon /ホロン/
home /ホーム/
homedir /ホームディレクトリ/
homedirectory /ホームディレクトリ/
homeless /ホームレス/
homepage /ホームページ/
homeroom /ホームルーム/
homerun /ホームラン/
homesick /ホームシック/
homing /ホーミング/
homo /ホモ/
honda /ホンダ/
honey /ハニー/
honeymoon /ハネムーン/
hongkong /香港/
honolulu /ホノルル/
hook /フック/
hop /ホップ/
hope /ホープ/
hopkins /ホプキンス/
hopper /ホッパー/
horizont /ホリゾント/
horizontal /水平/水平方向/
horn /ホーン/ホルン/
horror /ホラー/
horse /ホース/
hose /ホース/
hoshi /☆/★/
hospice /ホスピス/
host /ホスト/
hostdata /ホストデータ/
hostname /ホストネーム/ホスト名/
hot /ホット/
hotel /ホテル/
hotpants /ホットパンツ/
hotplate /ホット・プレート/
hough /ハフ/
hour /アワー/
house /ハウス/
housekeeping /ハウスキーピング/
how /ハウ/
howling /ハウリング/
hp /ＨＰ/ヒューレット・パッカード/HP/
hpf /ハイパスフィルタ/
hr /ホルン/
hrtf /頭部伝達関数/頭部音響伝達関数/
hs /ＨＳ/
hterm /ｈｔｅｒｍ/
htf /頭部伝達関数/
hub /ハブ/
hubbard /ハバード/
hudson /ハドソン/波怒村/
hue /色調/
huffman /ハフマン/
huge /ヒュージ/
human /ヒューマン/
humanlike /ヒューマンライク/
humming /ハミング/
humor /ユーモア/
humour /ユーモア/
hung /ハング/
hungup /ハングアップ/
hunk /ハンク/
hunter /ハンター/
hunting /ハンティング/
hurd /Hurd/
hurricane /ハリケーン/
hybrid /ハイブリッド/
hydra /ヒドラ/ヒュドラ/
hyper /ハイパー/
hypercard /ハイパーカード/
hypercube /ハイパーキューブ/
hypermedia /ハイパーメディア/
hypertext /ハイパーテキスト/
hyphen /ハイフン/‐/
hyphenation /ハイフネーション/
hz /Ｈｚ/
i /Ｉ/ｉ/私/
i/o /Ｉ／Ｏ/
ibm /ＩＢＭ/インターナショナル・ビジネス・マシーンズ・コーポレーション/アイ・ビー・エム/
ibmpc /ＩＢＭ-ＰＣ/
ic /ＩＣ/
icann /ＩＣＡＮＮ/
ice /アイス/ＩＣＥ/インサーキットエミュレーター/氷/
icebox /アイスボックス/
icecream /アイスクリーム/
icetea /アイスティ/
ici /ＩＣＩ/
icmc /ＩＣＭＣ/
icmp /ＩＣＭＰ/
icnc /ＩＣＮＣ/
icnn /ＩＣＮＮ/
icon /アイコン/
iconic /アイコン化/
iconify /アイコニファイ/
icot /新世代コンピュータ開発機構/ＩＣＯＴ/新世代コンピュータ技術開発機構/
icu /ＩＣＵ/
id /ＩＤ/識別子/Ｉｄ/帰納的定義/ID/識別子列/
idea /アイディア/アイデア/
ideal /イデアル/
identifier /アイデンティファイア/識別子/
identity /アイデンティティ/アイデンティティー/
idic /Ｉ-ｄｉｃ/
idiom /イディオム/
idiomatic /イディオマティック/
idle /アイドル/
idol /アイドル/
ieee /ＩＥＥＥ/
ieice /電子情報通信学会/
if /ｉｆ/イフ/インターフェース/インタフェース/
iff /必要十分条件/⊃⊂/<==>/
ifft /ｉＦＦＴ/
ignore /イグノア/
ih /帰納法の仮定/
ijcai /ＩＪＣＡＩ/
ijcnn /ＩＪＣＮＮ/
illinois /イリノイ/
illumination /イリュミネイション/
illusion /イリュージョン/
illust /イラスト/
illustration /イラストレーション/
image /イメージ/
imagemap /イメージマップ/
imagewindow /イメージウインドー/
imaging /イメージング/
imbalance /インバランス/
imho /ＩＭＨＯ/
imitation /イミテーション/
imp /⊃/ＩＭＰ/
impact /インパクト/
impedance /インピーダンス/
implement /インプリメント/
implementation /インプリメンテーション/インプリメンテイション/
implementor /インプリメンタ/
implication /⊃/
implied /⊂/
implies /ならば/→/⇒/⊃/
imply /⊃/→/
import /インポート/
impose /インポーズ/
impression /インプレッション/
impulse /インパルス/
in /イン/ＩＮ/∈/インチ/
inactive /インアクティブ/
inc /Ｉｎｃ．/
ince-j /日本騒音制御工学会/
incentive /インセンティブ/
inch /インチ/吋/
include /インクルード/∈/∋/epsilon/
income /インカム/
increment /インクリメント/
incremental /インクリメンタル/
indent /インデント/
indentation /インデンテーション/インデンテイション/字下げ/
independent /インディペンデント/
index /インデックス/インデクス/
indexation /インデクセーション/
indexing /インデクシング/
indexmode /インデックスモード/
india /インド/
indian /インディアン/
indication /インディケーション/
indicator /インジケータ/
indicial /インディシャル/
indo /インド/
indonesia /インドネシア/
inductance /インダクタンス/
induction /インダクション/帰納法/
industrial /インダストリアル/
inews /ｉｎｅｗｓ/
infinity /∞/
inflation /インフレーション/
inflationary /インフレーショナリ/インフレ/
info /インフォ/
informal /インフォーマル/
information /インフォメーション/情報/
informatique /アンフォルマティーク/
informed /インフォームド/
infra /インフラ/
infrastructure /インフラストラクチャー/インフラ/
ing /イング/
inheritance /インヘリタンス/
inhouse /インハウス/
initial /イニシャル/
initialize /イニシャライズ/
initiative /イニシアティブ/
initiator /イニシエータ/
injector /インジェクター/
ink /インク/
inkjet /インクジェット/
inlane /インレーン/
inline /インライン/
inn /イン/
inner /インナー/
innocence /イノセンス/
inode /ｉノード/iノード/
inprovisation /インプロヴァイゼィション/
inpulse /インパルス/
input /インプット/入力/
insensitive /インセンシティブ/
insert /インサート/
insertion /インサーション/
inside /インサイド/
insider /インサイダー/
insoft /インソフト/
inspector /インスペクタ/
inspiration /インスピレーション/
inst /インスト/
install /インストール/
installation /インストレーション/
installer /インストーラ/
instance /インスタンス/
instant /インスタント/
instantiate /インスタンシエート/具体化/
institution /インスティテューション/
instruction /インストラクション/
instructor /インストラクター/
instrument /インスツルメント/
instrumental /インスツルメンタル/
instruments /インスツルメンツ/
insufficient /不充分/不足/
int /∫/
integer /インテジャ/整数/
integra /インテグラ/
integral /∫/∬/
integrate /インテグレート/
integration /インテグレーション/
integrity /インテグリティ/完全/
intel /インテル/Intel/
intellectual /インテレクチュアル/
intelligent /インテリジェント/
intensity /インテンシティ/
intensive /インテンシブ/
inter /インター/インタ/
interact /インタラクト/
interaction /インタラクション/
interactive /インタラクティブ/インタラクティヴ/
interbank /インターバンク/
intercept /インターセプト/インタセプト/
interface /インターフェース/インタフェース/インターフェイス/インタフェイス/
interfaceboard /インターフェースボード/
interferon /インターフェロン/
interleave /インターリーブ/インタリーブ/
interlock /インターロック/インタロック/
intern /インターン/
internal /インターナル/
international /インターナショナル/
internet /インターネット/Ｉｎｔｅｒｎｅｔ/インタネット/
internetwork /インターネットワーク/
internetworking /インターネットワーキング/
internoise /インターノイズ/
interpol /インターポール/
interpret /インタープリト/
interpreter /インタープリタ/インタプリタ/インタープリータ/
interpretive /インタプリティブ/
interrace /インターレース/
interrupt /インタラプト/
interrupter /インタラプター/
intersection /∩/
interval /インターバル/インタバル/
interview /インタビュー/インタヴュー/
interviewer /インタヴュアー/
intonation /イントネーション/
intrinsics /イントリンシックス/
intro /イントロ/
introduction /イントロダクション/導入/
invalid /誤った/無効な/インバリッド/
invalidate /インバリデート/
invalidation /インバリデーション/
invariant /インヴァリアント/
invention /インヴェンション/
inventory /インベントリ/
inverse /インヴァース/インバース/
inversion /インヴァージョン/
inverter /インバーター/インバータ/
investment /インベストメント/
invitation /インビテーション/
invitational /インヴィテイショナル/
invoice /インボイス/インヴォイス/
io /Ｉ／Ｏ/入出力/
ion /イオン/
ionicchannel /イオニック・チャンネル/
iosome /アイソメ/
iota /ι/
iowa /アイオワ/
ip /ＩＰ/IP/IPアドレス/
ipc /ＩＰＣ/
ips /知的処理システム/
ipx /ｉｐｘ/
iraq /イラク/
ircam /ＩＲＣＡＭ/
ireland /アイルランド/
iron /アイアン/
irony /アイロニー/
irq /IRQ/
irregular /イレギュラー/
is /ＩＳ/
isa /ＩＳＡ/
isaac /アイザック/イサク/
isdn /ＩＳＤＮ/
island /アイランド/
iso /ISO/
isolator /アイソレータ/
isoparametric /アイソパラメトリック/
isotonic /アイソトニック/
israel /イスラエル/
italia /イタリア/
italic /イタリック/
italy /イタリア/
itd /両耳間到達時間差/
item /アイテム/項目/- /
iterative /逐次型/
itriangle /▼/
ivory /アイヴォリー/
ivy /アイビー/
j /Ｊ/
j2 /Ｊ２/
j3100 /Ｊ３１００/
jack /ジャック/
jacket /ジャケット/
jacob /ヤコブ/
jacobi /ヤコビ/
jain /ＪＡＩＮ/
jaist /北陸先端大/ＪＡＩＳＴ/ジャイスト/北陸先端科学技術大学院大学/JAIST/Japan Advanced Institute of Science and Technology/
jal /ＪＡＬ/日本航空/日航/
jam /ジャム/ＪＡＭ/
james /ジェームス/
jane /ジェーン/
japan /ジャパン/日本/
japanese /ジャパニーズ/
jargon /ジャーゴン/
jarrett /ジャレット/
jasj /日本音響学会/
jasper /碧玉/
jazz /ジャズ/
jazzchorus /ジャズコーラス/
jazzfes /ジャズフェス/
jazzlife /ジャズライフ/
jazzpiano /ジャズピアノ/
jbibtex /jBibTeX/
jcb /ＪＣＢ/
jcc /日本電算/日本電算機/
jeans /ジーンズ/
jeep /ジープ/
jelly /ゼリー/
jenkins /ジェンキンズ/
jenny /ジェニー/
jesus /イエス/イエズス/ジーザス/
jet /ジェット/
jew /ユダヤ/
jicst /ＪＩＣＳＴ/
jig /ジグ/
jigsaw /ジグソー/
jimmy /ジミー/
jimny /ジムニー/
jingiskan /ジンギスカン/
jinx /ジンクス/
jis /ＪＩＳ/
jis# /JIS#0/
jj /ＪＪ/
jlatex /jLaTeX/
jle /ＪＬＥ/
jnic /日本ネットワークインフォメーションセンター/
job /ジョブ/
joe /ジョー/
jog /ジョグ/
jogging /ジョギング/
john /ジョン/ヨハネ/
johnlennon /ジョンレノン/
join /ジョイン/
joint /ジョイント/
joke /ジョーク/
jokes /ｊｏｋｅｓ/
jordan /ジョルダン/
joseph /ジョーゼフ/ヨセフ/
josephson /ジョセフソン/
journal /ジャーナル/
joy /ジョイ/
joypad /ジョイパッド/
joystick /ジョイスティック/
jperiod /．/
jr /ＪＲ/ジュニア/
jserver /ＪＳＥＲＶＥＲ/ｊｓｅｒｖｅｒ/
jsme /日本機械学会/
jst /ＪＳＴ/ｊｓｔ/
jt /ＪＴ/
jtex /jTeX/
judge /ジャッジ/
judgement /ジャッジメント/
juice /ジュース/ｊｕｉｃｅ/
jukebox /ジュークボックス/
julia /ジュリア/
julian /ジュリアン/
jumbo /ジャンボ/
jump /ジャンプ/
jumper /ジャンパー/ジャンパ/
junet /ＪＵＮＥＴ/JUNET/ｊｕｎｅｔ/
jungle /ジャングル/
junior /ジュニア/
junk /ジャンク/
jupiter /ジュピター/
jurassic /ジュラシック/
jus /Ｊｕｓ/ＪＵＳ/
just /ジャスト/
justification /ジャスティフィケーション/
justify /ジャスティファイ/
jv /共同企業体/
jvi /ｊｖｉ/
jwave /Ｊ−ＷＡＶＥ/
k /Ｋ/ｋ/キロ/
kai /χ/
kalman /カルマン/
kanakan /仮名漢字変換/
kant /カント/
kappa /カッパ/Ｋａｐｐａ/κ/
kara /〜/
karaoke /カラオケ/
kawai /カワイ/
kb /キーボード/ＫＢ/キロバイト/
kbyte /キロバイト/
kcl /ＫＣＬ/KCL/
kdd /ＫＤＤ/
keep /キープ/
keeper /キーパー/
keith /キース/
kemacs /ｋｅｍａｃｓ/
kenny /ケニー/
kentucky /ケンタッキー/
kenwood /ケンウッド/Ｋｅｎｗｏｏｄ/
kermit /ｋｅｒｍｉｔ/
kern /カーン/
kernel /カーネル/
key /キー/ｋｅｙ/キー入力/
keybind /キーバインド/
keybinding /キーバインディング/
keyboard /キーボード/
keycode /キーコード/
keymap /キーマップ/
keypad /キーパッド/
keysequence /キーシーケンス/
keystroke /キーストローク/
keytop /キートップ/
keytouch /キータッチ/
keyword /キーワード/
kfc /ケンタッキーフライドチキン/
kg /Ｋｇ/
kgb /ＫＧＢ/
khy /金学胤/
kick /キック/
kickback /キックバック/
kickoff /キックオフ/
kids /キッズ/
kiki /キキ/
kill /キル/ｋｉｌｌ/
kilo /キロ/
kind /カインド/
king /キング/
kingdom /キングダム/
kiosk /キオスク/
kirchhoff /キルヒホッフ/
kirkland /カークランド/
kiss /キス/キッス/×××/
kit /キット/
kitchen /キッチン/
kittel /キッテル/
kiwi /キウイ/
kk /株式会社/（株）/
kleene /クリーネ/
klips /ＫＬＩＰＳ/
km /Ｋｍ/
kmc /京大マイコンクラブ/
knee /ニー/
knife /ナイフ/
knight /ナイト/
knob /ノブ/
knock /ノック/
knot /ノット/節/
know /ノウ/
knowhow /ノウハウ/
knowledge /ナレッジ/
known /ノウン/
knuckle /ナックル/
ko /ＫＯ/Ｋ．Ｏ．/ＫｎｏｃｋＯｕｔ/
koala /こあら/コアラ/
kobold /コボルド/
kodak /コダック/
kolmogorov /コルモゴロフ/
kome /※/
korg /コルグ/
kripke /クリプケ/
kronecker /クロネッカー/
kroneckerdelta /クロネッカーのデルタ/
ksp /ＫＳＰ/
kterm /ｋｔｅｒｍ/KTerm/
kubota /クボタ/
l /リットル/Ｌ/ラウドネス/
la /ＬＡ/
lab /ラボ/研究室/
label /ラベル/レーベル/
labeling /ラベリング/ラベル付け/
labelwidget /ラベル・ウィジット/
laboratories /ラボラトリーズ/
lady /レディ/レディー/
ladyborden /レディボーデン/
lag /ラグ/
lagrange /ラグランジュ/
lambda /λ/ラムダ/ｌａｍｂｄａ/λ-算法/
lambert /ランバート/
lamp /ランプ/
lan /ＬＡＮ/LAN/
lance /ランス/
land /ランド/∧/
landing /ランディング/
landscape /ランドスケープ/
lane /レーン/
lang /ラング/
language /ランゲージ/
lantern /ランタン/
lap /ラップ/
laplace /ラプラス/
laplacian /ラプラシアン/
laptop /ラップトップ/
laputa /ラピュタ/
large /ラージ/
larmen /ラーメン/
lasalle /ラ・サール/ラサール/
laser /レーザー/レーザ/
laserdisc /ＬＤ/レーザーディスク/
laserdisk /ＬＤ/レーザーディスク/
laserprinter /レーザープリンタ/
laserwriter /レーザーライタ/ＬａｓｅｒＷｒｉｔｅｒ/
last /ラスト/
lastboss /ラスボス/
latch /ラッチ/
latency /レイテンシ/レイテンシー/
latex /ＬａＴｅＸ/ＬAＴEＸ/LaTeX/\LaTeX/
latin /ラテン/
latin# /Latin-#0/
lattice /ラチス/ラティス/
launcher /ランチャ/
laundry /ランドリー/
lavender /ラベンダー/
lawson /Ｌａｗｓｏｎ/ローソン/
lay /レイ/
laydock /レイドック/
layer /レイヤ/
layered /レイヤード/
layman /レイマン/
laymantype /レイマン型/
layout /レイアウト/
layoutsystem /レイアウトシステム/
laytracing /レイトレーシング/
lazer /レーザー/
lbp /レーザビームプリンタ/
lcd /ＬＣＤ/液晶/
ld /ＬＤ/LD/
ldk /ＬＤＫ/
ldots /.../
le /≦/
lead /リード/
leader /リーダ/リーダー/
leaderalbum /リーダーアルバム/
leadership /リーダーシップ/
leaf /リーフ/
league /リーグ/
leaison /リエゾン/
leak /リーク/
learning /学習/ラーニング/
lease /リース/
leather /レザー/
leave /リーブ/
leaving /リービング/
lecture /レクチャー/レクチャ/
led /ＬＥＤ/
left /←/レフト/左/
leftarrow /←/
leg /レッグ/
legal /リーガル/
leghorn /レグホーン/
lemma /レンマ/Lemma/補題/
lemon /レモン/檸檬/
length /レングス/
lennon /レノン/
lens /レンズ/
leo /レオ/
leq /≦/
lespaul /レスポール/
less /レス/
lesson /レッスン/
let /ｌｅｔ/レット/
letter /レター/手紙/
lettering /レタリング/
level /レベル/レヴェル/
lever /レバー/
lexical /レキシカル/
lf /ロジカル・フレームワーク/
liar /Ｌｉａｒ/
lib /ライブラリ/ライブラリー/リブ/
liberty /リバティ/
library /ライブラリ/ライブラリー/
libro /リブロ/
licence /ライセンス/
license /ライセンス/
life /ライフ/ＬＩＦＥ/
lifeservice /ライフサービス/
lifetime /ライフタイム/
lifework /ライフワーク/
lift /リフト/
light /ライト/
lighter /ライター/
like /ライク/
lilliput /リリパット/
lime /ライム/
limit /リミット/
limitcycle /リミットサイクル/
limited /リミテッド/
limiter /リミッター/リミッタ/
line /ライン/---------------------------------------------------------------------------/------------------------------------------------------------------/(make-string (- (window-width) 5) ?-)/￣/＿/(make-string (- (window-width) 5) (string-to-char comment-start))/
linear /リニア/
liner /ライナー/
lineup /ラインアップ/
lingual /リンガル/
link /リンク/
linkage /リンケージ/
linked /リンクト/
linker /リンカ/リンカー/
linkfield /リンクフィールド/
linus /ライナス/
linux /Linux/
lion /ライオン/
lip /リップ/
lipbrush /リップブラシ/
lipliner /リップライナー/
lipstick /リップスティック/
lisp /リスプ/ＬＩＳＰ/Ｌｉｓｐ/Lisp/
lisper /Ｌｉｓｐｅｒ/ｌｉｓｐｅｒ/
list /リスト/ｌｉｓｔ/
listbox /リストボックス/
listen /リッスン/
listener /リスナー/
listening /リスニング/
listing /リスティング/
listup /リストアップ/
lite /Ｌｉｔｅ/
literacy /リテラシ/
literal /リテラル/
lithium /リチウム/
litre /リッタ/リットル/
litter /リットル/リッター/
little /リトル/
live /ライブ/ライヴ/
livehouse /ライヴハウス/
livelock /ライブロック/
liver /レバー/
liveunderthesky /ライヴ・アンダー・ザ・スカイ/
living /リビング/
livre /£/
ll /≪/
lm /ＬＭ/ロードモジュール/
lms /ＬＭＳ/
load /ロード/
loadable /ローダブル/
loader /ローダ/ローダー/
loading /ローディング/
loadmodule /ロードモジュール/
loan /ローン/
lobby /ロビー/
local /局所/ローカル/ｌｏｃａｌ/
locale /ロケール/ロカール/
locality /ローカリティ/
localization /ローカリゼーション/
localminima /ローカルミニマ/局所的最良解/
localtime /ローカルタイム/
locate /ロケート/
location /ロケーション/
locator /ロケータ/
lock /ロック/施錠/
locker /ロッカー/
lockfile /ロックファイル/
locking /ロッキング/
lockmode /ロックモード/
lockout /ロックアウト/
lode /ロード/
lodge /ロッジ/
loft /Ｌｏｆｔ/
log /ログ/ｌｏｇ/
logfile /ログファイル/
logger /ロガー/
logging /ログィング/ロギング/
logic /ロジック/⊃/∧/∨/¬/∀/∃/論理/
logical /ロジカル/
logicprogramming /ロジック・プログラミング/
login /ログイン/
logistics /ロジスティクス/
logo /ロゴ/
logoff /ログオフ/
logon /ログオン/
logos /ロゴス/
logout /ログアウト/
london /ロンドン/
lonely /ロンリィ/
long /ロング/
longman /ＬＯＮＧＭＡＮ/
longword /ロングワード/
look /ルック/
lookahead /ルックアヘッド/
looks /ルックス/
lookup /ルックアップ/
loop /ループ/
loopback /ループバック/
loose /ルース/ルーズ/
lor /∨/
lord /ロード/
los /ロス・アンゼルス/
losalamos /ロス・アラモス/
lose /ルーズ/
loss /ロス/
lost /ロスト/
lot /ロット/
lotte /ロッテ/
lotteria /ロッテリア/
lotus /ロータス/
loud /ラウド/
loudness /ラウドネス/
loudspeaker /ラウドスピーカ/
lounge /ラウンジ/
love /ラブ/ラヴ/
lovehotel /ラヴホテル/
loveletter /ラブレター/
lovestory /ラブ・ストーリー/
low /ロー/
lowend /ローエンド/
lowpass /ローパス/
lowtom /ロータム/
loyalty /ローヤリティ/
lp /ＬＰ/LP/
lpc /LPC/ＬＰＣ/
lpf /ローパスフィルタ/
lsd /ＬＳＤ/
lse /最小2乗法/
lsi /ＬＳＩ/
lt /＜/
lucid /Ｌｕｃｉｄ/Lucid/
luck /ラック/
lucky /ラッキー/Ｌｕｃｋｙ/
lucy /ルーシー/
lump /ランプ/
lun /Logical Unit Number/
luna /Ｌｕｎａ/ＬＵＮＡ/
lunch /ランチ/ランチ /
lunchset /ランチセット/
lupe /ルーペ/
lupin /ルパン/
lute /リュート/
m /Ｍ/ｍ/
m# /Ｍ#1/
m1 /Ｍ１/M1/
m17n /multilingualization/多言語化/
m2 /Ｍ２/
m3 /Ｍ３/
mac /マック/Ｍａｃ/マッキントッシュ/Macintosh/Ｍａｃｉｎｔｏｓｈ/
macadamia /マカデミア/
macaroni /マカロニ/
mace /メイス/
mach /Ｍａｃｈ/マッハ/Mach/
machine /マシン/マシーン/計算機/
machineroom /マシンルーム/
machinevision /マシン・ビジョン/マシンビジョン/
macintosh /マッキントッシュ/
macro /マクロ/
macross /マクロス/
made /メイド/
madonna /マドンナ/
maf /最小可聴値/
mafia /マフィア/
mag /マグニチュード/
maga /マガ/
magagine /マガジン/
magazine /マガジン/ｍａｇａｚｉｎｅ/
magenta /マゼンタ/
magic /マジック/
magical /マジカル/
magma /マグマ/
magnet /マグネット/
magnetic /マグネチック/
magzine /マガジン/
mahalanobis /マハラノビス/
maharanobis /マハラノビス/
mahjong /マージャン/
mahler /マーラー/
mail /メール/メイル/〒/手紙/ｍａｉｌ/
mailaddress /メールアドレス/
mailbox /メールボックス/
mailer /メイラー/メイラ/メーラー/
mailing /メイリング/メーリング/
mailing-list /メイリングリスト/
mailinglist /メーリングリスト/メイリングリスト/
maillist /メイルリスト/
mailreader /メールリーダー/
mailserver /メイルサーバ/
mailsystem /メールシステム/
main /メイン/メーン/
mainframe /メインフレーム/
mainmemory /メインメモリ/
mainroutine /メインルーチン/
maintainance /メンテナンス/
maintenance /メンテナンス/メインテナンス/
mainwindow /メインウインドー/メーンウインドー/
maison /メゾン/
majong /麻雀/
major /メージャ/メジャー/メイジャー/
make /メイク/メーク/ｍａｋｅ/
makefile /Makefile/メークファイル/
maker /メーカー/メーカ/
makeup /メーキャップ/メイクア〜ップ！/
mall /モール/
mallow /マロウ/
mama /ママ/
mambo /マンボ/
man /マン/♂/ｍａｎ/マニュアル/
man-machine /マン-マシン/
manage /マネージ/
management /マネージメント/マネジメント/
manager /マネージャ/マネージャー/マネジャ/
mandelbrot /マンデルブロート/
mandrill /マンドリル/
mania /マニア/
maniac /マニアック/
manicure /マニキュア/
manipulate /マニピュレイト/
manipulation /マニピュレーション/
manipulator /マニピュレータ/
manna /マンナ/
mannequin /マヌカン/マネキン/
manner /マナー/
manpower /マンパワー/
mansfield /マンスフィールド/
manshon /マンション/
mansion /マンション/
mantle /マントル/
manual /マニュアル/
map /マップ/写像/ｍａｐ/
mapentry /マップエントリ/
maple /メイプル/
mapped /マップド/
mapping /マッピング/
marathon /マラソン/
marble /マーブル/
march /マーチ/
marcica /マーシカ/
margin /マージン/
marie /マリー/
mario /マリオ/ＭＡＲＩＯ/
marionette /マリオネット/
mark /マーク/マルク/
marker /マーカ/マーカー/
market /マーケット/
marketing /マーケティング/
marking /マーキング/
markov /マルコフ過程/マルコフ遷移/マルコフ/
markup /マークアップ/
mars /マーズ/ｍａｒｓ/
marshall /マーシャル/
mart /マート/マー/
martha /マーサ/
martin /マーティン/
martinlof /マーティンレーフ/
maru /●/○/〇/◎/
marx /マルクス/
mary /メアリー/
maryann /メアリーアン/メリーアン/
maryland /メリーランド/
mascara /マスカラ/
mascot /マスコット/
mask /マスク/仮面/
masked /マスクト/
maskedspector /マスクトスペクトル/
maskee /マスキー/マスキ/
masker /マスカ/マスカー/
masking /マスキング/
masoch /ザッヘル＝マゾッホ/マゾ/マゾッホ/
masochism /マゾヒズム/被虐淫乱症/被虐趣味/嗜虐的趣味/
masochist /マゾヒスト/被虐趣味者/嗜虐的趣味者/
mass /マス/
massage /マッサージ/
masscomp /マスコンプ/
massmedia /マスメディア/
mast /マスト/
master /マスター/マスタ/修士/
mastering /マスタリング/
masturbation /マスターベーション/
mat /マット/
match /マッチ/
matching /マッチング/
mate /メイト/
maternity /マタニティ/
math /∈/∋/⊆/⊇/⊂/⊃/∪/∩/∧/∨/¬/⇒/⇔/∀/∃/∠/⊥/∂/∇/≡/≒/≪/≫/
matic /マチック/
matrix /マトリックス/行列/マトリクス/
matroid /マトロイド/
max /ＭＡＸ/マックス/最大/
maximum /最大/最大値/
mayday /メーデー/
mayonnaise /マヨネーズ/
mb /ＭＢ/メガバイト/
mbps /Ｍｂｐｓ/
mc /ＭＣ/
mc1 /ＭＣ１/
mc2 /ＭＣ２/
mccarthy /マッカーシー/ＭｃＣａｒｔｈｙ/McCarthy/
mcculloch /マッカロー/
mcgrawhill /マグロウヒル/
md /ミニディスク/
me /ＭＥ/メディカルエレクトロニクス/
measuring /メジャリング/
mecha /メカ/
mechanic /メカニック/
mechanical /メカニカル/
mechanism /メカニズム/
medal /メダル/
media /メディア/ミーディア/
mediator /メディエータ/
medical /メディカル/
medium /ミディアム/
medley /メドレー/
meeting /ミーティング/会議/
meg /メガ/
mega /メガ/
megadrive /メガドライブ/
meistersinger /マイスタージンガー/
meitec /メイテック/
melby /メルビー/
melodia /メロディア/
melodious /メロディアス/
melodius /メロディアス/
melody /メロディー/メロディ/
melon /メロン/
melt /メルト/
meltdown /メルトダウン/
member /メンバー/メンバ/
members /メンバーズ/
memberscard /メンバーズカード/
membership /メンバシップ/メンバーシップ/
memo /メモ/φ(._.)/
memorandum /メモランダム/メモ/
memorial /メモリアル/
memory /メモリ/メモリー/
memorymapped /メモリマップド/
memoryset /メモリセット/
mens /メンズ/
mental /メンタル/
menthol /メンソール/薄荷脳/
mentor /メンター/
menu /メニュー/
menubar /メニューバー/メニュー・バー/
mercury /マーキュリー/メルクリウス/
merge /マージ/
merit /メリット/
mermaid /マーメイド/
merrit /メリット/
merry /メリー/
merrychristmas /メリークリスマス/
mesh /メッシュ/
message /メッセージ/
messagebox /メッセージボックス/
messageid /メッセージＩｄ/
messe /メッセ/
meta /メタ/
metadata /メタデータ/
metafont /メタフォント/
metal /メタル/
metalevel /メタレベル/
metalic /メタリック/
metaltape /メタルテープ/
metamorphose /メタモルフォーゼ/
metaphor /メタファー/
meter /メートル/メータ/メーター/
method /メソッド/
methodology /メソドロジ/
metric /メトリック/
metrics /メリックス/
metro /東京都立大学/メトロ/
metronome /メトロノーム/
metropolitan /メトロポリタン/
mexico /メキシコ/
mexp /M式/
mf /MetaFont/ＭＦ/
mflop /ＭＦＬＯＰ/
mg /宮城学院/
mh /ｍｈ/ＭＨ/
mhz /ＭＨｚ/
miami /マイアミ/
mic /マイク/
michael /マイケル/
michigan /ミシガン/
mick /ミック/
mickey /ミッキー/
micom /マイコン/
micro /マイクロ/ミクロ/μ/
microchip /マイクロチップ/
microcomputer /マイクロコンピュータ/
microkernel /マイクロカーネル/
micron /ミクロン/
microphone /マイクロフォン/マイクロホン/
microprocessor /マイクロプロセッサ/
microsoft /マイクロソフト/
microsystems /マイクロシステムズ/
middle /ミドル/
middleware /ミドルウエア/
midi /ＭＩＤＩ/
midnight /ミッドナイト/
migrate /移送/マイグレート/マイグレイト/
migration /マイグレーション/移送/マイグレイション/
mike /マイク/
milage /マイレッジ/
mild /マイルド/
mildseven /マイルドセブン/
mile /マイル/
mileage /マイレッジ/
miles /マイルス/
milestone /マイルストーン/
milk /ミルク/
milktea /ミルクティ/
mill /ミル/
milli /ミリ/
milner /ミルナー/
mimd /MIMD/
min /ミニマム/
mind /マインド/
mine /マイン/
mineral /ミネラル/
mini /ミニ/
minibuffer /ミニバッファ/
minicom /ミニコン/
minicomputer /ミニコンピュータ/ミニコン/
minidisk /ミニディスク/
minimum /最小/最小値/ミニマム/
miniskirt /ミニスカート/
minitower /ミニタワー/
minolta /ミノルタ/
minor /マイナー/マイナ/
minority /マイノリティ/
mint /ミント/
minus /マイナス/―/−/
minutia /マニューシャ/
mips /ＭＩＰＳ/MIPS/
miracle /ミラクル/
miranda /ミランダ/
miri /ミリ/
mirror /ミラー/
mirroring /ミラーリング/
mis /ミス/
miscast /ミスキャスト/
mismatch /ミスマッチ/
miss /ミス/
misshit /ミスヒット/
missile /ミサイル/
mission /ミッション/
misspicking /ミスピッキング/
misstype /ミスタイプ/
mister /ミスター/
mistery /ミステリー/
mit /ＭＩＴ/MIT/
mix /ミックス/ｍｉｘ/
mixer /ミキサー/ミキサ/
mixing /ミキシング/
mjq /ＭＪＱ/
ml /メイリングリスト/ＭＬ/メーリングリスト/
mle /最尤推定/
mls /最尤推定法/
mm /ｍｍ/ミリメートル/
mmi /マン・マシン・インタフェース/
mnemonic /ニーモニック/
mo /ＭＯ/MO/光磁気ディスク/
mobile /モビール/モービル/モバイル/
mocha /モカ/
mockup /モックアップ/
modal /モーダル/
modality /モダリティ/
mode /モード/
mode-line /モードライン/
model /モデル/
modeless /モードレス/
modeline /モードライン/
modeling /モデリング/
modelling /モデリング/
modem /モデム/
moderate /モデレイト/モデラート/モデレート/
moderator /モデレータ/
modern /モダン/
modifier /モディファイア/
modify /モディファイ/
modular /モジュラー/モジュラ/
modularity /モジュラリティ/
modulation /モジュレーション/
module /モジュール/モデュール/
moduler /モジュラー/
modulo /モジュロ/
moire /モアレ/
mol /モル/
mole /モル/
moment /モーメント/
momentum /モーメント/モーメント項/
mon /月/
monad /モナド/
monday /月曜日/
monet /モネ/
money /マネー/
mongol /モンゴル/
monitor /モニタ/モニター/
monitoring /モニタリング/
monitormode /モニタモード/
monk /モンク/
monkey /モンキー/
mono /モノ/モノクロ/
monochro /モノクロ/
monochrome /モノクロ/
monograph /モノグラフ/
monoid /モノイド/
monopole /モノポール/
monopoly /モノポリー/
monorail /モノレール/
monotone /モノトーン/
monster /モンスター/
montage /モンタージュ/
montecarlo /モンテカルロ法/モンテカルロ/
mood /ムード/
moon /ムーン/
moonlight /ムーンライト/
moore /ムーア/
mop /MOP/メタオブジェクトプロトコル/MetaObject Protocol/
moral /モラル/
more /モア/
moretti /モレッティ/
morning /モーニング/
morph /モーフィング/モーフ/
morris /モーリス/
morrison /モリソン/
mos /ＭＯＳ/モス/
mosaic /モザイク/
moscow /モスクワ/
motel /モーテル/
mother /マザー/
motherboard /マザーボード/
mothra /モスラ/
mothreboard /マザーボード/
motif /Ｍｏｔｉｆ/モティーフ/Motif/
motion /モーション/
motionfeedback /モーションフィードバック/
motivation /モチベーション/
motor /モータ/モーター/
motorola /モトローラ/Motorola/
motrola /Ｍｏｔｏｒｏｌａ/モトローラ/
mount /マウント/
mountain /マウンテン/
mounter /マウンタ/
mounting /マウンティング/
mouse /マウス/
mousebutton /マウスボタン/
mousecursor /マウスカーソル/
mova /ｍｏｖａ/
move /ムーブ/
movie /ムービー/ムーヴィー/
mozart /モーツァルト/
mpp /ＭＰＰ/
mpu /ＭＰＵ/
mr /Ｍｒ．/
mr2 /ＭＲ/ＭＲII/
mrna /ｍ-ＲＮＡ/
ms /ｍｓ/ミリセコンド/ＭＳ/マイクロソフト/ミリ秒/
ms-dos /MS-DOS/
msdos /ＭＳ−ＤＯＳ/MS-DOS/
mse /ＭＳＥ/
msi /数理システム/
msx /ＭＳＸ/
mt /ＭＴ/マウント/
mu /μ/ミュウ/ムー/ムウ/
mud /マッド/
muffler /マフラー/
mugcup /マグカップ/
mul /ＭＵＬ/
mule /ＭＵＬＥ/Mule/
muller /ミュラー/
multi /マルチ/
multiagent /マルチエイジェント/マルチエージェント/
multibyte /マルチバイト/
multicast /マルチキャスト/
multichip /マルチチップ/
multicomputer /マルチコンピュータ/
multilevel /マルチレベル/
multimedia /マルチメディア/
multimodal /マルチモーダル/
multiple /マルチプル/
multiplexer /マルチプレクサ/
multiplexor /マルチプレクサ/
multiplier /マルチプライヤ/
multiprocessor /マルチプロセッサ/
multirate /マルチレート/
multiscan /マルチスキャン/
multiserver /マルチサーバ/
multiset /マルチセット/
multitalker /マルチトーカ/
multitalkernoise /マルチトーカノイズ/
multitask /マルチタスク/
multithread /マルチスレッド/
multitrack /マルチトラック/
multiuser /マルチユーザー/
multiwindow /マルチウィンドウ/
munich /ミュンヘン/
muse /ＭＵＳＥ/
music /ミュージック/∫/∬/♭/♪/
musical /ミュージカル/
musician /ミュージシャン/
musium /ミュージアム/
mutable /ミュータブル/
mute /ミュート/
mutex /ミューテックス/
mw /ミドルウエア/
mx /ＭＸ/
my /マイ/
mypace /マイペース/
mysterious /ミステリアス/
mystery /ミステリ/ミステリー/
n /Ｎ/ｎ/
naiad /ナイアード/
nail /ネイル/
nailenamel /ネイルエナメル/
naive /ナイーブ/
namco /ナムコ/
name /ネーム/名/名称/名前/
nameserver /ネームサーバー/ネームサーバ/
namespace /ネームスペース/
namevalue /ネームヴァリュー/
nami /〜/
naming /ネーミング/
nanao /ナナオ/
narration /ナレーション/
narrator /ナレーター/
narrow /ナロー/
nas /ＮＡＳ/
nasa /NASA/
national /ナショナル/
native /ネイティヴ/ネイティブ/ネーティブ/
natural /ナチュラル/
naturalist /ナチュラリスト/
nature /Ｎａｔｕｒｅ/
nautilus /ノーチラス/
navi /Ｎａｖｉ/ナビ/
navier /ナビア/
navigation /ナビゲーション/
navigator /ナビゲーター/
nd /ＮＤ/ｎｄ/
ne /≠/
near /ニア/
nearlyequal /≒/
nebula /ネビュラ/
nec /ＮＥＣ/日本電気/NEC/
neck /ネック/
necktie /ネクタイ/
nector /ネクター/
needs /ニーズ/
neg /¬/
nega /ネガ/
negative /ネガティブ/ネガティヴ/
negotiate /ネゴシエート/
negotiation /ネゴシエーション/
nemacs /ＮＥｍａｃｓ/Ｎｅｍａｃｓ/ｎｅｍａｃｓ/NEmacs/
neon /ネオン/
nepoch /NEpoch/
neq /≠/
nervous /ナーバス/
ness /ネス/
nest /ネスト/
nesting /ネスティング/
net /ネット/ネットワーク/
netbsd /netBSD/
netdatabase /ネットデータベース/
netlist /ネットリスト/
netmask /ネットマスク/
netnews /ネットニュース/
netone /ネットワン/
netscape /ネットスケープ/
nettalk /ＮＥＴｔａｌｋ/
nettopology /ネット・トポロジー/
netware /ネットウェア/NetWare/
network /ネットワーク/
networkadmin /ネットワークアドミン/
networker /ネットワーカー/
networking /ネットワーキング/
neumann /ノイマン/ノイマン型/
neural /ニューラル/Ｎｅｕｒａｌ/
neuralnet /ニューラルネット/ＮｅｕｒａｌＮｅｔ/
neuralnetwork /ニューラルネットワーク/
neuralware /ＮｅｕｒａｌＷａｒｅ/
neuro /ニューロ/
neurocomputer /ニューロコンピュータ/
neurocomputing /ニューロコンピューティング/
neuroethology /ニューロエソロジー/
neuromancer /ニューロマンサー/
neuron /ニューロン/
neuroscience /ニューロサイエンス/
neutral /ニュートラル/
new /ニュー/ｎｅｗ/
newage /ニューエージ/
newcastle /ニューキャッスル大学/
newfrontier /ニューフロンティア/
newjersey /Ｎｅｗ−Ｊｅｒｓｅｙ/
newmedia /ニューメディア/
newmexico /ニューメキシコ州立大学/
newohtani /ニューオータニ/
news /ニュース/ＮＥＷＳ/ネットニュース/ニューズ/ＮｅＷＳ/
newsfeed /ニュースフィード/
newsgroup /ニュースグループ/
newsletter /ニューズレター/ニュースレター/
newsreader /ニュースリーダー/
newsserver /ニュースサーバー/
newsspool /ニューススプール/
newsstation /ニュースステーション/
newssystem /ニュースシステム/
newtech /ニューテック/
newton /ニュートン/
newwave /ニューウェーヴ/
newyork /ニューヨーク/
newzealand /ニュージーランド/
next /ＮｅＸＴ/ネクスト/NeXT/
nfl /ＮＦＬ/
nfs /ＮＦＳ/
ng /ＮＧ/ニュースグループ/
nhk /ＮＨＫ/
ni /∋/
nic /The Network Information Center/
nicd /NiCd/
nice /ナイス/ニース/
nicholas /ニコラス/
nick /ニック/
nickel /ニッケル/
nickname /ニックネーム/
nielsen /ニールセン/
nies /ＮＩＥＳ/
nif /Ｎｉｆｔｙ/
nifty /Ｎｉｆｔｙ/ＮＩＦＴＹ/ニフティ/
niftyserve /ニフティサーブ/
night /ナイト/
nighter /ナイター/
nihil /ニヒル/
nihilism /ニヒリズム/
nihilist /ニヒリスト/
nikoli /ニコリ/
nikon /ニコン/
nil /空リスト/
nim /ニム/
nip /ニップ/
nips /ＮＩＰＳ/
nis /ＮＩＳ/
njigen /ｎ次元/
njp /ＮＪＰ/
nk /自然演繹/
nkk /ＮＫＫ/
nko /ｎ個/
nmr /ＮＭＲ/
nn /ＮＮ/
nntp /ＮＮＴＰ/
no /ノー/Ｎｏ．/ＮＯ/No./番号/ナンバー/
no1 /Ｎｏ．１/
nobrand /ノーブランド/
noc /ＮＯＣ/
nocomment /ノーコメント/
node /ノード/節点/
noel /Ｎｏёｌ/
noise /ノイズ/
noiselevel /ノイズレベル/
noisiness /ノイジネス/
noisy /ノイズィ/ノイジー/
nomadic /ノマディック/
non /ノン/
nonbank /ノンバンク/
nonmaskable /ノンマスカブル/
nonsense /ナンセンス/ナンセンス！/
noon /ヌーン/
norm /ノルム/
norma /ノルマ/
normal /ノーマル/正常/
normalize /ノーマライズ/
norman /ノルマン/
north /ノース/
northwestern /ノースウェスタン/
northwesternuniv /ノースウェスタン大学/
norway /ノルウェイ/諾威/ノルウェー/
nose /ノーズ/
nosleeve /ノースリーヴ/
not /¬/〜/ノット/
notation /ノウテイション/
notch /ノッチ/
notchfilter /ノッチフィルタ/
note /ノート/
notebook /ノートブック/
noteq /≠/
notequal /≠/
notify /ノーティファイ/
notouch /ノータッチ/
nova /ノバ/ノヴァ/
now /(current-time-string)/(substring (current-time-string) 11 16)/(substring (current-time-string) 11 19)/
np /ＮＰ/
npc /ＮＰＣ/
npcomplete /ＮＰ-完全/
nqueen /Ｎクィーン/
nroff /エヌロフ/
nrzi /NRZI/
ns /ナショナルセミコンダクタ/ＮＳ/│/┃/
nse /┠/├/┣/┝/
nsew /┼/╋/┿/╂/
nsf /ＮＳＦ/
nsfnet /ＮＳＦｎｅｔ/
nsug /日本サンユーザーズグループ/
nsw /┤/┫/┨/┥/
nsx /ＮＳＸ/
nten /Ｎ点/
ntt /ＮＴＴ/NTT/
ntv /日本テレビ/
nu /ν/
nuance /ニュアンス/
nude /ヌード/
null /ヌル/NULL/ナル/
number /ナンバー/ナンバ/番号/
numbering /ナンバリング/
numerics /ニューメリックス/
nuts /ナッツ/
nw /┘/┛/
nwj /黄維哲/
ny /Ｎ.Ｙ./
nymph /ニンフ/
nyquist /ナイキスト/
nyu /ν/
nz /ニュージーランド/
o /○/Ｏ/ο/
oa /ＯＡ/
oasis /オアシス/
ob /ＯＢ/
obj /オブジェクト/
object /オブジェクト/
objectoriented /オブジェクトオリエンテッド/
objectshikou /オブジェクト指向/
obs /ＯＢＳ/
observation /オブザベーション/
observer /オブザーバ/オブザーバー/
ocalina /オカリナ/
ocarina /オカリナ/
occam /オッカム/
occlusion /オクルージョン/
occupation /職業/
occurrence /オカレンス/
ocr /ＯＣＲ/
octave /オクターブ/
octet /オクテット/
octopus /オクトパス/
odeon /オデオン/
odyssey /オデッセイ/オデュッセイア/
oem /ＯＥＭ/
of /オブ/
off /オフ/
offense /オフェンス/
office /オフィス/
office-computer /オフコン/
officecomputer /オフコン/
official /オフィシャル/
offline /オフライン/
offrec /オフレコ/
offreco /オフレコ/
offroader /オフローダー/
offset /オフセット/
ogata /Ｏ型/
ogre /オーガ/オウガ/
ohm /オーム/Ω/
ohp /ＯＨＰ/
oid /オブジェクト識別性/
oil /オイル/
oilheater /オイルヒーター/
ok /承知しました./ＯＫ/オーケー/大丈夫/Ｏ.Ｋ./
ol /ＯＬ/
old /オールド/
oldenburg /オルデンブルグ/
olive /オリーブ/
olympas /オリンパス/
olympiad /オリンピック/
olympic /オリンピック/
olympus /オリンパス/
omega /ω/Ω/オメガ/
omicron /ο/
omnibus /オムニバス/
omnis /オムニス/
omron /オムロン/ＯＭＲＯＮ/立石電機/OMRON/
on /オン/
onair /オンエア/
onboard /オンボード/
onchip /オンチップ/
ondemand /オンデマンド/
one /ワン/
one-to-one /一対一/
onkyo /ＯＮＫＹＯ/
online /オンライン/
onlinemanual /オンラインマニュアル/
only /オンリー/
onoff /オン・オフ/
ontario /オンタリオ/
ontek /オンテック/
oo /オジェクト指向/オブジェクト指向/∞/ＯＯ/Object-Oriented/○○/OO/
oodb /オブジェクト指向データベース/
oodl /OODL/
oolongtea /ウーロン茶/
oop /オジェクト指向プログラミング/オブジェクト指向プログラミング/
oopl /OOPL/
opal /蛋白石/オパール/
ope /オペ/
opecode /オペコード/
open /オープン/開/
openhouse /オープンハウス/
opening /オープニング/
openlook /ＯｐｅｎＬｏｏｋ/
openwindow /OpenWindow/
openwindows /ＯｐｅｎＷｉｎｄｏｗｓ/
opera /オペラ/歌劇/
operability /オペラビリティ/
operand /オペランド/
operant /オペラント/
operating /オペレーティング/
operatingsystem /オペレーティングシステム/
operation /オペレーション/操作/
operational /オペレーショナル/
operations /オペレーションズ/
operationsresearch /オペレーションズ リサーチ/
operator /オペレータ/オペレーター/演算子/
opt /ＯＰＴ/
optical /オプティカル/
opticalflow /オプティカルフロー/
optimize /オプティマイズ/最適化/
optimizer /オプティマイザ/
option /オプション/
optional /オプショナル/
optionbutton /オプション・ボタン/
optionmenu /オプションメニュー/
options /オプションズ/
or /∨/ｏｒ/または/
orange /おれんじ/オレンジ/
orc /オーク/
orchard /オーチャード/
orchardhall /オーチャードホール/
orche /オケ/
orchestra /オーケストラ/
order /オーダ/オーダー/
oread /オレアード/
oregon /オレゴン/
organ /オルガン/
organize /オーガナイズ/
organizer /オーガナイザ/
oricon /オリコン/
oriental /オリエンタル/
orientation /オリエンテイション/オリエンテーション/
oriented /オリエンテッド/
orifice /オリフィス/
origin /オリジン/
original /オリジナル/
originality /オリジナリティ/
orignial /オリジナル/
orion /オリオン/
orix /オリックス/
orthodox /オーソドックス/
os /ＯＳ/オペレーティングシステム/オペレイティング・システム/オペレーティング・システム/基本ソフトウェア/OS/
os9 /ＯＳ９/
oscar /オスカー/
oscilloscope /オシロスコープ/
oscilo /オシロ/
osciloscope /オシロスコープ/
osf /OSF/
osi /ＯＳＩ/
oslo /オスロ/
otacky /オタッキー/
othello /オセロ/
other /その他/
out /アウト/
outdoor /アウトドア/
outer /アウター/
outlane /アウトレーン/
outlaw /アウトロー/
outline /アウトライン/
outplacement /アウトプレースメント/
output /アウトプット/出力/
outsider /アウトサイダー/
ova /ＯＶＡ/
oval /楕円/オーバル/
ovation /オヴェイション/
oven /オーブン/
over /オーバ/オーバー/
overcoat /オーバーコート/
overcomplete /オーバコンプリート/
overdrive /オーバードライブ/
overflow /オーバーフロー/
overhead /オーバヘッド/オーバーヘッド/
overlap /オーバラップ/オーバーラップ/
overlay /オーバレイ/
overload /オーバーロード/
overloading /オーバーローディング/
override /オーバーライド/
overspec /オーバースペック/
overview /オーバービュー/
overwrite /オーバーライト/オーバライト/
owner /オーナ/オウナー/オーナー/
oxford /オックスフォード/
oxygen /オキシジェン/酸素/
oxygen-destroyer /オキシジェン・デストロイヤー/水中酸素破壊剤/
p /Ｐ/P/
pP /ｐＰ/
pa /ＰＡ/
pace /ペース/
pachinko /パチンコ/
pacific /パシフィック/
pack /パック/
package /パッケージ/
packaging /パッケージング/
packet /パケット/
packing /パッキング/
pad /パッド/
padding /パッディング/パディング/
padstack /パッドスタック/
page /ページ/頁/
pagefault /ページフォールト/
pagein /ページイン/
pageone /ページワン/
pageout /ページアウト/
pager /ページャ/ページャー/
pagesize /ページサイズ/
pagetable /ページテーブル/
paging /ページング/
pagingdaemon /ページングデーモン/
paid /ペイド/
pain /パン/
paint /ペイント/ペンキ/
pair /ペア/
pairwise /ペアワイズ/
pajamas /パジャマ/
pakistan /パキスタン/
palabora /パラボーラ/
palace /パレス/
palette /パレット/
pallet /パレット/
palm /パーム/
palmtop /パームトップ/
palpal /パルパル/
pamph /パンフ/
pamphlet /パンフレット/
pan /パン/
panda /パンダ/
pandora /パンドーラー/パンドラ/
pane /ペイン/
panel /パネル/
paneldiscussion /パネルディスカッション/
paneler /パネラー/
panelist /パネリスト/
panflet /パンフレット/
panic /パニック/
panku /パンク/
panning /パンニング/
panorama /パノラマ/
pansy /パンジー/
pantograph /パンタグラフ/
pants /パンツ/
papa /パパ/
paper /ペーパー/論文/
paperback /ペーパーバック/
paperjam /ペーパージャム/
par /ＰＡＲ/改ページ/
para /パラ/
parade /パレード/
paradigm /パラダイム/
paradigmshift /パラダイム・シフト/
paradise /パラダイス/
paradox /パラドックス/パラドクス/
paragraph /パラグラフ/¶/
parallel /パラレル/‖/
parameter /パラメータ/パラメーター/パラメタ/引数/パラメター/
parameterfile /パラメーターファイル/
parameterization /パラメタリゼーション/
parameterized /パラメタライズド/
parametric /パラメトリック/
paramount /パラマウント/
paranoia /パラノイア/偏執狂/偏執病/
paraphrase /パラフレーズ/
paris /パリ/
parity /パリティ/
paritybit /パリティビット/
park /パーク/
parking /パーキング/
parody /パロディ/パロディー/
parse /パーズ/パース/
parsec /パーセク/
parser /パーザ/パーザー/
parsifal /パルシファル/
parsing /パージング/
parsley /パセリ/
part /パート/
part# /パート#1/
partial /パーシャル/∂/
partition /パーティション/
partitioning /パーティショニング/
partner /パートナー/パートナ/
partnership /パートナーシップ/
parts /パーツ/
party /パーティー/パーティ/
pasadena /パサデナ/
pascal /パスカル/ＰＡＳＣＡＬ/
pasocom /パソコン/パーソナルコンピュータ/
pasocon /パソコン/
pass /パス/
passcode /パスコード/
passing /パッシング/
passive /パッシブ/
passphrase /パスフレーズ/
passport /パスポート/
passwd /パスワード/
password /パスワード/
paste /ペースト/貼り付け/
pastel /パステル/
pastral /パストラル/
pat /パット/
patcar /パトカー/
patch /パッチ/
patchkit /パッチキット/
path /パス/
patio /パティオ/
patlabor /パトレイバー/
patrol /パトロール/
patron /パトロン/
pattern /パターン/パタン/
patternmatching /パターン・マッチング/
patternrecognition /パターン認識/
patty /パティ/
pauch /パウチ/
paul /ポール/
pause /ポーズ/
pavlov /パヴロフ/
pay /ペイ/
payload /ペイロード/
pbx /ＰＢＸ/
pc /パソコン/パーソナルコンピュータ/ＰＣ/PC/
pc98 /ＰＣ９８/
pcat /ＰＣ／ＡＴ/
pcl /ＰＣＬ/PCL/PCL(Portable Common Loops)/
pcm /ＰＣＭ/
pcmodel /ＰＣモデル/
pdp /ＰＤＰ/
pdp# /PDP-#0/
pdp11 /ＰＤＰ１１/
pds /ＰＤＳ/パブリックドメインソフト/パブリックドメーンソフトウエア/
pe /ＰＥ/プロセッシングエレメント/
peace /ピース/
peach /ピーチ/
peak /ピーク/
peaky /ピーキー/
peano /ペアノ/
peanuts /ピーナッツ/
pearl /パール/真珠/
pedal /ペダル/
pedantic /ペダンティック/
pedophilia /ペドフィリア/
peephole /ピープホール/
peer /ピア/
pegasus /ペガサス/
peking /北京/
pel /ペル/
pen /ペン/
penalty /ペナルティ/ペナルティー/
pendant /ペンダント/
pending /ペンディング/
pene /ペネ/
penguin /ペンギン/
penlight /ペンライト/
penname /ペンネーム/
pennant /ペナント/
penny /ペニー/
penrose /ペンローズ/
pentagon /ペンタゴン/
pentium /Pentium/ペンティアム/
pentouch /ペンタッチ/
people /ピープル/
pepper /ペパー/
per /ペール/
percent /％/パーセント/
percentage /パーセンテージ/
perceptron /パーセプトロン/
percussion /パーカッション/
perfect /パーフェクト/
performance /パフォーマンス/パーフォーマンス/
period /ピリオド/Ｐｅｒｉｏｄ/．/
periodic /ピリオディック/
perl /Ｐｅｒｌ/Perl/
perma /パーマ/
permil /‰/
permill /‰/
permission /パーミッション/
perp /┴/
persistent /永続/
persocom /パソコン/
personal /パーソナル/
personal-computer /パソコン/
personality /パーソナリティ/
personnel /パーソネル/
peru /ペルー/
pesrsonal /パーソナル/
pet /ペット/
peter /ピーター/ピョートル/ペーター/
petri /ペトリ/
pex /ｐｅｘ/
pfu /ＰＦＵ/
phase /フェーズ/フェイズ/
phasing /フェイズィング/
pheromone /フェロモン/
phi /φ/Φ/ψ/
phigs /ｐｈｉｇｓ/
philadelphia /フィラデルフィア/
phone /フォン/ホン/
phonon /フォノン/
phononics /フォノニクス/
photo /フォト/
phrase /フレーズ/
phrasing /フレイジング/
physical /フィジカル/
pi /π/パイ/Π/
pia /ピア/
pianist /ピアニスト/
piano /ピアノ/
pick /ピック/
picking /ピッキング/
pickup /ピックアップ/
picture /ピクチャー/
pie /パイ/
piece /ピース/
pigma /ピグマ/
pill /ピル/
pilot /パイロット/
pin /ピン/
pinball /ピンボール/
pinch /ピンチ/
pine /パイン/
pineapple /パイナップル/
ping /ピン/ピング/
pingpong /ピンポン/
pink /ピンク/
pinknoise /ピンクノイズ/
pinky /ピンキー/
pinpoint /ピンポイント/
pint /ピント/
pioneer /パイオニア/
pipe /パイプ/
pipeline /パイプライン/
pipeorgan /パイプオルガン/
pistol /ピストル/
piston /ピストン/
pit /ピット/
pitch /ピッチ/
pitcher /ピッチャー/
pitching /ピッチング/
pitinn /ＰｉｔＩｎｎ/
pivot /ピボット/
pixel /ピクセル/
pixmap /ピックスマップ/
pizza /ピザ/
pk /ＰＫ/
pl /パッチレベル/(concat "P\057L")/Ｐ／Ｌ/Profit and Loss Statement/損益計算書;財務諸表の1つ/
place /プレース/プレイス/
plain /プレーン/プレイン/
plan /ｐｌａｎ/プラン/
plane /プレーン/
planetary /プラネタリー/
planing /プランニング/
plankton /プランクトン/
planner /プランナ/プランナー/
planning /プランニング/
plant /プラント/
planter /プランター/
plasma /プラズマ/プラズマ電子工学/
plastic /プラスチック/
plate /プレート/
platform /プラットフォーム/プラットホーム/
platinum /プラチナ/
platon /プラトン/
play /プレイ/プレー/
playboy /プレイボーイ/
player /プレイヤー/プレーヤー/プレーヤ/プレイヤ/
playgirl /プレイガール/
playing /プレーイング/プレイング/
playmode /プレイモード/
plaza /プラザ/
please /プリーズ/
pleats /プリーツ/
plind /プリンディ/
plot /プロット/
plototype /プロトタイプ/
plotter /プロッタ/プロッター/
plug /プラグ/
plumi /±/
plus /プラス/＋/
plusminus /プラスマイナス/±/
pm /±/
pocket /ポケット/
point /ポイント/・/点/
pointer /ポインタ/ポインター/
pointing /ポインティング/
poisson /ポアソン/
poker /ポーカー/
pola /ポーラ/
poland /ポーランド/
polaroid /ポラロイド/
pole /ポール/
policy /ポリシー/ｐｏｌｉｃｙ/
poling /ポーリング/
polish /ポーランド/
poll /ポール/
polling /ポーリング/
poly /ポリ/
polydor /ポリドール/
polygon /ポリゴン/
polyline /ポリライン/
polymer /ポリマー/
polymorphic /ポリモルフィック/多相型/
polymorphism /ポリモルフィズム/
polyphony /ポリフォニー/
polypropylene /ポリプロピレン/
pomp /ＰＯＭＰ/
pond /£/
pong /ポン/
pony /ポニー/
poo /Parallel Object-Oriented/
pool /プール/Parallel Object-Oriented Language/
poor /プア/
pop /ＰＯＰ/ポップ/
poppy /ポピー/
pops /ポップス/
popular /ポピュラー/
popup /ポップアップ/
popupmenu /ポップアップメニュー/ポップアップ・メニュー/
port /ポート/
portability /ポータビリティ/
portable /ポータブル/
portasound /ポータサウンド/
portatone /ポータトーン/
portfolio /ポートフォリオ/
porting /ポーティング/
portrait /ポートレート/
portugal /ポルトガル/
pose /ポーズ/
position /ポジション/
positioning /ポジショニング/
positive /ポジティヴ/
posix /POSIX/
post /ポスト/〒/
postdoc /ポストドク/
poster /ポスター/ポスタ/
postersession /ポスターセッション/
posting /ポスティング/
postit /ポウストイット/ポストイット/
postmaster /ポストマスター/ポストマスタ/
postprocess /ポストプロセス/
postscript /ポストスクリプト/
pot /ポット/
potatochip /ポテトチップ/
potential /ポテンシャル/
potentiometer /ポテンショメータ/
pouch /ポーチ/
pound /ポンド/£/パウンド/
powder /パウダー/
power /パワー/
powerbook /パワーブック/
powerful /パワフル/
powerspector /パワースペクトル/
powerup /パワーアップ/
poweruser /パワーユーザ/
ppm /PPM(Peater Paul and Mary)/
practical /プラクティカル/
pragma /プラグマ/
prague /プラハ/
prasma /プラズマ/
pre /プリ/
prealocate /プリアロケート/
preamble /プリアンブル/
preamp /プリアンプ/
precision /プレシジョン/
predicate /述語/プレディケート/プレディケイト/
predump /プリダンプ/
preemmptive /プリエンプティブ/
preemption /プリエンプション/
preemptive /プリエンプティブ/
prefab /プレハブ/
preference /プリファレンス/プレファレンス/
prefetch /プリフェッチ/
prefix /プレフィクス/プリフィクス/プレフィックス/
preinstall /プレインストール/
preload /プレロード/プリロード/
prelocate /プリロケート/
prelude /プレリュード/
prepaid /プリペイド/
preprint /プレプリント/
preprocessor /プリプロセッサ/
present /プレゼント/
presentation /プレゼンテーション/プレゼンテイション/
preset /プリセット/
press /プレス/
pressure /プレッシャー/
pretty /プリティ/
prettyprint /プリティプリント/
preview /プレビュー/プレヴュー/
previewer /プレビュアー/プレビューア/プレヴュア/
prf /原始帰納的関数/
pri /プリ/
price /プライス/
pride /プライド/
priest /プリースト/
primary /プライマリ/
prime /プライム/
primitive /プリミティブ/プリミティヴ/
prince /プリンス/プリンスホテル/
princess /プリンセス/
principal /プリンシパル/
print /プリント/
printer /プリンタ/プリンター/
printerbuffer /プリンタバッファ/
printout /プリントアウト/
priori /プライオリ/
priority /プライオリティ/
prism /プリズム/
privacy /プライバシー/プライヴァシー/
private /プライベート/
pro /プロ/
probe /プローブ/
proc /プロシジャ/
procedural /プロシジュアル/
procedure /プロシージャ/プロシジャ/手続き/
procedurecall /プロシジャ・コール/プロシジャコール/
proceeding /プロスィーディング/
proceedings /プロシーディングス/
process /プロセス/処理/
processing /プロセッシング/
processor /プロセッサ/
processorset /プロセッサセット/
procyon /プロキオン/
produce /プロデュース/
producer /プロデューサー/
product /プロダクト/
production /プロダクション/
products /プロダクツ/
professional /プロフェッショナル/
profile /プロフィール/プロファイル/
profiler /プロファイラ/
profit /利潤/
prog /プログラム/
progamming /プログラミング/
program /プログラム/算譜/
programable /プログラマブル/
programmability /プログラマビリティ/
programmable /プログラマブル/
programmer /プログラマ/プログラマー/
programmers /プログラマーズ/
programming /プログラミング/
progre /プログレ/
progress /進行/
project /プロジェクト/
projecter /プロジェクタ/
projector /プロジェクター/プロジェクタ/
prolog /Ｐｒｏｌｏｇ/プロログ/
prologue /プロローグ/
prom /ＰＲＯＭ/
promiscuous /プロミスカス/
promote /プロモート/
promotion /プロモーション/
prompt /プロンプト/
proof /プルーフ/証明/
propaganda /プロパガンダ/
propagation /プロパゲーション/
proper /プロパー/
property /プロパティ/
proportion /プロポーション/
proportional /プロポーショナル/
proposal /プロポーザル/
propose /プロポーズ/
propto /∝/
protect /プロテクト/
protected /プロテクテッド/
protection /プロテクション/
protein /タンパク質/プロテイン/
proteon /Ｐｒｏｔｅｏｎ/プロテオン/
protestant /プロテスタント/
protocal /プロトコル/
protocol /プロトコル/
prototype /プロトタイプ/
prototyping /プロトタイピング/
proves /┣/├/
provia /ＰＲＯＶＩＡ/プロビア/
provider /プロバイダ/
prowres /プロレス/
proxy /プロキシ/
prs /ＰＲＳ/
ps /ＰＳ/ＰＳ．/Ｐ．Ｓ．/ＰｏｓｔＳｃｒｉｐｔ/ポストスクリプト/PS./PostScript/プロセス/
ps/# /ＰＳ／２/ＰＳ／５５/
pse /主観的等価点/
psersonal /パーソナル/
psi /ψ/ＰＳＩ/
psych /サイク/
psycho /サイコ/
psys /サイズ/PSY・S/
ptex /pTeX/
ptr /ポインタ/
pub /パブ/
public /パブリック/
publication /パブリケイション/
publicity /公告/宣伝/パブリシティ/
publish /パブリッシュ/
publishing /パブリッシング/
pudding /プリン/
pull /プル/
pulldown /プルダウン/
pulp /パルプ/
pulse /パルス/
pump /ポンプ/
pumping /パンピング/
pumpkin /南瓜/パンプキン/
punch /パンチ/
puncher /パンチャー/
punk /パンク/
pure /ピュア/
purge /パージ/
purist /ピュアリスト/
purple /パープル/
push /プッシュ/
pushbutton /プッシュボタン/
put /プット/
puzzle /パズル/
pv /粒子速度/
pwd /(pwd)/
px /ＰＸ/
pyramid /ピラミッド/
q /Ｑ/Ｑ．/¶/
q&a /Ｑ＆Ａ/
qa /Ｑ＆Ａ/
qic /QIC/
qp /ＱＰ/
quality /クオリティ/
quantifier /コンティファイア/
quantize /クォンタイズ/
quark /クォーク/
quartet /カルテット/
quartette /カルテット/
quate /クウェート/
que /キュー/
queen /クィーン/クイーン/
query /問合せ/クエリ/キュエリ/
quest /クエスト/
question /？/クエスチョン/質問/
queue /キュー/
queueing /キューイング/
quick /クイック/クィック/
quit /クイット/
quiz /クイズ/
quot /クウォート/
quota /クォータ/クオータ/
quotation /クォーテーション/
quote /クウォート/クオート/クォウト/“/クォート/『』/”/
r /Ｒ/ｒ/アール/
r&b /リズム・アンド・ブルース/
r&d /Ｒ＆Ｄ/
r6000 /Ｒ６０００/
ra /→/
rabbit /ラビット/
race /レース/
racer /レーサー/
rack /ラック/
racket /ラケット/
radar /レーダー/
radial /ラジアル/
radian /ラジアン/
radiator /ラジエータ/
radio /ラジオ/ラヂオ/レイディオ/
radio-casette /ラジカセ/
radiobotton /ラジオボタン/
radiobox /ラジオボックス/
radiobutton /ラジオボタン/
raggae /レゲエ/
ragtime /ラグタイム/
rail /レール/レイル/
rain /レイン/
raise /レイズ/
rally /ラリー/
ram /ＲＡＭ/RAM/
ramp /ランプ/
rana /ラナ/
random /ランダム/
randomize /ランダマイズ/
randomized /ランダマイズド/
randy /ランディー/
range /レンジ/範囲/
ranger /レンジャー/
rank /ランク/
ranking /ランキング/
rare /レア/
rash /ラッシュ/
raster /ラスタ/ラスター/
rasterfile /ラスターファイル/
rat /ラット/
rate /レート/
ravel /ラベル/
raw /ロー/
ray /レイ/
rayleigh /レイリー/
rc /ＲＣ/
rcs /ＲＣＳ/RCS/
rdb /リレーショナルデータベース/関係データベース/
re /リ/
reach /リーチ/
reachable /リーチャブル/
reacitivate /リアクティベート/
reaction /リアクション/
reactivation /リアクティベーション/
read /リード/
readable /リーダブル/
reader /リーダー/リーダ/
readers /リーダーズ/
reading /リーディング/
readme /README/
readonly /リードオンリー/
ready /レディ/
real /リアル/ＲＥＡＬ/
reality /リアリティ/
realtime /リアルタイム/
realtimesystem /リアルタイムシステム/
rear /リヤ/
reasonable /リーズナブル/
reasoning /リーズニング/
reassemble /リアセンブル/
rebecca /レベッカ/
rebirth /リバース/
reboot /リブート/
rebound /リバウンド/
rebuild /リビルド/
rec /ｒｅｃ/
recall /リコール/
receipt /レシート/
receive /レシーブ/
receiver /リシーバ/レシーバ/
reception /レセプション/
recognition /認識/
recompile /リコンパイル/
record /レコード/
recorder /レコーダ/レコーダー/
recording /レコーディング/
recordya /レコード屋/
recover /リカバー/
recovery /レカバリ/リカバリー/リカバリ/
recreation /レクリエーション/
recruit /リクルート/
recruiter /リクルーター/
recruitment /リクルートメント/
recursion /リカージョン/
recursive /リカーシブ/再帰的/
recycle /リサイクル/
red /レッド/≫/
redial /リダイアル/
redirect /リダイレクト/
redirection /リダイレクション/
redisplay /リディスプレイ/
redo /リドゥ/
redouble /リダブル/
redribbon /レッドリボン/
reduce /リデュース/
reducer /レデューサ/
reduction /リダクション/
reel /リール/
reentrant /リエントラント/
refer /リファー/
referee /レフェリー/
reference /リファレンス/参照型/参考文献/
referencer /リファレンサ/
refile /リフィル/リファイル/
refill /リフィル/
refine /リファイン/
reflection /リフレクション/
reflective /リフレクティブ/
reflector /反射鏡/リフレクター/
reform /リフォーム/
refrain /リフレイン/
refresh /リフレシュ/リフレッシュ/
refuse /拒否/
regexp /正規表現/
region /リージョン/
regional /リージョナル/
register /レジスタ/レジ/レジスター/
registration /レジストレーション/
regret /リグレット/
regular /レギュラー/
regulation /レギュレーション/
rehabilitation /リハビリテーション/機能回復訓練/
reharsal /リハーサル/
rehearsal /リハーサル/
reinstall /リインストール/
reject /リジェクト/
relation /リレーション/
relational /リレーショナル/
relax /リラックス/
relay /リレー/
release /リリース/
reload /リロード/
relocatable /リロケータブル/
relocate /リロケート/
remake /リメーク/リメイク/
remark /リマーク/
remix /リミックス/
remocon /リモコン/
remote /リモート/
removable /リムーバブル/
remove /リムーブ/
rename /リネーム/
rendering /レンダリング/
rendez-vous /ランデヴー/
rendition /レンディション/
reno /Ｒｅｎｏ/
renta /レンタ/
rentacar /レンタカー/
rental /レンタル/
renumber /レナンバ/
repeat /々/リピート/
repeater /リピータ/
replace /リプレース/
replacement /リプレースメント/
replay /リプレイ/
replication /レプリケーション/
reply /リプライ/返事/返信/
report /レポート/リポート/
reporter /レポーター/
repository /リポジトリ/
repost /リポスト/
request /リクエスト/要求/
requiem /レクイエム/
rescan /リスキャン/
research /リサーチ/
reservation /リザベーション/
reserve /リザーブ/
reserved /リザーブド/
reset /リセット/
resize /リサイズ/
resolution /リゾリューション/
resolve /リゾルブ/
resolver /レゾルバ/リゾルバ/
resonance /レゾナンス/
resort /リゾート/
resource /リソース/
resourcefile /リソースファイル/
resourcemanager /リソースマネージャ/
responce /レスポンス/
response /レスポンス/リスポンス/
rest /レスト/
restart /リスタート/
restaurant /レストラン/
restore /リストア/
result /リザルト/
resume /レジューム/レジュメ/
retail /リテイル/
retainer /リテイナー/
retire /リタイア/
retract /レトラクト/
retrieval /検索/
retrieve /リトリーブ/
retry /リトライ/
return /リターン/復帰/
reusable /リユーザブル/
reverse /リバース/
review /レビュー/レヴュー/リヴュー/リビュー/
reviewer /レビューアー/レビューア/
revise /リヴァイズ/
revision /リビジョン/
revival /リヴァイヴァル/リバイバル/
rewrite /リライト/
reynolds /レイノルズ/
rfc /ＲＦＣ/
rgb /ＲＧＢ/
rho /ρ/
rhythm /リズム/
ri /繰り返し衝撃音/
riacs /ＲＩＡＣＳ/
ribbon /リボン/
ribosome /リボソーム/
rice /ライス/
rich /リッチ/
richard /リチャード/
richo /リコー/
ricoh /リコー/
rics /ＲＩＣＳ/計算機科学研究所/
ride /ライド/
rider /ライダー/
riec /東北大学電気通信研究所/電気通信研究所/東北大通研/
riemann /リーマン/
riezon /リエゾン/
rifle /ライフル/
right /ライト/→/右/
rightarrow /→/
righthand /ライトハンド/
rigid /リジッド/
rimnet /リムネット/
rims /数理解析研究所/京都大学数理解析研究所/
rimshot /リムショット/
ring /リング/
ringo /リンゴ/
rinse /リンス/
rion /リオン/
rip /ＲＩＰ/
risc /ＲＩＳＣ/リスク/RISC/
riscnews /ＲＩＳＣＮＥＷＳ/
risk /リスク/
rival /ライバル/ライヴァル/
rlogin /ｒｌｏｇｉｎ/リモートログイン/
rmail /ＲＭＡＩＬ/
rms /Richard M. Stallman/ＲＭＳ/リチャード・Ｍ・ストールマン/
rna /ＲＮＡ/
rnp /ＲＮＰ/
ro /ＲＯ/
ro-maji /ローマ字/
road /ロード/
roadracer /ロードレーサー/
roadshow /ロードショウ/
roaster /ロースター/
robby /ロビー/
robert /ロバート/ロベルト/
robin /ロビン/
robo /ロボ/
robot /ロボット/
robotics /ロボティックス/
robust /ロバスト/
rochester /ロチェスター/
rock /ロック/
rock'n /ロックン/
rockband /ロックバンド/
rocket /ロケット/
rockridge /ロックリッジ/
rockrigde /ロックリッジ/
rogue /ローグ/
roland /ローランド/
roleplaying /ロールプレイング/
roll /ロール/
rollback /ロールバック/
roller /ローラー/
rolling /ローリング/
rom /ＲＯＭ/リードオンリ/ロム/ROM/
roma /ローマ/羅馬/
romaji /ローマ字/
roman /ローマン/ロマン/ローマ字/
romance /ロマンス/
romancing /ロマンシング/
romancingstone /ロマンシングストーン/
romania /ルーマニア/
romantic /ロマンティック/
romantist /ロマンチスト/
rome /ローマ/
ronde /ロンド/輪舞/
roof /ルーフ/
room /ルーム/
roomservice /ルームサービス/
roop /ループ/
root /ルート/√/根/スーパーユーザ/
roots /ルーツ/
rop /ＲＯＰ/
rope /ロープ/
ros /ＲＯＳ/
rose /ローズ/
rosemary /ローズマリー/
rossby /ロスビー/
rossbywave /ロスビー波/
rosser /ロッサー/
rot /ロット/
rotary /ロータリー/
rotation /ローテーション/
rouge /ルージュ/
rough /ラフ/
round /ラウンド/
roundrobin /ラウンドロビン/
route /ルート/
router /ルータ/ルーター/
routine /ルーチン/ルーティン/
routing /ルーティング/
row /ロウ/
royal /ロイヤル/
royality /ローヤリティ/
royalty /ローヤリティ/
rpc /ＲＰＣ/
rpg /ＲＰＧ/
rs /ＲＳ/
rs232c /ＲＳ−２３２Ｃ/
rsh /ｒｓｈ/
rt /残響時間/
rubber /ラバー/
ruby /ルビ/紅玉/ルビー/
ruff /ラフ/
rugby /ラグビー/
rule /ルール/規則/
ruled /ルールド/
ruler /ルーラ/
ruleset /ルールセット/
rumble /Ｒｕｍｂｌｅ/ランブル/
run /ラン/
runlength /ランレングス/
runner /ランナー/
running /ランニング/
runtime /ランタイム/
rush /ラッシュ/
russell /ラッセル/
russia /а/б/в/г/д/е/ё/ж/з/и/к/й/м/н/л/п/с/о/р/т/у/ш/ф/х/ч/ц/ь/щ/я/ъ/ы/э/ю/ロシア/魯西亜/露西亜/
russian /ロシア語/
rx /ＲＸ/
s /Ｓ/エス/
s# /昭和#0年/
sa /ＳＡ/
saber /サーベル/セイバー/
sack /ザック/
sacrifice /サクリファイス/
saddle /サドル/
sade /サド/サド侯爵/Marquis de Sade/Donation Alphonse Francois de Sade/
sadism /サディズム/加虐淫乱症/加虐趣味/嗜虐的趣味/
sadist /サディスト/加虐趣味者/嗜虐的趣味者/
safe /セーフ/
sage /セージ/
sail /セール/
sailer /セイラー/
sailor /セーラー/
saison /セゾン/
salad /サラダ/
salamander /サラマンダー/サラマンダ/サラマンドラ/
salary /サラリー/
salaryman /サラリーマン/
sale /セール/
sales /セールス/
salesman /セールスマン/
sally /サリー/
salmon /サーモン/
sample /サンプル/
sampler /サンプラー/
sampling /サンプリング/
samuel /サミュエル/
san /サン/
san-francisco /サンフランシスコ/
sand /サンド/
sandal /サンダル/
sandiego /サン・ディエゴ/
sandwich /サンドイッチ/
sandwitch /サンドイッチ/
sandy /サンディー/
sanfrancisco /サン・フランシスコ/
sankaku /△/▲/
sans /サン/
santacruz /サンタ・クルーズ/
santafe /サンタフェ/
sap /ｓａｐ/SAP/
saphire /青玉/サファイア/
sas /ＳＡＳ/
sasi /ＳＡＳＩ/SASI/Shugart Associates System Interface;Shugart社開発のシステムインターフェイス/
sat /土/
satellite /サテライト/
saturation /彩度/
sausage /ソーセージ/
save /セーブ/
saver /セーバ/セーバー/
saw /ソー/
sax /サックス/
saxophone /サクソフォン/
sbdd /共有二分決定グラフ/
sbir /ＳＢＩＲ/
scalability /スケイラビリティ/スケーラビリティ/
scalable /スケイラブル/
scalar /スカラー/スカラ/スケーラ/
scale /スケール/スケイル/
scaler /スカラー/
scalewindow /スケールウインドー/
scaling /スケーリング/
scalingfactor /スケーリングファクター/
scan /スキャン/
scandal /スキャンダル/
scandinavia /スカンジナビア/
scanline /スキャンライン/
scanner /スキャナー/スキャナ/
scatterometer /スキャトロメーター/
sccs /ＳＣＣＳ/
scd /ＳＣＤ/
scenario /シナリオ/
scene /シーン/
schedule /スケジュール/
scheduler /スケジューラ/スケジュ-ラ/
scheduling /スケジューリング/
scheffe /シェッフェ/
schema /スキーマ/
schemata /スキーマタ/
schematic /スケマティック/
scheme /スキーム/ｓｃｈｅｍｅ/Scheme/
school /スクール/
schumann /シューマン/
science /サイエンス/
sclereid /スクレレイド/
scola /スコラ/
scope /スコープ/
score /スコア/
scort /スコート/
scotch /Ｓｃｏｔｃｈ/スコッチ/
scott /スコット/
scramble /スクランブル/
scrap&build /スクラップ＆ビルド/
scratch /スクラッチ/
screen /スクリーン/
screening /スクリーニング/
screw /スクリユー/
script /スクリプト/
scroll /スクロール/
scrollbar /スクロールバー/
scrolledwindow /スクロール・ウィンドー/
scsi /ＳＣＳＩ/SCSI/Small Computer System Interface/
scuba /スキューバ/スクーバ/
sd /標準偏差/最急降下/
sdm /ＳＤＭ/
sds /システムデザインサービス/
se /ＳＥ/┌/┏/
sea /シー/
seafood /シーフード/
seal /シール/
seamless /シームレス/
search /サーチ/探索/
searcher /サーチャ/
searle /サール/
season /シーズン/
seat /シート/
seattle /シアトル/
sec /ｓｅｃ/
secom /セコム/
second /セカンド/セカント/第2要素/秒/
secondary /セカンダリー/セカンダリ/
sect /セクト/
section /セクション/§/
sectionalism /セクショナリズム/
sectionning /セクショニング/
sector /セクタ/セクター/
secure /セキュア/
security /セキュリティ/セキュリティー/セキュリチー/
sedan /セダン/
seed /シード/
seeds /シーズ/
seek /シーク/
seen /シーン/
sega /セガ/
segment /セグメント/
segmentation /セグメンテーション/
seidel /ザイデル/
seiko /セイコー/
seismic /サイスミック/
select /セレクト/
selecter /セレクタ/
selection /セレクション/
selector /セレクタ/
self /セルフ/Self/
selfservice /セルフサービス/
seller /セラー/
sellers /セラーズ/
semantics /セマンティクス/意味/
semaphore /セマフォ/セマフォー/
semblance /センブランス/
semester /セメスター/
semi /ゼミ/セミ/セミナー/
semicolon /セミコロン/
seminar /セミナー/セミナ/ゼミ/
seminor /セミナー/
seminorm /セミノルム/
semophore /セマフォ/
send /センド/
senior /シニア/
sensational /センセーショナル/
sense /センス/
sensing /センシング/
sensor /センサ/センサー/
sentence /センテンス/
seoul /ソウル/
separate /セパレート/
separator /セパレータ/
seq /順序機械/
seqencer /シーケンサー/
sequence /シーケンス/シークエンス/シークェンス/
sequencer /シーケンサー/シーケンサ/
sequencial /シーケンシャル/
sequent /シークエント/シーケント/
sequential /シーケンシャル/
sera /セラ/
serendipity /セレンディピティー/
serge /サージ/
serial /シリアル/
serialize /シリアライズ/
series /シリーズ/
serif /セリフ/
serious /シリアス/
server /サーバ/サーバー/サーヴァ/
service /サービス/サーヴィス/
session /セッション/
set /セット/集合/
setminus /＼/
setting /セッティング/
setup /セットアップ/
seven /セブン/
seveneleven /セブンイレブン/
seventeen /セヴンティーン/
severe /シビア/
sex /セックス/Ｓ−ｅｘｐｒｅｓｓｉｏｎ/Ｓ式/
sexp /S式/
sexy /セクシー/
sf /ＳＦ/
sfc /ＳＦＣ/
sfinx /ＳＦＩＮＸ/
sfx /ＳＦＸ/
sg /シリコン・グラフィックス/ＳＧ/
sgi /シリコングラフィックス/
sgml /SGML/
sh /Bシェル/
shading /シェーディング/
shadow /シャドウ/シャドー/
shadowing /シャドウイング/
shaft /シャフト/
shampoo /シャンプー/
shanghai /シャンハイ/上海/
shanghi /上海/シャンハイ/
shannon /シャノン/
shape /シェープ/
shapeup /シェイプアップ/
shaping /シェイピング/
share /シェア/
shared /シェアード/
shareware /シェアウェア/
sharing /シェアリング/
sharp /シャープ/＃/♯/
shattle /シャトル/
shaver /シェーバー/
shear /シアー/
sheat /シート/
sheena /シーナ/
sheet /シート/
sheets /シーツ/
shell /シェル/
shellscript /シェルスクリプト/
shelter /シェルター/
shepherd /シェパード/
sherbet /シャーベット/
shield /シールド/
shift /シフト/
shiftjis /シフトＪＩＳ/
shiftkey /シフト・キー/
shikaku /□/■/
shime /〆/
shining /シャイニング/
ship /シップ/
shirt /シャツ/
shirts /シャツ/
shock /ショック/
shocking /ショッキング/
shoe /シュー/
shoebox /シューボックス/
shoes /シューズ/
shoot /シュート/
shootdown /シュートダウン/
shooting /シューティング/
shop /ショップ/
shopping /ショッピング/
short /ショート/
shorts /ショーツ/
shortscale /ショートスケール/
shot /ショット/
show /ショウ/ショー/
shower /シャワー/
showroom /ショウルーム/
shredder /シュレッダ/
shroedinger /シュレーディンガー/
shuffle /シャッフル/シャフル/
shuffling /シャッフリング/
shut /シャット/
shutdown /シャットダウン/
shutter /シャッター/
shuttle /シャトル/
shy /シャイ/
si /音響インテンシティ/
sibip /シビップ/
sice /計測自動制御学会/
sicp /ＳＩＣＰ/ＳＩＣＰ(Structure and Interpretation of Computer Programs)/
side /サイド/
sift /シフト/
sig /シグ/
sigma /σ/Σ/シグマ/
sigmoid /シグモイド関数/シグモイド/
sign /サイン/署名/
signal /シグナル/
signalhandler /シグナルハンドラ/
signature /シグネチャー/シグナチャー/シグニチャ/シグネイチャー/シグネチャ/
silhouette /シルエット/
silicon /シリコン/
silver /シルバー/
silvia /シルヴィア/
sim /〜/
simbox /シミュレーション・ボックス/
simd /ＳＩＭＤ/
simm /ＳＩＭＭ/
simple /シンプル/
simulate /シミュレート/シミュレイト/
simulater /シミュレータ/
simulation /シミュレーション/シミュレイション/シミュレ−ション/
simulator /シミュレータ/シミュレーター/シミュレイタ/シミュレ-タ/
sin /サイン/
sine /サイン/
singapole /シンガポール/
singapore /シンガポール/
singer /シンガー/
singersongwriter /シンガーソングライター/
single /シングル/
singles /シングルズ/
singleton /シングルトン/
sinusoid /サイン曲線/
siren /サイレン/セイレーン/
sitar /シタール/
site /サイト/
situation /シチュエーション/
size /サイズ/
sizing /サイジング/
skate /スケート/
skating /スケーティング/
skeleton /スケルトン/
skelton /スケルトン/
sketch /スケッチ/
skew /スキュー/
ski /スキー/
skid /スキッド/
skier /スキーヤー/
skill /スキル/
skinning /スキニング/
skinship /スキンシップ/
skip /スキップ/
skirt /スカート/
skiware /スキーウェア/
skk /SKK/ＳＫＫ/ｓｋｋ/(skk-version)/
skolem /スコーレム/
sky /スカイ/
skylark /すかいら〜く/
skyline /スカイライン/
sl /ＳＬ/
slack /スラック/
slacks /スラックス/
slam /スラム/
slapstick /スラップスティック/
slash /／/スラッシュ/
slave /スレーブ/
slax /スラックス/
sleep /スリープ/
sleeve /スリーヴ/
sleigh /スレー/
slender /スレンダー/
slice /スライス/
slicer /スライサ/
slicing /スライシング/
slide /スライド/
slider /スライダー/
slidermemory /スライダーメモリ/
sliding /スライディング/
slim /スリム/
slime /スライム/
slip /ＳＬＩＰ/スリップ/
slipper /スリッパ/
slit /スリット/
slogan /スローガン/
slope /スロープ/
slot /スロット/
slow /スロー/
slowly /スローリー/
slowness /スローネス/
slowstep /スローステップ/
slump /スランプ/
sm /ＳＭ/
small /スモール/
smalltalk /Ｓｍａｌｌｔａｌｋ/SmallTalk/Smalltalk/
smart /スマート/
smile /(concat "^_^\073\073")/(^_^)/:-)/(concat "(^_^\073\073)")/^_^/%-)/%-}/(^o^)/:->/B-)/＼＼(^_^)／／/スマイル/(concat "(^_^\073)")/(concat "(\073_\073)")/(_ _)/(*_*)/^^)/:-</:-(/(concat "\073-)")/
smiley /:-)/
smog /スモッグ/
smoker /スモーカー/
smooth /スムース/スムーズ/
smoothing /スムージング/
smtp /ＳＭＴＰ/
snack /スナック/
snake /スネーク/
snap /スナップ/
snapshot /スナップショット/
snatcher /スナッチャー/
sneaker /スニーカー/
snic /ＳＮＩＣ/
snmp /ＳＮＭＰ/
snob /スノッブ/
snoop /スヌープ/
snooping /スヌーピング/
snoopy /スヌーピー/
snow /スノー/
soap /ソープ/
soarer /ソアラ/
soccer /サッカー/
social /ソシアル/ソーシャル/ソーシアル/
society /ソサエティ/ソサエティー/
socket /ソケット/
socks /ソックス/
socrates /ソクラテス/
sofa /ソファ/
sofmap /ソフマップ/
soft /ソフト/ソフトウェア/
softball /ソフトボール/
software /ソフトウェア/ソフトウエア/
softwarestack /ソフトウェア・スタック/
softwear /ソフトウェア/
solaris /Ｓｏｌａｒｉｓ/ソラリス/Solaris/
sole /ソール/ソウル/
solenoid /ソレノイド/
solid /ソリッド/
solist /ソリスト/
soliton /ソリトン/
solo /ソロ/
soloalbum /ソロアルバム/
solution /ソリューション/
solver /ソルバ/
sommelier /ソムリエ/
sonar /ソナー/
sonata /ソナタ/
song /ソング/
sonic /ソニック/
sonn /ＳＯＮＮ/
sonogram /ソノグラム/
sony /ソニー/ＳＯＮＹ/
sonynews /ＳＯＮＹ ＮＥＷＳ/
sophisticate /ソフィスティケート/
soprano /ソプラノ/
sorry /(concat "(^_^\073)")/
sort /ソート/
sorting /ソーティング/
soul /ソウル/
sound /サウンド/
soup /スープ/
source /ソース/
sourcecode /ソースコード/
sourcefile /ソースファイル/
southern /サザン/
soviet /ソ連/ソヴィエト/
sp /　/ＳＰ/
spa /ＳＰＡ/
space /スペース/　/□/スペイス/
spacing /スペーシング/
spade /スペード/スペイド/
spaghetti /スパゲッティ/スパゲッティー/
spain /スペイン/Ｓｐａｉｎ/
span /スパン/
spanish /スペイン語/
spanning /スパニング/
sparc /ＳＰＡＲＣ/ｓｐａｒｃ/Sparc/スパーク/
spare /スペア/
spark /スパーク/
sparse /スパース/
speaker /スピーカ/スピーカー/
spec /スペック/ＳＰＥＣ/仕様/
special /スペシャル/スペシャリティ/特殊形式/
specialist /スペシャリスト/
specific /スペシフィック/
specification /スペシフィケーション/
specifier /指示子/
spector /スペクトル/
spectral /スペクトラル/スペクトル/
spectrogram /スペクトログラム/
spectrum /スペクトラム/スぺクトラム/スペクトル/スペクトラム`/
speech /スピーチ/
speed /スピード/すぴーど/
speedup /スピードアップ/
speedy /スピーディ/
spell /スペル/
spelling /スペリング/
spencer /スペンサー/
spice /スパイス/
spielberg /スピルバーグ/
spike /スパイク/
spin /スピン/
spindle /スピンドル/
spinglass /スピングラス/
spinics /スピニクス/
spinlock /スピンロック/
spiral /スパイラル/
spirit /スピリット/
spirits /スピリッツ/
splay /スプレー/
splice /スプライス/
spline /スプライン/
split /スプリット/
splus /Splus/
spoiler /スポイラー/
sponge /スポンジ/
sponsor /スポンサー/
spool /スプール/
spooler /スプーラ/
spoon /スプーン/
sport /スポーツ/
sports /スポーツ/スポーツ新聞/
sportscenter /スポーツセンター/
sportsclub /スポーツクラブ/
sportsfair /スポーツフェアー/
sportsman /スポーツマン/
spot /スポット/
spr /ＳＰＲ/
spray /スプレー/
spread /スプレッド/
spreadsheet /スプレッドシート/
sprice /スプライス/
spring /スプリング/
springer /シュリンガー・フェアラーク/
sprinkler /スプリンクラー/
sprite /スプライト/
spur /シュプール/
spy /スパイ/
sq /□/
sqrt /√/
square /スクェア/■/□/
squashing /スカッシング関数/
squeeze /スクイズ/
sra /ＳＲＡ/Software Research Associate,Inc./
sram /ＳＲＡＭ/
src /ソース/
srilanka /スリランカ/
ss /§/ＳＳ/
ss10 /ＳＰＡＲＣステーション１０/
sseki /Ｓ席/
stable /ステーブル/
stack /スタック/
stackable /スタッカブル/
stackframe /スタックフレーム/
stackobject /スタック・オブジェクト/
stackpointer /スタック・ポインタ/
staff /スタッフ/
stage /ステージ/
stainless /ステンレス/
stake /ステーキ/
stall /ストール/
stallman /ストールマン/
stamp /スタンプ/
stance /スタンス/
stand /スタンド/
standalone /スタンドアローン/
standard /スタンダード/標準/
standards /スタンダーズ/
stanford /スタンフォード/スタンフォード大学/
star /★/スター/＊/☆/STAR/
start /スタート/
starter /スターター/
starting /スターティング/
startrek /スタートレック/
startup /スタートアップ/
state /ステート/ステイト/
statefull /ステートフル/
stateless /ステートレス/
statement /ステートメント/ステイトメント/文/
static /スタティック/静的/
station /ステーション/ステイション/
status /ステータス/ステイタス/
statusbar /ステータスバー/
stdin /標準入力/
stdout /標準出力/
steady /ステディ/
steak /ステーキ/
steel /スチール/
steer /ステア/
steering /ステアリング/
steivie /スティービー/
step /ステップ/ステップ応答/ステップ関数/
stepping /ステッピング/
steps /ステップス/
stepsize /ステップサイズ/
stepup /ステップアップ/
stereo /ステレオ/
stereotype /ステレオタイプ/
stew /シチュー/
stewardess /スチュワーデス/
stick /スティック/スティク/
sticker /ステッカー/
stiffness /スチフネス/
still /スチル/スチール/
stk /STk/
stock /ストック/
stockholm /ストックホルム/
stoic /ストイック/
stokes /ストークス/
stolon /ストロン/
stone /ストーン/
stones /ストーンズ/
stop /ストップ/
stopbit /ストップビット/
stopper /ストッパー/
stopwatch /ストップウォッチ/
storage /ストーレジ/ストレージ/
store /ストア/
storethrough /ストアスルー/
storm /ストーム/
storming /ストーミング/
story /ストーリー/ストーリ/
stove /ストーヴ/ストーブ/
straight /ストレート/ストレイト/
strap /ストラップ/
strategy /ストラテジ/
stream /ストリーム/
streamer /ストリーマ/
street /ストリート/
stress /ストレス/
strict /ストリクト/
strike /ストライキ/ストライク/
string /ストリング/文字列/
strings /ストリングス/
strip /ストリップ/
stripe /ストライプ/
striping /ストライピング/
strobe /ストローブ/
stroke /ストローク/
struct /ストラクト/構造体/
structure /ストラクチャー/ストラクチャ/
stub /スタブ/
stud /スタッド/
studio /スタジオ/
studium /スタジアム/
studless /スタッドレス/
study /スタディ/
stuff /スタッフ/
sturges /スタージェス/
sty /スタイル/
style /スタイル/
styleguide /スタイルガイド/
su /ｓｕ/スーパーユーザ/スーパユーザ/
sub /サブ/部分/
subaddress /サブアドレス/
subblock /サブブロック/
subclass /サブクラス/
subdirectory /サブディレクトリ/
subdomain /サブドメイン/サブドメーン/
subgoal /サブゴール/
subgraph /サブグラフ/
subgroup /サブグループ/
subheader /サブヘッダ/
subject /サブジェクト/
submap /サブマップ/
submarine /サブマリン/
submaster /サブマスター/
submenu /サブメニュー/
submodel /サブモデル/
subnet /サブネット/
subnetting /サブネッティング/
subnetwork /サブネットワーク/
subnote /サブノート/
subpattern /サブパターン/
subprocess /サブプロセス/
subprogram /サブプログラム/
subroutine /サブルーチン/
subscribe /サブスクライブ/
subscript /サブスクリプト/
subset /サブセット/⊂/
subseteq /⊆/
subshell /サブシェル/
substitute /置換/
subsystem /サブシステム/
subtitle /サブタイトル/
subtraction /サブトラクション/
subtype /サブタイプ/
suesan /スーザン/
suffix /サフィックス/拡張子/添字/
sug /サン・ユーザ・グループ/
sugar /シュガー/
suggest /サジェスト/
suggestion /サジェスチョン/
suit /スーツ/スート/
suitcase /スーツケース/
suite /スィーツ/
suits /スーツ/
suitscase /スーツケース/
sum /サム/∪/
summary /サマリ/
summer /サマー/
sun /サン/日/Ｓｕｎ/ｓｕｎ/Sun/ＳＵＮ/
sun3 /Ｓｕｎ３/
sun4 /Ｓｕｎ４/
sunday /サンデー/
sunglass /サングラス/
sunkist /サンキスト/
sunmusic /サン・ミュージック/
sunnet /ＳｕｎＮｅｔ/
sunos /ＳｕｎＯＳ/SunOS/
sunshine /サンシャイン/
suntory /サントリー/
suntoryhall /サントリーホール/
sunview /ＳｕｎＶｉｅｗ/
super /スーパー/スーパ/
superascii /ＳｕｐｅｒＡｓｃｉｉ/
superclass /スーパクラス/
supercom /スパコン/
supercomputer /スーパーコンピューター/スーパーコンピュータ/
supermarket /スーパーマーケット/
superoption /スーパーオプション/
superscalar /スーパスカラ/スーパースケーラ/
superscaler /スーパースケーラ/
superset /⊃/
superseteq /⊇/
supersize /スーパーサイズ/
superuser /スーパーユーザ/スーパーユーザー/スーパユーザ/
supervisor /スーパバイザ/
supplier /サプライア/
supply /サプライ/
support /サポート/
supporter /サポーター/
suppress /サプレス/
supset /⊃/
supseteq /⊇/
surface /サーフェイス/サーフェス/
surround /サラウンド/
survey /サーベイ/
survival /サバイバル/
susceptance /サセプタンス/
susie /スージー/
suspend /サスペンド/
suspense /サスペンス/
suspension /サスペンション/
svd /特異値分解/
svga /ＳＶＧＡ/
svhs /ＳＶＨＳ/
sw /ＳＷ/┐/┓/
swan /スワン/
swap /スワップ/
swapout /スワップアウト/
swapper /スワッパ/
swapping /スワッピング/
sweat /スウェット/
sweater /セーター/
sweden /スウェーデン/
sweep /スウィープ/スイープ/
sweeper /スイーパー/
sweet /スイート/スウィート/
swimming /スィミング/スウィミング/スイミング/
swing /スウィング/
swiss /スイス/
switch /スィッチ/スイッチ/ｓｗｉｔｃｈ/
switching /スイッチング/
swizzling /シズリング/
sword /ソード/
syan /シアン/
syllabus /シラバス/
sylph /シルフ/
symbol /シンボル/
symbolic /シンボリック/
symbolic-link /シンボリック・リンク/
symboliclink /シンボリック・リンク/
symlink /シンボリックリンク/
symphony /シンフォニー/
sympo /シンポ/
symposium /シンポジウム/
synaps /シナプス/
synapse /シナプス/
sync /シンク/
synch /シンク/
synchronizing /シンクロナイジング/
synchronous /シンクロナス/
synergy /シナジー/
syntactic /シンタクティック/
syntax /シンタクス/シンタックス/
synth /シンセ/
synthe /シンセ/
synthesizer /シンセサイザ/
sys /シス/ＳＹＳ５/
sysad /シスアド/
syslab /シスラボ/
sysop /シスオペ/
system /システム/
system5 /システム５/
systematic /システマティック/
systemcall /システムコール/
systems /システムズ/
systollic /シストリック/
systollicarray /シストリックアレイ/
sysv /ＳｙｓＶ/
t /Ｔ/├/┬/┤/┴/┣/┳/┫/┻/┠/┯/┨/┷/┝/┰/┥/┸/〒/
t-shirt /Ｔシャツ/
tab /タブ/
tabaco /タバコ/
table /テーブル/表/
tableaux /タブロー/
tablet /タブレット/
taboo /タブー/
tac /TAC/
tack /タック/
tackle /タックル/
tactic /タクティック/
tag /タグ/Ｔａｇ/た〜く/
tail /テイル/テール/
tains /テインズ/TAINS/
take /テイク/
tale /テール/
talent /タレント/
talk /トーク/
talker /トーカ/
talking /トーキング/
tandem /タンデム/
tank /タンク/
tannin /タンニン/
tap /タップ/
tape /テープ/テイプ/
tapping /タッピング/
tar /ｔａｒ/
target /ターゲット/
task /タスク/
taskforce /タスクフォース/
tasking /タスキング/
tate /│/┃/
tau /τ/
tautology /トートロジー/
tax /タックス/
taxi /タクシー/
taxy /タクシー/
tb /ＴＢ/
tbs /ＴＢＳ/
tc /時定数/
tcp /ＴＣＰ/ＴＣＰ／ＩＰ/TCP/
tcpip /ＴＣＰ／ＩＰ/
tdk /ＴＤＫ/
tea /ティ/ティー/
teaching /ティーチング/
team /チーム/
teapot /ティーポット/
tec /ＴＥＣ/
tech /テク/テック/
technic /テクニック/
technical /テクニカル/
technique /テクニック/
techno /テクノ/
technology /テクノロジー/
tee /ティー/
teenage /ティーンエイジ/
teenager /ティーンエージャー/
teflon /テフロン/
tektro /テクトロ/
tel /電話/Ｔｅｌ/電話番号/TEL/
tele /テレ/
telecom /テレコム/
telemark /テレマーク/
telemarker /テレマーカー/
telemeter /テレメータ/テレメーター/
telephone /テレフォン/テレホン/
teleport /テレポート/
telesis /テレシス/
teletype /テレタイプ/
television /テレビジョン/テレビ/
telnet /ｔｅｌｎｅｔ/
tema /テーマ/
temp /テンポラリ/temporary/
template /テンプレート/テンプレイト/
templete /テンプレート/
tempo /テンポ/
temporal /テンポラル/
temporary /テンポラリ/
ten /・/テン/
tenant /テナント/
tenkey /テンキー/
tennis /テニス/
tenniswear /テニスウェア/
tension /テンション/
tensor /テンソル/
tent /テント/
tentative /試験的/
tenten /・・・/…/
term /ターム/ＴＥＲＭ/用語/
terminal /ターミナル/端末/
terminate /ターミネイト/ターミネート/
terminator /ターミネータ/ターミネイタ/ターミネーター/
territory /テリトリー/
terror /テロ/
terrorist /テロリスト/
test /テスト/試験/ｔｅｓｔ/
testcase /テストケース/
tester /テスター/
testing /テスティング/
testmail /テストメール/
testset /テストセット/
tetris /テトリス/
tex /ＴｅＸ/ＴEＸ/テフ/TeX/\TeX/テック/
texas /テキサス/テキサス大学/
texel /テクセル/
texinfo /Texinfo/
text /テキスト/文字列/教科書/テクスト/
textfield /テキストフィールド/
textfile /テキストファイル/
textual /テクスチュアル/
texture /テクスチャ/テキスチャ/
textwidget /テキスト・ウィジット/
tf /伝達関数/
tfj /ＴＦＪ/
thai /タイ/
thailand /タイ/
the /ザ/ジ/
theater /シアター/
thebestten /ザ・ベストテン/
thema /テーマ/
theme /テーマ/
theory /セオリー/
therefore /∴/
thesaurus /シソーラス/
theta /θ/
thetelevision /ザ・テレビジョン/
thick /シック/
thief /シーフ/
thin /シン/
third /サード/３ｒｄ/第3要素/
thomas /トマス/
thompson /トンプソン/
thomson /トムソン/
thrashing /スラッシング/
thread /スレッド/
three /スリー/
threshold /スレッシュホールド/閾値/
thriling /スリリング/
thrill /スリル/
thrilling /スリリング/
through /スルー/
throughput /スループット/
throughtput /スループット/
thu /木/
thunder /サンダー/
thyme /タイム/
ti /ＴＩ/テキサスインスツルメンツ/
tia /東北インターネット協議会/
tiananmen /天安門/
tiara /ティアラ/
tick /ティック/
ticket /チケット/切符/
tie /タイ/
tifanny /ティファニー/
tiffany /ティファニー/
tiger /タイガー/
tigers /タイガース/
tight /タイト/
tilda /チルダ/
tilde /〜/
tile /タイル/
time /タイム/ＴＩＭＥ/時間/(current-time-string)/
timecard /タイムカード/
timely /タイムリー/
timeout /タイムアウト/
timer /タイマ/タイマー/
times /タイムズ/×/
timescale /タイムスケール/
timeshift /タイムシフト/
timestamp /タイムスタンプ/
timezone /タイムゾーン/
timing /タイミング/
tiny /タイニー/
tip /チップ/ｔｉｐ/
tips /ティップス/
tire /タイヤ/タイア/
tirol /チロル/
tisn /ＴＩＳＮ/
tissue /ティッシュ/
tit /東工大/
titan /タイタン/Ｔｉｔａｎ/
title /タイトル/
titlebar /タイトルバー/
tk80 /ＴＫ８０/
tm /ＴＭ/
tna /ＴＮＡ/
to /トゥ/→/━ここまで━/━━━━━ここまで━━━━━/(concat "----- ここまで ----- ここまで ----- ここまで ----- ここまで -----\n")/
toaster /トースタ/
tobacco /タバコ/
today /(skk-current-date (lambda (date-information format gengo and-time) (skk-default-current-date date-information nil 0 'gengo 0 0 0)))/(skk-current-date (lambda (date-information format gengo and-time) (skk-default-current-date date-information "%s-%s-%s(%s)" 0 nil 0 0 nil)))/(skk-current-date (lambda (date-information format gengo and-time) (skk-default-current-date date-information nil 0 'gengo 1 0 0)))/(skk-current-date (lambda (date-information format gengo and-time) (skk-default-current-date date-information nil 3 'gengo 0 0 0)))/
toe /トウ/
toeic /ＴＯＥＩＣ/TOEIC/トーイック/
toeplitz /テプリッツ/
together /トゥギャザー/
toggle /トグル/
togglebutton /トグルボタン/
tohoku /東北大学/東北/東北地方/
toile /トイレ/
toilet /トイレ/トイレット/
token /トークン/
tokyo /トーキョー/
tolerance /トレランス/
tolerant /トレラント/
tom /トム/
tomato /トマト/
tonal /トーナル/
tonality /トーナリティ/
tone /トーン/
toner /トナー/
tonight /トゥナイト/
tool /ツール/
toolbar /ツールバー/
toolkit /ツールキット/
tools /ツールス/
top /トップ/Ｔ/上/
topdomain /トップドメイン/
topdown /トップダウン/
topic /トピック/
topics /トピックス/
toplevel /トップレベル/
topnote /トップノート/
topological /トポロジカル/
topology /トポロジー/
toppan /トッパン/
toppe /トッピー/
topping /トッピング/
toprank /トップランク/
topten /トップテン/
torerant /トレラント/
toronto /トロント大学/
torque /トルク/
torus /トーラス/
total /トータル/
totipotent /トティポテント/
touch /タッチ/
tough /タフ/
tour /ツアー/
touring /ツーリング/
tournament /トーナメント/
towel /タオル/
tower /タワー/
town /タウン/
towns /ＴＯＷＮＳ/
toyota /トヨタ/
tp /ＴＰ/
tpo /ＴＰＯ/
trace /トレース/トレイス/
tracer /トレーサ/
tracing /トレーシング/
track /トラック/
tracking /トラッキング/
traction /トラクション/
tractor /トラクタ/
trad /トラッド/
trade /トレード/
trade-off /トレードオフ/
trademark /トレードマーク/
tradeoff /トレードオフ/
trading /トレーディング/
traffic /トラフィック/トラヒック/
trainer /トレーナ/トレイナー/トレイナ/
training /トレーニング/
tramp /トランプ/
tranceiver /トランシーバ/
trancy /トランシー/
tranquilizer /トランキライザ/
trans /トランス/
transaction /トランザクション/
transactional /トランザクショナル/
transceiver /トランシーバー/トランシーバ/
transducer /トランスジューサ/
transfer /トランスファー/転送/
transistor /トランジスタ/
transit /トランジット/
translate /トランスレート/
translater /トランスレータ/
translation /トランスレーション/
translator /トランスレータ/
transmit /転送/
transparent /透過/トランスペアレント/
transport /トランスポート/
transputer /トランスピュータ/
transversal /トランスバーサル/
trap /トラップ/
trash /トラッシュ/
trasport /トランスポート/
travel /トラベル/トラヴェル/
traveler /トラベラー/
traverse /トラバース/
tray /トレー/トレイ/
tree /ツリー/
trend /トレンド/
trendo /トレンド/
trendy /トレンディー/
triad /トライアド/
trial /トライアル/
triangle /▲/△/トライアングル/▽/▼/
triathlete /トライアスリート/
trick /トリック/
tricky /トリッキー/
trie /トライ/
trigger /トリガー/トリガ/
trigraph /三連文字/
trim /トリム/
trimming /トリミング/
trinitron /トリニトロン/
trio /トリオ/
trip /トリップ/
tritech /トライテック/
trivial /トリビアル/
troff /ティーロフ/
tron /ＴＲＯＮ/トロン/
trondheim /トロンヘイム/
trouble /トラブル/
troubleshooting /トラブルシューティング/
troy /トロイ/
truck /トラック/
true /正/
truetype /ＴｒｕｅＴｙｐｅ/
truffaut /トリュフォー/
trump /トランプ/
trumpet /トランペット/
trumpoline /トランポリン/
trunk /トランク/
trunks /トランクス/
trust /トラスト/
truth /ＴＲＵＴＨ/
try /トライ/
try&error /トライ＆エラー/
ts /ＴＳ/
tshirts /Ｔシャツ/
tsp /時間引き延ばしパルス/ＴＳＰ/
tss /ＴＳＳ/
ttl /ＴＴＬ/
tuba /チューバ/
tube /チューブ/
tucker /タッカー/
tue /火/
tug /タグ/
tugjump /タグジャンプ/
tulip /チューリップ/
tuna /ツナ/
tune /チューン/
tuner /チューナー/チューナ/
tuning /チューニング/テューニング/
tunnel /トンネル/
tunneling /トネリング/トンネリング/
tuple /タプル/
tupple /タプル/
turbine /タービン/
turbo /ターボ/
turing /チューリング/テューリング/
turingmachine /チューリングマシン/
turingtest /チューリングテスト/
turk /トルコ/土耳古/
turkey /トルコ/
turn /ターン/
turnstile /├/┣/
turnstyle /├/┣/
tutor /チューター/チュータ/
tutorial /チュートリアル/
tuxedo /タキシード/
tv /テレビ/ＴＶ/
tvk /ＴＶＫ/
tvtokyo /テレビ東京/
tw /時間荷重/
tweed /ツイード/
twilight /トワイライト/
twin /ツイン/
twin-peaks /ツイン・ピークス/
twinbee /ツインビー/
twist /ツイスト/
twisted /ツイステッド/
twistpair /ツイストペア/
two /ツー/
tyo /ＴＹＯ/
typ /ＴＹＰ/
type /タイプ/型/
typesetter /タイプセッタ/
typewriter /タイプライタ/
typing /タイピング/
typo /タイポ/
typographer /タイポグラファ/
typography /タイポグラフィ/
u /Ｕ/μｍ/
ubiquitous /ユービキタス/
uc /ＵＣ/
ucb /ＵＣＢ/
ucla /ＵＣＬＡ/
ucsd /ＵＣＳＤ/
ufo /ＵＦＯ/
ui /ＵＩ/ユーザーインターフェース/ユーザインターフェース/
uif /ユーザ・インタフェース/
uk /ＵＫ/イギリス/
ultima /ウルティマ/
ultra /ウルトラ/
ultraman /ウルトラマン/
um /UNIX Magazine/
umount /アンマウント/
un /アン/
unbalance /アンバランス/
undead /アンデッド/
under /アンダー/
underflow /アンダーフロー/
underfull /アンダーフル/
underline /アンダーライン/
underscore /アンダースコア/
undine /ウンディーネ/
undo /アンドゥ/
unfair /アンフェア/
unformat /アンフォーマット/
unhappy /アンハッピー/
uni /ユニ/
unicorn /ユニコーン/
unifiable /ユニファイアブル/
unification /ユニフィケーション/
unifier /ユニファイア/
uniform /ユニフォーム/
unify /ユニファイ/単一化/
unimaga /ユニマガ/UNIX Magazine/
union /ユニオン/∪/共有体/共用体/
uniprocessor /ユニプロセッサ/
uniq /ユニーク/
unique /ユニーク/
unisol /ユニソル/
unison /ユニゾン/
unisys /ユニシス/
unit /ユニット/単位/
unitary /ユニタリ/
united /ユナイテッド/
universal /ユニバーサル/
unix /ＵＮＩＸ/UNIX/ユニックス/
unixfair /ＵＮＩＸフェアー/
unixmagazine /ＵＮＩＸマガジン/
unload /アンロード/
unlock /アンロック/
unmap /アンマップ/
unmount /アンマウント/
uno /ＵＮＯ/
unparse /アンパーズ/
unparser /アンパーザー/アンパーザ/
unrecognized /識別不能/
unrolling /アンローリング/
untied /アンタイド/
untouchable /アンタッチャブル/
up /アップ/↑/
uparrow /↑/
upcall /アップコール/
update /アップデート/アップデイト/
updater /アップデータ/
updown /アップダウン/
upgrade /アップグレード/
upic /ＵＰＩＣ/
uplight /アップライト/
uplink /アップリンク/
upload /アップロード/
upper /アッパー/
upsilon /υ/
upward /アップワード/
urban /アーバン/
urule /から/
us /ＵＳ/
usa /ＵＳＡ/
usc /ＵＳＣ大/
use /ユース/
usenet /ＵＳＥＮＥＴ/
usenix /ＵＳＥＮＩＸ/
user /ユーザ/ユーザー/USER/
userid /ユーザid/
userinterface /ユーザーインターフェース/ユーザインタフェース/
usermode /ユーザモード/
users /ユーザーズ/
usersguide /ユーザーズガイド/
usersmanual /ユーザーズマニュアル/
usr /ユーザ/ユーザー/
utility /ユーティリティ/ユーティリティー/
utnet /UTnet/
utopia /ユートピア/
uturn /Ｕターン/
uu /UNIX USER/
uucp /ＵＵＣＰ/ｕｕｃｐ/UUCP/
uunet /ＵＵＮＥＴ/
ux386 /ＵＸ３８６/
v /↓/Ｖ/
va /ビオラ/
vaccine /ワクチン/
vale /ヴェール/
valentine /バレンタイン/
valid /ヴァリッド/恒真/バリッド/
valken /ヴァルケン/
valley /バレー/
value /バリュー/Ｖａｌｕｅ/値/ヴァリュー/
valve /ヴァルヴ/バルブ/
valvu /バルブ/
vampire /バンパイヤ/
van /ＶＡＮ/
vanilla /バニラ/
vanvogt /ヴァン=ヴォークト/
vap /ＶＡＰ/
variable /ヴァリアブル/変数/
variation /バリエーション/
variety /ヴァラエティ/ヴァリエティ/バラエティ/
vax /ＶＡＸ/VAX/
vc /ビレッジセンター/チェロ/Ｖｃ/
vck /ＶＣＫ/
vdash /├/
vdots /：/
vdt /ＶＤＴ/
ve /ＶＥ/
vector /ベクトル/ベクタ/ベクター/
vectorchi /ベクトル値/
vee /∨/
vega /ベガ/
veil /ベール/
velocity /ヴェロシティ/
vender /ベンダー/ベンダ/
vendor /ベンダ/ベンダー/ヴェンダー/
vent /ベント/
ventri /ベンチュリ/
venture /ベンチャー/ベンチャ/
venus /ヴィーナス/
verbose /冗長な/
verify /ベリファイ/
versailles /ベルサイユ/ヴェルサイユ/
version /バージョン/版/ヴァージョン/
version-up /バージョンアップ/
versionup /バージョンアップ/ヴァージョンアップ/
vertical /垂直/垂直方向/
vest /ベスト/
veteran /ベテラン/ヴェテラン/
vga /ＶＧＡ/
vhll /VHLL(Very High Level Language)/
vhs /ＶＨＳ/
vi /ｖｉ/振動インテンシティ/
vib /ｖｉｂ/
vibrato /ビブラート/
victor /ビクター/
victoria /ビクトリア/
video /ビデオ/ヴィデオ/
videotape /ビデオテープ/
videotex /ビデオテックス/
vietnam /ベトナム/
vietnum /ベトナム/
view /ビュー/Ｖｉｅｗ/
viewer /ビューワ/ビューア/ビューアー/
viewpoint /ビューポイント/
viewport /ビューポート/
villa /ビラ/
vinyl /ビニール/
viola /ヴィオラ/
violence /バイオレンス/
violin /ヴァイオリン/
virgin /ヴァージン/
virtual /バーチャル/仮想/ヴァーチャル/
virus /ウィルス/ビールス/
visa /ビザ/
vision /ビジョン/視覚/ヴィジョン/
vista /ビスタ/
visual /ビジュアル/
visualization /ビジュアライゼーション/
visualize /ビジュアライズ/
vitality /ヴァイタリティ/バイタリティ/
vitamin /ビタミン/
vitamine /ビタミン/
vjebeta /VJE-β/
vliw /ＶＬＩＷ/
vlsi /ＶＬＳＩ/
vm /ＶＭ/
vme /ＶＭＥ/
vms /ＶＭＳ/
vn /ヴァイオリン/
vocabulary /ヴォキャブラリ/ヴォキャブラリィ/語彙/ボキャブラリ/
vocal /ヴォーカル/ボーカル/
vocalist /ヴォーカリスト/
vocoder /ボコーダ/
voice /ボイス/
voicing /ヴォイシング/
volkl /Ｖｏｌｋｌ/
volley /バレー/
volt /ボルト/
voltage /ボルテージ/
volume /ボリューム/ヴォリューム/
volunteer /ボランティア/
von /フォン/
vonnegut /ヴォネガット/
vop /ＶＯＰ/
vow /ＶＯＷ/
vr /バーチャルリアリティー/バーチャルリアリティ/仮想現実感/
vram /ＶＲＡＭ/
vs /ｖｓ．/
vsop /ＶＳＯＰ/
vt /ＶＴ/
vtr /ＶＴＲ/
vulnerability /ヴァルネラビリティ/
vulunteer /ボランティア/
wa-pro /ワープロ/
wacoal /ワコール/
wafer /ウェファ/ウエーハ/ウェーハ/
wagner /ワグナー/
wagon /ワゴン/
waikiki /ワイキキ/
wais /ウェイズ/
waist /ウェスト/
wait /ウェイト/ウエイト/
waiter /ウェイター/
waiting /ウェイティング/
waitress /ウェイトレス/
waiver /ウェーバー/
wakeup /ウェイクアップ/
walk /ウォーク/
walkman /ウォークマン/
wall /ウォール/
walsh /ウォルッシュ/
wan /ＷＡＮ/
wangel /ワンゲル/
wao /和田治/
ware /ウェア/Ｗａｒｅ/ウエア/
warning /ワーニング/ウォーニング/警告/
warp /ワープ/
wars /ウォーズ/
washington /ワシントン/
washingtondc /ワシントンＤＣ/
washlet /ワォシュレット/
watch /ウォッチ/
watchdog /ウォッチドッグ/
watching /ウォッチング/
water /ウォーター/
waterfall /ウォータフォール/
waterproof /ウォータープルーフ/
watson /ワトソン/
wave /ＷＡＶＥ/ウエーブ/ウェーブ/波/
wavefront /ウェーブフロント/
wavelet /ウェーブレット/
wax /ワックス/
way /ウェイ/ウエイ/
weakning /水増し/
wear /ウェア/
webster /ウェブスター/
wed /水/
wedding /ウェディング/
weddingdress /ウェディングドレス/
wedge /∧/
week /ウィーク/
weekday /ウィークデイ/
weekly /ウィークリー/
wegner /ウェグナー/ウェゲナー/
weight /ウェイト/
well-done /ウェルダン/
wellness /ウェルネス/
wenders /ヴェンダース/
west /ウエスト/
western /ウェスタン/
wet /ウェット/ウエット/
wg /ワーキンググループ/ＷＧ/
wheel /ホイール/
where /ただし/
while /ｗｈｉｌｅ/
whip /ホイップ/
whiskey /ウィスキー/ウヰスキー/
whisky /ウイスキー/ウィスキー/
whistle /ホイッスル/
white /ホワイト/
whiteboard /ホワイトボード/
whiteday /ホワイトデイ/
whitenoise /ホワイトノイズ/
whole /ホール/
wide /ワイド/ＷＩＤＥ/WIDE/
wideshow /ワイドショウ/
widget /ウィジェット/ウィジット/Widget/
width /幅/
wiener /ウィナー/
wild /ワイルド/
wildcard /ワイルドカード/
win /ＷＩＮ/
win3 /Ｗｉｎ３/
winch /ウィンチ/
wind /ウインド/
window /ウィンドウ/ウインドー/ウインドウ/
windowing /ウインドウィング/
windowmanager /ウィンドウマネージャ/
windows /ウインドウズ/Windows/
windowsystem /ウィンドウシステム/
wine /ワイン/
wineglass /ワイングラス/
wing /ウイング/
wings /ウィングス/
wink /Ｗｉｎｋ/ウインク/ウィンク/
winker /ウィンカー/
winning /ウィニング/
winter /Ｗｉｎｔｅｒ/ウィンター/
winterp /WINTERP(Widget Interpreter)/
wiper /ワイパー/
wire /ワイヤ/ワイヤー/
wired /ワイヤード/
wiredor /ワイヤードオア/
wireless /ワイヤレス/
wirewrapping /ワイヤラッピング/
wiring /ワイヤリング/
wishbone /ウィッシュボーン/
wit /ウィット/
witch /ウィッチ/
with /ウィズ/
wizard /ウィザード/
wizardry /ウィザードリィ/ウイザードリィ/
wm /ウィンドウマネージャー/
wnn /Ｗｎｎ/WNN/
wolf /ウルフ/
woman /ウーマン/
wonder /ワンダー/
wood /ウッド/
woodshole /ウッズホール/
woogie /ウギ/
wool /ウール/
word /ワード/ｗｏｒｄ/
word-processor /ワードプロセッサ/ワープロ/
work /ワーク/
workarea /ワークエリア/
workaround /ワークアラウンド/
workbench /ワークベンチ/
workbook /ワークブック/
worker /ワーカー/
workflow /ワークフロー/
working /ワーキング/
workinggroup /ワーキンググループ/
workingset /ワーキングセット/
workload /ワークロード/
works /ワークス/
worksheet /ワークシート/
workshop /ワークショップ/
workspace /ワークスペース/
workstation /ワークステーション/
world /ワールド/
worm /ワーム/
worpro /ワープロ/
worst /ワースト/
wowow /WOWOW/
wp /ワープロ/
wrap /ラップ/
wrapper /ウラッパー/ラッパー/
wrapping /ラッピング/
write /ライト/書き込み/
writeonly /ライトオンリー/
writer /ライター/ライタ/
writing /ライティング/
ws /ワークステーション/ＷＳ/WS/
x /Ｘ/ｘ/×/Ｘ−ウィンドウ/x-window/Ｘ端末/X端末/X Window System/X-Window/X/エックス/Xウィンドウ・システム/
x# /Ｘ#1/X#0/
x#r# /Ｘ#1Ｒ#1/
xc /XConsortium/
xe /ＸＥ/
xerography /ゼログラフィ/
xerox /ゼロックス/
xi /ξ/
xlib /Xlib/
xlisp /ＸＬｉｓｐ/XLisp/
xpost /クロスポスト/
xps /XPS(eXpansion Passing Style)/
xterminal /Ｘ端末/
xtp /ＸＴＰ/
xview /Ｘｖｉｅｗ/
xwindow /Ｘウィンドウ/
xx /××/
y /Ｙ/ｙ/
y# /#0円/
ya /←/→/
yacht /ヨット/
yajirushi /→/←/↑/↓/
yakult /ヤクルト/
yale /エール大学/
yamaha /ヤマハ/ＹＡＭＡＨＡ/
yank /ヤンク/
yapoo /ヤプー/
yard /ヤード/
yarder /ヤーダ/
yca /ＹＣＡ/
ydan /Ｙ談/
ydc /ＹＤＣ/
yellow /イェロー/イエロー/
yen /￥/円/
yes /イエス/ＹＥＳ/
yhp /ＹＨＰ/横河ヒューレット・パッカード/
yield /イールド/
ymo /ＹＭＯ/
yoga /ヨガ/
yogurt /ヨーグルト/
yoko /─/━/
you /ユー/
young /ヤング/
youth /ユース/
yp /ＹＰ/
yumin /ユーミン/
z /Ｚ/
zabadak /ザバダック/
zack /ザク/
zarathustra /ツァラトゥストラ/
zaurus /ザウルス/
zelda /ゼルダの伝説/
zemi /ゼミ/
zepher /ゼファー/
zephilus /ゼフィルス/蝶/
zephyr /ゼファー/
zero /ゼロ/〇/零/
zeta /ζ/
zh /←/
zienkiewicz /ツィエンキーヴィッツ/
ziggy /Ｚｉｇｇｙ/
zigsaw /ジグソーパズル/
zip /〒/
zj /↓/
zk /↑/
zl /→/
zombie /ゾンビ/
zone /ゾーン/ゾ―ン/
zoom /ズーム/
zoomin /ズームイン/
zoomout /ズームアウト/
{ /｛/
| /｜/‖/┃/
|- /├/┣/
|| /‖/
} /｝/
~ /〜/¬/￣/
ー /〜/
あ /阿/娃/亜/安/明/亞/哇/嗚/婀/椏/痾/襾/唖/
あーかいぶ /アーカイブ/
あーく /アーク/
あーす /アース/
あーち /アーチ/
あーちすと /アーチスト/
あーてぃすと /アーティスト/
あーびとれーしょん /アービトレーション/
ああ /嗚呼/噫/
あい /愛/相/哀/合/姶/挨/亜衣/藍/曖/隘/娃/会/饗/噫/埃/欸/瞹/穢/藹/阨/靉/
あいあいがさ /相合い傘/
あいあん /アイアン/
あいいく /愛育/
あいいそ /相磯/
あいいちろう /愛一郎/
あいいろ /藍色/
あいいん /愛飲/合印/
あいうら /相浦/
あいえん /愛煙/
あいえんか /愛煙家/
あいおい /相生/
あいか /哀歌/
あいかぎ /合鍵/
あいかた /合方/相方/
あいかわ /相川/愛川/合川/
あいかわらず /相変わらず/
あいかん /哀歓/
あいが /相賀/
あいがん /哀願/愛玩/
あいがんけん /愛玩犬/
あいがんどうぶつ /愛玩動物/
あいき /愛機/
あいきどう /合気道/
あいきゃく /相客/
あいきょう /愛敬/愛嬌/愛郷/
あいくち /匕首/
あいけん /愛犬/
あいこ /愛子/愛顧/アイ子/藍子/
あいこう /愛校/愛好/愛甲/
あいこういしだ /愛甲石田/
あいこうか /愛好家/
あいこうかい /愛好会/
あいこうしゃ /愛好者/
あいこうしん /愛校心/
あいこうだいめいでん /愛工大名電/
あいこうぼん /愛好本/
あいこく /愛国/
あいこくこうこう /愛国高校/
あいこくしん /愛国心/
あいことば /合言葉/
あいご /愛護/
あいごま /合い駒/合駒/
あいさい /愛妻/
あいさいか /愛妻家/
あいさいごう /愛妻号/
あいさつ /挨拶/
あいさつじょう /挨拶状/
あいさつまわり /挨拶回り/
あいさわ /相沢/
あいざわ /会沢/相沢/相澤/
あいしかた /愛し方/
あいしゃ /愛車/
あいしゃせいしん /愛社精神/
あいしゃだいずかん /愛車大図鑑/
あいしゅう /哀愁/
あいしょ /愛書/
あいしょう /相性/愛称/愛誦/愛唱/
あいしょうか /愛唱歌/
あいしょうきょく /愛唱曲/
あいしょうひょう /相性表/
あいしょうめい /愛称名/
あいしょか /愛書家/
あいしんかくら /愛新覺羅/
あいしんせいき /アイシン精機/
あいじ /愛児/
あいじょう /愛情/哀情/
あいじん /愛人/
あいす /アイス/
あいすくりーむ /アイスクリーム/
あいすみちょう /愛住町/
あいず /合図/会津/
あいずだい /会津大/
あいずだいがく /会津大学/
あいずばんだいさん /会津磐梯山/
あいずみ /藍住/
あいせき /相席/哀惜/愛惜/
あいせつ /哀切/
あいそ /愛想/相磯/相曽/愛相/
あいそう /愛想/
あいそわらい /愛想笑い/
あいぞう /愛憎/愛蔵/
あいぞうばん /愛蔵版/
あいたい /相対/
あいだ /間/藍田/相田/会田/合田/英田/愛田/
あいだい /愛大/
あいだいじょうほう /愛大情報/
あいだがら /間柄/
あいだじゅう /間中/
あいだちょう /英田町/
あいち /愛知/相知/
あいちいかだいがく /愛知医科大学/
あいちいだい /愛知医大/
あいちかんじょうてつどう /愛知環状鉄道/
あいちがくせんだい /愛知学泉大/
あいちがくせんだいがく /愛知学泉大学/
あいちきょういくだい /愛知教育大/
あいちきょういくだいがく /愛知教育大学/
あいちきんろうかいかん /愛知勤労会館/
あいちぎんこう /愛知銀行/
あいちけん /愛知県/
あいちけんおかざきし /愛知県岡崎市/
あいちけんけい /愛知県警/
あいちけんしゅっしん /愛知県出身/
あいちけんじん /愛知県人/
あいちけんとよかわし /愛知県豊川市/
あいちけんとよだし /愛知県豊田市/
あいちけんない /愛知県内/
あいちこうぎょうだいがく /愛知工業大学/
あいちこうじょう /愛知工場/
あいちこうせいねんきん /愛知厚生年金/
あいちこうだい /愛知工大/
あいちしゅっしん /愛知出身/
あいちべん /愛知弁/
あいちみと /愛知御津/
あいちゃく /愛着/合着/
あいちょう /愛聴/愛鳥/哀調/
あいちょうばん /愛聴盤/
あいつぎ /相次/
あいづ /会津/
あいづき /相築/
あいづたかだ /会津高田/
あいづたじま /会津田島/
あいづだい /会津大/
あいづだいがく /会津大学/
あいづち /相づち/相槌/
あいづてつどう /会津鉄道/
あいづてつどうせん /会津鉄道線/
あいづばんだいさん /会津磐梯山/
あいづま /逢妻/
あいづわかまつ /会津若松/
あいづわかまつし /会津若松市/
あいて /相手/
あいてかた /相手方/
あいてがた /相手方/
あいてがわ /相手側/
あいてがわきょうぎしゃ /相手側競技者/
あいてきぎょう /相手企業/
あいてきゅうだん /相手球団/
あいてきょく /相手局/
あいてぎんこう /相手銀行/
あいてこく /相手国/
あいてさき /相手先/
あいてしだい /相手次第/
あいてしゃりょう /相手車両/
あいてじんない /相手陣内/
あいてせいふ /相手政府/
あいてせんしゅ /相手選手/
あいてだしゃ /相手打者/
あいてとうしゅ /相手投手/
あいてやく /相手役/
あいてりきし /相手力士/
あいであ /アイデア/
あいでぃあ /アイディア/
あいでんてぃてぃー /アイデンティティー/
あいとう /哀悼/
あいどく /愛読/
あいどくしゃ /愛読者/
あいどくしゃしょう /愛読者賞/
あいどくしょ /愛読書/
あいどりんぐ /アイドリング/
あいどる /アイドル/
あいにく /生憎/
あいの /愛野/
あいのえき /愛野駅/
あいのちょう /愛野町/
あいのみなこ /愛野美奈子/
あいのり /相乗り/
あいはら /相原/合原/愛原/粟飯原/
あいはん /合判/相判/
あいば /饗場/相場/愛馬/相庭/相羽/
あいばじょうほう /愛馬情報/
あいばら /合原/相原/
あいびき /逢引/合挽/
あいふく /間服/合服/
あいぶ /愛撫/
あいべ /相部/
あいべつ /哀別/愛別/
あいべつりく /愛別離苦/
あいべや /相部屋/
あいぼ /愛慕/
あいぼう /相棒/
あいま /合間/合い間/
あいまい /曖昧/愛昧/
あいまいせい /曖昧性/
あいまいもこ /曖昧模糊/
あいまって /相俟って/
あいみ /亜衣実/愛美/
あいもと /相本/
あいやぐら /相矢倉/
あいやど /相宿/
あいやま /相山/
あいよう /愛用/
あいようき /愛用機/
あいようしゃ /愛用者/
あいよく /愛欲/
あいよし /相吉/
あいら /姶良;地名/吾平/
あいらく /哀楽/
あいりん /愛輪/
あいるらんど /愛蘭/
あいれん /哀憐/愛憐/
あいろ /隘路/
あいろん /アイロン/
あいわ /哀話/
あう /央/奥/桜/奧/媼/櫻/
あうすとろばいれやか /アウストロバイレヤ科/Austrobaileyaceae/
あうと /アウト/
あうとさいだー /アウトサイダー/
あうん /阿吽/呵吽/
あえ /阿江/
あえぎ /喘ぎ/
あえもの /和え物/
あえり /愛絵理/
あえん /亜鉛/
あお /青/蒼/碧/靜/
あおあお /青々/
あおい /葵/青井/碧/
あおいきといき /青息吐息/
あおいけ /青池/
あおいっしょく /青一色/
あおいめ /青い目/
あおいもく /アオイ目/Malvales/
あおいろ /青色/
あおえ /青江/
あおえきしょう /青液晶/
あおおに /青鬼/
あおがき /青垣/
あおがく /青学/青山学院大学/
あおがくだい /青学大/
あおがしま /青ヶ島/
あおき /青木/
あおきいさお /青木功/
あおきこ /青木湖/
あおきっぷ /青切符/
あおきばし /青木橋/
あおぎいろ /青黄色/
あおぎり /青桐/榮/
あおくさ /青草/
あおけいとう /青系統/
あおしか /青鹿/
あおしま /青島/青嶋/
あおしんごう /青信号/
あおしんごうがわ /青信号側/
あおじ /青地/
あおじゃしん /青写真/
あおぞら /青空/蒼空/
あおぞらかいがてん /青空絵画展/
あおぞらきょうしつ /青空教室/
あおぞらちゅうしゃ /青空駐車/
あおた /青田/
あおたがり /青田刈/
あおたけ /青竹/
あおたん /青丹/
あおだいしょう /青大将/
あおだま /青玉/
あおてんじょう /青天井/
あおでんわ /青電話/
あおと /青戸/青砥/
あおとつうか /青砥通過/
あおとていしゃ /青砥停車/
あおに /青二/
あおにさい /青二才/
あおぬま /青沼/
あおねぎ /青葱/
あおの /青野/
あおのはら /青野原/
あおのり /青海苔/
あおはた /青旗/
あおはたていじ /青旗提示/
あおば /青葉/
あおばかい /青葉会/
あおばきねんかいかん /青葉記念会館/
あおばく /青葉区/
あおばしょう /青葉賞/
あおばじょう /青葉城/
あおばじょうし /青葉城址/
あおばだい /青葉台/
あおばだいえき /青葉台駅/
あおばどおり /青葉通/
あおばばし /青葉橋/
あおばやま /青葉山/
あおばん /青版/青盤/
あおぼうず /青坊主/
あおみどり /青緑/
あおみどりけい /青緑系/
あおむし /青虫/
あおむらさき /青紫/
あおもと /青本/
あおもの /青物/
あおものよこちょうえき /青物横丁駅/
あおもり /青森/
あおもりいき /青森行/
あおもりうんてんじょ /青森運転所/
あおもりうんゆく /青森運輸区/
あおもりえき /青森駅/
あおもりけん /青森県/
あおもりけんあおもりし /青森県青森市/
あおもりけんじん /青森県人/
あおもりけんはちのへし /青森県八戸市/
あおもりし /青森市/
あおもりしゅっしん /青森出身/
あおもりはこだてかん /青森函館間/
あおもりはつ /青森発/
あおもん /青門/
あおや /青谷/
あおやき /青焼/
あおやぎ /青柳/
あおやま /青山/
あおやまいっちょうめ /青山一丁目/
あおやまえんけいげきじょう /青山円形劇場/
あおやまがくいん /青山学院/
あおやまがくいんだい /青山学院大/
あおやまがくいんだいがく /青山学院大学/
あおやません /青山線/
あおやまちょう /青山町/
あおやまほうめん /青山方面/
あおやまぼち /青山墓地/
あおんそく /亜音速/
あか /赤/垢/亜科/閼伽/絳/
あかあお /赤青/
あかあおみどり /赤青緑/
あかあか /赤々/明々/
あかい /赤井/
あかいがわ /赤井川/
あかいくつ /赤い靴/
あかいけ /赤池/
あかいけえき /赤池駅/
あかいし /赤石/
あかいしだけ /赤石岳/
あかいっしょく /赤一色/
あかいでんき /赤井電機/
あかいろ /赤色/
あかいわ /赤磐/赤岩/
あかいわえき /赤岩駅/
あかいわぐん /赤磐郡/
あかいわし /赤鰯/
あかうんと /アカウント/
あかえだ /赤枝/
あかお /赤尾/
あかおか /赤岡/
あかおすぎ /赤尾杉/
あかおに /赤鬼/
あかかげ /赤影/
あかがい /赤貝/
あかがね /銅/
あかがみ /赤紙/
あかがり /赤狩/
あかがわ /赤川/
あかきっぷ /赤切符/
あかぎ /赤城/赤木/
あかぎいろ /赤黄色/
あかぎこうげん /赤城高原/
あかぎちょう /赤城町/
あかぎやま /赤城山/
あかくら /赤倉/
あかくろ /赤黒/
あかぐみ /紅組/
あかけいとう /赤系統/
あかげ /赤毛/
あかご /赤子/
あかさか /赤坂/
あかさかえき /赤坂駅/
あかさかきんぺん /赤坂近辺/
あかさかほんしゃ /赤坂本社/
あかさかみつけ /赤坂見付/赤坂見附/
あかさかみつけえき /赤坂見附駅/
あかさかみつけてん /赤坂見附店/
あかさき /赤碕/赤崎/
あかざ /藜/
あかざか /アカザ科/
あかざき /赤崎/
あかざわ /赤沢/赤澤/
あかし /明石/証/赤司/證/絳し/灯/
あかしお /赤潮/
あかしかいきょう /明石海峡/
あかしかいきょうおおはし /明石海峡大橋/
あかしがわ /明石側/
あかしこう /明石港/
あかしし /明石市/
あかしな /明科/
あかしば /赤芝/
あかしや /明石家/
あかしやき /明石焼/
あかしろ /赤白/
あかしんごう /赤信号/
あかしんごうてまえ /赤信号手前/
あかしんぶんか /赤新聞化/
あかじ /赤字/
あかじかくご /赤字覚悟/
あかじく /赤字区/
あかじろせん /赤字路線/
あかすいしょう /赤水晶/
あかずきん /赤頭巾/
あかせがわ /赤瀬川/
あかせがわげんぺい /赤瀬川原平/
あかせん /赤線/
あかたにせん /赤谷線/
あかたん /赤丹/
あかだな /閼伽棚/
あかだま /赤玉/
あかちゃ /赤茶/
あかちゃいろ /赤茶色/
あかちゃん /赤ちゃん/
あかつか /赤塚/
あかつかふじお /赤塚不二夫/
あかつき /暁/曉/
あかつち /赤土/赭/
あかつつみ /赤堤/
あかてん /赤点/
あかでん /赤電/
あかでんわ /赤電話/
あかどう /赤胴/
あかどまり /赤泊/
あかな /赤名/
あかにんじゃ /赤忍者/
あかぬま /赤沼/
あかね /茜/朱子/
あかねか /アカネ科/Rubiaceae/
あかねもく /アカネ目/Rubiales/
あかはた /赤旗/旃/
あかはな /赤鼻/
あかはに /赤埴/
あかはね /赤羽/
あかばこ /赤箱/
あかばね /赤羽/赤羽根/
あかばねいわぶちちょう /赤羽岩淵町/
あかばねえき /赤羽駅/
あかばねせん /赤羽線/
あかばん /赤盤/
あかひら /赤平/
あかびょうし /赤表紙/
あかびら /赤平/
あかふく /赤福/
あかふくほんてん /赤福本店/
あかふだ /赤札/
あかほ /赤穂/
あかほり /赤堀/
あかほん /赤本/
あかぼう /赤帽/
あかぼし /赤星/
あかぼり /赤堀/
あかま /赤間/
あかまえき /赤間駅/
あかまつ /赤松/
あかまど /赤窓/
あかまる /赤丸/
あかまるきゅうじょうしょう /赤丸急上昇/
あかまるじょうしょうちゅう /赤丸上昇中/
あかみそ /赤味噌/赤みそ/
あかむし /赤虫/
あかむらさき /赤紫/
あかめ /赤目/
あかめぐち /赤目口/
あかもん /赤門/
あかゆ /赤湯/
あかり /灯/明かり/燈/灯り/明り/
あかるみ /明るみ/
あかん /阿寒/
あかんこ /阿寒湖/
あかんちょう /阿寒町/
あかんぼう /赤ん坊/
あがおか /阿賀岡/
あがつま /吾妻/我妻/
あがの /阿賀野/
あがのがわ /阿賀野川/
あがほ /英賀保/
あがり /上り/
あがりかた /上がり方/
あがりがまち /上がり框/
あがりた /揚田/
あがわ /吾川/阿川/
あき /秋/明/空/穐/章/昭/亜紀/晰/亜季/安芸/晶/晃/彰/亮/朗/亜樹/暁/顕/光/哲/彬/晄/晢/朖/璋/龝/空き/安岐/亜希/晶紀/
あきあじ /秋味/
あきいこう /秋以降/
あきう /秋保/
あきうみ /明生/
あきえ /秋絵/章江/晃枝/昭江/明恵/亜紀恵/秋江/
あきお /昭雄/明雄/章夫/晃夫/秋男/秋夫/秋雄/昭男/昭夫/明男/明夫/晶夫/暁生/彰夫/彬生/亜希夫/明央/
あきおか /秋岡/
あきおみ /明臣/
あきかず /彰一/
あきかぜ /秋風/
あきかわ /秋川/
あきかわけいこく /秋川渓谷/
あきかん /空き缶/空き罐/空缶/
あきがせ /秋ケ瀬/
あきがわ /秋川/
あきく /安芸区/
あきぐち /秋口/
あきぐん /安芸郡/
あきけいば /秋競馬/
あきこ /亜希子/明子/章子/晶子/顕子/晃子/亜紀子/亜樹子/朗子/彰子/昭子/暁子/朱子/亜季子/亜以子/
あきごう /秋号/
あきごろ /秋頃/
あきさと /穐里/
あきさめ /秋雨/
あきさわ /秋澤/
あきしの /秋篠/
あきしのでら /秋篠寺/
あきしののみや /秋篠宮/
あきしま /昭島/安芸島/
あきしまけいさつしょ /昭島警察署/
あきしまし /昭島市/
あきしょせん /秋初戦/
あきじかん /空時間/
あきすえ /秋末/
あきせき /空き席/
あきぞら /秋空/
あきた /秋田/飽田/
あきたいき /秋田行/
あきたえき /秋田駅/
あきたぎんこう /秋田銀行/
あきたけん /秋田県/
あきたこまち /秋田小町/
あきたし /秋田市/
あきたしやくしょ /秋田市役所/
あきたしょてん /秋田書店/
あきただい /秋田大/
あきただいがく /秋田大学/
あきたちく /秋田地区/
あきたに /秋谷/
あきたべん /秋田弁/
あきたゆき /秋田行/
あきだい /秋大/
あきち /空き地/空地/
あきつ /秋津/蜻蛉/安芸津/
あきつぐ /明二/
あきづき /秋月/
あきづきでんし /秋月電子/
あきと /彰人/
あきとし /秋利/明敏/彰俊/晃年/
あきとも /秋友/
あきな /明菜/
あきない /商い/
あきなが /秋永/
あきなぎ /秋奈祇/
あきなす /秋茄子/
あきなり /章成/
あきなる /秋成/
あきの /昭乃/秋野/
あきのり /明憲/彰則/明紀/晧則/昭則/晃紀/昭徳/明徳/昭憲/
あきは /秋葉/
あきはばら /秋葉原/
あきはばらえき /秋葉原駅/
あきはばらかかく /秋葉原価格/
あきはばらきんぺん /秋葉原近辺/
あきはばらしゅうへん /秋葉原周辺/
あきば /秋葉/秋場/秋庭/
あきばこ /空箱/
あきばれ /秋晴れ/
あきひこ /昭彦/明彦/彰彦/晶彦/暁彦/秋彦/祥彦/
あきひさ /顕尚/彰久/
あきひで /彰英/
あきひと /祥仁/昭仁/明仁/
あきひろ /昭博/晃広/明宏/昭弘/章博/昭浩/明弘/彰宏/彰広/章浩/暁宏/晃弘/昭宏/章裕/碩宏/哲裕/明浩/晃宏/章宏/明広/章弘/明裕/章広/
あきびより /秋日和/
あきびん /空瓶/
あきふく /秋服/
あきふみ /章文/明文/晶文/
あきふゆ /秋冬/
あきぶもん /空部門/
あきべや /空き部屋/空部屋/
あきほ /明穂/秋穂/秋保/
あきま /空き間/秋間/
あきまで /秋迄/
あきまる /秋丸/
あきみ /秋生/
あきみず /秋水/
あきみち /明倫/
あきみつ /章充/彬光/
あきむら /秋村/
あきもと /秋元/秋本/
あきもの /秋物/
あきものがたり /秋物語/
あきや /空き家/空家/
あきやす /彰康/
あきやま /秋山/
あきゅう /秋保/
あきゅうせい /亜急性/
あきゆき /昭如/
あきよ /晃代/明代/
あきようりょう /空容量/空き容量/
あきよし /明吉/秋吉/明良/昭義/彰芳/昭良/
あきよしくみこ /秋吉久美子/
あきよしだい /秋吉台/
あきら /明/晃/彰/朗/璋/章/輝/晶/旭/光/昭/陽/亮/暁/彬/啓/聡/昜/晄/曉/朖/洸/滉/顯/顕/晧/鑑/日明/亨/
あきらか /明か/曠/昿/明らか/
あきりすと /空きリスト/
あきりょういき /空領域/
あきんど /商人/
あぎ /亜木/阿木/
あぎと /顎/
あぎょう /ア行/
あく /悪/握/渥/阿久/空/堊/幄/惡/軛/齷/灰汁/
あくい /悪意/阿久井/
あくいんしょう /悪印象/
あくうかん /亜空間/
あくうかんひこう /亜空間飛行/
あくうん /悪運/
あくえいきょう /悪影響/
あくえき /悪疫/
あくえん /悪縁/
あくかんきょう /悪環境/
あくかんじょう /悪感情/
あくぎ /悪戯/
あくぎゃく /悪虐/
あくぎょう /悪業/悪行/
あくこうか /悪効果/
あくごう /悪業/
あくさい /悪妻/
あくざいりょう /悪材料/
あくしつ /悪質/
あくしつか /悪質化/
あくしつかめいてん /悪質加盟店/
あくしでんと /アクシデント/
あくしゃ /幄舎/
あくしゅ /握手/悪手/悪趣/
あくしゅう /悪習/悪臭/
あくしゅかい /握手会/
あくしゅけん /握手券/
あくしゅみ /悪趣味/
あくしょ /悪所/悪書/
あくしょついほう /悪書追放/
あくしょん /アクション/
あくしん /悪心/
あくじ /悪事/
あくじき /悪食/
あくじゅんかん /悪循環/
あくじょ /悪女/
あくじょうけん /悪条件/
あくじょうけんか /悪条件下/
あくせい /悪性/悪政/悪声/
あくせいしゅよう /悪性腫瘍/
あくせいど /悪性度/
あくせさり /アクセサリ/
あくせす /アクセス/
あくせぷと /アクセプト/
あくせる /アクセル/
あくせん /悪戦/悪銭/
あくせんくとう /悪戦苦闘/
あくせんと /アクセント/
あくぜい /悪税/
あくた /芥/
あくたい /悪態/
あくたがわ /芥川/
あくたがわしょうこうほ /芥川賞候補/
あくたがわやすし /芥川也寸志/
あくたがわりゅうのすけ /芥川龍之介/
あくだいかん /悪代官/
あくだま /悪玉/
あくちのいど /アクチノイド/
あくつ /阿久津/圷/
あくてん /悪天/
あくてんこう /悪天候/
あくてんこうじ /悪天候時/
あくとう /悪党/
あくとく /悪徳/
あくとくがくえん /悪徳学園/
あくとくだんたい /悪徳団体/
あくとくふどうさんや /悪徳不動産屋/
あくどい /悪どい/
あくどう /悪童/悪道/
あくにん /悪人/
あくね /阿久根/
あくねんぴ /悪燃費/
あくば /悪罵/
あくひつ /悪筆/
あくひょう /悪評/
あくひょうばん /悪評判/
あくび /欠伸/
あくびょう /悪病/
あくふう /悪風/
あくぶん /悪文/
あくへい /悪弊/
あくへき /悪癖/
あくほう /悪法/
あくま /悪魔/
あくまがったい /悪魔合体/
あくまごうせい /悪魔合成/
あくまじょう /悪魔城/
あくまてき /悪魔的/
あくみ /飽海/
あくみょう /悪名/
あくむ /悪夢/
あくめい /悪名/
あくもん /悪問/
あくやく /悪役/
あくゆう /悪友/阿久悠/
あくよう /悪用/
あくようかのう /悪用可能/
あくらつ /悪辣/
あくりょう /悪霊/
あくりょうたいさん /悪霊退散/
あくりょく /握力/
あくりる /アクリル/
あくれい /悪例/
あくろ /悪路/
あぐい /安食/阿久比/
あぐさ /阿草/
あぐに /粟国/
あぐら /胡座/趺坐/
あぐり /亜久里/
あぐん /亜群/
あけ /暁/朱/曉/明/明け/
あけお /暁生/
あけがた /明け方/
あけこ /朱子/
あけち /明智/
あけちこごろう /明智小五郎/
あけちたんてい /明智探偵/
あけちみつひで /明智光秀/
あけの /明野/
あけはま /明浜/
あけびか /アケビ科/Lardizabalaceae/
あけぼの /曙/
あけぼのばし /曙橋/
あけみ /明美/明海/朱実/朱美/暁美/明珠/
あげ /上/揚/安芸/
あげあし /揚げ足/揚足/挙げ足/挙足/上げ足/上足/
あげお /上尾/
あげおえき /上尾駅/
あげおし /上尾市/
あげく /挙句/挙げ句/上げ句/揚句/
あげくのはて /挙げ句の果て/
あげぞこ /上げ底/
あげだま /揚げ玉/
あげの /揚野/
あげはば /上げ幅/
あげはましきえんでん /揚浜式塩田/
あげば /揚場/揚げ場/
あげまき /総角/
あげもの /揚げ物/
あこ /亜古/亜子/
あこう /赤穂/亜綱/
あこうせん /赤穂線/
あこうせんけいゆう /赤穂線経由/
あこうそく /亜光速/
あこうそくうちゅうせん /亜光速宇宙船/
あこうそくか /亜光速下/
あこぎ /阿漕/
あこそ /阿古曾/
あこめ /衵/袙/
あご /顎/阿児/
あごかんせつ /顎関節/
あごかんせつしょう /顎関節症/
あごかんせつだっきゅう /顎関節脱臼/
あごしゅうへん /顎周辺/
あごひげ /鬚/
あごひも /顎紐/
あさ /朝/浅/麻/阿佐/安佐/淺/厚狭/
あさい /浅井/淺井/朝井/
あさいち /朝一/朝市/
あさいちばん /朝一番/
あさいと /麻糸/麻絲/
あさえだ /浅枝/朝枝/
あさお /麻生/浅尾/朝雄/
あさおか /麻丘/浅丘/朝岡/朝丘/
あさか /浅香/朝霞/安積/朝加/
あさかぎじゅつかいはつ /朝霞技術開発/
あさかぜ /朝風/
あさかわ /浅川/
あさが /浅賀/朝賀/
あさがえり /朝帰り/
あさがお /朝顔/蕣/
あさがけ /朝駆/
あさがた /朝方/朝型/
あさがみ /麻上/
あさがや /阿佐谷/阿佐ヶ谷/阿佐々谷/
あさき /麻木/
あさきた /安佐北/
あさきたく /安佐北区/
あさぎ /浅葱/
あさぎり /朝霧/
あさぎりこうげん /朝霧高原/
あさくさ /浅草/
あさくさいき /浅草行/
あさくさえき /浅草駅/
あさくさこうかいどう /浅草公会堂/
あさくさしんげきじょう /浅草新劇場/
あさくさせん /浅草線/
あさくさばし /浅草橋/
あさくさばしえき /浅草橋駅/
あさくさほうめん /浅草方面/
あさくさゆき /浅草行/
あさくち /浅口/
あさくら /浅倉/朝倉/麻倉/
あさくらえき /朝倉駅/
あさくらしょてん /朝倉書店/
あさげ /朝餉/
あさこ /浅子/亜抄子/麻子/朝子/あさ子/
あさご /朝来/
あさごはん /朝ごはん/
あさざけ /朝酒/
あさしお /朝潮/
あさしな /浅科/
あさしろ /麻城/
あさじ /朝地/浅茅/
あさじえ /浅知恵/
あさせ /浅瀬/
あさせん /阿佐線/
あさだ /浅田/阿佐田/麻田/朝田/
あさだあきら /浅田彰/
あさだあめ /浅田飴/
あさだみよこ /浅田美代子/
あさぢえ /浅知恵/
あさって /明後日/
あさづけ /浅漬/
あさてい /朝定/
あさと /麻人/
あさとうちゃくぶん /朝到着分/
あさどら /朝ドラ/
あさぬま /浅沼/
あさね /朝寝/
あさねぼう /朝寝坊/
あさの /浅野/
あさのぶ /朝信/
あさはか /浅はか/
あさはら /浅原/麻原/
あさば /浅羽/
あさばん /朝晩/
あさひ /朝日/旭/アサヒ/朝陽/
あさひかせい /旭化成/
あさひかせいこうぎょう /旭化成工業/
あさひかせいじょうほう /旭化成情報/
あさひかわ /旭川/
あさひかわえき /旭川駅/
あさひかわけいばじょう /旭川競馬場/
あさひかわし /旭川市/
あさひかわせん /旭川線/
あさひかわふきん /旭川付近/
あさひがおか /旭ヶ丘/旭ケ丘/旭が丘/朝日々丘/
あさひがらす /旭硝子/
あさひがわ /旭川/
あさひく /旭区/
あさひけい /朝日系/
あさひけいれつ /朝日系列/
あさひこうよう /朝日航洋/
あさひしゅっぱんしゃ /朝日出版社/
あさひしんぶん /朝日新聞/
あさひしんぶんけい /朝日新聞系/
あさひしんぶんしゃ /朝日新聞社/
あさひしんぶんちょうかん /朝日新聞朝刊/
あさひしんぶんゆうかん /朝日新聞夕刊/
あさひせいめい /朝日生命/
あさひせんしょ /朝日選書/
あさひそのらま /朝日ソノラマ/
あさひだい /旭台/
あさひだけ /旭岳/
あさひちょう /朝日町/
あさひちょうかん /朝日朝刊/
あさひつうしんしゃ /旭通信社/
あさひな /朝比奈/朝日奈/
あさひなたかし /朝比奈隆/
あさひはい /朝日杯/
あさひびーる /アサヒビール/朝日麦酒/
あさひぶんこ /朝日文庫/
あさひほうそう /朝日放送/
あさひまち /旭町/
あさひむら /朝日村/
あさひや /旭屋/
あさひやしょてん /旭屋書店/
あさひゆうかん /朝日夕刊/
あさひる /朝昼/
あさひるばん /朝昼晩/
あさびん /朝便/
あさふく /浅福/
あさぶ /麻生/麻布/
あさぶき /麻吹/
あさほうそう /朝放送/
あさま /浅間/
あさました /浅間下/
あさまじんじゃ /浅間神社/
あさまつ /朝松/
あさまやま /浅間山/
あさみ /あさ美/浅見/麻美/朝美/麻見/亜左美/亜沙美/
あさみぞ /麻溝/
あさみなみ /安佐南/
あさみなみく /安佐南区/
あさみや /麻宮/
あさむし /浅虫/
あさめし /朝飯/朝メシ/
あさめしまえ /朝飯前/
あさもや /朝靄/
あさやけ /朝焼け/
あさやま /浅山/
あさゆ /朝湯/
あさゆう /朝夕/
あさり /鯏/浅利/浅蜊/蜊/朝里/
あされん /朝練/
あざ /字/痣/
あざい /浅井/
あざな /字/
あざぶ /麻布/
あざぶじゅうばん /麻布十番/
あざぶだい /麻布台/
あざみ /薊/
あざやか /鮮か/
あざわらい /嘲笑い/
あし /足/芦/葦/蹇/脚/蘆/跫/蹙/躄/
あしあと /足跡/
あしいろ /足色/
あしうら /足裏/
あしお /足尾/
あしおえき /足尾駅/
あしおざん /足尾山/
あしおせん /足尾線/
あしおと /足音/脚音/跫/
あしおり /足折/
あしかが /足利/
あしかがけ /足利家/
あしかがけいば /足利競馬/
あしかがこうぎょうだいがく /足利工業大学/
あしかがこうこう /足利高校/
あしかがし /足利氏/
あしかけ /足掛け/足掛/
あしかせ /足枷/桎/鐐/
あしかり /芦刈/
あしかわ /芦川/
あしがかり /足掛かり/足掛り/
あしがた /足型/
あしがため /足固め/
あしがら /足柄/
あしがらえき /足柄駅/
あしがらかみ /足柄上/
あしがらしも /足柄下/
あしがらとうげ /足柄峠/
あしがる /足軽/
あしがわ /芦川/
あしきた /葦北/芦北/
あしきょう /芦響/
あしくび /足首/
あしくびねんざ /足首捻挫/
あしくびふきん /足首付近/
あしげ /芦毛/足蹴/
あしこし /足腰/脚腰/
あしさき /足先/
あしざわ /芦沢/芦澤/
あしすたんと /アシスタント/
あしずり /足摺/
あしずりみさき /足摺岬/
あしそこ /足底/
あしぞこばん /足底板/
あした /明日/朝/
あしたか /愛鷹/
あしだ /芦田/
あしだい /足代/
あしつき /足付/
あしづけ /足付/
あしとり /足取り/
あしどめ /足止め/足止/
あしどり /足取り/足鳥/
あしな /芦品/芦名/足名/
あしなが /足長/
あしなみ /足並/足並み/
あしはら /芦原/蘆原/
あしはらちゅう /芦原中/
あしはらちゅうがっこう /芦原中学校/
あしば /足場/
あしばや /足早/
あしひっさつわざ /足必殺技/
あしび /馬酔木/
あしびょうし /足拍子/
あしぶみ /足踏み/足踏/
あしべ /芦部/芦辺/
あしべつ /芦別/
あしまえ /足前/
あしめ /走目/
あしもと /足元/足下/脚元/足許/
あしもり /足守/
あしや /芦屋/芦谷/
あしやがわ /芦屋川/
あしやがわえき /芦屋川駅/
あしやがんのすけ /芦屋雁之助/
あしやし /芦屋市/
あしやす /芦安/
あしゅ /亜種/
あしゅら /阿修羅/
あしゅらぞう /阿修羅像/
あしゆび /足指/趾/
あしょうさん /亜硝酸/
あしょうさんえんのうど /亜硝酸塩濃度/
あしょうさんのうど /亜硝酸濃度/
あしょろ /足寄/
あしろ /安代/
あしわざ /足技/
あしわだ /足和田/
あじ /味/鯵/鰺/庵治/
あじあ /亜細亜/亞細亞/
あじあだい /亜細亜大/
あじおう /味皇/
あじおか /味岡/
あじおんち /味音痴/
あじか /簣/
あじから /味方/
あじがさわ /鯵ヶ沢/
あじがわ /安治川/
あじき /味気/
あじきこう /味紀行/
あじけ /味気/
あじさい /紫陽花/
あじさか /鯵坂/
あじじまん /味自慢/
あじす /阿知須/
あじつけ /味付け/味付/
あじとみ /安次富/
あじな /芦品/阿品/
あじのもと /味の素/
あじふめい /味不明/
あじみ /味見/
あじみよう /味見用/
あじむ /安心院/
あじゃり /阿闍梨/
あじろ /網代/安代/
あす /明日/
あすいこう /明日以降/
あすか /飛鳥/明日香/
あすかい /飛鳥井/
あすかいちょう /飛鳥井町/
あすかじ /飛鳥路/
あすけ /足助/
あすじゅう /明日中/
あすたりすく /アスタリスク/
あすぢゅう /明日中/
あすぱらがす /アスパラガス/
あすら /阿修羅/
あすわ /足羽/
あずかりきん /預かり金/
あずかりしょ /預かり所/
あずかりしょう /預かり証/
あずき /小豆/
あずけきん /預け金/
あずさ /梓/
あずさがわ /梓川/
あずち /安土/堋/
あずま /東/吾妻/吾嬬/
あずません /吾妻線/
あずまばし /吾妻橋/
あずまふじ /東富士/
あずまや /阿亭/四阿/東屋/
あずみ /安曇/安住/杏美/
あずみぐん /安曇郡/
あずみの /安曇野/
あせ /汗/(concat "(^^\073\073")/阿瀬/(concat "(^^\073")/
あせっ /(concat "(^^\073)")/(concat "(^_^\073)")/(concat "^_^\073")/
あせみず /汗水/
あせり /焦り/
あぜ /畦/畔/
あぜりあ /アゼリア/
あぜん /唖然/
あそ /阿曽/阿蘇/安蘇/
あそう /麻生/
あそうがわ /麻生川/
あそうぎ /阿僧祇/
あそさん /阿蘇山/
あそしぇいつ /アソシェイツ/
あそしえーしょん /アソシエーション/
あそはつ /阿蘇発/
あそび /遊び/
あそびごころ /遊び心/
あそびにん /遊人/遊び人/
あそびば /遊び場/
あそびめ /遊び女/遊女/
あたい /値/価/價/値い/
あたいていぎ /値定義/
あたいひょう /値表/
あたいよび /値呼び/
あたえかた /与え方/
あたか /宛/恰/
あたかも /宛/
あたがわ /熱川/
あたく /安宅/
あたご /愛宕/
あたごばし /愛宕橋/
あたっく /アタック/
あたっちめんと /アタッチメント/
あたま /頭/アタマ/
あたまいがい /頭以外/
あたまかず /頭数/
あたまがわ /頭側/
あたまきん /頭金/
あたまだし /頭出し/
あたまわり /頭割り/
あたみ /熱海/
あたみえき /熱海駅/
あたみかん /熱海間/
あたらし /新子/
あたり /辺/当り/辺り/邊/邉/当たり/
あたりまえ /当たり前/
あたりやく /当役/
あたる /鼎/中/
あだ /仇/徒/讎/讐/
あだい /亜大/
あだうち /仇討ち/仇討/
あだしの /化野/
あだたら /安達太良/
あだたらこうげん /安達良高原/
あだたらやま /阿達太良山/
あだち /足立/安達/足達/
あだちく /足立区/
あだっきゅう /亜脱臼/
あだな /仇名/綽名/渾名/
あだばな /徒花/
あち /閼/阿智/窪地/
あちわ /阿知波/
あっか /悪化/悪貨/
あっかい /圧潰/
あっかく /圧覚/
あっかん /悪漢/圧巻/
あっかんたんてい /悪漢探偵/
あっかんども /悪漢共/
あっき /悪鬼/
あっきらせつ /悪鬼羅刹/
あっけ /呆気/
あっけし /厚岸/
あっこう /悪口/
あっこうぞうごん /悪口雑言/
あっさく /圧搾/
あっさつ /圧殺/
あっさぶ /厚沢部/
あっし /圧死/
あっしゅく /圧縮/
あっしゅくがす /圧縮ガス/
あっしゅくがわ /圧縮側/
あっしゅくき /圧縮機/
あっしゅくきのう /圧縮機能/
あっしゅくぎじゅつ /圧縮技術/
あっしゅくくうき /圧縮空気/
あっしゅくけい /圧縮系/
あっしゅくけいしき /圧縮形式/
あっしゅくこうりつ /圧縮効率/
あっしゅくご /圧縮後/
あっしゅくちゃっかきかん /圧縮着火機関/
あっしゅくちゃっかしき /圧縮着火式/
あっしゅくど /圧縮度/
あっしゅくはいれつ /圧縮配列/
あっしゅくばん /圧縮版/
あっしゅくひ /圧縮比/
あっしゅくひょうき /圧縮表記/
あっしゅくほう /圧縮法/
あっしゅくほうしき /圧縮方式/
あっしゅくほうほう /圧縮方法/
あっしゅくまえ /圧縮前/
あっしゅくよう /圧縮用/
あっしゅくりつ /圧縮率/
あっしょう /圧勝/
あっせい /圧政/圧制/
あっせつ /圧雪/圧接/
あっせつしゃ /圧雪車/
あっせつじょうたい /圧雪状態/
あっせん /斡旋/
あっそう /圧送/
あっちゃく /圧着/
あっちゃくぶ /圧着部/
あっつう /圧痛/
あっと /＠/
あっとう /圧倒/圧到/
あっとうてき /圧倒的/圧到的/
あっとうてきたすう /圧倒的多数/
あっとうてきたすうは /圧倒的多数派/
あっとうてきゆうり /圧倒的有利/
あっとこ /厚床/
あっぱい /圧排/
あっぱく /圧迫/
あっぱくかん /圧迫感/
あっぱれ /天晴/天晴れ/遖/
あっぴ /安比/
あっぴこうげん /安比高原/
あっぷ /アップ/
あっぷく /圧服/
あっぷでーと /アップデート/
あっぷる /アップル/
あつ /圧/斡/厚/篤/敦/暑/惇/熱/淳/壓/乢/軋/遏/閼/
あつあつ /熱々/
あついた /圧板/
あつえん /圧延/
あつお /淳夫/敦夫/厚雄/敦男/
あつかい /扱い/
あつかいかた /扱い方/
あつかいさき /扱先/
あつかいだか /扱い高/
あつかいてん /扱店/
あつかいりょう /扱い量/
あつかん /熱燗/
あつがま /厚釜/
あつがましき /厚釜式/
あつがみ /厚紙/
あつぎ /厚木/厚着/
あつぎいえん /厚木以遠/
あつぎえいぎょうしょ /厚木営業所/
あつぎえき /厚木駅/
あつぎえんそうかい /厚木演奏会/
あつぎかん /厚木間/
あつぎきち /厚木基地/
あつぎけいゆう /厚木経由/
あつぎし /厚木市/
あつぎしざいじゅう /厚木市在住/
あつぎしつまだ /厚木市妻田/
あつぎしない /厚木市内/
あつぎしゅうへん /厚木周辺/
あつぎないろん /厚木ナイロン/
あつぎほうめん /厚木方面/
あつぎり /厚切り/
あつけし /厚岸/
あつげしょう /厚化粧/
あつこ /温子/あつ子/敦子/厚子/淳子/篤子/亜都子/惇子/
あつさ /暑さ/厚さ/
あつし /篤志/敦/厚志/淳/充史/篤/厚/敦史/篤史/敦司/敦志/篤司/淳史/陸/
あつしば /厚芝/
あつじ /厚地/
あつた /厚田/熱田/
あつたか /篤孝/
あつたじんぐう /熱田神宮/
あつつぐ /淳嗣/
あつで /厚手/
あつでん /圧電/
あつでんざい /圧電材/
あつでんたい /圧電体/
あつにゅう /圧入/
あつぬり /厚塗/
あつのぶ /篤信/
あつひこ /淳彦/篤彦/敦彦/
あつひと /厚人/
あつひろ /厚宏/淳裕/敦弘/
あつへいこお /圧平衡/
あつま /厚真/
あつまり /集まり/集り/
あつみ /渥美/淳美/厚味/厚見/温海/厚み/
あつみちょう /渥美町/
あつみはんとう /渥美半島/
あつめ /厚目/
あつもの /羹/
あつもり /敦盛/
あつや /篤哉/
あつゆき /篤幸/淳之/敦之/
あつりょく /圧力/壓力/
あつりょくいじょう /圧力以上/
あつりょくか /圧力下/
あつりょくがま /圧力釜/
あつりょくけい /圧力計/
あつりょくこうどう /圧力行動/
あつりょくこうばい /圧力勾配/
あつりょくさ /圧力差/
あつりょくだんたい /圧力団体/
あつりょくなべ /圧力鍋/
あつりょくは /圧力波/
あつれき /軋轢/
あつろう /淳良/
あづかりきん /預かり金/
あづち /安土/
あづちじょう /安土城/
あづま /我妻/吾妻/東/
あづません /吾妻線/
あづまばし /吾妻橋/
あづまや /東谷/
あて /宛/
あてさき /宛先/宛て先/
あてさきじゅん /宛先順/
あてさきにん /宛先人/
あてさきふめい /宛先不明/
あてさきめい /宛先名/
あてじ /宛字/あて字/
あてつ /阿哲/
あてな /宛名/宛て名/
あてないんじ /宛名印字/
あてね /雅典/
あてはつ /宛発/
あてみ /当て身/
あてらざわ /左沢/
あで /艶/
あと /後/跡/痕/蹟/踪/
あとあし /後足/
あとあじ /後味/
あとあと /後々/
あといっこ /後一個/
あといっぽ /後一歩/
あとう /阿東/
あとうだ /阿刀田/
あとおい /後追/
あとおし /後押し/
あとかいぎ /後会議/
あとかた /跡形/跡かた/
あとかたづけ /後かたづけ/後片付/
あとかわ /後川/
あとがき /後書/
あとがま /後釜/
あときん /後金/
あとくされ /後腐れ/
あとくち /後口/
あとこうてい /後工程/
あとさき /後先/
あとざん /後産/
あとしまつ /後始末/
あとしょり /後処理/
あとすうねん /後数年/
あとち /跡地/
あとつぎ /跡継ぎ/
あとのり /後ノリ/
あとばらい /後払い/
あとばんぐみ /後番組/
あとべ /跡部/
あとまわし /後回し/
あとみ /跡見/
あとみがくえん /跡見学園/
あとみや /後宮/
あともどり /後戻り/
あとやく /後厄/
あとりえ /アトリエ/
あど /亜土/
あどがわ /安曇川/安雲川/
あどばいす /アドバイス/
あどほっく /アドホック/
あどみん /アドミン/
あどれす /アドレス/
あどれなりん /アドレナリン/
あな /穴/坑/孔/
あない /穴井/
あなうま /穴馬/
あなうめ /穴埋め/
あなうんさ /アナウンサ/
あなうんさー /アナウンサー/
あなうんす /アナウンス/
あながち /強ち/
あながわ /穴川/
あなぐま /穴熊/
あなぐら /穴蔵/
あなご /穴子/
あなし /阿梨/
あなた /貴方/貴女/
あなたじしん /貴方自身/
あなたたち /貴方達/
あなだ /穴田/
あなとう /穴党/
あなにんき /穴人気/
あなば /穴場/穴馬/
あなぶき /穴吹/
あなほり /穴掘り/
あなみず /穴水/
あなやま /穴山/
あなよそう /穴予想/
あなろぐ /アナログ/
あなろじー /アナロジー/
あなん /阿南/
あに /兄/豈/阿仁/
あにうえ /兄上/
あにき /兄貴/
あにでし /兄弟子/
あにめ /アニメ/
あにめーしょん /アニメーション/
あにや /安仁屋/
あによめ /兄嫁/嫂/
あね /姉/姐/
あねがさき /姉ヶ崎/
あねき /姉貴/
あねご /姐御/姉御/
あねさき /姉崎/
あねざき /姉崎/
あねったい /亜熱帯/
あのう /安濃/穴太/
あのくたら /阿耨多羅/
あのくたらさんみゃくさんぼだい /阿耨多羅三藐三菩提/
あのこ /あの娘/
あはなち /畔放/
あば /阿波/
あばしり /網走/
あばしりえき /網走駅/
あばしりこ /網走湖/
あばら /肋/
あばらぼね /肋骨/
あばれんぼう /暴れん坊/
あぱーと /アパート/
あぱれる /アパレル/
あひかけ /足腰/
あひる /家鴨/鶩/阿比留/
あび /阿鼻/
あびーむ /アビーム/
あびきょうかん /阿鼻叫喚/
あびこ /我孫子/安彦/
あびこし /我孫子市/
あびせたおし /浴びせ倒し/
あびる /阿比留/
あびるもじ /阿比留文字/
あぴーる /アピール/
あぴお /アピオ/
あふ /凹/押/
あふりか /阿弗利加/
あふりかぞう /アフリカ象/
あぶ /虻/阿武/
あぶくま /阿武隈/
あぶくまがわていぼう /阿武隈川堤防/
あぶくまきゅうこう /阿武隈急行/
あぶすとらくしょん /アブストラクション/
あぶすとらくと /アブストラクト/
あぶた /虻田/
あぶみ /鐙/
あぶら /油/脂/
あぶらあげ /油揚/
あぶらあせ /油汗/
あぶらえ /油絵/
あぶらかわ /油川/
あぶらげ /油揚/
あぶらぜみ /油蝉/
あぶらつぼ /油壷/
あぶらな /薹/
あぶらなか /アブラナ科/
あぶらひ /油日/
あぶらぶん /油分/
あぶらみ /脂身/油身/
あぶらむし /蜚/
あぶらもと /油本;姓/
あぶらや /油屋/
あぷりけーしょん /アプリケーション/
あぷろーち /アプローチ/
あへん /阿片/
あべ /阿部/安部/安倍/阿倍/阿武/
あべかわ /安倍川/
あべがくいん /安部学院/
あべた /安部田/
あべっく /アベック/
あべの /阿倍野/阿部野/
あべのく /阿倍野区/
あべれーじ /アベレージ/
あほ /阿呆/アホ/
あほう /阿呆/阿房/
あほうどり /信天翁/
あほうれっしゃ /阿房列車/
あぼ /安保/英保/
あぼう /安房/
あぼうとうげ /安房峠/
あぼがど /アボガド/
あぼし /網干/
あま /甘/天/尼/雨/海人/亜麻/海女/塰/蜑/海士/
あまあし /雨足/
あまいけ /天池/雨池/
あまいた /天板/
あまいろ /亜麻色/
あまえ /甘え/
あまえび /甘えび/甘エビ/甘海老/
あまお /雨尾/
あまおと /雨音/
あまかす /甘粕/
あまかぜ /雨風/
あまがい /天海/雨海/
あまがえる /雨蛙/
あまがさ /雨がさ/雨ガサ/雨傘/
あまがさき /尼崎/
あまがさきかいがんせん /尼崎海岸線/
あまがさきかん /尼崎間/
あまがさきし /尼崎市/
あまがさばんぐみ /雨傘番組/
あまがせ /天ケ瀬/天瀬/
あまき /天木/
あまぎ /天城/甘木/亜麻木/
あまぎせん /甘木線/
あまぎとうげ /天城峠/
あまぎゆがしま /天城湯ヶ島/
あまぎゆがしまちょう /天城湯ヶ島町/
あまくさ /天草/
あまくさしろう /天草四郎/
あまくだり /天下り/
あまくち /甘口/
あまくぼ /天久保/
あまぐ /雨具/
あまぐも /雨雲/
あまぐり /甘栗/
あまこ /尼子/
あまごい /雨乞い/
あまさ /甘さ/
あまざけ /甘酒/
あまし /蔗/
あまず /甘酢/
あまた /天田/数多/
あまだ /天田/
あまだい /甘鯛/
あまだれ /雨だれ/
あまち /天地/天池/
あまちまり /天地真理/
あまちゅあ /アマチュア/
あまつ /天津/
あまつかぜ /天津風/
あまつかみ /天津神/
あまつくに /天津国/
あまつじ /天辻/
あまつつみ /天津罪/
あまつぶ /雨粒/
あまづ /天津/
あまてらすおおみかみ /天照大神/
あまでら /尼寺/
あまとう /甘党/
あまど /雨戸/
あまどり /天鳥/
あまどりのみこと /天鳥命/
あまなっとう /甘納豆/
あまなつ /甘夏/
あまぬま /天沼/
あまね /周/
あまの /天野/雨野/
あまのいわと /天の磐戸/
あまのがわ /天の河/
あまのじゃく /天邪鬼/天の邪鬼/
あまのはしだて /天の橋立/天橋立/
あまべ /海部/
あまみ /奄美/甘味/
あまみおおしま /奄美大島/
あまみおおしません /奄美大島線/
あまみぐんとうく /奄美群島区/
あまみず /雨水/
あまみちほう /奄美地方/
あまみはっちゃく /奄美発着/
あまみや /雨宮/天宮/
あまもと /天本/
あまもよい /雨催/
あまもり /雨漏り/雨漏/雨森/
あまやどり /雨宿り/
あまり /甘利/余り/
あまるべ /餘部/余部/
あまるめ /余目/
あまんざ /甘座/
あみ /網/亜美/阿見/网/罔/
あみあぶら /網油/
あみうち /網打ち/
あみえ /網江/
あみかけ /網かけ/網掛/網掛け/
あみかんり /網管理/
あみき /編み機/
あみこ /安見子/
あみしま /網島/
あみじょう /網状/
あみせいぎょ /網制御/
あみせつぞく /網接続/
あみたいつ /網タイツ/
あみだ /阿弥陀/
あみだな /網棚/
あみだぶつ /阿弥陀仏/
あみちょう /阿見町/
あみど /網戸/
あみなか /網中/
あみの /網野/
あみのさん /アミノ酸/
あみのめ /網の目/
あみはま /網浜/
あみはり /網張/
あみぼし /網干/
あみめ /網目/編目/
あみもの /編物/
あみや /網屋/
あみやき /網焼/
あみわたり /網渡/
あむろ /安室/
あめ /雨/飴/天/
あめあがり /雨上がり/
あめあられ /雨霰/
あめいろ /飴色/
あめおとこ /雨男/
あめおんな /雨女/
あめかぜ /雨風/
あめたいさく /雨対策/
あめだま /飴玉/
あめつち /天地/
あめつゆ /雨露/
あめのもり /雨森/
あめふり /雨ふり/雨降り/
あめふりょうばば /雨不良馬場/
あめみや /雨宮/
あめもよう /雨模様/
あめよこ /アメ横/
あめよほう /雨予報/
あめりか /アメリカ/亜米利加/亞米利加/米/
あめりかがっしゅうこく /アメリカ合衆国/
あめりかじん /アメリカ人/
あめりかん /アメリカン/
あめりしうむ /アメリシウム/
あもい /廈門/厦門/
あもく /亜目/
あもん /亜門/
あや /文/綾/絢/彩/礼/亜也/彪/禮/亜矢/亜弥/
あやうた /綾歌/
あやか /綾香/彩香/
あやかみ /綾上/
あやがみ /綾上/
あやぎく /綾菊/
あやぎぬ /綺/
あやこ /亜矢子/彩子/綾子/亜也子/絢子/亜弥子/文子/章子/操子/
あやし /愛子/
あやしろ /綾城/
あやせ /綾瀬/綾世/
あやせえいぎょうしょ /綾瀬営業所/
あやせえき /綾瀬駅/
あやせがわ /綾瀬川/
あやせし /綾瀬市/
あやせししょうこうかい /綾瀬市商工会/
あやせぶんかかいかん /綾瀬文化会舘/
あやせま /綾瀬間/
あやせゆき /綾瀬行/
あやつか /綾塚/
あやつじ /綾辻/
あやつり /操/
あやつりにんぎょう /操人形/
あやとも /文友/
あやね /綾音/
あやの /綾乃/綾野/
あやのこうじ /綾小路/
あやのみや /礼宮/
あやはな /彩花/
あやふみ /礼史/
あやべ /綾部/
あやべししゅっしん /綾部市出身/
あやま /阿山/
あやまち /過ち/誤ち/
あやまり /誤り/
あやまりりつ /誤り率/
あやむら /文村/
あやめ /文目/
あやめいけ /あやめ池/
あやめか /アヤメ科/
あやめもく /アヤメ目/Iridales/
あやめもくあぐん /アヤメ目亜群/
あゆ /鮎/阿諛/
あゆかわ /鮎川/
あゆこ /亜佑子/
あゆさわ /鮎澤/
あゆざわ /鮎澤/
あゆついじゅう /阿諛追従/
あゆつり /鮎釣り/
あゆづり /鮎釣り/
あゆみ /彩友美/亜由美/歩み/歩/歩美/亜弓/アユミ/
あゆむ /渉/
あら /荒/新/
あらい /荒井/新居/新井/
あらいけん /荒井研/
あらいじゅく /新井宿/
あらいそ /荒磯/
あらいだし /洗い出し/
あらいど /荒井戸/
あらいまち /新居町/
あらいもの /洗い物/
あらいわ /荒岩/
あらお /荒尾/荒生/
あらかじめ /予め/予/豫/豫め/
あらかね /鉱;未精錬の金属/粗金;未精錬の金属/
あらかると /アラカルト/
あらかわ /荒川/
あらかわおき /荒川沖/
あらかわおきえき /荒川沖駅/
あらかわく /荒川区/
あらかわしゃこまえ /荒川車庫前/
あらかわせん /荒川線/
あらかわだけ /荒川岳/
あらかわほうすいろ /荒川放水路/
あらがき /新垣/荒書き/
あらがね /鉱;未精錬の金属/粗金;未精錬の金属/荒金;地名(茨城県)、姓/
あらき /荒木/
あらきの /新木野/
あらきゆみこ /荒木由美子/
あらくれ /荒くれ/
あらけ /有明/
あらこ /荒子/
あらごと /荒事/
あらごなし /荒ごなし/
あらさき /荒崎/
あらさわ /荒澤/荒沢/
あらし /嵐/
あらしがおか /嵐ヶ丘/
あらしね /荒稲/
あらしやま /嵐山/
あらしやましぜんこうえん /嵐山自然公園/
あらしやまはくぶつかん /嵐山博物館/
あらしやまびじゅつかん /嵐山美術館/
あらしやまふきん /嵐山付近/
あらすじ /粗筋/
あらず /韭/齏/韲/韮/
あらぜき /荒関/
あらそい /争い/
あらた /新/新た/新田/
あらたけ /荒武/
あらたに /荒谷/新たに/
あらたま /新田間/
あらたまがわ /新田間川/
あらて /新手/
あらなみ /荒波/
あらの /荒野/
あらはた /荒畑/
あらはま /荒浜/
あらひとがみ /現人神/
あらびあ /亞剌比亞/
あらびあせきゆ /アラビア石油/
あらびき /粗引き/
あらふか /荒深/
あらふね /荒船/
あらまき /荒巻/荒牧/新巻/
あらまさ /新政/
あらまた /荒俣/
あらまち /荒町/
あらまつ /荒松/
あらむしゃ /荒武者/
あらめ /荒目/
あらもと /荒本/
あらものや /荒物屋/
あらや /新屋/新谷/
あらゆる /凡/
あらり /粗利/
あらりえき /粗利益/
あらりょうじ /荒療治/
あらりょうち /荒療治/
あられ /霰/
あらわ /現/表/
あらわざ /荒技/荒業/
あらわしかた /表し方/
あらん /亜蘭/亜欄/
あり /有/蟻/阿梨/衽/袵/
ありあけ /有明/
ありあけかい /有明海/
ありあけころしあむ /有明コロシアム/
ありあけせん /有明線/
ありあけちく /有明地区/
ありあけばし /有明橋/
ありあわせ /有り合わせ/
ありえ /有家/
ありか /亜里香/在処/
ありかた /あり方/有り方/
ありかべ /有壁/
ありかわ /有川/
ありが /有賀/有我/
ありがたみ /ありがた味/有難味/
ありがとう /有り難う/有難う/
ありき /有木/
ありくい /食蟻獣/
ありくら /有倉/
ありさ /亜里沙/アリサ/亜理佐/亜利沙/
ありさか /有坂/
ありさま /有様/有り様/
ありさわ /有澤/有沢/
ありざ /有座/
ありしゃかい /蟻社会/
ありじごく /蟻地獄/
ありす /有栖/
ありすがわ /有栖川/
ありた /有田/
ありたてつどう /有田鉄道/
ありたま /有玉/
ありだ /有田/
ありつぎ /有次/
ありつね /有恒/
ありづか /蟻塚/
ありてい /有体/有態/
ありとう /有藤/
ありとも /有朋/
ありなが /有永/
ありのとうぐさもく /アリノトウグサ目/Haloragales/
ありのとうぐさもくぐん /アリノトウグサ目群/
ありはた /有畠/
ありはら /有原/
ありま /有馬/
ありまおんせん /有馬温泉/
ありまきねん /有馬記念/
ありまぐち /有馬口/
ありまさ /有正/
ありみ /有里巳/
ありみつ /有光/
ありむら /有村/
ありむらさんぎょう /有村産業/
ありもと /有本/
ありもり /有森/
ありや /有家/
ありやま /有山/
ありゅう /亜流/
ありゅうさん /亜硫酸/
ありゅうさんえんるい /亜硫酸塩類/
ありよし /有吉/
ある /或/亜留/
あるいは /或は/
あるかり /アルカリ/
あるかりせい /アルカリ性/
あるが /有賀/
あるきかた /歩き方/
あるこーる /アルコール/
あるごん /アルゴン/
あるしゅ /或る種/
あるじ /主/
あるぜんちん /亞爾然丁/
あるたみらどうくつ /アルタミラ洞窟/
あるばいと /アルバイト/
あるばむ /アルバム/
あるふぁ /α/
あるふぁせん /α線/
あるふぁは /α波/
あるふぁべっと /アルファベット/
あるふぃー /アルフィー/
あるぷすでんき /アルプス電気/
あるぺん /アルペン/
あるまいと /アルマイト/
あるみ /アルミ/
あるみにうむ /アルミニウム/
あれ /アレ/
あれち /荒地/荒れ地/
あれるぎ /アレルギ/
あれんじ /アレンジ/
あわ /泡/粟/阿波/安房/慌/
あわいけだ /阿波池田/
あわこうぞう /泡構造/
あわさ /粟佐/
あわさか /泡坂/
あわじ /淡路/
あわじしま /淡路島/
あわじちょう /淡路町/
あわじちょうえき /淡路町駅/
あわず /粟津/
あわせ /袷/
あわせいれつ /泡整列/
あわせわざ /合わせ技/
あわた /粟田/
あわたてき /泡立て器/
あわだち /泡立/
あわだてき /泡立て器/
あわつ /粟津/
あわづ /粟津/
あわづはら /粟津原/
あわの /阿波野/粟野/
あわばこ /泡箱/
あわび /鮑/蚫/鰒/アワビ/
あわもり /泡盛/
あわや /淡谷/粟屋/粟谷/
あわゆき /淡雪/
あわら /芦原/
あわれむ /恤れむ/
あん /案/暗/安/鞍/闇/杏/庵/按/行/罨/晏/菴/諳/閼/餡/鮟/黯/
あんい /安易/
あんいつ /安逸/安佚/
あんうつ /暗鬱/
あんうん /暗雲/
あんえい /暗影/
あんか /安価/行火/
あんかせい /安価性/
あんかん /暗槓/安閑/
あんがい /案外/
あんがいかんたん /案外簡単/
あんがいとくてん /案外得点/
あんがいようい /案外容易/
あんき /暗記/暗鬼/
あんきかもく /暗記科目/
あんきほう /暗記法/
あんきも /アンキモ/
あんきょ /安居/暗渠/
あんきりょく /暗記力/
あんぎゃ /行脚/
あんぐう /行宮/
あんけーと /アンケート/
あんけん /案件/
あんこ /暗刻/
あんこーる /アンコール/
あんこう /鮟鱇/安康/鮟/鱇/
あんこうなべ /鮟鱇鍋/
あんこく /暗黒/
あんこくがい /暗黒街/
あんこくくうかん /暗黒空間/
あんこくげいじゅつ /暗黒芸術/
あんこくじ /安国寺/
あんこくせいうん /暗黒星雲/
あんこくちたい /暗黒地帯/
あんこくめん /暗黒面/
あんご /安吾/
あんごう /暗号/暗合/
あんごうか /暗号化/
あんごうさくひん /暗号作品/
あんごうちょう /暗号帳/
あんごうひょう /暗号表/
あんごうぶん /暗号文/
あんさつ /暗殺/
あんさつけいかく /暗殺計画/
あんさつしゃ /暗殺者/
あんさつしれい /暗殺指令/
あんさつめいれい /暗殺命令/
あんざい /安西/安斎/安斉/安在/安齊/安齋/
あんざん /安産/暗算/
あんざんがん /安山岩/
あんし /暗視/晏子;春秋時代の斉の宰相/
あんしつ /暗室/
あんしゅつ /案出/
あんしょう /暗証/暗礁/暗唱/暗誦/諳誦/
あんしょうか /暗証化/
あんしょうばんごう /暗証番号/暗唱番号/
あんしょうぶ /暗証部/
あんしん /安心/
あんしんかん /安心感/
あんしんど /安心度/
あんしんりつめい /安心立命/
あんしんりょう /安心料/
あんじ /暗示/
あんじてき /暗示的/
あんじてきいんよう /暗示的引用/
あんじゅ /杏樹/
あんじゅう /安住/
あんじょう /安城/安生/鞍上/
あんじょうきょうか /鞍上強化/
あんじょうふあん /鞍上不安/
あんじんりゅうみょう /安心立命/
あんじんりょうみょう /安心立命/
あんず /杏/杏子/
あんせい /安静/安政/
あんせいじ /安静時/
あんせきしょく /暗赤色/
あんぜん /安全/暗然/
あんぜんいき /安全域/
あんぜんうんてん /安全運転/
あんぜんえいせい /安全衛生/
あんぜんかくじつ /安全確実/
あんぜんかくにん /安全確認/
あんぜんかくほ /安全確保/
あんぜんかんり /安全管理/
あんぜんかんりきょうかい /安全管理協会/
あんぜんがわ /安全側/
あんぜんがわせん /安全側線/
あんぜんがわひょうか /安全側評価/
あんぜんき /安全器/
あんぜんきじゅん /安全基準/
あんぜんきょういく /安全教育/
あんぜんきょり /安全距離/
あんぜんく /安全区/
あんぜんぐつ /安全靴/
あんぜんけん /安全研/
あんぜんけんきゅうしょ /安全研究所/
あんぜんげんかいそくど /安全限界速度/
あんぜんこうしゅう /安全講習/
あんぜんこうしゅうかい /安全講習会/
あんぜんさく /安全策/
あんぜんしゃかんきょり /安全車間距離/
あんぜんじょう /安全上/
あんぜんせい /安全性/
あんぜんせいかくほ /安全性確保/
あんぜんせつび /安全設備/
あんぜんそうこう /安全走行/
あんぜんそうち /安全装置/
あんぜんたいさく /安全対策/
あんぜんたいさくきじゅん /安全対策基準/
あんぜんだいいち /安全第一/
あんぜんちたい /安全地帯/
あんぜんていし /安全停止/
あんぜんとう /安全燈/
あんぜんぱい /安全牌/
あんぜんひょうか /安全評価/
あんぜんび /安全日/
あんぜんべん /安全弁/
あんぜんほあんきじゅん /安全保安基準/
あんぜんほしょう /安全保障/
あんぜんめん /安全面/
あんぜんよう /安全用/
あんぜんりつ /安全率/
あんそうおん /暗騒音/
あんそく /安息/
あんそくこうさん /安息香酸/
あんそくび /安息日/
あんたい /安泰/
あんたく /安宅/
あんたん /暗澹/
あんだ /安打/
あんだー /アンダー/
あんだすう /安打数/
あんち /安置/庵地/安地/
あんちゃく /安着/
あんちゅう /暗中/闇中/
あんちゅうもさく /暗中模索/
あんちょく /安直/
あんちょくか /安直過/
あんちん /安珍/
あんてい /安定/
あんていか /安定化/
あんていかでんげん /安定化電源/
あんていかどう /安定稼働/
あんていかん /安定感/
あんていかんばつぐん /安定感抜群/
あんていき /安定期/
あんていきょうきゅう /安定供給/
あんていきょうきゅうさき /安定供給先/
あんていきょうしんき /安定共振器/
あんていこうぞう /安定構造/
あんていざい /安定剤/
あんていじょうたい /安定状態/
あんていじょうたいべくとる /安定状態ベクトル/
あんていせい /安定性/
あんていせいじゅうし /安定性重視/
あんていせいじょうけん /安定性条件/
あんていせいそう /安定成層/
あんていせいりろん /安定性理論/
あんていてき /安定的/
あんていてん /安定点/
あんていど /安定度/
あんていどうさ /安定動作/
あんていひこう /安定飛行/
あんてな /アンテナ/
あんてん /鞍点/暗転/
あんてんほう /鞍点法/
あんでんりゅう /暗電流/
あんとう /安東/暗闘/
あんとく /安徳/
あんど /安堵/
あんどう /安藤/安東/
あんどうでんき /安藤電気/
あんどかん /安堵感/
あんどく /暗読/
あんどん /行灯/行燈/闇鈍/
あんな /アンナ/杏奈/
あんない /案内/
あんないかんばん /案内看板/
あんないがかり /案内係/
あんないきじ /案内記事/
あんないしゃ /案内者/
あんないしょ /案内書/
あんないじどうそうふ /案内自動送付/
あんないじょ /案内所/
あんないじょう /案内状/
あんないず /案内図/
あんないそうち /案内装置/
あんないちず /案内地図/
あんないどうこう /案内同行/
あんないにん /案内人/
あんないばん /案内板/
あんないひょうしき /案内標識/
あんないひょうじ /案内表示/
あんないぶん /案内文/
あんないぶんしょ /案内文書/
あんないほうそう /案内放送/
あんないよう /案内用/
あんなか /安中/
あんなかかん /安中間/
あんに /暗に/
あんにん /杏仁/
あんにんどうふ /杏仁豆腐/
あんねい /安寧/
あんねん /安念/
あんの /庵野/安野/
あんのじょう /案の定/
あんのん /安穏/
あんばい /按排/案配/塩梅/
あんばらんす /アンバランス/
あんぱち /安八/
あんひつ /安謐/
あんぴ /安否/
あんぶ /鞍部/暗部/
あんぶん /按分/案文/案分/
あんぷ /暗譜/
あんぺあ /アンペア/
あんぼれらか /アンボレラ科/Amborellaceae/
あんぽ /安保/
あんぽう /罨法/
あんぽたいせい /安保体制/
あんぽもんだい /安保問題/
あんぽり /安保理/
あんぽりけつぎ /安保理決議/
あんぽりじかい /安保理事会/
あんま /按摩/
あんまく /暗幕/
あんみん /安眠/
あんもく /暗黙/
あんもくてき /暗黙的/
あんもち /餡餅/
あんもにあ /アンモニア/
あんや /暗夜/
あんやく /暗躍/
あんゆ /暗喩/
あんらく /安楽/
あんらくいす /安楽椅子/
あんらくし /安楽死/
あんらくしがた /安楽死型/
あんり /杏里/
あんろくざん /安禄山/
い /位/井/意/彙/異/胃/為/偉/遺/医/違/衣/伊/亥/謂/移/居/唯/萎/委/如/維/囲/易/以/椅/畏/慰/猪/緯/依/惟/威/尉/夷/ゐ/偽/鋳/韋/五/射/倚/僞/噫/囗/圍/姨/已/帷/幃/彝/彜/怡/恚/懿/洟/渭/熨/爲/痍/痿/矣/肄/苡/詒/貽/逶/醫/鑄/頤/饐/鰄/忌/猗/矮/蔚/堰/莞/詑/胆/斐/鮪/揖/李/
い> /異/
い? /異/
いーすと /ＥＡＳＴ/
いあ /依阿/
いあい /居合/
いあく /帷幄/
いあくじょうそう /帷幄上奏/
いあつ /威圧/威壓/
いあつかん /威圧感/
いあつてき /威圧的/
いあん /慰安/
いあんかい /慰安会/
いあんじょ /慰安所/
いあんじょせつりつ /慰安所設立/
いあんふ /慰安婦/
いあんふちょうよう /慰安婦徴用/
いあんりょこう /慰安旅行/
いい /飯/猪/伊井/謂/井伊/依依/依倚/依違/猪井/
いいあい /言い合い/
いいあらそい /言い争い/
いいうり /言売/
いいおか /飯岡/
いいかげん /いい加減/
いいかた /言い方/
いいくら /飯倉/
いいくらかたまち /飯倉片町/
いいぐさ /言い草/
いいさか /飯坂/
いいざか /飯坂/
いいざかおんせん /飯坂温泉/
いいざわ /飯沢/
いいし /飯石/
いいじま /飯島/飯嶋/
いいずか /飯塚/
いいたか /飯高/
いいたがわ /飯田川/
いいたて /飯館/
いいだ /飯田/
いいだか /飯高/
いいだし /飯田市/
いいだしっぺ /言い出しっぺ/
いいだせん /飯田線/
いいだばし /飯田橋/
いいだばしえき /飯田橋駅/
いいだばしほうめん /飯田橋方面/
いいつたえ /言い伝え/
いいづか /飯塚/
いいづかし /飯塚市/
いいづかしかわつ /飯塚市川津/
いいづな /飯綱/
いいで /飯豊/
いいなが /稲永/
いいなずけ /許嫁/
いいなん /飯南/
いいぬま /飯沼/
いいね /言い値/
いいの /飯野/
いいはま /飯浜/
いいはん /一翻/
いいぶん /言い分/
いいぼし /飯干/
いいま /飯間/
いいまわし /言い回し/
いいむら /飯村/
いいもり /飯森/飯盛/
いいやま /飯山/
いいやまでんき /飯山電機/
いいわけ /言い訳/言訳/
いいわけむよう /言訳無用/
いいん /委員/医院/
いいんかい /委員会/
いいんかいあん /委員会案/
いいんかいいにん /委員会委任/
いいんかいかんり /委員会管理/
いいんかいぎちょう /委員会議長/
いいんかいけいゆ /委員会経由/
いいんかいこうにん /委員会公認/
いいんかいさくせい /委員会作成/
いいんかいせい /委員会制/
いいんかいせいいこう /委員会制移行/
いいんかいせいど /委員会制度/
いいんかいせいりつご /委員会成立後/
いいんかいせつりつ /委員会設立/
いいんかいぜんたい /委員会全体/
いいんかいそしき /委員会組織/
いいんかいたいせい /委員会体制/
いいんかいないぶ /委員会内部/
いいんかいほうしき /委員会方式/
いいんじたい /委員自体/
いいんぜんたい /委員全体/
いいんちょう /委員長/
いいんちょうあて /委員長宛/
いいんどうし /委員同士/
いうち /井内/
いうら /井浦/
いぇん /￥/円/
いえ /家/彌/伊江/
いえい /遺影/
いえいえ /家々/
いえいがい /家以外/
いえがた /家型/
いえがら /家柄/
いえき /胃液/
いえしま /家島/
いえじ /家路/
いえじゅう /家中/
いえだ /家田/
いえつき /家付/
いえで /家出/
いえでしょうじょ /家出少女/
いえども /雖/
いえなが /家永/
いえなみ /家並み/
いえふきん /家付近/
いえみつ /家光/
いえもち /家茂/
いえもと /家元/
いえやす /家康/
いえやま /家山/
いえらいしゃん /夜来香/
いえろー /イエロー/
いえん /胃炎/以遠/
いえんくかん /以遠区間/
いえんけん /以遠権/
いおう /硫黄/
いおうしゅう /硫黄臭/
いおうじま /伊王島/硫黄島/
いおか /井岡/
いおち /庵地/
いおの /魚野/
いおり /伊織/庵/菴/
いおん /イオン/異音/
いおんか /イオン化/
いか /以下/医科/如何/≦/異化/烏賊/伊香/位下/イカ/
いかい /位階/異界/猪飼/伊貝/
いかいよう /胃潰瘍/胃かいよう/
いかいんよう /以下引用/
いかが /如何/
いかがく /医科学/
いかく /威嚇/居角/威赫/
いかけ /鋳掛/
いかけん /医科研/
いかさんしょう /以下参照/
いかざき /五十崎/
いかしか /医科歯科/
いかしょうりゃく /以下省略/
いかずち /霆/霹/雷/
いかた /伊方/
いかだ /筏/
いかだい /筏井/
いかだいがく /医科大学/
いかづち /雷/
いかてん /イカ天/
いかどうぶん /以下同文/
いかどうよう /以下同様/
いかないよう /以下内容/
いかなご /玉筋魚/
いかなる /如何なる/
いかの /以下の/
いかひ /異花被/
いかひか /異花被花/
いかほ /伊香保/
いかほおんせん /伊香保温泉/
いかほんぶん /以下本文/
いかむけ /医家向け/
いかよう /如何様/
いからし /五十嵐/
いかり /怒り/錨/碇/怒/
いかりがせき /碇ヶ関/
いかりど /錨戸/
いかりゃく /以下略/
いかる /鵤/
いかるが /斑鳩/
いかわ /井川/井河/居川/
いかわだに /伊川谷/
いかん /移管/如何/遺憾/偉観/衣冠/医官/
いかんそく /維管束/
いかんそくたい /衣冠束帯/
いが /伊賀/
いがい /以外/意外/遺骸/
いがいせい /意外性/
いがうえ /伊賀上/
いがく /医学/医学部/
いがくおんきょう /医学音響/
いがくか /医学科/
いがくかい /医学界/
いがくかんけい /医学関係/
いがくかんけいしゃ /医学関係者/
いがくかんれん /医学関連/
いがくけい /医学系/
いがくけんきゅう /医学研究/
いがくけんきゅうか /医学研究科/
いがくけんきゅうしゃ /医学研究者/
いがくげんてい /医学限定/
いがくざっし /医学雑誌/
いがくしゃ /医学者/
いがくしょ /医学書/
いがくしょいん /医学書院/
いがくしょいんしゅっぱん /医学書院出版/
いがくじしょ /医学辞書/
いがくじっけんちゅう /医学実験中/
いがくじっしゅうよう /医学実習用/
いがくじてん /医学事典/
いがくじょう /医学上/
いがくせい /医学生/
いがくせいぶつがくじょう /医学生物学上/
いがくせいぶつけい /医学生物系/
いがくそうだん /医学相談/
いがくたちば /医学立場/
いがくてき /医学的/
いがくてきけんきゅう /医学的研究/
いがくてきこうさつ /医学的考察/
いがくてきじょうほう /医学的情報/
いがくてきちしき /医学的知識/
いがくてきもんだい /医学的問題/
いがくはかせ /医学博士/
いがくはくし /医学博士/
いがくぶ /医学部/
いがくぶせい /医学部生/
いがくもくてき /医学目的/
いがくようご /医学用語/
いがぐり /毬栗/
いがぐりあたま /毬栗頭/
いがこうべ /伊賀神戸/
いがさてつどう /井笠鉄道/
いがしら /井頭/
いがせん /伊賀線/
いがた /鋳型/井形/范/鎔/
いがっか /医学科/
いがみ /井上/
いがや /井ヶ谷/
いがらぎけんかつたし /茨城県勝田市/
いがらし /五十嵐/
いがり /猪狩/
いがわ /井川/居川/
いがん /依願/胃癌/
いがんたいしょく /依願退職/
いき /息/域/意気/粋/囲気/閾/遺棄/生/壱岐/委棄/粹/行き/行/
いきあたりばったり /行き当たりばったり/
いきいき /生き生き/イキイキ/
いきうま /生き馬/
いきうめ /生き埋め/
いきえ /生き餌/
いきおい /勢い/
いきかた /生き方/行き方/
いきかん /異機間/
いきがい /生きがい/域外/生き甲斐/
いきがみ /生き神/
いきき /行き来/往き来/一箕/
いきぎも /生き肝/
いきぎれ /息切れ/
いきごみ /意気ごみ/
いきさき /行き先/行先/
いきさきあんない /行先案内/
いきさきせっていき /行先設定機/
いきさきひょうじ /行先表示/
いきさつ /経緯/
いきさわ /生澤/
いきざま /生き様/
いきしゅ /異機種/
いきしゅかん /異機種間/
いきしょうちん /意気消沈/
いきじごく /生き地獄/
いきじびき /生き字引/
いきす /伊岐須/
いきそそう /意気沮喪/
いきち /閾値/域値/生血/生き血/
いきちがい /行き違い/
いきちしょり /閾値処理/
いきつき /生月/
いきつぎ /息継ぎ/
いきづかい /息遣い/
いきとうごう /意気投合/
いきどまり /行き止まり/
いきな /生名/
いきない /域内/
いきぬき /息抜き/息抜/
いきのこり /生き残り/
いきのね /息の根/
いきはじ /生き恥/
いきぼとけ /生き仏/
いきもの /生き物/生物/
いきょ /依拠/
いきょう /異境/異教/異郷/井京/
いきょうと /異教徒/
いきょく /医局/異曲/
いきようよう /意気揚々/
いきりょう /生霊/生き霊/
いぎ /意義/異議/威儀/異義/猪木/
いぎあり /異議有り/
いぎご /異義語/
いぎす /伊岐須/
いぎょう /偉業/異形/遺業/医業/
いぎょうしゅ /異業種/
いぎりす /イギリス/英吉利/
いく /郁/育/幾/毓/燠/礇/鬻/粥/
いくいっぷめんと /イクイップメント/
いくいな /生稲/
いくうかん /異空間/
いくえ /郁恵/育江/幾重/
いくえい /育英/
いくえいかい /育英会/
いくえいしょうがくきん /育英奨学金/
いくお /郁雄/育男/幾雄/郁夫/幾夫/郁生/
いくこ /郁子/以玖子/育子/郁久子/幾久子/
いくさ /戦/戰/
いくさか /生坂/
いくさち /生幸/
いくしま /生島/
いくしゅ /育種/
いくしゅがく /育種学/
いくしゅるい /幾種類/
いくじ /育児/意気地/
いくじきゅうか /育児休暇/
いくじきゅうしょくせいど /育児求職制度/
いくじけいけん /育児経験/
いくじけいけんしゃ /育児経験者/
いくじさんぎょう /育児産業/
いくじしょ /育児書/育児所/
いくじせいど /育児制度/
いくじひ /育児費/
いくじぶんたん /育児分担/
いくすじ /幾筋/
いくせい /育成/
いくせいしゃ /育成者/
いくせいしょ /育成所/
いくせいじぎょう /育成事業/
いくせいそう /幾星霜/
いくせいぶ /育成部/
いくせいぼくじょう /育成牧場/
いくせん /幾千/
いくせんまん /幾千万/
いくそう /幾層/
いくぞう /幾三/郁三/
いくた /生田/幾多/
いくたがわ /生田川/
いくたさい /生田祭/
いくたはら /生田原/
いくたび /幾度/
いくつ /幾つ/
いくつか /幾つか/
いくつき /幾月/
いくとしつき /幾年月/
いくど /幾度/
いくどうおん /異口同音/
いくにち /幾日/
いくにん /幾人/
いくねん /幾年/
いくの /生野/
いくのとうげ /生野峠/
いくはら /幾原/
いくばく /幾許/幾何/
いくひと /生人/
いくひろ /郁博/
いくぶん /幾分/いく分/
いくま /伊玖磨/
いくまん /幾万/
いくみ /育巳/
いくもうざい /育毛剤/
いくや /育也/郁哉/
いくゆう /育友/
いくゆうかい /育友会/
いくゆうかいかつどう /育友会活動/
いくよ /育代/郁代/
いくら /幾ら/居倉/伊倉/
いくりん /育林/
いくん /遺訓/
いぐ /伊具/
いぐさ /伊草/井草/
いぐさもく /イグサ目/Juncales/
いぐすり /胃薬/
いぐち /井口/
いぐるみ /弋/弑/
いぐん /威軍/
いけ /池/
いけい /畏敬/異型/医系/異形/
いけいさいぼう /異形細胞/
いけいしき /異形式/
いけいちょう /衣掛町/
いけいのねん /畏敬の念/
いけいほうしゃそしき /異形放射組織/
いけいよう /異形葉/
いけいようせい /異形葉性/
いけうち /池内/
いけうら /池浦/
いけえ /池江/
いけお /池尾/
いけがき /生け垣/生垣/
いけがみ /池上/
いけがみきみこ /池上季実子/
いけがみせん /池上線/
いけがみつうしんき /池上通信機/
いけがめ /池亀/
いけがや /池谷/池ケ谷/
いけがわ /池川/
いけさか /池坂/
いけざわ /池沢/生澤/池澤/
いけした /池下/
いけしょうじ /池庄司/
いけじり /池尻/
いけじりおおはし /池尻大橋/
いけす /生け簀/
いけた /井桁/
いけたに /池谷/
いけだ /池田/
いけだこうこう /池田高校/
いけだし /池田市/
いけだちょう /池田町/
いけだりよこ /池田理代子/
いけつき /池月/
いけつつみ /池堤/
いけど /池戸/
いけなが /池永/
いけなみ /池波/
いけにえ /犠/牲/生贄/犧/犠牲/
いけの /池野/池乃/
いけのうえ /池ノ上/
いけのはた /池の端/
いけのはたもん /池の端門/
いけのぼう /池の坊/
いけはぎ /生剥/
いけはら /池原/
いけばな /生け花/
いけぶくろ /池袋/
いけぶくろえき /池袋駅/
いけぶくろえきしゅうへん /池袋駅周辺/
いけぶくろえきひがしぐち /池袋駅東口/
いけぶくろかん /池袋間/
いけぶくろぐち /池袋口/
いけぶくろせいぶ /池袋西武/
いけぶくろせん /池袋線/
いけぶくろせんえんせん /池袋線沿線/
いけぶくろてん /池袋店/
いけぶくろとうぶ /池袋東武/
いけぶくろにしぐち /池袋西口/
いけぶくろはっちゃく /池袋発着/
いけぶくろふきん /池袋付近/
いけぶくろほんせん /池袋線本線/
いけべ /池辺/
いけみず /池水/
いけみや /池宮/
いけもと /池本/
いけや /池谷/
いけやま /池山/
いけん /意見/違憲/異見/
いけんこうい /違憲行為/
いけんこうかん /意見交換/
いけんこうかんちゅう /意見交換中/
いけんこうこく /意見広告/
いけんしょ /意見書/
いけんしんぎ /違憲審議/
いけんじょうこう /違憲条項/
いけんせい /違憲性/
いけんなど /意見等/
いけんはんけつ /違憲判決/
いけんひょうめい /意見表明/
いけんようぼう /意見要望/
いけんらん /意見欄/
いけんりっぽうしんさ /違憲立法審査/
いげん /威厳/威嚴/
いげんご /異言語/
いこ /依怙/
いこーる /＝/
いこい /憩い/憩/
いこう /以降/移行/意向/移項/偉功/威光/遺稿/
いこうあん /移行案/
いこうき /移行期/
いこうきかん /移行期間/
いこうきかんちゅう /移行期間中/
いこうご /移行後/
いこうさぎょう /移行作業/
いこうじ /移行時/
いこうずみ /移行済/
いこうそち /移行措置/
いこうそちきかん /移行措置期間/
いこうぞう /異構造/
いこうだんかい /移行段階/
いこうちゅう /移行中/
いこうちょうさ /意向調査/
いこうゆうよきかん /移行猶予期間/
いこく /異国/
いこくじょうちょ /異国情緒/
いこじ /意固地/依怙地/
いこつ /遺骨/
いこつちょうさ /遺骨調査/
いこま /生駒/居駒/
いこまこうさくせん /生駒鋼索線/
いこまし /生駒市/
いこまやま /生駒山/
いこん /遺恨/
いこんじあい /遺恨試合/
いこんたいけつ /遺恨対決/
いご /以後/囲碁/伊語/
いごう /伊号/
いごきし /囲碁棋士/
いごきょうかい /囲碁協会/
いごこうざ /囲碁講座/
いごこち /居心地/
いごころ /居心/
いごしょうぎぶ /囲碁将棋部/
いごたいかい /囲碁大会/
いさ /伊佐/異差/諌/
いさい /委細/異彩/偉才/異才/
いさお /勲/功/勇夫/勇雄/勲男/勳/
いさか /伊坂/井坂/
いさかい /諍い/諍/
いさく /遺作/
いさこ /いさ子/
いさご /砂金/
いささか /聊か/
いさはや /諌早/
いさはやわん /諫早湾/
いさはら /井佐原/
いさみ /勇/
いさみあし /勇み足/勇足/
いさむ /勇/勲/勳/
いさやま /伊佐山/諌山/
いさり /漁/
いさりび /漁火/
いさわ /伊沢/伊澤/井沢/井澤/石和/
いさん /遺産/胃酸/胃散/違算/
いさんかた /胃酸過多/
いさんしょぶん /遺産処分/
いさんそうぞく /遺産相続/
いさんそうぞくけん /遺産相続権/
いさんどうき /遺産動機/
いさんぶんかつ /遺産分割/
いざかや /居酒屋/
いざき /井崎/伊崎/
いざなぎ /伊弉諾/伊邪那岐/
いざなぎのみこと /伊邪那岐命/伊弉諾尊/
いざなみ /伊弉冉/伊邪那美/
いざよい /十六夜/
いざわ /伊沢/井沢/伊澤/
いし /石/意思/意志/医師/遺思/遺志/遺址/縊死/
いしあたま /石頭/
いしい /石井/
いしうち /石打/
いしうちやま /石打山/
いしおか /石岡/
いしおざん /石尾山/
いしかい /医師会/
いしかべ /石壁/
いしかめ /石亀/
いしかり /石狩/
いしかりがわ /石狩川/
いしかりし /石狩市/
いしかりちょう /石狩町/
いしかりぬまた /石狩沼田/
いしかわ /石川/石河/
いしかわえき /石川駅/
いしかわけん /石川県/
いしかわけんしゅっしん /石川県出身/
いしかわけんない /石川県内/
いしかわこうせん /石川高専/
いしかわじま /石川島/
いしかわじまはりま /石川島播磨/
いしかわせん /石川線/
いしかわたくぼく /石川啄木/
いしかわだい /石川台/
いしかわちょう /石川町/
いしかわちょうえき /石川町駅/
いしがき /石垣/
いしがきくうこう /石垣空港/
いしがきし /石垣市/
いしがきじま /石垣島/
いしがね /石金/
いしがみ /石神/石上/
いしがめ /石亀/
いしき /意識/伊敷/
いしきか /意識下/意識化/
いしきかいかく /意識改革/
いしきかてい /意識過程/
いしきじょう /意識上/
いしきてき /意識的/
いしきふめい /意識不明/
いしくに /石國/
いしくら /石倉/
いしぐみ /石組み/
いしぐろ /石黒/
いしぐろけん /石黒賢/
いしけってい /意思決定/意志決定/
いしけっていかてい /意志決定過程/
いしけっていしゃ /意思決定者/
いしけっていほうしき /意思決定方式/
いしけっていほうほう /意志決定方法/意思決定方法/
いしげ /石毛/石下/
いしこし /石越/
いしこしえき /石越駅/
いしこじん /医師個人/
いしこっかしけん /医師国家試験/
いしごう /石郷/
いしごおり /石氷/
いしざか /石坂/
いしざかせん /石坂線/
いしざき /石崎/
いしざきがわ /石崎川/
いしざわ /石澤/石沢/
いししかく /医師資格/
いしした /石下/
いししゅたい /意思主体/
いしじま /石島/石嶋/
いしずえ /礎/
いしずか /石塚/
いしずけ /石附/
いしそつう /意思疎通/
いしそね /石曽根/
いしぞね /石曽根/
いしだ /石田/
いしだたみ /石畳/甃/
いしだりゅう /石田流/
いしだん /石段/
いしつ /異質/遺失/
いしつか /石塚/
いしつせい /異質性/
いしつぶつ /遺失物/
いしづえ /礎/
いしづか /石塚/
いしづき /鐓/
いしづくり /石造り/
いしづけ /石附/
いしてき /意志的/
いしでら /石寺/
いしでんたつ /意思伝達/
いしとうろう /石燈篭/
いしとび /石飛/
いしどう /石堂/
いしどりや /石鳥谷/
いしなべ /石鍋/
いしぬき /石貫/
いしの /石野/
いしのまき /石巻/
いしのまきえき /石巻駅/
いしのまきし /石巻市/
いしのまきせん /石巻線/
いしのまきせんけいゆ /石巻線経由/
いしのまきせんけいゆう /石巻線経由/
いしのもり /石之森/
いしはくじゃく /意志薄弱/意思薄弱/
いしはた /石畑/
いしはま /石浜/
いしはら /石原/
いしはらさんぎょう /石原産業/
いしはらしんたろう /石原慎太郎/
いしはらゆうじろう /石原裕次郎/
いしはり /石播/
いしば /石場/
いしばし /石橋/
いしばしえき /石橋駅/
いしばしかん /石橋間/
いしひょうじ /意思表示/意志表示/
いしひょうめい /意思表明/意志表明/
いしぶみ /碑/
いしべ /石辺/石部/
いしほう /医師法/
いしほういはん /医師法違反/
いしま /石間/
いしまき /石巻/
いしまつ /石松/
いしまつえき /石松駅/
いしまる /石丸/
いしまるでんき /石丸電気/
いしみ /石見/
いしみつ /石光/
いしみね /石嶺/
いしむら /石村/
いしむれ /石牟礼/
いしめんきょ /医師免許/
いしもた /石母田/
いしもだ /石母田/
いしもと /石本/石元/
いしもり /石森/
いしもりしょうたろう /石森章太郎/
いしゃ /医者/慰謝/
いしゃきぼうしゃ /医者希望者/
いしゃやく /医者役/
いしゃりょう /慰謝料/
いしや /石屋/
いしやかわしゃこ /石屋川車庫/
いしやがわ /石屋川/
いしやき /石焼/
いしやま /石山/
いしやまさかもとせん /石山坂本線/
いしやまざか /石山坂/
いしやまでら /石山寺/
いしゅ /異種/射手/意趣/異株/
いしゅう /異臭/蝟集/
いしゅかくとうぎ /異種格闘技/
いしゅかくとうぎせん /異種格闘技戦/
いしゅかんきょう /異種環境/
いしゅがえし /意趣返し/
いしゅく /萎縮/委縮/畏縮/蝟縮/
いしゅこうさ /異種交差/
いしゅせい /異種性/
いしゅせいめいたい /異種生命体/
いしゅぞく /異種族/
いしゅつ /移出/
いしゆみ /弩/
いしょ /遺書/医書/
いしょう /衣裳/衣装/意匠/異称/
いしょうがえ /衣装替/
いしょうけん /意匠権/
いしょうてき /意匠的/
いしょうとうろく /意匠登録/
いしょうとうろくちゅう /意匠登録中/
いしょうほう /意匠法/
いしょく /移植/委嘱/異色/衣食/依嘱/
いしょくさぎょう /移植作業/
いしょくさく /異色作/
いしょくしゃ /移植者/
いしょくじゅう /衣食住/
いしょくじょう /委嘱状/移植上/
いしょくじょうほう /移植情報/
いしょくすう /移植数/
いしょくせい /移植性/
いしょくたんぺんしゅう /異色短編集/異色短篇集/
いしょくちゅう /移植中/
いしょくてじゅん /移植手順/
いしょくど /移植度/
いしょくばん /移植版/
いしょくぶつ /移植物/
いしょけんめい /一所懸命/
いしりょく /意志力/
いしわおんせん /石和温泉/
いしわた /石綿/石渡/
いしわたり /石渡/
いしわら /石原/
いしん /威信/維新/以深/
いしんぐんだん /維新軍団/
いしんご /維新後/
いしんでんしん /以心伝心/
いしんは /維新派/
いしんりき /維新力/
いじ /維持/意地/遺児/医事/依次/依恃/
いじかんり /維持管理/
いじげん /異次元/
いじげんくうかん /異次元空間/
いじしゅうりぶひん /維持修理部品/
いじたい /異字体/
いじち /伊地知/
いじひ /維持費/
いじふくせい /維持複製/
いじゅう /移住/
いじゅういん /伊集院/
いじゅうけん /居住権/
いじゅうしゃ /移住者/
いじゅつ /医術/
いじょう /以上/異常/≧/委譲/異状/移乗/移譲/
いじょういでんし /異常遺伝子/
いじょうかしょ /異常箇所/
いじょうきしょう /異常気象/
いじょうけい /異常系/
いじょうけんしゅつ /異常検出/
いじょうげんしょう /異常現象/
いじょうこうどう /異常行動/
いじょうしゃ /異常者/
いじょうしゅうりょう /異常終了/
いじょうしんどう /異常振動/
いじょうじ /異常時/
いじょうじょうたい /異常状態/
いじょうじんかく /異常人格/
いじょうせい /異常性/
いじょうそうこう /異常走行/
いじょうぞうしょく /異常増殖/
いじょうたいりょうはんしょく /異常大量繁殖/
いじょうち /異常値/
いじょうつうち /異常通知/
いじょうど /異常度/
いじょうどうさ /異常動作/
いじょうにんき /異常人気/
いじょうねんしょう /異常燃焼/
いじょうはっせい /異常発生/
いじょうはんざい /異常犯罪/
いじょうはんしょく /異常繁殖/
いじょうひだいせいちょう /異常肥大生長/
いじょうぶんさん /異常分散/
いじょく /居職/
いじら /伊自良/
いじり /井尻/
いじるし /井印/
いじわる /意地悪/
いじん /異人/偉人/
いじんかん /異人館/
いじんしゅ /異人種/
いじんでん /偉人伝/
いす /椅子/
いすう /位数/異数/
いすうか /異数花/
いすがた /椅子型/
いすけ /伊介/
いすこうげき /椅子攻撃/
いすず /いすゞ/
いすずがわ /五十鈴川/
いすずじどうしゃ /いすゞ自動車/
いすせき /椅子席/
いすみ /夷隅/
いすみぐんし /夷隅郡市/
いすみまち /夷隅町/
いず /伊豆/伊津/
いずかいようこうえん /伊豆海洋公園/
いずきゅう /伊豆急/
いずきゅうこう /伊豆急行/
いずきゅうしもだ /伊豆急下田/
いずくんぞ /焉/
いずけいとう /伊豆系統/
いずこ /何処/
いずこうげん /伊豆高原/
いずし /出石/
いずしま /出島/
いずしょとう /伊豆諸島/
いずた /泉田/
いずちほう /伊豆地方/
いずつ /井筒/
いずながおか /伊豆長岡/
いずながおかちょう /伊豆長岡町/
いずにった /伊豆仁田/
いずぬま /伊豆沼/
いずはこね /伊豆箱根/
いずはこねてつどう /伊豆箱根鉄道/
いずはんとう /伊豆半島/
いずふきん /伊豆付近/
いずほうめん /伊豆方面/
いずまい /居ずまい/
いずみ /泉/和泉/出水/五住/湶/偉津美/
いずみおおつ /泉大津/
いずみかわ /泉川/
いずみがおか /泉ヶ丘/
いずみがたけ /泉ヶ岳/
いずみく /泉区/
いずみごう /泉郷/
いずみさき /泉崎/
いずみさの /泉佐野/
いずみたに /泉谷/
いずみたまがわ /和泉多摩川/
いずみたまがわかん /和泉多摩川間/
いずみだ /泉田/
いずみちゅうおう /泉中央/
いずみや /泉谷/イズミヤ/
いずみやま /泉山/
いずも /出雲/
いずもざき /出雲崎/
いずもし /出雲市/
いずもしんわ /出雲神話/
いずもたいしゃ /出雲大社/
いずもたいしゃまえ /出雲大社前/
いずものくに /出雲国/
いずれ /何れ/
いせ /伊勢/
いせい /異性/以西/異星/威勢/
いせいか /異性化/
いせいかんけい /異性関係/
いせいけん /遺生研/
いせいこうゆう /異性交友/
いせいしゃ /為政者/
いせいじん /異星人/
いせいぶつ /異生物/
いせえび /伊勢海老/
いせおきつ /伊勢奥津/
いせかい /異世界/
いせき /移籍/遺跡/井関/
いせききんがく /移籍金額/
いせきぐみ /移籍組/
いせきけってい /移籍決定/
いせきご /移籍後/
いせきさき /移籍先/
いせきせつ /移籍説/
いせきのうき /井関農機/
いせきはっくつ /遺跡発掘/
いせきばなし /移籍話/
いせきもんだい /移籍問題/
いせきりょう /移籍料/
いせさき /伊勢崎/伊勢左木/
いせざき /伊勢崎/
いせざきいき /伊勢崎行/
いせざきかん /伊勢崎間/
いせざきせん /伊勢崎線/伊勢佐木線/
いせざきちょう /伊勢崎町/
いせざきほんせん /伊勢崎本線/
いせしま /伊勢志摩/
いせじどうしゃどう /伊勢自動車道/
いせじんぐう /伊勢神宮/
いせせん /伊勢線/
いせたん /伊勢丹/
いせだ /伊勢田/
いせちょう /伊勢町/
いせつ /移設/異説/
いせつこうじ /移設工事/
いせつご /移設後/
いせてつどう /伊勢鉄道/
いせなかがわ /伊勢中川/
いせはら /伊勢原/
いせはらし /伊勢原市/
いせはらしみん /伊勢原市民/
いせほうめん /伊勢方面/
いせもと /伊勢本/
いせや /伊勢屋/
いせり /井芹/
いせわん /伊勢湾/
いせん /緯線/伊仙/以浅/
いぜき /井関/
いぜな /伊是名/
いぜん /以前/依然/
いぜんとうこう /以前投稿/
いぜんほうそう /以前放送/
いぜんもんだい /以前問題/
いぜんわだい /以前話題/
いそ /磯/五十/
いそう /移送/位相/移相/
いそうかいせき /位相解析/
いそうかく /位相角/
いそうかんけい /位相関係/
いそうがいねん /位相概念/
いそうがく /位相学/
いそうきかこうぞう /位相幾何構造/
いそうきかてき /位相幾何的/
いそうくうかん /位相空間/
いそうくうかんろん /位相空間論/
いそうさ /位相差/
いそうさき /移送先/
いそうじょうほう /位相情報/
いそうせいぎょ /位相制御/
いそうそくど /位相速度/
いそうてき /位相的/
いそうとうかせい /移送透過性/
いそうとくせい /位相特性/
いそうはんてい /移送判定/
いそうぶんかつき /位相分割器/
いそうぶんぷ /位相分布/
いそうろう /居候/
いそがい /磯貝/
いそがみ /磯上/
いそがわ /五十川/
いそぎあし /急ぎ足/
いそくど /異速度/
いそご /磯子/
いそごえき /磯子駅/
いそごく /磯子区/
いそざお /磯竿/
いそざき /磯崎/
いそじまん /磯自慢/
いそじん /磯陣/
いそだ /磯田/
いそていえん /磯庭園/
いその /磯野/
いそのけ /磯野家/
いそべ /磯部/磯辺/
いそまつもく /イソマツ目/Plumbaginales/
いそみち /磯道/
いそむら /磯村/
いそや /磯谷/
いそやま /磯山/礒山/
いそん /依存/
いそんせい /依存性/
いぞう /遺贈/以蔵/
いぞく /遺族/
いぞり /居反り/
いぞん /依存/異存/
いぞんかいせき /依存解析/
いぞんかいせきぶ /依存解析部/
いぞんかんけい /依存関係/
いぞんかんけいきそく /依存関係規則/
いぞんがた /依存型/
いぞんぎみ /依存気味/
いぞんしょう /依存症/
いぞんじゅんじょせい /依存順序性/
いぞんじょうほう /依存情報/
いぞんせい /依存性/
いぞんせき /依存積/
いぞんせんたくこうり /依存選択公理/
いぞんたいしつ /依存体質/
いぞんてき /依存的/
いぞんど /依存度/
いぞんどひょうかひょう /依存度評価表/
いぞんぶ /依存部/
いぞんわ /依存和/
いた /板/致/至/分/痛/
いたあつ /板厚/
いたい /遺体/異体/板井/
いたいじ /異体字/
いたがき /板垣/
いたがね /板金/鈑/
いたがみ /板紙/
いたがらす /板硝子/
いたきそえき /伊太祁曽駅/
いたく /委託/依託/
いたくきん /依託金/
いたくけんきゅう /委託研究/
いたくしょうこきん /委託証拠金/
いたくはんばい /委託販売/
いたくはんばいひん /委託販売品/
いたくら /板倉/
いたくりょう /委託料/
いたけだか /居丈高/
いたこ /潮来/板子/
いたさと /板里/
いたざい /板材/
いたざき /板崎/
いたしかた /致し方/
いたしんどう /板振動/
いたじき /板敷/
いたじょう /板状/
いたずら /悪戯/徒/徒ら/
いたずらに /徒に/
いただき /頂/
いただきもの /頂き物/
いたち /鼬/
いたちょこ /板チョコ/
いたづら /悪戯/惡戲/
いたで /痛手/傷手/
いたどり /板取/
いたに /猪谷/
いたの /板野/
いたはし /板橋/
いたばさみ /板挟み/
いたばし /板橋/
いたばしく /板橋区/
いたばしくやくしょ /板橋区役所/
いたばしほんちょう /板橋本町/
いたばり /板張り/
いたひょうめん /板表面/
いたべい /板塀/
いたま /板間/
いたまえ /板前/
いたみ /伊丹/
いたみし /伊丹市/
いたみどめ /痛み止め/
いため /板目/
いためし /イタ飯/
いためん /板面/
いたや /板谷/板矢/
いたやえき /板谷駅/
いたやとうげ /板谷峠/
いたやなぎ /板柳/
いたりー /伊太利/
いたりあ /伊太利屋/伊太利亜/
いたる /至/格/到/
いたん /異端/医短/医療技術短期大学部/
いたんかがく /異端科学/
いたんし /異端視/
いたんしゃ /異端者/
いたんしんもん /異端審問/
いたんじ /異端児/
いたんてき /異端的/
いたんぶんし /異端分子/
いだ /井田/伊田/委佗/
いだい /偉大/医大/
いだいさ /偉大さ/
いだてん /韋駄天/
いち /一/位置/壱/市/１/1/伊知/弌/壹/依遅/Ｉ/
いち< /一/
いち> /一/
いちあん /一案/
いちい /一意/一位/一井/市井/櫟/
いちいこうほ /一位候補/
いちいしめい /一位指名/
いちいせい /一意性/
いちいち /一々/
いちいてき /一意的/
いちいにんしきりつ /一位認識率/
いちいん /一員/一因/
いちう /一宇/
いちえいが /一映画/
いちえん /一円/
いちえんだま /一円玉/
いちおう /一応/
いちおうかくにん /一応確認/
いちおうふく /一往復/
いちおうふくぶん /一往復分/
いちおく /一億/
いちおくえん /一億円/
いちおくえんきょう /一億円強/
いちおくにん /一億人/
いちおし /一押し/一推し/
いちおん /一音/
いちおんせつ /一音節/
いちかい /市貝/
いちかいいん /一会員/
いちかいけつほう /一解決法/
いちかいそう /一階層/
いちかくにん /位置確認/
いちかくほ /位置確保/
いちかたい /一方井;姓/
いちから /一から/
いちかわ /市川/
いちかわえんのすけ /市川猿之助/
いちかわけおり /市川毛織/
いちかわし /市川市/
いちかわふさえ /市川房枝/
いちかんけい /位置関係/
いちかんそく /位置観測/
いちかんたい /一艦隊/
いちがい /一概/
いちがいに /一概に/
いちがお /市ヶ尾/
いちがくしょう /一楽章/
いちがくせい /一学生/
いちがくねん /1学年/
いちがくねんした /一学年下/
いちがっき /一学期/
いちがつ /１月/1月/一月/睦月/
いちがつごう /1月号/
いちがつまえ /一月前/
いちがめん /一画面/
いちがや /市ケ谷/市ヶ谷/市谷/
いちがやさないちょう /市谷左内町/
いちがん /一眼/一丸/
いちがんれふ /一眼レフ/
いちき /一木/市來/市来/
いちきしゅ /一機種/
いちきじゅん /位置基準/
いちぎ /一義/
いちぎてき /一義的/
いちぎてきせきにん /一義的責任/
いちぎょう /一行/１行/1行/
いちぎょういちぎょう /一行一行/
いちぎょうめ /一行目/
いちく /移築/
いちぐう /一遇/一隅/
いちぐん /一群/一軍/
いちぐんこうしきせん /一軍公式戦/
いちぐんとうろく /一軍登録/
いちけい /位置系/
いちけいさん /位置計算/
いちけいたい /一形態/
いちけいとう /一系統/
いちけってい /位置決定/
いちけん /一研/
いちけんしき /一見識/
いちけんしゅつ /位置検出/
いちけんしゅつぶ /位置検出部/
いちけんとう /一検討/
いちげ /市毛/
いちげい /一芸/
いちげき /一撃/
いちげきひっさつ /一撃必殺/
いちげきりだつ /一撃離脱/
いちげん /一言/一見/一元/一限/一弦/
いちげんか /一元化/
いちげんかんり /一元管理/
いちげんせい /一元性/
いちげんてき /一元的/
いちげんろん /一元論/
いちこ /一子/市子/伊智子/
いちこう /一高/
いちこうさつ /一考察/
いちこうもく /一項目/
いちこくみん /一国民/
いちこし /市越/
いちこじん /一個人/
いちこたい /一個体/
いちこつ /壱越/
いちこてい /位置固定/
いちご /一語/苺/一期/莓/
いちごいちえ /一期一会/
いちごう /一号/一合/壱号/
いちごうかん /一号館/
いちごうき /一号機/
いちごうせん /一号線/
いちごうてん /一号店/
いちごうとう /一号棟/
いちごん /一言/
いちさんかしゃ /一参加者/
いちざ /一座/
いちざひょう /位置座標/
いちし /一志/
いちしじん /一私人/
いちしちょうしゃ /一視聴者/
いちしてい /位置指定/
いちしみん /一市民/
いちしゅうきょう /一宗教/
いちしゅぞく /一種族/
いちしゅほう /一手法/
いちしょうじょ /一少女/
いちしょうじょう /一症状/
いちしんきょう /一神教/
いちじ /一時/一次/一事/一字/１時/1時/１次/伊知地/一児/1次/
いちじいかんそく /一次維管束/
いちじいっく /一字一句/
いちじおくれ /一次遅れ/
いちじおくれようそ /一次遅れ要素/
いちじおんげん /1次音源/
いちじかい /一次会/1次会/
いちじかん /一時間/1時間/
いちじかんいない /一時間以内/
いちじかんご /一時間後/
いちじかんすう /一次関数/
いちじかんはん /一時間半/
いちじかんまえ /一時間前/
いちじかんめ /一時間目/
いちじがわ /一次側/
いちじき /一時期/
いちじきかつどう /一時期活動/
いちじきこく /一時帰国/
いちじきざいせき /一時期在籍/
いちじきどうにゅう /一時期導入/
いちじきもんだい /一時期問題/
いちじきゅうし /一時休止/
いちじきゆうめい /一時期有名/
いちじきん /一時金/
いちじきんじ /一次近似/
いちじく /一軸/無花果/
いちじげん /一次元/1次元/
いちじげんてき /一次元的/
いちじさんらん /一次散乱/
いちじし /一次子/
いちじしき /一次式/
いちじしぶ /一次篩部/
いちじしょうがい /一次障害/
いちじしょうりゃく /一字省略/
いちじしりょう /一次資料/
いちじせいちょう /一次生長/
いちじせんたく /一次選択/
いちじだい /一時代/
いちじちゅうし /一時中止/
いちじちゅうだん /一時中断/
いちじつせんしゅう /一日千秋/
いちじていし /一時停止/
いちじていしゃ /一時停車/
いちじていすう /一時定数/
いちじてき /一時的/一次的/
いちじとうごう /一次統合/
いちじねっと /一次ネット/
いちじはんしゃ /1次反射/
いちじぶんぷ /一次分布/
いちじぶんれつそしき /一次分裂組織/
いちじへき /一次壁/
いちじへんかん /一次変換/
いちじへんすう /一時変数/
いちじほうていしき /一次方程式/
いちじほぞん /一時保存/
いちじま /市嶋/市島/
いちじみゃく /一次脈/
いちじもくぶ /一次木部/
いちじゅう /一重/
いちじゅん /一巡/一順/
いちじゅんめ /一巡目/
いちじょ /一助/一女/
いちじょう /一条/一城/一畳/
いちじょうじ /一条寺/一乗寺/
いちじょうほう /位置情報/
いちじょせい /一女性/
いちじよせん /一次予選/
いちじれんさい /一時連載/
いちじわだい /一時話題/
いちじん /一陣/
いちじんえい /一陣営/
いちすぎ /一杉/
いちず /一途/一頭/
いちせ /一瀬/
いちせいぎょ /位置制御/
いちせいど /位置精度/
いちせいぶつ /一生物/
いちせいぶん /一成分/
いちぜん /一膳/
いちそうさ /一走査/
いちそくめん /一側面/
いちぞく /一族/
いちぞくろうとう /一族郎党/
いちぞん /一存/
いちたいいち /一対一/1対1/
いちたいいちたいおう /一対一対応/
いちたいた /一対多/
いちたに /市谷/
いちたろう /一太郎/市太郎/
いちたんご /一単語/
いちだ /市田/伊地田/一打/
いちだい /一台/一大/一代/
いちだいかぎり /一代限り/
いちだいがく /一大学/
いちだいけっしん /一大決心/
いちだいけつい /一大決意/
いちだいじ /一大事/
いちだいぶん /一台分/
いちだいめ /一代目/一台目/
いちだいろんぎ /一大論議/
いちださ /一打差/
いちだん /一段/一団/
いちだんうえ /一段上/
いちだんかい /一段階/
いちだんかくした /一段格下/
いちだんした /一段下/
いちだんどうし /一段動詞/
いちだんへんそく /一段変速/
いちだんめ /一段目/
いちだんらく /一段落/
いちちほうそしき /一地方組織/
いちちほうとし /一地方都市/
いちちょうせい /位置調整/
いちぢ /伊知地/
いちづけ /位置付け/
いちてき /位置的/
いちてんき /一転機/
いちとうかせい /位置透過性/
いちとくせい /一特性/
いちとし /一都市/
いちど /一度/１度/1度/
いちどう /一同/一堂/
いちどき /一時/
いちどく /一読/
いちどくらい /一度位/
いちどていど /一度程度/
いちどめ /一度目/
いちなん /一難/
いちに /一二/
いちにかい /一二回/
いちにち /一日/1日/
いちにちいちおうふく /一日一往復/
いちにちいちぜん /一日一善/
いちにちいっかい /一日一回/
いちにちいっしょく /一日一食/
いちにちくらい /一日位/
いちにちけん /一日券/
いちにちご /一日後/
いちにちしょちょう /一日署長/
いちにちじゅう /一日中/
いちにちじゅうきどう /一日中起動/
いちにちじゅうほうち /一日中放置/
いちにちじょうしゃけん /一日乗車券/
いちにちせんしゅう /一日千秋/
いちにちたいざい /一日滞在/
いちにちてんちょう /一日店長/
いちにちにしょく /一日二食/
いちにちぶん /一日分/
いちにちめ /一日目/
いちにょ /一如/
いちにん /一任/
いちにんしゃ /一人者/
いちにんしょう /一人称/
いちにんまえ /一人前/
いちねん /一年/1年/一念/
いちねんいか /一年以下/
いちねんいじょう /一年以上/
いちねんいじょうまえ /一年以上前/
いちねんいない /一年以内/
いちねんかん /一年間/1年間/
いちねんかんげんてい /一年間限定/
いちねんかんしよう /一年間使用/
いちねんけいか /一年経過/
いちねんけいやく /一年契約/
いちねんご /1年後/一年後/
いちねんじ /一年次/
いちねんじゅう /一年中/
いちねんせい /一年生/
いちねんせいそうほん /一年生草本/
いちねんていど /一年程度/
いちねんはん /一年半/
いちねんはんほどまえ /一年半程前/
いちねんぶん /一年分/
いちねんほっき /一念発起/
いちねんほど /一年程/
いちねんまえ /一年前/
いちねんめ /一年目/
いちの /市野/
いちのう /一能/
いちのき /一の樹/
いちのぎく /市乃菊/市之菊/
いちのくら /一の倉/一ノ倉/一ノ蔵/
いちのせ /市之瀬/一野瀬/一ノ瀬/一瀬/一の瀬/
いちのせき /一関/一ノ関/
いちのちょう /一の町/
いちのへ /一戸/
いちのぼう /一の坊/
いちのみや /一ノ宮/一宮/一の宮/
いちのもと /櫟本/檪本/
いちはさま /一迫/
いちはざま /一迫/
いちはし /市橋/
いちはた /一畑/
いちはやく /いち早く/
いちはら /市原/
いちはらし /市原市/
いちはらん /一波乱/
いちば /市場/一馬/一場/
いちばい /一倍/
いちばいはん /一倍半/
いちばた /一畑/
いちばめん /一場面/
いちばん /一番/壱番/
いちばんあんい /一番安易/
いちばんあんしん /一番安心/
いちばんあんぜん /一番安全/
いちばんあんてい /一番安定/
いちばんいや /一番嫌/
いちばんいんしょうてき /一番印象的/
いちばんうえ /一番上/
いちばんおく /一番奥/
いちばんかくじつ /一番確実/
いちばんかん /一番艦/壱番館/
いちばんかんじん /一番肝心/一番肝腎/
いちばんかんそ /一番簡素/
いちばんかんたん /一番簡単/
いちばんき /一番機/
いちばんきたい /一番期待/
いちばんきほんてき /一番基本的/
いちばんきれい /一番奇麗/
いちばんくろう /一番苦労/
いちばんぐみ /一番組/
いちばんけいざいてき /一番経済的/
いちばんげんじゅう /一番厳重/
いちばんこうか /一番高価/
いちばんこうかてき /一番効果的/
いちばんこうりつ /一番効率/
いちばんごうか /一番豪華/
いちばんさいあく /一番最悪/
いちばんさいきん /一番最近/
いちばんさいご /一番最後/
いちばんさいしょ /一番最初/
いちばんさき /一番先/
いちばんざんねん /一番残念/
いちばんした /一番下/
いちばんじゅうよう /一番重要/
いちばんじょうず /一番上手/
いちばんそこ /一番底/
いちばんそと /一番外/
いちばんたいせつ /一番大切/
いちばんたんじゅん /一番単純/
いちばんだいじ /一番大事/
いちばんちょう /一番町/一番丁/
いちばんて /一番手/
いちばんてまえ /一番手前/
いちばんでし /一番弟子/
いちばんとく /一番得/
いちばんにほんてき /一番日本的/
いちばんにんき /一番人気/
いちばんのり /一番乗/
いちばんはし /一番端/
いちばんひだり /一番左/
いちばんひだりがわ /一番左側/
いちばんふしぎ /一番不思議/
いちばんべんり /一番便利/
いちばんまえ /一番前/
いちばんみぎ /一番右/
いちばんみぎがわ /一番右側/
いちばんみりょくてき /一番魅力的/
いちばんめ /一番目/1番目/
いちばんもんだい /一番問題/
いちばんらく /一番楽/
いちひめにたろう /一姫二太郎/
いちびょう /一秒/
いちびょういか /一秒以下/
いちびょうかん /一秒間/
いちびょうたんい /一秒単位/
いちびん /一便/
いちぶ /一部/一分/1部/
いちぶいみめいりょう /一部意味明瞭/
いちぶいん /一部員/
いちぶいんよう /一部引用/
いちぶかいつう /一部開通/
いちぶかっそうか /一部滑走可/
いちぶきぎょう /一部企業/
いちぶきしゅ /一部機種/
いちぶきんえん /一部禁煙/
いちぶきんえんせき /一部禁煙席/
いちぶくかん /一部区間/
いちぶしじゅう /一部始終/
いちぶしていせき /一部指定席/
いちぶしゃりょう /一部車両/
いちぶしゅうせい /一部修正/
いちぶしょうりゃく /一部省略/
いちぶしよう /一部仕様/
いちぶしろくろ /一部白黒/
いちぶじょういきしゅ /一部上位機種/
いちぶちいき /一部地域/
いちぶついか /一部追加/
いちぶていせい /一部訂正/
いちぶはっぴょう /一部発表/
いちぶばっすい /一部抜粋/
いちぶふくせんか /一部複線化/
いちぶふっき /一部復帰/
いちぶぶん /一部分/
いちぶへんこう /一部変更/
いちぶへんしゅう /一部編集/
いちぶもん /一部門/
いちぶゆうこう /一部有効/
いちぶりゃく /一部略/
いちぶりょうがえ /一部両替/
いちぶん /一文/一分/一聞/
いちぶんかいのう /位置分解能/
いちぶんし /一分子/
いちぶんせつ /一文節/
いちぶんや /一分野/
いちへいし /一兵士/
いちへんすう /1変数/一変数/位置変数/
いちへんせい /一編成/
いちべつ /一瞥/一別/
いちほうこう /一方向/
いちほうし /一法師/
いちほうほう /一方法/
いちぼう /一望/
いちまい /一枚/
いちまいいた /一枚板/
いちまいいわ /一枚岩/
いちまいうわて /一枚上手/
いちまいした /一枚下/
いちまいぶん /一枚分/
いちまいめ /一枚目/
いちまつ /一松/一抹/市松/
いちまつもよう /市松模様/
いちまん /一万/一萬/
いちまんえん /一万円/1万円/壱万円/壱萬圓/
いちまんえんいじょう /一万円以上/
いちまんえんさつ /一万円札/
いちまんえんしへい /一万円紙幣/
いちまんえんぶん /一万円分/
いちまんまい /一万枚/
いちみ /一味/
いちみとうがらし /一味唐辛子/
いちみゃく /一脈/
いちむら /市村/一村/
いちめい /一名/1名/一命/
いちめいれい /一命令/
いちめん /一面/
いちめんしき /一面識/
いちめんてき /一面的/
いちもうさく /一毛作/
いちもく /一目/
いちもくさん /一目散/
いちもくりょうぜん /一目瞭然/
いちもじ /一文字/１文字/1文字/
いちもじそうしゅつ /一文字送出/
いちもじひょうじ /一文字表示/
いちもじめ /一文字目/
いちもつ /一物/
いちもん /一問/一門/一文/
いちもんいっとう /一問一答/
いちもんじ /一文字/
いちもんめ /一問目/
いちや /一夜/
いちやく /一躍/
いちやくきゃっこう /一躍脚光/
いちやなぎ /一柳/
いちやぶん /一夜分/
いちゅう /意中/移駐/
いちゆう /一揖/
いちょ /遺著/
いちょう /胃腸/移調/銀杏/威張/移牒/公孫樹/異聴/
いちょうかん /胃腸管/
いちょうがっき /移調楽器/
いちょうけいこう /異聴傾向/
いちょうこう /イチョウ綱/Ginkgopsida/
いちょうしょうがい /胃腸障害/
いちょうひょう /異聴表/
いちょうびょう /胃腸病/
いちょうやく /胃腸薬/
いちよ /市代/
いちよう /一様/一葉/
いちようか /一様化/
いちようしゅうそく /一様収束/
いちようしゅうはすう /一様周波数/
いちようじゅうりょくば /一様重力場/
いちようせい /一様性/
いちようそ /一要素/
いちようぶんぷ /一様分布/
いちようへいきんりゅう /一様平均流/
いちようらんすう /一様乱数/
いちよく /一翼/
いちよし /市吉/
いちよそく /位置予測/
いちらん /一覧/壹覽/
いちらんさくせい /一覧作成/
いちらんせい /一卵性/
いちらんせいそうせいじ /一卵性双生児/
いちらんひょう /一覧表/
いちらんひょうじ /一覧表示/
いちり /一理/一里/一利/
いちりき /一力/
いちりつ /一律/市立/一率/
いちりつかぜい /一律課税/
いちりつひかぜい /一律非課税/
いちりつふなばし /市立船橋/
いちりの /一里野/
いちりやま /一里山/
いちりゅう /一流/一留/
いちりゅうせんしゅ /一流選手/
いちりゅうだいがく /一流大学/
いちりゅうば /一流馬/
いちりょう /一両/
いちりょういき /一領域/
いちりょうしゃ /一両車/
いちりょうじつ /一両日/
いちりようしゃ /一利用者/
いちりん /一輪/1輪/
いちりんか /一輪花/
いちりんしゃ /一輪車/
いちる /一縷/
いちるい /一塁/一類/
いちるいがわ /一塁側/
いちるいしゅ /一塁手/
いちるいそうしゃ /一塁走者/
いちれい /一例/一礼/
いちれつ /一列/1列/
いちれつめ /一列目/
いちれん /一連/一蓮/
いちれんたくしょう /一蓮托生/
いちろ /一路/
いちろう /一郎/一浪/伊知郎/一朗/市郎/
いちろうた /一朗太/
いちろなんか /一路南下/
いちろん /一論/
いちわ /一羽/一話/
いちわいじょう /一話以上/
いちわかんけつ /一話完結/
いちわり /一割/
いちわりいじょう /一割以上/
いちわりびき /一割引/
いっ /逸/
いっか /一家/一課/一過/一価/
いっかい /一回/一階/一介/１回/1回/一塊/１Ｆ/
いっかいごと /一回毎/
いっかいじゅつごろんり /一階述語論理/
いっかいせい /一回性/
いっかいせき /一階席/
いっかいせん /一回戦/一回線/
いっかいていど /一回程度/
いっかいてん /一回転/
いっかいぶん /一回分/
いっかいめ /一回目/１回目/
いっかいろんり /一階論理/
いっかく /一角/一獲/一画/一攫/
いっかくじゅう /一角獣/
いっかくせんきん /一獲千金/一攫千金/
いっかげつ /一箇月/一ヶ月/１か月/１ヶ月/一カ月/
いっかげつまえ /一箇月前/
いっかげん /一家言/
いっかごん /一家言/
いっかしょ /一箇所/一ヶ所/1カ所/一カ所/一か所/
いっかせい /一過性/
いっかつ /一括/一喝/
いっかつこうにゅう /一括購入/
いっかつさくじょ /一括削除/
いっかつしょり /一括処理/
いっかつじかんかじゅう /一括時間荷重/
いっかつそうしん /一括送信/
いっかつとうち /一括統治/
いっかつとうろく /一括登録/
いっかつにゅうりょく /一括入力/
いっかつへんかん /一括変換/
いっかつほう /一括法/
いっかつほしょう /一括補償/
いっかてき /一過的/
いっかりさん /一家離散/
いっかりつ /一価律/
いっかん /一貫/一環/一巻/
いっかんせい /一貫性/
いっかんぼん /一巻本/
いっき /一気/一期/一揆/一輝/一機/
いっきいちゆう /一喜一憂/
いっきうち /一騎打/
いっきかせい /一気呵成/
いっきせい /一期生/
いっきたいさく /一揆対策/
いっきに /一気に/
いっきのみ /一気飲み/
いっきゃく /一脚/
いっきゅう /一級/一休/一球/
いっきゅうひん /一級品/
いっきょ /一挙/
いっきょう /一興/
いっきょく /一曲/一極/一局/
いっきょくこうぞう /一極構造/
いっきょくしゅうちゅう /一極集中/一局集中/
いっきょくめ /一曲目/
いっきょこうかい /一挙公開/
いっきょしゅ /一挙手/
いっきょりょうどく /一挙両得/
いっきん /一金/一斤/
いっく /一句/一区/
いっくかん /一区間/
いっけい /一計/一景/
いっけつ /一決/
いっけん /一見/一件/一軒/1件/
いっけんしき /一見識/
いっけんや /一軒家/
いっけんやど /一軒宿/
いっけんらくちゃく /一件落着/
いっこ /一個/一顧/1個/一戸/一ヶ/#1個/
いっこう /一向/一行/一考/1項/一幸/一項/一稿/溢口/一鉤/
いっこういっき /一向一揆/
いっこうかんけい /1項関係/一項関係/
いっこうしゅう /一向衆/
いっこうじゅつご /1項述語/
いっこく /一刻/一国/
いっこくたいざい /一国滞在/
いっこしゅうちゅうがた /一個集中型/
いっこすうせんえん /一個数千円/
いっこだて /一戸建て/
いっこぶん /一個分/
いっこん /一献/
いっさ /一茶/
いっさい /一切/一歳/一済/一際/
いっさいがっさい /一切合切/一切合財/
いっさいきんし /一切禁止/
いっさいしょうりゃく /一切省略/
いっさいせきにん /一切責任/
いっさいふかのう /一切不可能/
いっさいむかんけい /一切無関係/
いっさいむし /一切無視/
いっさく /一作/一昨/一策/
いっさくじつ /一昨日/
いっさくねん /一昨年/
いっさくねんど /一昨年度/
いっさくめ /一作目/
いっさつ /一冊/
いっさつぶん /一冊分/
いっさつめ /一冊目/
いっさんかたんそ /一酸化炭素/
いっさんかちっそ /一酸化窒素/
いっし /一矢/一子/一指/一死/一糸/逸史/一志/
いっしあい /一試合/
いっしき /一式/一色/
いっしきにゅうしゅ /一式入手/
いっしそうでん /一子相伝/
いっしつ /一室/
いっしどうじん /一視同仁/
いっしまんるい /一死満塁/
いっしゃ /一社/
いっしゃせん /一車線/
いっしゃせんり /一瀉千里/
いっしゃていきょう /一社提供/
いっしゅ /一種/一首/
いっしゅう /一周/一蹴/一週/
いっしゅうかん /一週間/
いっしゅうかんいじょう /一週間以上/
いっしゅうかんくらい /一週間位/
いっしゅうかんこうたい /一週間交替/
いっしゅうかんご /一週間後/
いっしゅうかんていど /一週間程度/
いっしゅうかんぶん /一週間分/
いっしゅうかんほど /一週間程/
いっしゅうかんまえ /一週間前/
いっしゅうき /一周忌/一周期/
いっしゅうねん /一周年/
いっしゅうめ /一周目/一週目/
いっしゅうようぶん /一周要聞/
いっしゅつ /逸出/
いっしゅどくとく /一種独特/
いっしゅふじょうり /一種不条理/
いっしゅるい /一種類/
いっしゅん /一瞬/
いっしゅんかん /一瞬間/
いっしゅんでんき /一瞬電気/
いっしょ /一緒/一所/
いっしょう /一生/一升/一勝/一章/一笑/
いっしょういっぱい /一勝一敗/
いっしょうがい /一生涯/
いっしょうけんめい /一生懸命/一所懸命/
いっしょうせつ /一小節/
いっしょうびん /一升瓶/
いっしょく /一色/一食/
いっしょくそくはつ /一触即発/
いっしょくた /一緒くた/
いっしょけんめい /一所懸命/
いっしん /一新/一心/一身/一審/
いっしんいったい /一進一退/
いっしんきょう /一神教/
いっしんじょう /一身上/
いっしんとう /一親等/
いっしんどうたい /一心同体/
いっしんはいそ /一審敗訴/
いっしんふらん /一心不乱/
いっすい /一睡/溢水/
いっすうか /一数花/
いっすん /一寸/
いっすんぼうし /一寸法師/
いっせ /一世/一瀬/
いっせい /一斉/一世/一生/一成/一誠/
いっせいいちだい /一世一代/
いっせいこうげき /一斉攻撃/
いっせいしゃげき /一斉射撃/
いっせいじゅぎょう /一斉授業/
いっせいちだい /一世一代/
いっせいどう /一誠堂/
いっせいに /一斉に/
いっせいゆうきゅう /一斉有休/
いっせき /一隻/一席/一石/一夕/
いっせきにちょう /一石二鳥/
いっせつ /一節/一説/
いっせつな /一刹那/
いっせん /一千/一線/一銭/一戦/一閃/
いっせんきゅう /一戦級/
いっせんごりん /一銭五厘/
いっせんねん /一千年/
いっせんねんまえ /一千年前/
いっせんまん /一千万/
いっせんまんえん /一千万円/
いっそ /一噌/不如/
いっそう /一層/一掃/
いっそうこうかてき /一層効果的/
いっそうねっと /一層ネット/
いっそうべんり /一層便利/
いっそく /一足/
いったい /一体/一帯/一隊/
いったいいち /一対一/
いったいか /一体化/
いったいかん /一体感/
いったいがた /一体型/
いったいけい /一体形/
いったいしき /一体式/
いったいせいけい /一体成形/
いったいぜんたい /一体全体/
いったいそんざい /一体存在/
いったいだれ /一体誰/
いったいてき /一体的/
いったいなに /一体何/
いったいなにもの /一体何者/
いったく /一卓/
いったん /一旦/一端/一短/一反/一たん/
いったんしゅうりょう /一旦終了/
いったんちゅうし /一旦中止/
いったんていし /一旦停止/
いったんでんげん /一端電源/
いったんもめん /一反木綿/
いっち /一致/
いっちせい /一致性/
いっちせいぎょ /一致制御/
いっちだんけつ /一致団結/
いっちてん /一致点/
いっちど /一致度/
いっちはんてい /一致判定/
いっちゃく /一着/
いっちゅう /一中/
いっちゅうや /一昼夜/
いっちょう /一朝/一長/一丁/一兆/一張/一聴/
いっちょういっせき /一朝一夕/
いっちょういったん /一長一短/
いっちょうめ /一丁目/１丁目/
いっちょうら /一張羅/
いっちょくせん /一直線/
いっちょくせんじょう /一直線上/
いっちょくせんてき /一直線的/
いっちょまえ /一丁前/
いっつい /一対/
いっついひかく /一対比較/
いっついひかくほう /一対比較法/
いっつう /一通/1通/
いっつうめ /一通目/
いっつうわ /一通話/
いって /一手/
いってい /一定/
いっていいか /一定以下/
いっていいじょう /一定以上/
いっていおんどいじょう /一定温度以上/
いっていかいてん /一定回転/
いっていかいてんすう /一定回転数/
いっていかく /一定角/
いっていかんかく /一定間隔/
いっていがく /一定額/
いっていがくいじょう /一定額以上/
いっていきかん /一定期間/
いっていきかんちょうさ /一定期間調査/
いっていきぼいじょう /一定規模以上/
いっていきょうど /一定強度/
いっていきょり /一定距離/
いっていきんがくたんい /一定金額単位/
いっていしゅうき /一定周期/
いっていしゅうはすう /一定周波数/
いっていじかん /一定時間/
いっていじかんいじょう /一定時間以上/
いっていじかんかんかく /一定時間間隔/
いっていじかんご /一定時間後/
いっていじかんない /一定時間内/
いっていすう /一定数/
いっていすういじょう /一定数以上/
いっていそくど /一定速度/
いっていち /一定値/
いっていていど /一定程度/
いっていねんげん /一定年限/
いっていはば /一定幅/
いっていふへん /一定不変/
いっていりつ /一定率/
いっていりょう /一定量/
いっていりょうきん /一定料金/
いってき /一滴/一擲/
いってつ /一徹/
いってん /一点/一転/1点/
いってんさ /一点差/
いってんさせん /一点鎖線/
いってんしゅうごう /一点集合/
いってんとうし /一点透視/
いってんとうしず /一点透視図/
いってんめ /一点目/
いってんろ /一点炉/
いっと /一途/一斗/
いっとう /一等/一党/一投/一頭/一刀/
いっとうこうかいし /一等航海士/
いっとうこく /一等国/
いっとうさい /一刀斉/
いっとうしょう /一等賞/
いっとうしん /一等親/
いっとうせい /一等星/
いっとうそく /一投足/
いっとうそつ /一等卒/
いっとうち /一等地/
いっとうどくさい /一党独裁/
いっとうへい /一等兵/
いっとうりょうだん /一刀両断/
いっとき /一時/
いっぱ /一派/
いっぱい /一杯/一敗/
いっぱいぶん /一杯分/
いっぱいほど /一杯程/
いっぱく /一泊/一拍/
いっぱくえんぱく /一泊延泊/
いっぱくふつか /一泊二日/
いっぱくめ /一拍目/
いっぱくりょこう /一泊旅行/
いっぱつ /一発/一髪/
いっぱつかいかんがた /一発快感型/
いっぱつがくしゅう /一発学習/
いっぱつぎゃくてん /一発逆転/
いっぱつけいそく /一発計測/
いっぱつげい /一発芸/
いっぱつしょうぶ /一発勝負/
いっぱつだい /一発台/
いっぱつだいぎゃくてん /一発大逆転/
いっぱつどり /一発録り/
いっぱつにはつ /一発二発/
いっぱつへんかん /一発変換/
いっぱつめ /一発目/
いっぱつや /一発屋/
いっぱつやろう /一発野郎/
いっぱつろくおん /一発録音/
いっぱん /一般/一版/一半/一班/
いっぱんいし /一般意思/
いっぱんうけ /一般受/一般受け/
いっぱんうんどうりょう /一般運動量/
いっぱんえいが /一般映画/
いっぱんえんだい /一般演題/
いっぱんか /一般化/
いっぱんかい /一般解/
いっぱんかいいん /一般会員/
いっぱんかいけい /一般会計/
いっぱんかいほうび /一般解放日/
いっぱんかがく /一般科学/
いっぱんかがくしょ /一般科学書/
いっぱんかく /一般角/
いっぱんかざひょう /一般化座標/
いっぱんかてい /一般家庭/
いっぱんかにゅうよう /一般加入用/
いっぱんかのうりょく /一般化能力/
いっぱんかばいあす /一般化バイアス/
いっぱんかもんだい /一般化問題/
いっぱんかりょく /一般化力/
いっぱんかんこうち /一般観光地/
いっぱんきぎょう /一般企業/
いっぱんきじゅん /一般基準/
いっぱんきゃく /一般客/
いっぱんきゃくしゃ /一般客車/
いっぱんきょういく /一般教育/
いっぱんきょういくぶ /一般教育部/
いっぱんきょうかい /一般境界/
いっぱんきょうそう /一般競争/
いっぱんきょうよう /一般教養/
いっぱんきょうようよう /一般教養用/
いっぱんぐんじん /一般軍人/
いっぱんけい /一般形/一般型/
いっぱんけいじじょうがく /一般形而上学/
いっぱんけんきゅう /一般研究/
いっぱんけんきゅうはっぴょう /一般研究発表/
いっぱんげんり /一般原理/
いっぱんこうえん /一般講演/
いっぱんこうえんしゃ /一般講演者/
いっぱんこうかい /一般公開/
いっぱんこうかいび /一般公開日/
いっぱんこうかいまえ /一般公開前/
いっぱんこうしゅうかいせん /一般公衆回線/
いっぱんこうそくどうろ /一般高速道路/
いっぱんこうつう /一般交通/
いっぱんこうどう /一般公道/
いっぱんこうどうよう /一般公道用/
いっぱんこくどう /一般国道/
いっぱんこくみん /一般国民/
いっぱんご /一般語/
いっぱんさつえい /一般撮影/
いっぱんさんか /一般参加/
いっぱんさんかしゃ /一般参加者/
いっぱんさんかしゃよう /一般参加者用/
いっぱんさんかよてい /一般参加予定/
いっぱんざい /一般材/
いっぱんざいげん /一般財源/
いっぱんざっし /一般雑誌/
いっぱんざひょう /一般座標/
いっぱんざひょうへんかん /一般座標変換/
いっぱんし /一般誌/
いっぱんしじょう /一般市場/一般誌上/
いっぱんしつもん /一般質問/
いっぱんしていせき /一般指定席/
いっぱんしはんかかく /一般市販価格/
いっぱんしみん /一般市民/
いっぱんしゃ /一般車/
いっぱんしゃいん /一般社員/
いっぱんしゃかい /一般社会/
いっぱんしゃしん /一般写真/
いっぱんしゃりょう /一般車両/
いっぱんしゅうゆうけん /一般周遊券/
いっぱんしゅふ /一般主婦/
いっぱんしょ /一般書/
いっぱんしょうひぜい /一般消費税/
いっぱんしょく /一般職/一般色/
いっぱんしょくじょし /一般職女子/
いっぱんしょせき /一般書籍/
いっぱんしょてん /一般書店/
いっぱんしょみん /一般庶民/
いっぱんしょもつ /一般書物/
いっぱんしよう /一般使用/
いっぱんじげん /一般次元/
いっぱんじこう /一般事項/
いっぱんじどう /一般児童/
いっぱんじゅうたく /一般住宅/
いっぱんじゅうみん /一般住民/
いっぱんじょうきゃく /一般乗客/
いっぱんじょうしき /一般常識/
いっぱんじょうせい /一般情勢/
いっぱんじょうほうばんぐみ /一般情報番組/
いっぱんじょうようしゃ /一般乗用車/
いっぱんじょせい /一般女性/
いっぱんじん /一般人/
いっぱんせい /一般性/
いっぱんせいかつ /一般生活/
いっぱんせいきょう /一般生協/
いっぱんせつび /一般設備/
いっぱんせつびひ /一般設備費/
いっぱんせんしゅ /一般選手/
いっぱんぜいしゅう /一般税収/
いっぱんそうたいせいりろん /一般相対性理論/
いっぱんそうたいろん /一般相対論/
いっぱんそく /一般則/
いっぱんたいしゅう /一般大衆/
いっぱんたいしょく /一般退職/
いっぱんだい /一般台/
いっぱんだんし /一般男子/
いっぱんち /一般値/
いっぱんちしき /一般知識/
いっぱんてき /一般的/
いっぱんてきかいしゃく /一般的解釈/
いっぱんてきけいこう /一般的傾向/
いっぱんてきけんかい /一般的見解/
いっぱんてきしよう /一般的使用/
いっぱんてきじょうしき /一般的常識/
いっぱんてきもんだい /一般的問題/
いっぱんてきりかい /一般的理解/
いっぱんてん /一般店/
いっぱんでんわよう /一般電話用/
いっぱんとうえい /一般投影/
いっぱんとうしか /一般投資家/
いっぱんとうろく /一般登録/
いっぱんどう /一般道/
いっぱんどうろ /一般道路/
いっぱんどくしゃ /一般読者/
いっぱんにほんじん /一般日本人/
いっぱんにゅうし /一般入試/
いっぱんにゅうじょう /一般入場/
いっぱんにゅうじょうけん /一般入場券/
いっぱんにゅうじょうしゃ /一般入場者/
いっぱんはっぴょう /一般発表/
いっぱんはつさんか /一般初参加/
いっぱんはつばい /一般発売/
いっぱんふか /一般不可/
いっぱんふきゅうせい /一般普及性/
いっぱんぶもん /一般部門/
いっぱんぶんれつそしき /一般分裂組織/
いっぱんほう /一般法/
いっぱんほうそく /一般法則/
いっぱんまどぐち /一般窓口/
いっぱんみんかんじん /一般民間人/
いっぱんむき /一般向/
いっぱんむけけいもうしょ /一般向啓蒙書/
いっぱんめい /一般名/
いっぱんめいし /一般名詞/
いっぱんめいしょう /一般名称/
いっぱんゆうりょうどうろ /一般有料道路/
いっぱんよう /一般用/
いっぱんようご /一般用語/
いっぱんようてびき /一般用手引/
いっぱんよやくかいし /一般予約開始/
いっぱんりょく /一般力/
いっぱんりょこう /一般旅行/
いっぱんりようしゃ /一般利用者/
いっぱんりようしゃむき /一般利用者向/
いっぱんりろん /一般理論/
いっぱんれっしゃ /一般列車/
いっぱんろ /一般路/
いっぱんろめん /一般路面/
いっぱんろん /一般論/
いっぱんろんてき /一般論的/
いっぱんろんぶん /一般論文/
いっぴ /１日/
いっぴき /一匹/
いっぴきおおかみ /一匹狼/
いっぴつ /一筆/
いっぴょう /一票/1票/
いっぴょういじょう /一票以上/
いっぴん /一品/逸品/
いっぷう /一風/一封/
いっぷく /一服/
いっぷたさいせい /一夫多妻制/
いっぷん /１分/1分/一分/
いっぷんいない /一分以内/
いっぷんかん /一分間/
いっぷんはんていど /一分半程度/
いっぺい /一平/
いっぺき /一碧/
いっぺん /一遍/一辺/一編/一片/一変/一篇/
いっぺんとう /一辺倒/
いっぽ /一歩/
いっぽう /一方/一報/一法/
いっぽうこう /一方行/
いっぽうつうこう /一方通行/
いっぽうつうこうきせい /一方通行規制/
いっぽうつうこうろ /一方通行路/
いっぽうてき /一方的/
いっぽうてききじ /一方的記事/
いっぽうてきすいろん /一方的推論/
いっぽぜんしん /一歩前進/
いっぽてまえ /一歩手前/
いっぽまえ /一歩前/
いっぽん /一本/
いっぽんあし /一本足/
いっぽんあしだほう /一本足打法/
いっぽんか /一本化/
いっぽんさ /一本鎖/
いっぽんしょうぶ /一本勝負/
いっぽんすぎ /一本杉/
いっぽんすじ /一本筋/
いっぽんせん /一本線/
いっぽんぜおい /一本背負/一本背負い/
いっぽんだち /一本立ち/
いっぽんばし /一本橋/
いっぽんぶん /一本分/
いっぽんまつ /一本松/
いっぽんみち /一本道/
いっぽんめ /一本目/
いっぽんやり /一本槍/
いつ /何時/逸/溢/一/壱/乙/五/伍/弌/佚/壹/聿/軼/鎰/鴪/
いつう /胃痛/
いつお /逸生/
いつか /５日/五日/不知/5日/
いつかいち /五日市/
いつかいちかいどう /五日市街道/
いつかいちせん /五日市線/
いつき /五木/樹/五紀/五月/
いつきだ /五木田/
いつきひろゆき /五木寛之/
いつくしま /厳島/
いつこ /伊都子/
いつごろ /いつ頃/
いつざい /逸材/
いつだつ /逸脱/
いつちょうら /一張羅/
いつつ /五つ/５つ/5つ/
いつつばし /五橋/
いつはし /五橋/
いつぶつ /逸物/
いつみ /逸美/逸見/
いつわ /逸話/五輪/五和/
いつわり /偽り/
いづ /伊津/
いづつ /井筒/
いづつや /井筒屋/
いづはら /出原/厳原/
いづぶち /出渕/
いづれ /孰れ/何れ/
いて /射手/
いてき /夷狄/
いてざ /射手座/
いてん /移転/
いてんけいかく /移転計画/
いてんさき /移転先/
いてんまえ /移転前/
いで /井出/井手/出/出澤/
いでおろぎー /イデオロギー/
いでぐち /井手口/
いでさわ /出沢/出澤/
いでみつ /出光/
いでむら /出村/
いでん /遺伝/異伝/
いでんあるごりずむ /遺伝アルゴリズム/
いでんあんごう /遺伝暗号/
いでんがく /遺伝学/
いでんがくしゃ /遺伝学者/
いでんけん /遺伝研/
いでんし /遺伝子/
いでんしいじょう /遺伝子異常/
いでんしかいせき /遺伝子解析/
いでんしかんけい /遺伝子関係/
いでんしかんれん /遺伝子関連/
いでんしがく /遺伝子学/
いでんしきき /遺伝子危機/
いでんしげん /遺伝資源/
いでんしこうがく /遺伝子工学/
いでんしごうせい /遺伝子合成/
いでんしさいぼう /遺伝子細胞/
いでんしざ /遺伝子座/
いでんししっかん /遺伝子疾患/
いでんしじょうほう /遺伝子情報/
いでんしぜんたい /遺伝子全体/
いでんしそうさ /遺伝子操作/
いでんしちりょう /遺伝子治療/
いでんしてき /遺伝子的/
いでんしはいれつ /遺伝子配列/
いでんしひょうげん /遺伝子表現/
いでんじょうほう /遺伝情報/
いでんじょうほうぎんこう /遺伝情報銀行/
いでんじょうほうしょり /遺伝情報処理/
いでんせい /遺伝性/
いでんせいしっかん /遺伝性疾患/
いでんせいたいけんきゅう /遺伝生態研究/
いでんてき /遺伝的/
いでんてきえいきょう /遺伝的影響/
いでんてきげんいん /遺伝的原因/
いでんびょう /遺伝病/
いでんほうそく /遺伝法則/
いでんや /遺伝屋/
いと /意図/糸/伊都/絲/縷/
いとーよーかどう /イトーヨーカ堂/
いとい /糸井/
いといがわ /糸魚川/
いといがわし /糸魚川市/
いといがわせん /糸魚川線/
いといしげさと /糸井重里/
いとう /伊藤/伊東/以東/依投/
いとうえん /伊藤園/
いとうおんせん /伊東温泉/
いとうけん /伊藤研/
いとうし /伊東市/
いとうせん /伊東線/
いとうちゅう /伊藤忠/
いとうちゅうしょうじ /伊藤忠商事/
いとうちゅうねんりょう /伊藤忠燃料/
いとうはむ /伊藤ハム/
いとうまん /伊藤萬/
いとうや /伊東屋/
いとが /糸賀/
いとぐち /糸口/
いとぐるま /糸車/
いとこ /従兄弟/従姉妹/
いとさき /糸崎/
いとざき /糸崎/
いとしま /糸島/
いとじたい /意図自体/
いとたに /糸谷/
いとだ /糸田/
いとちゅう /伊藤忠/
いとてき /意図的/
いとてきぎゃくさつ /意図的虐殺/
いとでんわ /糸電話/
いとぬき /糸貫/
いとのこぎり /糸鋸/
いとふめい /意図不明/
いとへん /綱/
いとま /暇/
いとまき /糸巻/
いとまん /糸満/
いとまんせん /糸満線/
いとめ /糸目/厭目/
いとやま /糸山/
いど /井戸/緯度/
いどう /移動/異動/異同/
いどういち /移動位置/
いどううんよう /移動運用/
いどうかいし /移動開始/
いどうかいしび /移動開始日/
いどうかのう /移動可能/
いどうかんけい /移動関係/
いどうがた /移動型/
いどうきゃく /移動客/
いどうきょく /移動局/
いどうきょり /移動距離/
いどうきろく /移動記録/
いどうぐみ /異動組/
いどうけい /移動系/
いどうけんけつしゃ /移動献血車/
いどうこうひょう /移動公表/
いどうご /移動後/
いどうさき /移動先/異動先/
いどうさきさくせい /移動先作成/
いどうしき /移動式/
いどうしゃ /移動者/
いどうしゅうりょうび /移動終了日/
いどうしゅだん /移動手段/
いどうじ /移動時/
いどうじかん /移動時間/
いどうじき /移動時期/
いどうせい /移動性/
いどうそうさ /移動操作/
いどうそうち /移動装置/
いどうそくど /移動速度/
いどうそくどせってい /移動速度設定/
いどうたい /移動体/
いどうたいじょうほう /移動体情報/
いどうたいつうしん /移動体通信/
いどうたいでんわ /移動体電話/
いどうだな /移動棚/
いどうち /移動地/
いどうちゅう /移動中/
いどうつうしん /移動通信/
いどうつうしんぎじゅつ /移動通信技術/
いどうつうしんもう /移動通信網/
いどうていあん /移動提案/
いどうてじゅん /移動手順/
いどうとどけ /異動届/
いどうど /移動度/
いどうどうぎ /移動動議/
いどうは /移動派/
いどうはば /移動幅/
いどうはん /移動班/
いどうはんい /移動範囲/
いどうはんいへんこう /移動範囲変更/
いどうひ /移動費/
いどうひょう /移動票/
いどうび /移動日/
いどうぶったい /移動物体/
いどうへいきん /移動平均/
いどうほうこう /移動方向/
いどうほうほう /移動方法/
いどうほどう /移動歩道/
いどうまえ /移動前/
いどうめいれい /移動命令/
いどうもう /移動網/
いどうもと /移動元/
いどうもんだい /移動問題/
いどうゆうよきかん /移動猶予期間/
いどうよう /移動用/
いどうりゆう /移動理由/
いどうりょう /移動量/
いどうりょく /移動力/
いどうりょくひょう /移動力表/
いどがわ /井戸川/
いどけいど /緯度経度/
いどころ /居所/拠所/
いどたい /緯度帯/
いどばた /井戸端/
いどばたかいぎ /井戸端会議/
いどほうこう /緯度方向/
いな /否/稲/伊那/伊奈/稻/伊南/
いない /以内/稲井/
いなえ /稲枝/
いなお /稲尾/
いなおえき /稲生駅/
いなおか /稲岡/
いなか /田舎/
いなかしゅたい /田舎主体/
いなかしゅっしん /田舎出身/
いなかそば /田舎蕎麦/
いなかだて /田舎館/
いなかまち /田舎町/
いなかみち /田舎道/
いなかもの /田舎者/
いなかわ /稲川/
いながき /稲垣/
いながけ /稲掛;姓/
いながわ /稲川/猪名川/
いなき /稲城/稲木/
いなぎ /稲城/稲木/
いなぎし /稲城市/
いなげ /稲毛/
いなげえき /稲毛駅/
いなご /蝗/
いなさ /引佐/
いなさく /稲作/
いなさくでんらい /稲作伝来/
いなさくぶんか /稲作文化/
いなさぐん /引佐郡/
いなさやま /稲佐山/
いなざわ /稲沢/
いなしき /稲敷/
いなしろ /稲城/
いなしろしがわ /稲城市側/
いなず /稲津/
いなずま /稲妻/霆/稲光/
いなせ /粹/
いなだ /稲田/鰍/
いなち /稲地/
いなつき /稲築/
いなつぎ /稲継;姓/
いなづま /稲妻/
いななが /稲永/
いなにわ /稲庭/
いなの /稲野/
いなば /稲場/稲葉/因幡/
いなひさ /稲久/
いなぶ /稲武/
いなべ /員弁/
いなほ /稲穂/
いなみ /伊波/井波/稲美/印南/
いなみね /稲嶺/
いなむら /稲村/
いなもと /稲元/
いなもり /稲盛/稲森/
いなもりざいだん /稲盛財団/
いなよし /稲吉/
いなり /稲荷/
いなりこうじ /稲荷小路/
いなりだ /稲荷田/
いなりやま /稲荷山/
いなわしろ /猪苗代/
いなわしろこ /猪苗代湖/
いなん /以南/
いにしえ /古/古え/
いにしゃる /イニシャル/
いにゅう /移入/
いにん /委任/
いにんけいり /委任経理/
いにんけいりきん /委任経理金/
いにんじょう /委任状/
いにんとうち /委任統治/
いにんとうちりょう /委任統治領/
いぬ /犬/狗/戌/
いぬい /乾/犬井/
いぬかい /犬飼/
いぬかみ /犬上/
いぬがみ /犬神/
いぬがみぐん /犬上郡/
いぬがみけ /犬神家/
いぬごや /犬小屋/
いぬじに /犬死に/
いぬぞり /犬橇/
いぬつか /犬塚/
いぬなき /犬鳴/
いぬねこ /犬猫/
いぬは /犬派/
いぬぶえ /犬笛/
いぬぶし /犬伏/
いぬぼうさき /犬吠崎/
いぬまる /犬丸/
いぬやま /犬山/
いぬやまし /犬山市/
いぬやまじょう /犬山城/
いぬやまばし /犬山橋/
いね /稲/稻/伊根/禾/
いねか /イネ科/
いねかり /稲刈り/稲刈/
いねだ /稲田/
いねちょう /伊根町/
いねなが /稲永/
いねの /稲野/
いねみつ /稲光/
いねむり /居眠り/
いねもく /イネ目/Glumiflorae/Graminales/Poales/
いねん /為念/
いの /猪野/伊野/猪/井野/
いのうえ /井上/井之上/
いのうえようすい /井上陽水/
いのおか /猪岡/
いのかしら /井の頭/
いのかしらこうえん /井の頭公園/
いのかしらせん /井の頭線/
いのがしら /井の頭/
いのがしらこうえん /井の頭公園/
いのき /猪木/
いのくち /井口/
いのくま /猪熊/
いのぐち /井口/井ノ口/
いのさか /猪坂/
いのしかちょう /猪鹿蝶/
いのしし /猪/猯/豕/
いのししなべ /猪鍋/
いのした /井下/
いのせ /猪瀬/
いのだ /伊野田/
いのち /命/生命/
いのちづな /命綱/
いのちとり /命取り/
いのちびろい /命拾い/
いのはら /猪原/
いのべ /井ノ部/
いのま /猪摩/
いのまた /猪股/猪俣/
いのり /祷/
いのる /祷/
いはい /違背/位牌/
いはく /曰く/医博/
いはつ /遺髪/
いはら /伊原/庵原/井原/
いはらだ /居原田/
いはん /違反/
いはんこうい /違反行為/
いはんこうほしゃ /違反候補者/
いはんしゃ /違反車/違反者/
いはんしゃりょう /違反車両/
いはんじじつ /違反事実/
いはんないよう /違反内容/
いば /井場/伊庭/
いばく /帷幕/
いばしょ /居場所/
いばら /茨/荊/棘/
いばらき /茨木/茨城/
いばらきけん /茨城県/
いばらきてん /茨木店/
いばらきべん /茨城弁/
いばらぎ /茨城/
いばらぎえき /茨木駅/
いばらぎけん /茨城県/
いばらぎけんかつたし /茨城県勝田市/
いばらぎけんつちうらし /茨城県土浦市/
いばらぎけんない /茨城県内/
いばらぎけんほくぶ /茨城県北部/
いばらぎけんみん /茨城県民/
いばらぎし /茨木市/
いばらぎしゅっしん /茨城出身/
いばらぎだいがく /茨城大学/
いばらぎてん /茨木店/
いばらぎほうそう /茨城放送/
いばらももく /イバラモ目/Najadales/
いばん /異版/
いひょう /意表/違表/依憑/
いひょうき /異表記/
いひん /遺品/
いび /揖斐/依微/
いびがわ /揖斐川/
いびき /鼾/
いびしゃ /居飛車/
いふ /畏怖/依附/
いふう /威風/遺風/
いふうどうどう /威風堂々/
いふきょうだい /異父兄弟/
いふく /衣服/
いふくべ /伊福部/
いふごう /異符号/
いふしん /畏怖心/
いぶ /ＥＶＥ/伊武/慰撫/
いぶか /井深/
いぶき /息吹/伊吹/
いぶきやま /伊吹山/
いぶくろ /胃袋/
いぶしぎん /燻し銀/
いぶすき /指宿/
いぶすきおんせん /指宿温泉/
いぶすきせん /指宿線/
いぶすきまくらざきせん /指宿枕崎線/
いぶせ /井伏/
いぶつ /遺物/異物/
いぶり /胆振/
いぶん /異文/遺文/
いぶんか /異文化/
いぶんし /異分子/
いぷしろん /ε/
いぷしろんせんい /ε遷移/
いへき /胃壁/
いへや /伊平屋/
いへん /異変/
いべ /井部/
いべんと /イベント/
いべんとれつ /イベント列/
いほう /違法/異法/異方/異邦/彙報/
いほううんてんしゃ /違法運転者/
いほうかいぞう /違法改造/
いほうかいぞうき /違法改造機/
いほうかいぞうしゃ /違法改造車/
いほうかいぞうぶひん /違法改造部品/
いほうきじ /違法記事/
いほうきょく /違法局/
いほうこうい /違法行為/
いほうし /違法視/
いほうじょうたい /違法状態/
いほうじん /異邦人/
いほうせい /違法性/異方性/
いほうせんゆうぶつ /違法占有物/
いほうちゅうしゃ /違法駐車/
いほうちゅうしゃこうい /違法駐車行為/
いほうちゅうしゃしゃりょう /違法駐車車両/
いほうとうこう /違法投稿/
いほうとりつけ /違法取付/
いほうは /違法派/
いほうひん /違法品/
いほうようにんろん /違法容認論/
いほうろん /違法論/
いほく /以北/
いほん /異本/
いぼ /揖保/異母/疣/肬/贅/
いぼう /依傍/
いぼがわ /揖保川/
いま /今/居間/
いまい /今井/
いまいけ /今池/
いまいじょう /今以上/
いまいずみ /今泉/
いまいち /今一/今市/
いまいちど /今一度/
いまいちばん /今一番/
いまいっぽ /今一歩/
いまいで /今出/
いまいみき /今井美樹/
いまおか /今岡/
いまがね /今金/
いまがわ /今川/
いまがわやき /今川焼/
いまげんざい /今現在/
いまころ /今頃/
いまごろ /今頃/今ごろ/
いまさき /今崎/
いまさと /今里/
いまさら /今更/今さら/
いましがた /今し方/
いましばらく /今暫く/
いましま /今嶋/
いましめ /戒め/
いまじょう /今城/今庄/
いまず /今津/
いまずせん /今津線/
いまぜき /今関/
いまだ /未/今田/未だ/
いまだて /今立/
いまち /井街/
いまづ /今津/
いまづえき /今津駅/
いまづかん /今津間/
いまづほうめん /今津方面/
いまで /今出/
いまでがわ /今出川/
いまでがわどおり /今出川通り/
いまどき /今時/
いまなか /今仲/今中/
いまなが /今永/
いまに /今仁/
いまにし /今西/
いまはし /今橋/
いまはん /今半/
いまばやし /今林/
いまばり /今治/
いまひと /今仁/
いまひとつ /今一つ/
いまふう /今風/
いまふく /今福/
いまべっぷ /今別府/
いまべつ /今別/
いままで /今迄/今まで/
いまみや /今宮/
いまむら /今村/
いまや /今や/
いまやま /今山/
いまよう /今様/
いまよし /今吉/
いまり /伊万里/
いまりゅう /今流/
いまる /井丸/
いまわだい /今話題/
いまわの /忌野/
いみ /意味/
いみあい /意味合い/意味合/
いみかいしゃく /意味解釈/
いみかいせき /意味解析/
いみかんすう /意味関数/
いみきじゅつ /意味記述/
いみきそく /意味規則/
いみげんご /意味言語/
いみこうぞう /意味構造/
いみしょり /意味処理/
いみしん /意味深/
いみしんちょう /意味深長/
いみじょう /意味上/
いみず /射水/
いみちしき /意味知識/
いみてき /意味的/
いみてきひょうき /意味的表記/
いみてきりかい /意味的理解/
いみな /諱/
いみないよう /意味内容/
いみなし /意味無/
いみひょうげんけいしき /意味表現形式/
いみひょうげんちゅう /意味表現中/
いみふごう /意味符合/
いみふめい /意味不明/
いみふめいりょう /意味不明瞭/
いみめいはく /意味明白/
いみめいりょう /意味明瞭/
いみや /井宮/
いみょう /異名/
いみりょういき /意味領域/
いみろん /意味論/
いみろんてき /意味論的/
いみん /移民/
いみんきょく /移民局/
いみんぞく /異民族/
いむ /医務/諱/異夢/
いむた /伊牟田/
いむちょう /医務長/
いむら /井村/
いむらや /井村屋/
いむらやせいか /井村屋製菓/
いめーじ /イメージ/
いめい /違名/依命/異名/
いも /芋/薯/藷/
いもうと /妹/
いもうとふうふ /妹夫婦/
いもうとやく /妹役/
いもお /妹尾/
いもづる /芋蔓/
いもと /井本/井元/
いもに /芋煮/
いもにかい /芋煮会/
いもになべ /芋煮鍋/
いもの /鋳物/
いもむし /芋虫/
いももと /芋本/
いもようかん /芋羊羹/
いもり /井森/
いもん /慰問/
いや /嫌/厭/祖谷/彌/イヤ/
いやいや /嫌々/
いやおう /否応/
いやがさこ /伊屋ヶ迫/
いやがらせ /嫌がらせ/
いやき /嫌気/
いやく /意訳/違約/医薬/依約/
いやくきん /違約金/
いやくひん /医薬品/
いやくぶんぎょう /医薬分業/
いやけ /嫌気/
いやけい /祖谷渓/
いやし /鄙/
いやなが /彌永/
いやま /井山/
いやみ /厭味/嫌味/厭み/嫌み/
いゆう /畏友/
いよ /伊代/伊予/
いよいよ /愈々/愈/
いよう /異様/医用/威容/偉容/
いようがぞう /医用画像/
いようこうがく /医用工学/
いようこうぶんし /医用高分子/
いようせいみつこうがく /医用精密工学/
いような /異様な/
いよぎんこう /伊豫銀行/
いよく /意欲/
いよくさく /意欲作/
いよくてき /意欲的/
いよくてきはっぴょう /意欲的発表/
いよこ /伊代子/
いよし /伊予市/
いよじ /五代嗣/
いよたに /伊豫谷/
いよだ /伊與田/
いよてつ /伊予鉄/
いよてつどう /伊予鉄道/
いよほうじょう /伊予北条/
いよみしま /伊予三島/
いら /苛/
いらい /依頼/以来/
いらいげんこう /依頼原稿/
いらいしゃ /依頼者/
いらいしょ /依頼書/
いらいしん /依頼心/
いらいじょう /依頼状/
いらいせい /依頼制/
いらいたいしょく /依頼退職/
いらいちゅう /依頼中/
いらいにん /依頼人/
いらいひん /依頼品/
いらいもと /依頼元/
いらいら /イライラ/苛苛/苛々/
いらく /イラク/
いらくさ /蕁麻/
いらくさもく /イラクサ目/Urticales/
いらくさもくあぐん /イラクサ目亜群/
いらこ /伊良湖/
いらここう /伊良湖港/
いらこみさき /伊良湖岬/
いらすと /イラスト/
いらぶ /伊良部/
いらべ /伊良部/
いらんくう /囲卵腔/
いり /伊理/入/圦/杁/
いりあい /入会/
いりあいけん /入会権/
いりうち /入内/
いりうちじま /入内島/
いりえ /入江/入り江/
いりおもて /西表/
いりおもてじま /西表島/
いりかさやま /入笠山/
いりがい /入貝/
いりき /入来/
いりくち /入り口/
いりぐち /入口/入り口/
いりぐちがわ /入口側/
いりぐちふきん /入口付近/
いりぐちわき /入口脇/
いりぐに /入口/
いりさ /入佐/
いりさわ /入澤/
いりた /入田/
いりたはま /入田浜/
いりなか /杁中/
いりの /入野/
いりひ /入り日/
いりふね /入船/入り船/
いりまじり /入交/
いりまち /入り待ち/
いりまめ /煎豆/
いりもや /入母屋/
いりや /入谷/
いりやま /入山/
いりゅう /慰留/遺留/移流/
いりゅうひん /遺留品/
いりょう /医療/衣料/衣糧/
いりょういがい /医療以外/
いりょういっぱん /医療一般/
いりょうかんけい /医療関係/
いりょうかんけいしゃ /医療関係者/
いりょうきかん /医療機関/
いりょうきき /医療機器/
いりょうきぐ /医療器具/
いりょうぎじゅつ /医療技術/
いりょうぎょうせい /医療行政/
いりょうげんば /医療現場/
いりょうこうい /医療行為/
いりょうこうがく /医療工学/
いりょうしせつ /医療施設/
いりょうしょち /医療処置/
いりょうしんだん /医療診断/
いりょうじゅうじしゃ /医療従事者/
いりょうせいど /医療制度/
いりょうせいひん /衣料製品/医療製品/
いりょうせん /医療船/
いりょうそうだん /医療相談/
いりょうそうだんてき /医療相談的/
いりょうそうだんまどぐち /医療相談窓口/
いりょうそくてい /医療測定/
いりょうたんきだいがく /医療短期大学/
いりょうたんきだいがくぶ /医療短期大学部/
いりょうてきこうさつ /医療的考察/
いりょうてんすう /医療点数/
いりょうひ /医療費/
いりょうひぜんたい /医療費全体/
いりょうひふたん /医療費負担/
いりょうひん /衣料品/医療品/
いりょうひんてん /衣料品店/
いりょうふくし /医療福祉/
いりょうふたん /医療負担/
いりょうぶ /医療部/
いりょうほう /医療法/
いりょうほうしゅう /医療報酬/
いりょうほけんせいど /医療保険制度/
いりょうもくてき /医療目的/
いりょうもんだい /医療問題/
いりょうよう /医療用/
いりょく /威力/
いりょくぎょうむぼうがい /威力業務妨害/
いりよう /入用/
いるーじょん /イルージョン/
いるい /衣類/異類/
いるいがっちゃく /異類合着/
いるか /海豚/イルカ/鯆/
いるす /居留守/
いるま /入間/
いるまがわ /入間川/
いるまし /入間市/
いるましていしゃ /入間市停車/
いれ /入れ/
いれい /異例/慰霊/
いれいさい /慰霊祭/
いれいひ /慰霊碑/
いれかえ /入れ換え/入替/入換/
いれかえせん /入替戦/
いれかえよう /入換用/
いれかた /入れ方/
いれこ /入れ子/入籠/
いれこみ /入込/
いれこみすう /入込数/
いれずみ /刺青/
いれちがい /入れ違い/
いれぢえ /入れ知恵/
いれて /入れて/
いれば /入れ歯/
いれもの /入れ物/容れ物/
いろ /色/艷/
いろあい /色合い/色合/色相/
いろいがい /色以外/
いろいろ /色々/色いろ/色色/
いろう /慰労/遺漏/
いろうかい /慰労会/
いろうきん /慰労金/
いろえんぴつ /色鉛筆/
いろおち /色落ち/
いろおとこ /色男/
いろおび /色帯/
いろおんど /色温度/
いろか /色香/
いろかず /色数/
いろかわ /色川/
いろかんけい /色関係/
いろがみ /色紙/
いろきろく /色記録/
いろくうかん /色空間/
いろぐろ /色黒/
いろけ /色気/
いろこい /色恋/
いろこうじょうせい /色恒常性/
いろさいげん /色再現/
いろさいげんせい /色再現性/
いろしきべつばんごう /色識別番号/
いろしてい /色指定/
いろしんごう /色信号/
いろしんごうしょり /色信号処理/
いろしんごうせいぶん /色信号成分/
いろじょうほう /色情報/
いろじろ /色白/
いろすう /色数/
いろずり /色刷/色刷り/
いろたいおう /色対応/
いろづけ /色付/
いろどり /彩/
いろはいち /色配置/
いろはんてん /色反転/
いろばんごう /色番号/
いろひょうじ /色表示/
いろふごう /色符号/
いろふごうか /色符号化/
いろぶんかい /色分解/
いろぶんかいき /色分解機/
いろほうしき /色方式/
いろほせい /色補正/
いろみほん /色見本/
いろめ /色目/
いろめい /色名/
いろめがね /色眼鏡/
いろもの /色物/
いろり /囲炉裏/鑪/鈩/
いろわけ /色分け/色分/
いろん /異論/
いろんな /色んな/
いわ /岩/違和/磐/巖/
いわい /祝/磐井/岩井/岩韋/
いわいごと /祝事/
いわいずみ /岩泉/
いわいはら /岩井原/
いわうち /岩内/
いわうめもく /Diapensiales/イワウメ目/
いわお /巌/岩男/岩夫/岩雄/磐/巖/岩尾/岩生/
いわおおじ /岩大路/
いわおか /岩岡/
いわかげ /岩陰/
いわかみ /岩上/
いわかめ /岩亀/
いわかわ /岩川/
いわかん /違和感/異和感/
いわき /岩城/磐城/岩木/岩鬼/
いわきさん /岩木山/
いわきじ /磐城路/
いわきり /岩切/
いわぎ /岩城/
いわく /曰/曰く/
いわくに /岩国/
いわくま /岩熊/
いわくら /岩倉/岩鞍/
いわさ /岩佐/
いわさき /岩崎/
いわさききょうこ /岩崎恭子/
いわさきしょてん /岩崎書店/
いわさきつうしん /岩崎通信/
いわさきでんき /岩崎電気/
いわさわ /岩沢/
いわし /鰯/鰮/鰛/
いわした /岩下/
いわしたしま /岩下志麻/
いわしみず /岩清水/
いわしみづ /岩清水/
いわしろ /岩城/岩代/
いわせ /岩瀬/
いわた /岩田/磐田/
いわたき /岩滝/
いわたけ /岩岳/
いわたし /磐田市/
いわたしえいきゅうじょう /磐田市営球場/
いわたしがい /磐田市街/
いわたしみんぶんかかいかん /磐田市民文化会館/
いわたに /岩谷/
いわたや /岩田屋/
いわだけ /岩岳/
いわつう /岩通/
いわつか /岩塚/
いわつき /岩月/岩槻/
いわて /岩手/
いわてけん /岩手県/
いわてけんみやこわん /岩手県宮古湾/
いわてけんみんかいかん /岩手県民会館/
いわてこうげん /岩手高原/
いわてしゅっしん /岩手出身/
いわてだいがく /岩手大学/
いわてほうそう /岩手放送/
いわてんじょう /岩天井/
いわで /岩出/
いわでやま /岩出山/
いわと /岩戸/磐戸/
いわとくせん /岩徳線/
いわど /岩戸/
いわな /岩魚/
いわない /岩内/
いわないこう /岩内港/
いわなみ /岩波/岩浪/
いわなみえき /岩波駅/
いわなみこうざ /岩波講座/
いわなみこくごじてん /岩波国語辞典/
いわなみしょてん /岩波書店/
いわなみしんしょ /岩波新書/
いわなみじしょ /岩波辞書/
いわなみすうがくじてん /岩波数学辞典/
いわなみぜんしょ /岩波全書/
いわなみばん /岩波版/
いわなみばんじしょ /岩波版辞書/
いわなみぶんこ /岩波文庫/
いわなみぶんこばん /岩波文庫版/
いわなみやく /岩波訳/
いわにちきたせん /岩日北線/
いわにちせん /岩日線/
いわぬま /岩沼/
いわぬまし /岩沼市/
いわぬまや /岩沼屋/
いわね /岩根/
いわの /岩野/
いわはし /岩橋/
いわはだ /岩肌/
いわはら /岩原/
いわば /岩場/謂わば/言わば/
いわばやし /岩林/
いわひろ /岩廣/
いわふね /岩船/岩舟/
いわぶち /岩渕/岩淵/
いわほり /岩堀/
いわま /岩間/
いわまつ /岩松/
いわみ /岩美/石見/
いわみさわ /岩見沢/
いわみざわ /岩見沢/
いわみだ /岩見田/
いわむら /岩村/
いわむろ /岩室/
いわもと /岩本/
いわや /岩屋/岩谷/窟/
いわやま /岩山/
いわゆる /所謂/
いん /印/院/員/引/音/韻/因/陰/隠/飲/隕/蔭/胤/淫/姻/允/咽/堙/婬/尹/廴/慇/飮/殞/殷/氤/湮/茵/蚓/贇/酳/隱/霪/韵/
いんい /陰萎/因依/
いんうつ /陰鬱/
いんえい /陰影/印影/陰翳/
いんおうご /印欧語/
いんか /印加/引火/陰窩/
いんかか /隠花果/
いんかく /陰核/
いんかしょくぶつ /隠花植物/
いんかせい /引火性/
いんかてん /引火点/
いんかでんあつ /印加電圧/
いんかろん /因果論/
いんかん /印鑑/
いんかんしょうめい /印鑑証明/
いんかんしょうめいなど /印鑑証明等/
いんかんすう /陰関数/
いんかんせいぞうぎょう /印鑑製造業/
いんかんとうろく /印鑑登録/
いんかんや /印鑑屋/
いんが /因果/印画/陰画/
いんがい /院外/
いんがおうほう /因果応報/
いんがかんけい /因果関係/
いんがけっていろん /因果決定論/
いんがし /印画紙/
いんがしじょう /印画紙上/
いんがじょう /印画上/
いんがせい /因果性/
いんがてき /因果的/
いんがてきけっか /因果的結果/
いんがりつ /因果律/
いんき /陰気/
いんきょ /隠居/殷墟/
いんきょく /陰極/
いんきょくかん /陰極管/
いんきょくきんぼう /陰極近傍/
いんきょくせん /陰極線/
いんぎ /院議/
いんぎゃく /淫虐/
いんぎょう /印形/隠形/
いんぎん /慇懃/
いんぎんぶれい /慇懃無礼/
いんく /インク/
いんぐらんど /英蘭/
いんけい /陰茎/
いんけん /陰険/引見/隠顕/
いんげん /隠元/
いんこ /鸚哥/インコ/
いんこう /淫行/咽喉/淫荒/
いんご /隠語/
いんごう /因業/
いんさつ /印刷/
いんさついち /印刷位置/
いんさつかのうもじ /印刷可能文字/
いんさつかんじ /印刷漢字/
いんさつがいしゃ /印刷会社/
いんさつき /印刷機/
いんさつきのう /印刷機能/
いんさつぎじゅつ /印刷技術/
いんさつぎょうかい /印刷業界/
いんさつけいしき /印刷形式/
いんさつけいひ /印刷経費/
いんさつけっか /印刷結果/
いんさつげんこう /印刷原稿/
いんさつしつ /印刷室/
いんさつしゅっぱん /印刷出版/
いんさつしゅつりょく /印刷出力/
いんさつしょ /印刷所/
いんさつじ /印刷時/
いんさつじゅつ /印刷術/
いんさつじょ /印刷所/
いんさつせいはんき /印刷製版機/
いんさつそうち /印刷装置/
いんさつそくど /印刷速度/
いんさつたい /印刷体/
いんさつたいしょう /印刷対象/
いんさつだい /印刷代/
いんさつていさい /印刷体裁/
いんさつはんい /印刷範囲/
いんさつばいたい /印刷媒体/
いんさつひ /印刷費/
いんさつぶすう /印刷部数/
いんさつぶつ /印刷物/
いんさつほうほう /印刷方法/
いんさつまいすう /印刷枚数/
いんさつもじ /印刷文字/
いんさつもじにんしき /印刷文字認識/
いんさつや /印刷屋/
いんさつよう /印刷用/
いんさつようげんこう /印刷用原稿/
いんさつようご /印刷用語/
いんさつようし /印刷用紙/
いんさん /陰惨/
いんざい /印西/
いんし /院試/因子/印紙/淫祠/淫祀/
いんしか /因子化/
いんしぜい /印紙税/
いんしだい /印紙代/
いんしつ /陰湿/
いんしぶんせき /因子分析/
いんしぶんせきほう /因子分析法/
いんしゅ /飲酒/
いんしゅう /因襲/因習/
いんしゅうてき /因襲的/
いんしゅうんてん /飲酒運転/
いんしゅきんし /飲酒禁止/
いんしゅふか /飲酒不可/
いんしゅりつ /飲酒率/
いんしょう /印象/印章/
いんしょうてき /印象的/
いんしょうど /印象度/
いんしょうは /印象派/
いんしょく /飲食/
いんしょくぎょう /飲食業/
いんしょくだい /飲食代/
いんしょくてん /飲食店/
いんしょくてんがい /飲食店街/
いんしょくぶつ /飲食物/
いんしん /陰唇/殷賑/
いんじ /印字/
いんじいち /印字位置/
いんじかのう /印字可能/
いんじかんきょう /印字環境/
いんじくろっく /印字クロック/
いんじけーた /インジケータ/
いんじけっか /印字結果/
いんじしゅつりょく /印字出力/
いんじしょたい /印字書体/
いんじそくど /印字速度/
いんじどうさ /印字動作/
いんじのうど /印字濃度/
いんじはば /印字幅/
いんじひょうげん /印字表現/
いんじひんしつ /印字品質/
いんじほうしき /印字方式/
いんじほしょう /印字保証/
いんじみつど /印字密度/
いんじめい /印字名/
いんじゃ /隠者/
いんじゅう /陰獣/
いんじゅん /因循/
いんじれい /印字例/
いんすう /因数/引数/員数/
いんすうぶんかい /因数分解/
いんすうれつ /引数列/
いんすたんす /インスタンス/
いんすたんと /インスタント/
いんすとーる /インストール/
いんずう /員数/
いんせい /院生/陰性/院政/隠棲/
いんせいけんきゅうしつ /院生研究室/
いんせいしつ /院生室/
いんせいぜんたい /院生全体/
いんせき /隕石/引責/姻戚/殞石/
いんせきかんけい /姻戚関係/
いんせん /陰線/隠線/
いんぜい /印税/
いんぜいしゅうにゅう /印税収入/
いんぜみ /院ゼミ/
いんぜみしりょう /院ゼミ資料/
いんぜん /隠然/
いんそつ /引率/院卒/
いんそつきょうし /引率教師/
いんたーせぷと /インターセプト/
いんたーちぇんじ /インターチェンジ/
いんたーなる /インターナル/
いんたーねっと /インターネット/
いんたーばる /インターバル/
いんたーふぇーす /インターフェース/
いんたい /引退/隠退/
いんたいあいさつ /引退挨拶/
いんたいご /引退後/
いんたいしき /引退式/
いんたいじ /引退時/
いんたいじあい /引退試合/
いんたいじょゆう /引退女優/
いんたいずもう /引退相撲/
いんたいせつ /引退説/
いんたいせんげん /引退宣言/
いんたいひょうめい /引退表明/
いんたいまえ /引退前/
いんたせぷと /インタセプト/
いんたびゅー /インタビュー/
いんたらくしょん /インタラクション/
いんだすとり /インダストリ/
いんち /吋/インチ/
いんちょう /院長/
いんてりあ /インテリア/
いんてん /院展/
いんでぃあん /インディアン/
いんでぃけーた /インディケータ/
いんでっくす /インデックス/
いんでんと /インデント/
いんとう /咽頭/淫蕩/
いんとうえん /咽頭炎/
いんとく /隠匿/
いんとくざい /隠匿罪/
いんとねーしょん /イントネーション/
いんとん /隠遁/
いんど /印度/
いんどう /引導/
いんどじん /印度人/
いんどよう /インド洋/
いんない /院内/印内/
いんないかんせん /院内感染/
いんなみ /印南/
いんに /陰に/因位/
いんにく /印肉/
いんにゅうし /院入試/
いんねん /因縁/
いんのう /陰嚢/
いんのしま /因島/
いんば /印旛/
いんばい /淫売/
いんばぐん /印旛郡/
いんばぬま /印旛沼/
いんぱくと /インパクト/
いんぱるすおうとう /インパルス応答/
いんび /淫靡/
いんびさ /淫靡さ/
いんびせん /因美線/
いんふるえんざ /インフルエンザ/
いんふれ /インフレ/
いんぶ /陰部/
いんぶん /韻文/
いんぷくかんすう /陰伏関数/
いんぷっと /インプット/
いんべん /員弁/
いんぺい /隠蔽/
いんぺいかん /隠蔽艦/
いんぺいし /隠蔽子/
いんぺいりょく /隠蔽力/
いんぼう /陰謀/
いんめい /因明/
いんめつ /湮滅/隠滅/
いんめん /隠面/
いんめんしょうきょ /隠面消去/
いんもう /陰毛/
いんゆ /隠喩/
いんゆぶん /隠喩文/
いんよう /引用/飲用/陰陽/
いんよういがい /引用以外/
いんようか /引用可/
いんようかいし /引用開始/
いんようきごう /引用記号/
いんようきじ /引用記事/
いんようきょか /引用許可/
いんようぎょう /引用行/
いんようさんしょう /引用参照/
いんようし /引用始/
いんようしゅうりょう /引用終了/
いんようしょ /引用書/
いんようじ /引用時/
いんようじゅん /引用順/
いんようすい /飲用水/
いんようちゅう /引用中/
いんようふ /引用符/
いんようふか /引用不可/
いんようぶ /引用部/
いんようぶぶん /引用部分/
いんようぶん /引用文/
いんようぶんけん /引用文献/
いんようぶんちゅう /引用文中/
いんようほうほう /引用方法/
いんようもと /引用元/
いんようれい /引用例/
いんらん /淫乱/
いんりつ /韻律/
いんりょう /飲料/
いんりょうすい /飲料水/
いんりょうよう /飲料用/
いんりょく /引力/
いんりょくけん /引力圏/
いんりょくけんだっしゅつ /引力圏脱出/
いんれい /引例/
いんれき /陰暦/
いんれつ /陰裂/
いんろう /印籠/印篭/
いんわい /淫猥/
う /雨/右/有/鵜/宇/迂/羽/卯/烏/于/生/禹/傴/夘/嫗/挧/盂/紆/饂/齲/芋/胡/兎/菟/得/
うーはん /武漢/
うーふぁ /ウーファ/
うーまん /ウーマン/
うーろん /烏龍/
うーろんちゃ /烏龍茶/
うぃーく /ウィーク/
うぃーん /維納/
うぃじぇっと /ウィジェット/
うぃり /干莉/
うぃるす /ウィルス/
うぃんず /ウィンズ/
うぃんど /ウィンド/
うぃんどう /ウィンドウ/
うい /初/有為/宇井;姓/
ういういしい /初々しい/
ういきょう /茴香/
ういざん /初産/
ういじん /初陣/
ういすきー /ウイスキー/
ういち /宇一/
ういてんぺん /有為転変/
ういるす /ウイルス/
ういろう /外郎/
ういんく /ウインク/
ういんぐす /ウイングス/
ううろんちゃ /烏龍茶/
うぇい /ウェイ/
うぇるたーきゅう /ウェルター級/
うえ /上/↑/植/飢え/
うええだ /上枝/
うえおか /植岡/
うえがはら /上ヶ原/
うえがめん /上画面/
うえがわ /上側/
うえき /植木/植え木/
うえきぐみ /植木組/
うえきばち /植木鉢/植え木鉢/
うえきや /植木屋/
うえくさ /植草/
うえくぼ /上窪/
うえこみ /植え込み/
うえさか /上坂/
うえさま /上様/
うえさんかく /上三角/
うえさんかくぎょうれつ /上三角行列/上3角行列/
うえしき /上式/
うえした /上下/
うえしば /植芝/
うえしま /上島/
うえじに /餓死/
うえす /上江洲/上須/
うえすぎ /上杉/
うえすぎけんしん /上杉謙信/
うえすぎてるとら /上杉輝虎/
うえすぎまさとら /上杉政虎/
うえぞの /上園/
うえた /植田/
うえたけ /植竹/
うえたに /上谷/
うえだ /上田/植田/
うえだし /上田市/
うえちゅうだん /上中段/
うえつ /羽越/
うえつせん /羽越線/
うえつせんほうめん /羽越線方面/
うえつほうめん /羽越方面/
うえつほんせん /羽越本線/
うえづけ /上付/
うえなか /植中/
うえにし /上西/
うえの /上野/植野/
うえのあおもりかん /上野青森間/
うえのいき /上野行/
うえのえき /上野駅/
うえのえきしゅうへん /上野駅周辺/
うえのえきまえてん /上野駅前店/
うえのかん /上野間/
うえのがくえん /上野学園/
うえのぐち /上野口/
うえのこうえん /上野公園/
うえのし /上野市/
うえのちかえき /上野地下駅/
うえのちゃく /上野着/
うえのちょくつう /上野直通/
うえのてん /上野店/
うえのどうぶつえん /上野動物園/
うえのはつ /上野発/
うえのはら /上野原/
うえのひろこうじ /上野広小路/
うえのゆき /上野行/
うえは /ウエハ/
うえはま /上浜/
うえはら /上原/植原/
うえはらせい /上原成/
うえはんぶん /上半分/
うえひら /植平/
うえほうこう /上方向/
うえほんまち /上本町/
うえほんまちろくちょうめ /上本町六丁目/
うえまち /上町/
うえまつ /植松/上松/
うえむき /上向き/
うえむら /植村/上村/
うえもと /植本/
うえもり /上森/
うえもん /右衛門/
うえや /↑/
うえやじるし /上矢印/
うえやま /上山/
うえろく /上本町六丁目/
うえん /迂遠/
うぉーみんぐ /ウォーミング/
うぉーむ /ウォーム/
うお /魚/宇夫/
うおい /魚井/
うおいちば /魚市場/
うおうさおう /右往左往/
うおがし /魚河岸/
うおごころ /魚心/
うおざ /魚座/
うおざき /魚崎/
うおざききたちょう /魚崎北町/
うおざききたまち /魚崎北町/
うおしま /魚島/
うおずみ /魚住/
うおせ /魚瀬/
うおっちんぐ /ウオッチング/
うおつか /魚塚/
うおづ /魚津/
うおづし /魚津市/
うおぬま /魚沼/
うおみ /魚見/
うおみつ /魚光/
うおや /魚屋/
うか /羽化/
うかい /迂回/鵜飼/
うかいうんてん /迂回運転/
うかいうんてんじ /迂回運転時/
うかいうんてんちゅう /迂回運転中/
うかいくかん /迂回区間/
うかいじょうしゃくかん /迂回乗車区間/
うかいろ /迂回路/
うかいろせん /迂回路線/
うかがい /伺/窺/
うかじ /宇梶/
うかつ /迂闊/迂濶/
うかれめ /浮かれ女/
うかん /有漢/
うがい /鵜飼/嗽/
うがん /右眼/右岸/
うき /雨期/浮/右記/雨季/
うき> /浮/
うきあし /浮足/
うきえ /浮江/
うきがや /浮ヶ谷/
うきくさ /浮草/
うきくさるい /浮草類/
うきぐ /浮具/
うきぐも /浮雲/
うきしずみ /浮き沈み/
うきしま /浮島/
うきた /浮田/
うきな /浮名/
うきはし /浮橋/
うきばし /浮橋/
うきふね /浮舟/浮船/
うきぶくろ /浮袋/鰾/
うきぼり /浮き彫り/
うきみ /浮き身/浮身/憂き身/
うきめ /憂き目/
うきょう /右京/
うきよ /浮世/憂き世/
うきよえ /浮世絵/
うきよえびじゅつかん /浮世絵美術館/
うきわ /浮輪/
うく /宇久/
うくらいな /烏克蘭/
うぐい /鯏/
うぐいす /鶯/鴬/
うぐいすざわ /鶯沢/鴬沢/
うぐいすだに /鴬谷/
うぐいすだにえき /鶯谷駅/
うけい /右傾/
うけいれ /受入/受け入れ/
うけうり /受け売り/
うけおい /請負/
うけおいぎょう /請負業/
うけおいにん /請負人/
うけかた /受け方/
うけがわ /受け側/
うけくち /受け口/
うけぐち /受け口/受口/
うけこたえ /受け答え/
うけごし /受け腰/
うけざら /受け皿/
うけしょ /受書/請書/
うけつけ /受付/受け付け/受付け/
うけつけかいし /受付開始/
うけつけきかん /受付期間/
うけつけきげん /受付期限/
うけつけじかん /受付時間/
うけつけじょう /受付嬢/
うけつけちゅう /受付中/
うけつけねんがっぴ /受付年月日/
うけつけばんごう /受付番号/
うけつけび /受付日/
うけて /受け手/
うけてしゅどう /受け手主導/
うけとり /受取/受け取り/
うけとりかた /受け取り方/
うけとりかのう /受取可能/
うけとりがわ /受取側/受け取り側/
うけとりきょひ /受取拒否/
うけとりご /受取後/
うけとりて /受け取り手/
うけとりてがた /受取手形/
うけとりにん /受取人/
うけにぬし /受荷主/
うけにん /請人/
うけはらい /受払い/
うけばらい /受け払い/
うけみ /受身/受け身/
うける /受ける/
うけわたし /受渡し/受け渡し/受渡/
うけわたしほうほう /受渡方法/
うけん /宇検/
うげん /迂言/右舷/
うこう /宇高/
うこうけん /宇航研/
うこうこくどう /宇高国道/
うこうれんらくせん /宇高連絡船/
うこさべん /右顧左眄/
うこん /鬱金/
うご /羽後/雨後/
うごう /烏合/
うごき /動き/
うごほんじょう /羽後本庄/
うさ /宇佐/右左/憂さ/
うさがわ /宇佐川/
うさぎ /兎/菟/兔/莵/
うさぎごや /兎小屋/
うさぎだいら /兎平/
うさこうじょう /宇佐工場/
うさせつ /右左折/
うさせつしゃ /右左折車/
うさみ /宇佐見/宇佐美/宇沙美/
うさわ /宇沢/
うさん /胡散/
うさんくさい /胡散臭い/
うざき /宇崎/
うざわ /宇沢/鵜沢/鵜澤/
うし /牛/丑/
うしお /潮/牛尾/
うしおしゅっぱん /潮出版/
うしおしゅっぱんしゃ /潮出版社/
うしおだ /潮田/
うしおだけん /潮田研/
うしおでんき /ウシオ電機/
うしかい /牛飼い/牛飼/
うしき /牛木/
うしく /牛久/
うしくぬま /牛久沼/
うしごめ /牛込/
うしごめやなぎちょう /牛込柳町/
うしじま /牛島/牛嶋/
うしじろう /牛次郎/
うした /牛田/
うしづ /牛津/
うしね /牛根/
うしの /牛野/
うしぶか /牛深/
うしぼり /牛堀/
うしまど /牛窓/
うしまる /牛丸/
うしみつ /丑三つ/
うしょう /鵜匠/
うしろ /後/後ろ/
うしろあし /後ろ足/
うしろかわ /後川/
うしろがみ /後髪/
うしろがわ /後側/
うしろすがた /後ろ姿/後姿/
うしろだて /後ろだて/後ろ盾/
うしろで /後ろ手/
うしろはんぶん /後半分/
うしろほうこう /後方向/
うしろまわしげり /後ろ廻し蹴り/
うしろみ /後見/
うしろむき /後ろ向き/後向き/
うしろめ /後目/
うしろゆび /後ろ指/
うしわかまる /牛若丸/
うしわた /牛渡/
うしんしつ /右心室/
うしんふぜん /右心不全/
うじ /氏/宇治/蛆/
うじいえ /氏家/
うじがわ /宇治川/
うじがわきょうりょう /宇治川橋梁/
うじきんとき /宇治金時/
うじさと /氏郷/
うじし /宇治市/
うじすじょう /氏素姓/氏素性/
うじせん /宇治線/
うじな /宇品/
うじはら /氏原/
うじむし /蛆虫/
うじやまだ /宇治山田/
うじやまだせん /宇治山田線/
うじょう /雨上/羽状/鵜匠/
うじょうふくよう /羽状複葉/
うじょうみゃく /羽状脈/
うす /薄/臼/碓/有珠/
うすあおいろ /薄青色/
うすあじ /薄味/
うすい /臼井/碓氷/薄井/雨水/碓井/
うすいえき /臼井駅/
うすいた /薄板/
うすいとうげ /碓氷峠/
うすいまち /碓井町/
うすうす /薄々/
うすがた /薄型/
うすがたか /薄型化/
うすがみ /薄紙/
うすき /薄/臼杵/
うすきいろ /薄黄色/
うすきし /臼杵市/
うすぎ /薄着/
うすぎり /薄切り/
うすくちしょうゆ /薄口醤油/
うすぐも /薄雲/
うすぐもり /薄曇/うす曇り/
うすげしょう /薄化粧/
うすじ /薄地/
うすじお /薄塩/
うすた /薄田/
うすだ /臼田/
うすちゃ /薄茶/
うすちゃいろ /薄茶色/
うすで /薄手/
うすば /薄葉/
うすび /薄日/
うすべに /薄紅/
うすべにいろ /薄紅色/
うすまく /薄膜/
うすみどりいろ /薄緑色/
うすめ /薄目/
うすももいろ /薄桃色/
うすやみ /薄闇/
うすらばか /薄ら馬鹿/
うず /渦/右図/
うずい /渦位/
うずき /宇津木/
うずでんりゅう /渦電流/
うずど /渦度/
うずどほうていしき /渦度方程式/
うずどほぞんそく /渦度保存則/
うずの /鶉野/
うずば /渦場/
うずまき /渦巻き/渦巻/
うずまきもよう /渦巻模様/
うずゆそう /渦輸送/
うずら /鶉/
うせつ /右折/
うせつさせつ /右折左折/
うせつしゃ /右折車/
うせつしゃかいひ /右折車回避/
うせつしゃせん /右折車線/
うせつやじるし /右折矢印/
うせつやじるししんごう /右折矢印信号/
うせんけい /右線形/
うぜん /羽前/
うぜんちとせ /羽前千歳/
うそ /嘘/ウソ/鷽/嘯/
うそうそ /嘘々/
うそく /右側/
うそつき /嘘つき/
うそはっけんき /嘘発見器/嘘発見機/
うそはっぴゃく /嘘八百/
うぞうむぞう /有象無象/
うた /歌/唄/詩/謌/宇田/謳/
うたい /謡/謠/
うたいかた /歌い方/
うたいがい /歌以外/
うたいもんく /歌文句/謡い文句/謳文句/
うたいり /歌入り/
うたえもん /歌右衛門/
うたかい /歌会/
うたかた /泡沫/
うたがい /疑い/
うたがわ /歌川/宇田川/
うたぐち /歌口/
うたげ /宴/
うたこ /詩子/歌子/
うたごえ /歌声/
うたごころ /歌心/
うたしない /歌志内/
うたしろ /歌代/
うたた /転/
うたたね /転寝/
うたつ /宇多津/歌津/
うたつえき /宇多津駅/
うたづ /宇多津/
うたの /歌野/宇多野/菟田野/
うたのかみ /雅楽頭/
うたばん /歌伴/
うたばんぐみ /歌番組/
うたひめ /歌姫/
うたひめがっしょうだん /歌姫合唱団/
うたひめでんせつ /歌姫伝説/
うたほん /歌本/
うたまろ /歌麿/
うたよ /詩代/歌代/
うたん /右端/
うだ /宇陀/宇田/
うだい /宇大/
うだいじん /右大臣/
うだがわ /宇田川/
うだがわちょう /宇田川町/
うち /内/家/中/鬱/欝/
うちあげ /打ち上げ/
うちあわせ /打ち合わせ/打ち合せ/打合せ/
うちい /内井/
うちいけ /内池/
うちいわい /内祝/
うちうち /内々/
うちうみ /内海/
うちうら /内浦/
うちかけ /打掛け/裲襠/
うちかた /打ち方/内潟/
うちかわ /内川/
うちかんだ /内神田/
うちがけ /内掛け/
うちがわ /内側/
うちき /内気/内木/
うちきず /打傷/
うちきば /内木場/
うちきり /打ち切り/打切/
うちきん /内金/
うちぎ /袿/
うちくび /打ち首/
うちげば /内ゲバ/
うちこ /内子/
うちこば /内木場/
うちこみ /打ち込み/
うちこわし /打ち毀し/
うちさいわい /内幸/
うちさいわいちょう /内幸町/
うちざいこぶん /内在庫分/
うちぜい /内税/
うちそで /内袖/
うちた /打田/
うちだ /内田/
うちだゆき /内田有紀/
うちだようこう /内田洋行/
うちづま /内妻/
うちで /打ち出/
うちでし /内弟子/
うちどめ /打止/打ち止め/
うちなかはら /内中原/
うちなだ /内灘/
うちの /内野/
うちのうら /内之浦/
うちのみ /内海/
うちのり /内のり/内法/
うちはら /内原/
うちばば /内馬場/
うちひとり /内一人/
うちひょうじ /内表示/
うちひら /内平/
うちぶくろ /内袋/
うちべんけい /内弁慶/
うちぼう /内房/
うちぼうせん /内房線/
うちぼうせんそが /内房線蘇我/
うちぼり /内堀/
うちまく /内幕/
うちまた /内股/
うちみ /打ち身/
うちみず /打ち水/
うちみや /内宮/
うちむそう /内無双/
うちむら /内村/
うちもと /内一/
うちやま /内山/
うちやまだ /内山田/
うちゅう /宇宙/雨中/
うちゅういち /宇宙一/
うちゅうえいゆう /宇宙英雄/
うちゅうかいぞく /宇宙海賊/
うちゅうかいはつ /宇宙開発/
うちゅうかいはつけいかく /宇宙開発計画/
うちゅうかいはつじぎょうだん /宇宙開発事業団/
うちゅうかいぶつ /宇宙怪物/
うちゅうかがくけんきゅうじょ /宇宙科学研究所/
うちゅうかぞく /宇宙家族/
うちゅうかん /宇宙観/右中間/
うちゅうかんきょう /宇宙環境/
うちゅうがく /宇宙学/
うちゅうきち /宇宙基地/
うちゅうきぼ /宇宙規模/
うちゅうくうかん /宇宙空間/
うちゅうくうぼ /宇宙空母/
うちゅうけん /宇宙研/
うちゅうげんしょう /宇宙現象/
うちゅうこう /宇宙項/
うちゅうこうがく /宇宙工学/
うちゅうしゅうじんせん /宇宙囚人船/
うちゅうしゅし /宇宙種子/
うちゅうしょく /宇宙食/
うちゅうしょくみんち /宇宙植民地/
うちゅうじっけん /宇宙実験/
うちゅうじょうほう /宇宙情報/
うちゅうじん /宇宙人/宇宙塵/
うちゅうせん /宇宙船/宇宙戦/宇宙線/
うちゅうせんかん /宇宙戦艦/
うちゅうせんかんそくじょ /宇宙線観測所/
うちゅうせんそう /宇宙戦争/
うちゅうせんとう /宇宙戦闘/
うちゅうせんとうき /宇宙戦闘機/
うちゅうせんない /宇宙船内/
うちゅうぜろねん /宇宙零年/
うちゅうぜんたい /宇宙全体/
うちゅうそうせい /宇宙創成/
うちゅうそくど /宇宙速度/
うちゅうたんさ /宇宙探査/
うちゅうたんさきょうかい /宇宙探査協会/
うちゅうつうしん /宇宙通信/
うちゅうてい /宇宙挺/
うちゅうていおう /宇宙帝王/
うちゅうていすう /宇宙定数/
うちゅうとし /宇宙都市/
うちゅうにんじゃたい /宇宙忍者隊/
うちゅうねんだいき /宇宙年代記/
うちゅうひこう /宇宙飛行/
うちゅうひこうし /宇宙飛行士/
うちゅうふく /宇宙服/
うちゅうぶつり /宇宙物理/
うちゅうぼうえんきょう /宇宙望遠鏡/
うちゅうよう /宇宙用/
うちゅうりょこう /宇宙旅行/
うちゅうれき /宇宙暦/宇宙歴/
うちゅうれきがんねん /宇宙歴元年/
うちゅうろん /宇宙論/
うちゅうろんかんけい /宇宙論関係/
うちゅうろんばたけ /宇宙論畑/
うちゆ /内湯/
うちょうてん /有頂天/
うちょく /右直/
うちょくじこ /右直事故/
うちら /内良/
うちわ /内輪/団扇/
うちわうけ /内輪受/
うちわく /内枠/
うちわけ /内訳/
うちわけしょ /内訳書/
うちわたし /内渡し/
うちわばなし /内輪話/
うちわもめ /内輪揉め/
うっき /鬱気/
うっくつ /鬱屈/
うっけつ /欝血/鬱血/うっ血/鬱結/
うっこ /鬱乎/
うっこん /鬱金/
うっこんこう /鬱金香/
うっせい /鬱生/
うっせき /うっ積/欝積/鬱積/
うっそう /欝蒼/鬱蒼/鬱葱/
うっそく /鬱塞/
うったい /鬱滞/
うったえ /訴え/
うったえかた /訴え方/
うっちゃり /打っ棄り/
うっちょう /鬱鬯/
うっとう /欝陶/鬱陶/
うっとうしい /欝陶しい/鬱陶しい/
うっぷん /鬱憤/欝憤/
うつ /蔚/鬱/欝/
うつい /鬱伊/
うついく /鬱郁/
うつう /鬱紆/
うつうつ /鬱鬱/
うつおう /鬱泱/鬱怏/鬱懊/
うつき /宇津喜/宇津木/
うつぎ /宇津木/
うつぎみ /鬱気味/
うつく /美/
うつくしがはら /美ヶ原/
うつし /写/写し/
うつしよ /現世/
うつじゅう /鬱情/
うつせみ /空蝉/現身/
うつぜん /鬱然/
うつのみや /宇都宮/
うつのみやえき /宇都宮駅/
うつのみやこうじょう /宇都宮工場/
うつのみやし /宇都宮市/
うつのみやせん /宇都宮線/
うつのみやだい /宇都宮大/
うつのみやだいがく /宇都宮大学/
うつびょう /鬱病/
うつぼ /靭/笂/靱/
うつぼつ /鬱勃/
うつみ /内海/慈/宇都美/
うつみや /宇津宮/
うつも /鬱茂/
うつもん /鬱悶/
うつゆう /鬱悒/鬱邑/
うつよう /鬱陶/
うつよく /鬱抑/
うつりかわり /移り変わり/
うつりつ /鬱律/
うつろ /虚ろ/虚/宇津呂/
うつわ /器/噐/
うづ /宇津/
うづき /卯月/宇津木/
うづきゅうめいがん /宇津救命丸/
うて /右手/
うてき /雨滴/
うてきかんち /雨滴感知/
うてん /雨天/
うてんきょうしゅう /雨天教習/
うてんけっこう /雨天決行/
うてんじ /雨天時/
うてんちゅうし /雨天中止/
うで /腕/
うでかざり /腕飾り/
うできき /腕利き/
うでくらべ /腕比べ/
うでぐみ /腕組み/
うでずく /腕ずく/腕尽く/
うでずもう /腕相撲/
うでたて /腕立/
うでたてふせ /腕立伏せ/
うでだめし /腕試し/
うでづく /腕尽く/
うでどけい /腕時計/
うでまえ /腕前/
うでまくら /腕枕/
うでわ /腕輪/
うと /宇土/宇都/
うとう /宇籐/宇藤/
うとく /宇徳/
うとろ /宇登呂/
うどの /鵜殿/
うどり /羽鳥/
うどん /饂飩/
うない /宇内/
うなかみ /海上/
うなぎ /鰻/
うなぎや /鰻屋/
うなじ /項/
うなづき /宇奈月/
うなどん /鰻丼/
うなばら /海原/
うなり /唸り/
うに /雲丹/海胆/
うぬ /己/
うぬぼれ /自惚れ/
うね /畦/畝/宇根/畆/疇/畴/有年/
うねおか /宇根岡/
うねかわ /畝川/
うねび /畝傍/
うねめ /采女/
うねもと /畝本/
うの /宇野/宇能/鵜野/
うのう /右脳/
うのき /宇野木/卯野木/卯木/鵜木/
うのけ /宇ノ気/
うのせん /宇野線/
うのたかまつかん /宇野高松間/
うのはな /卯の花/
うのみ /鵜呑み/鵜呑/
うは /右派/
うば /乳母/姥/
うばいあい /奪い合い/
うばぐるま /乳母車/
うばすて /姥捨/
うびょう /宇廟/
うふさま /右府様/
うぶ /産/初心/初/
うぶぎ /産着/
うぶげ /産毛/
うぶごえ /産声/
うぶや /産屋/
うぶやま /産山/
うぶゆ /産湯/
うぷしろん /Υ/υ/
うへん /右辺/
うへんち /右辺値/
うべ /宇部/宜/
うべこう /宇部興/
うべこうさん /宇部興産/
うべせん /宇部線/
うほう /右方/
うま /馬/旨/午/
うまいり /馬入/
うまこ /馬子/
うまこし /馬越/
うまごめ /馬込/
うまごや /馬小屋/
うまじ /馬路/
うまじしん /馬自身/
うまじたい /馬自体/
うまじるし /馬標/
うまずら /馬面/
うまたち /馬達/
うまに /甘煮/
うまの /馬野/
うまのすずくさか /ウマノスズクサ科/Aristolochiaceae/
うまのすずくさもく /ウマノスズクサ目/Aristolochiales/
うまのり /馬乗り/
うまはし /馬橋/
うまばん /馬番/
うまふざい /馬不在/
うまみ /旨味/
うまみち /馬道/
うまや /厩/馬屋/廐/廏/
うまれ /生まれ/生/
うまれこきょう /生まれ故郷/
うまれつき /生まれつき/
うまれどし /生まれ年/
うまれん /馬連/
うみ /海/膿/生/宇美/
うみいちめん /海一面/
うみかぜ /海風/
うみがみ /海神/
うみがめ /海亀/
うみがわ /海側/
うみしばうら /海芝浦/
うみせんやません /海千山千/
うみそだち /海育ち/
うみぞい /海沿い/
うみだし /海田市/
うみづり /海釣/
うみの /海野/
うみのいえ /海の家/
うみのなかみち /海の中道/
うみはら /海腹/
うみはらかわせ /海腹川背/
うみべ /海辺/
うむ /有無/孳/
うむらうと /ウムラウト/
うめ /梅/楳/
うめあわせ /埋め合せ/埋め合わせ/
うめがえ /梅枝/
うめがえもち /梅枝餅/
うめがおか /梅が丘/
うめがき /梅垣/
うめがしま /梅ヶ島/
うめき /呻き/
うめきごえ /呻き声/
うめきち /梅吉/
うめくさ /埋め草/埋草/
うめこ /梅子/
うめこうじ /梅小路/
うめこぶちゃ /梅昆布茶/
うめこみ /埋め込み/
うめさお /梅棹/
うめさわ /梅沢/
うめざき /梅崎/
うめざわ /梅沢/梅澤/
うめしゅ /梅酒/
うめず /梅図/梅津/楳図/梅酢/
うめぞの /梅園/
うめた /梅田/
うめたて /埋立/
うめたてち /埋立地/
うめたに /梅谷/
うめだ /梅田/楳田/
うめだえき /梅田駅/
うめだかもつえき /梅田貨物駅/
うめだかもつせん /梅田貨物線/
うめだがわ /梅田川/
うめだがわぞい /梅田川沿/
うめだきた /梅田北/
うめだきんぺん /梅田近辺/
うめだしてん /梅田支店/
うめだしゅうへん /梅田周辺/
うめだはっちゃく /梅田発着/
うめだはんきゅうまえ /梅田阪急前/
うめだはんしん /梅田阪神/
うめつくし /埋め尽くし/
うめづ /梅津/
うめづしゃこ /梅津車庫/
うめにしき /梅錦/
うめの /梅野/
うめはら /梅原/
うめぼし /梅干し/梅干/
うめみ /梅見/
うめみや /梅宮/
うめむら /梅村/
うめむろ /梅室/
うめもと /梅本/
うめもり /梅森/
うめやま /梅山/
うめわかべや /梅若部屋/
うもう /羽毛/
うもうだ /羽毛田/
うもうふく /羽毛服/
うもうふとん /羽毛布団/
うもん /宇門/
うやま /宇山/
うよ /紆余/紆餘/
うよう /右葉/
うよきょくせつ /紆余曲折/迂余曲折/
うよく /右翼/
うよくだんたい /右翼団体/
うよくてき /右翼的/
うら /裏/浦/占/裡錙/
うら> /裏/
うらあみ /裏編み/
うらうす /浦臼/
うらうち /裏打ち/
うらえ /浦江/
うらおくみの /裏奥美濃/
うらおもて /裏表/
うらおもてがみ /裏表紙/
うらかいどう /裏街道/
うらかすみ /浦霞/
うらかぜ /裏風/
うらかた /裏方/
うらかみ /浦上/
うらかわ /浦川/浦河/
うらが /浦賀/
うらがえし /裏返し/
うらがお /裏顔/
うらがき /裏書/裏書き/
うらがきじょうと /裏書譲渡/
うらがきにん /裏書人/
うらがけいゆ /浦賀経由/
うらがすみ /浦霞/
うらがすみぜん /浦霞禅/
うらがすみだいぎんじょう /浦霞大吟醸/
うらがせん /浦賀線/
うらがね /裏金/
うらがみ /裏紙/浦上/
うらがみえきまえ /浦上駅前/
うらがみしゃこ /浦上車庫/
うらがめん /裏画面/
うらがわ /裏側/浦川/
うらきばん /裏基盤/
うらきもん /裏鬼門/
うらぎり /裏切り/
うらぎりもの /裏切者/
うらぐち /裏口/
うらけん /裏拳/
うらこう /浦港/
うらこうさく /裏工作/
うらさ /浦佐/
うらさく /裏作/
うらさわ /浦沢/
うらさんしょう /裏参照/
うらしの /嬉野/
うらしま /浦島/
うらしまたろう /浦島太郎/
うらじ /裏地/
うらじおすとっく /浦鹽斯徳/
うらじじょう /裏事情/
うらじょうほう /裏情報/
うらせ /浦瀬/
うらせってい /裏設定/
うらせんけ /裏千家/
うらぜん /浦禅/
うらそえ /浦添/
うらぞこ /浦底/
うらた /浦田/
うらち /浦地/
うらづけ /裏付け/裏付/
うらて /裏手/
うらとりひき /裏取引/
うらどおり /裏通り/
うらどら /裏ドラ/
うらない /占い/卜い/卦/
うらにし /浦西/
うらにほん /裏日本/
うらにわ /裏庭/
うらの /浦野/
うらはいけい /裏背景/
うらはま /浦浜/
うらはら /裏腹/
うらば /裏葉/
うらばなし /裏話/
うらばなしてき /裏話的/
うらばんく /裏バンク/
うらばんぐみ /裏番組/
うらばんだい /裏磐梯/
うらばんだいねこま /裏磐梯猫魔/裏磐梯猫摩/
うらびょうし /裏表紙/
うらぶた /裏蓋/
うらぶたい /裏舞台/
うらべ /卜部/浦部/占部/裏部/
うらべや /裏部屋/
うらほろ /浦幌/
うらぼん /盂蘭盆/
うらまち /裏町/
うらまちどおり /裏町通り/
うらまど /裏窓/
うらみごと /恨み言/
うらみち /裏道/
うらみぶし /怨み節/
うらむ /怏/
うらめ /裏目/
うらめし /浦飯/
うらめん /裏面/
うらめんさいせい /裏面再生/
うらもと /浦本/
うらもの /裏物/
うらもん /裏門/
うらやす /浦安/
うらやすかん /浦安間/
うらやすし /浦安市/
うらやま /裏山/浦山/
うらら /麗/
うらる /烏拉/
うらわ /浦和/
うらわえき /浦和駅/
うらわざ /裏技/
うらわざつかい /裏技使い/
うらわざてき /裏技的/
うらわし /浦和市/
うらわしざいじゅう /浦和市在住/
うらわしだいもん /浦和市大門/
うらわしとうぶ /浦和市東部/
うらわせん /浦和戦/
うらわだいもん /浦和大門/
うらわでんしゃく /浦和電車区/
うらわにしぐち /浦和西口/
うらわみなみ /浦和南/
うらん /ウラン/
うり /瓜/瓠/瓣/壺/壷/
うりあげ /売上/売上げ/売り上げ/
うりあげえいぎょうりえきりつ /売上営業利益率/
うりあげかかく /売上価格/
うりあげかくほ /売上確保/
うりあげがく /売上額/
うりあげきん /売上金/
うりあげげんか /売上原価/
うりあげこうせいひ /売上構成比/
うりあげさいけん /売上債権/
うりあげさいけんかいてんりつ /売上債権回転率/
うりあげそうりえきりつ /売上総利益率/
うりあげぞう /売上増/
うりあげぞうだい /売上増大/
うりあげだいすう /売上台数/
うりあげだか /売上高/
うりあげふしん /売上不振/
うりいえ /売り家/
うりか /ウリ科/
うりかい /売り買い/
うりかけ /売り掛け/売掛/
うりかけきん /売掛金/
うりきれ /売り切れ/売切/
うりくち /売り口/
うりこ /売子/
うりことば /売り言葉/
うりこみ /売り込み/
うりごえ /売声/
うりそうば /売相場/
うりだし /売り出し/売出/売出し/
うりだしきかん /売出期間/
うりだしちゅう /売出中/
うりづら /瓜連/
うりて /売り手/売手/
うりどき /売り時/
うりぬし /売り主/
うりね /売値/売り値/
うりの /売野/
うりば /売場/売り場/
うりばめんせき /売場面積/
うりもく /ウリ目/Cucurbitales/
うりもの /売り物/売物/
うりや /売り家/
うりゅ /雨龍/
うりゅう /雨竜/雨龍/瓜生/
うりょう /雨量/
うりょうけい /雨量計/
うりん /雨林/
うる /宇留/
うるう /閏/
うるうづき /閏月/
うるうどし /閏年/
うるうびょう /閏秒/
うるき /売木/
うるし /漆/
うるしはら /漆原/
うるしばた /漆畑/
うるしま /漆島/
うるしやま /漆山/
うるた /粳田/
うるち /粳/
うるちまい /粳米/
うれあし /売れ足/
うれい /憂い/愁い/恙/騷/
うれう /悄/
うれえ /愁え/憂え/
うれくち /売れ口/
うれしの /嬉野/
うれすじ /売れ筋/
うれせん /売れ線/
うれだか /売れ高/
うれっこ /売れっ子/
うれゆき /売行き/売行/売れ行き/
うろ /迂路/空洞/空/
うろう /傴僂/
うろおぼえ /うろ覚え/
うろこ /鱗/
うろん /胡乱/
うわ /上/宇和/
うわあご /上顎/
うわがき /上書き/上書/
うわがわ /上側/
うわき /浮気/
うわきがんぼう /浮気願望/
うわきごころ /浮気心/
うわきしょう /浮気性/
うわきちゅう /浮気中/
うわぎ /上着/上衣/
うわくちびる /上唇/
うわぐすり /釉薬/
うわぐつ /上靴/
うわごと /謔言/譫言/
うわさ /噂/
うわさばなし /噂話/
うわざら /上皿/
うわじま /宇和島/
うわじまじどうしゃ /宇和島自動車/
うわじまひがし /宇和島東/
うわすべり /上滑り/
うわずみ /上住/上澄み/
うわぞこ /上底/
うわつら /上面/
うわづみ /上積み/
うわて /上手/
うわてだしなげ /上手出し投げ/
うわてなげ /上手投げ/
うわてひねり /上手捻り/
うわぬり /上塗り/
うわね /上値/
うわの /宇和野/
うわのせ /上乗せ/
うわのだい /上の台/
うわのり /上乗り/
うわばき /上履き/
うわばみ /蠎蛇/
うわぶたしき /上蓋式/
うわべ /上辺/
うわまえ /上前/
うわみ /宇和海/
うわみぞ /上溝/
うわみの /上蓑/
うわむき /上向き/
うわめ /上目/
うわや /上屋/
うわやく /上役/
うわん /右腕/
うん /運/云/雲/曇/吽/慍/暈/紜/繧/耘/薀/蘊/褞/黄/
うんえい /運営/
うんえいいいん /運営委員/
うんえいいいんかい /運営委員会/
うんえいいこう /運営移行/
うんえいかつどう /運営活動/
うんえいがいしゃ /運営会社/
うんえいがわ /運営側/
うんえいしきん /運営資金/
うんえいしつ /運営室/
うんえいしゃ /運営者/
うんえいしゃがわ /運営者側/
うんえいじょう /運営上/
うんえいちゅう /運営中/
うんえいどりょく /運営努力/
うんえいのうりょく /運営能力/
うんえいひ /運営費/
うんえいぶ /運営部/
うんえいほうしん /運営方針/
うんえいほうほう /運営方法/
うんえいぼたい /運営母体/
うんえいもと /運営元/
うんえいよう /運営用/
うんえいりねん /運営理念/
うんか /雲霞/
うんかい /雲海/
うんが /運河/
うんがかん /運河間/
うんきゅう /運休/
うんけいじょうぎ /雲型定規/
うんげいせん /雲芸線/
うんげん /繧繝/
うんこう /運行/運航/
うんこうかいしまえ /運行開始前/
うんこうけいたい /運行形態/
うんこうじかん /運行時間/
うんこうじかんたい /運行時間帯/
うんこうじょうきょう /運行状況/
うんこうじょうけん /運行条件/
うんこうじょうむいん /運航乗務員/
うんこうちゅう /運航中/運行中/
うんこうちゅうし /運航中止/
うんこうていし /運航停止/
うんこうにってい /運航日程/
うんこうまえてんけん /運行前点検/
うんこうみつど /運行密度/
うんこうよう /運行用/
うんこうよてい /運行予定/
うんさん /雲散/
うんさんむしょう /雲散霧消/
うんざん /運算/
うんし /運指/
うんしだい /運次第/
うんしん /運針/雲身/
うんじゃく /雲雀/
うんじゅ /琅珠/
うんじょう /雲上/
うんすい /雲水/
うんせい /運勢/
うんぜん /雲仙/
うんぜんこうえん /雲仙公園/
うんぜんこうえんいき /雲仙公園行/
うんぜんこうえんゆき /雲仙公園行/
うんぜんだけ /雲仙岳/
うんぜんふげんだけ /雲仙普賢岳/
うんぜんゆき /雲仙行/
うんそう /運送/
うんそうがいしゃ /運送会社/
うんそうぎょう /運送業/
うんそうぎょうかい /運送業界/
うんそうけいやく /運送契約/
うんそうけいやくじょうけん /運送契約条件/
うんそうちゅう /運送中/
うんそうてん /運送店/
うんそうひ /運送費/
うんそうひよう /運送費用/
うんそうや /運送屋/
うんそうやっかん /運送約款/
うんそうりょう /運送料/
うんだい /雲台/
うんだめし /運試し/
うんちく /蘊蓄/薀蓄/
うんちょう /雲頂/
うんちん /運賃/
うんちんかいせい /運賃改正/
うんちんかいてい /運賃改定/
うんちんかくさ /運賃格差/
うんちんかんけい /運賃関係/
うんちんきそく /運賃規則/
うんちんくぶん /運賃区分/
うんちんけいさん /運賃計算/
うんちんしゅうにゅう /運賃収入/
うんちんせい /運賃制/
うんちんたいけい /運賃体系/
うんちんばこ /運賃箱/
うんちんひょう /運賃表/
うんちんひょうじ /運賃表示/
うんちんひょうじき /運賃表示器/運賃表示機/
うんちんひょうじまく /運賃表示幕/
うんちんふたん /運賃負担/
うんちんぶん /運賃分/
うんちんめん /運賃面/
うんちんりょうきん /運賃料金/
うんてん /運転/
うんてんいがい /運転以外/
うんてんかい /運転会/
うんてんかんかく /運転感覚/運転間隔/
うんてんぎじゅつ /運転技術/
うんてんぎほう /運転技法/
うんてんぎりょう /運転技量/
うんてんくかん /運転区間/
うんてんけいたい /運転形態/
うんてんけいとう /運転系統/
うんてんさいかい /運転再開/
うんてんし /運転士/
うんてんしつ /運転室/
うんてんしどう /運転指導/
うんてんしゃ /運転者/
うんてんしゃいがい /運転者以外/
うんてんしゃせき /運転者席/
うんてんしゅ /運転手/
うんてんしゅうりょうご /運転終了後/
うんてんしゅこじん /運転手個人/
うんてんしゅし /運転手氏/
うんてんしよう /運転士用/
うんてんしれい /運転指令/
うんてんしれいしょ /運転指令所/
うんてんじ /運転時/
うんてんじかん /運転時間/
うんてんじき /運転時期/
うんてんじょう /運転上/
うんてんせき /運転席/
うんてんせきがわ /運転席側/
うんてんせきこうほう /運転席後方/
うんてんせきじょう /運転席上/
うんてんせきひだりがわ /運転席左側/
うんてんせきぶ /運転席部/
うんてんせきよこ /運転席横/
うんてんそうさ /運転操作/
うんてんたいど /運転態度/
うんてんだい /運転台/
うんてんちゅう /運転中/
うんてんていしゃ /運転停車/
うんてんのうりょく /運転能力/
うんてんひんど /運転頻度/
うんてんび /運転日/
うんてんびちゅうい /運転日注意/
うんてんほう /運転法/
うんてんほうほう /運転方法/
うんてんほんすう /運転本数/
うんてんめんきょ /運転免許/
うんてんめんきょしけん /運転免許試験/
うんてんめんきょしょう /運転免許証/
うんてんよう /運転用/
うんてんれき /運転歴/
うんでい /雲泥/
うんどう /運動/
うんどういん /運動員/
うんどうかい /運動会/
うんどうかく /運動覚/
うんどうがく /運動学/
うんどうがくてき /運動学的/
うんどうがわ /運動側/
うんどうきこうか /運動機構課/
うんどうきのう /運動機能/
うんどうぐつ /運動靴/
うんどうこう /運動項/
うんどうこうえん /運動公園/
うんどうこうえんない /運動公園内/
うんどうこうぞう /運動構造/
うんどうしんけい /運動神経/
うんどうじ /運動時/
うんどうじょう /運動場/
うんどうじょうたい /運動状態/
うんどうせい /運動性/
うんどうせいぎょ /運動制御/
うんどうせいのう /運動性能/
うんどうせいぶん /運動成分/
うんどうそしき /運動組織/
うんどうたい /運動体/
うんどうちゅう /運動中/
うんどうのう /運動能/
うんどうのうりょく /運動能力/
うんどうぶそく /運動不足/
うんどうぶそくぎみ /運動不足気味/
うんどうぶったい /運動物体/
うんどうほうこう /運動方向/
うんどうほうそく /運動法則/
うんどうほうていしき /運動方程式/
うんどうようそ /運動要素/
うんどうりょう /運動量/
うんどうりょうしゅうし /運動量収支/
うんどうりょうほぞんそく /運動量保存則/
うんどうりょうゆそう /運動量輸送/
うんどうりょく /運動力/
うんどんりょう /運動量/
うんなん /雲南/
うんなんしょう /雲南省/
うんぬん /云々/
うんの /海野/
うんのう /蘊奥/雲衲/暈ノウ/
うんぱん /運搬/
うんぱんかのう /運搬可能/
うんぱんき /運搬機/
うんぱんぐ /運搬具/
うんぱんさいぼう /運搬細胞/
うんぱんしゅだん /運搬手段/
うんぱんちゅう /運搬中/
うんぱんよう /運搬用/
うんぱんりょく /運搬力/
うんぴつ /運筆/
うんぷう /雲風/
うんめい /運命/
うんめいてき /運命的/
うんめいとうげ /運命峠/
うんも /雲母/
うんもじょう /雲母状/
うんゆ /運輸/
うんゆぎいん /運輸議員/
うんゆぎょうせい /運輸行政/
うんゆしょう /運輸省;2001年1月の中央省庁再編で国土交通省に再編された/
うんゆしょうあいて /運輸省相手/
うんゆしょうかんりか /運輸省管理課/
うんゆしょうがわ /運輸省側/
うんゆせいさく /運輸政策/
うんゆだいじん /運輸大臣/
うんゆとうけい /運輸統計/
うんよう /運用/
うんようえき /運用益/
うんようかいし /運用開始/
うんようかのう /運用可能/
うんようかんりしゃ /運用管理者/
うんようがかり /運用掛/
うんようきゅうし /運用休止/
うんようぎじゅつぶ /運用技術部/
うんようけいけん /運用経験/
うんようけんとうしょういいんかい /運用検討小委員会/
うんようしゃ /運用者/
うんようしゅうりょう /運用終了/
うんようじ /運用時/
うんようじかん /運用時間/
うんようじっけん /運用実験/
うんようじっせき /運用実績/
うんようじょう /運用上/
うんようじょうたい /運用状態/
うんようすう /運用数/
うんようせい /運用性/
うんようたいせい /運用体制/
うんようちゅう /運用中/
うんようていし /運用停止/
うんようてき /運用的/
うんようばしょ /運用場所/
うんようばんごう /運用番号/
うんようひ /運用費/
うんようひょう /運用表/
うんようほう /運用法/
うんようほうほう /運用方法/
うんようほんぶ /運用本部/
うんようめん /運用面/
うんようよう /運用用/
うんりょう /雲量/
え /絵/会/江/回/柄/重/恵/餌/得/枝/荏/笑/衛/慧/画/ヱ/衣/榎/會/囘/惠/畫/繪/衞/懷/猥/依/杖/
えーじぇんと /エージェント/
えーす /エース/
えーた /η/
えーてる /エーテル/
えあ /エア/
えあわせ /絵合わせ/絵合/
えい /栄/英/映/影/鋭/詠/衛/永/瑛/営/嬰/泳/頴/洩/穎/盈/叡/曳/榮/咏/營/塋/暎/曵/楹/殪/潁/瀛/瑩/瓔/珱/睿/縊/纓/翳/蠑/衞/裔/贏/郢/頴娃/衡/
えいい /鋭意/営為/栄位/
えいいしっぴつちゅう /鋭意執筆中/
えいいち /英一/詠一/栄一/榮一/
えいいちろう /栄一郎/英一郎/
えいいどりょく /鋭意努力/
えいえい /営々/営営/英英/
えいえいじしょ /英英辞書/
えいえいじてん /英英辞典/
えいえん /永遠/
えいえんふめつ /永遠不滅/
えいおうしつ /英王室/
えいおおもじ /英大文字/
えいおん /嬰音/
えいか /穎果/
えいかいわ /英会話/
えいかいわかんけい /英会話関係/
えいかいわがっこう /英会話学校/
えいかいわきょうざい /英会話教材/
えいかいわきょうしつ /英会話教室/
えいかく /鋭角/
えいかくてき /鋭角的/
えいかん /栄冠/
えいかんたい /英艦隊/
えいが /映画/栄華/栄画/
えいがおんがく /映画音楽/
えいがおんがくとくしゅう /映画音楽特集/
えいがか /映画化/
えいがかい /映画界/
えいがかけん /映画化権/
えいがかびんじょう /映画化便乗/
えいがかん /映画館/
えいがかんけい /映画関係/
えいがかんけん /映画館券/
えいがかんしょう /映画観賞/映画鑑賞/
えいがかんしょうりょう /映画鑑賞料/
えいがかんとく /映画監督/
えいがかんめい /映画館名/
えいががいしゃ /映画会社/
えいがく /栄学/
えいがげいじゅつ /映画芸術/
えいがげきじょう /映画劇場/
えいがさい /映画祭/
えいがさくひん /映画作品/
えいがさっか /映画作家/
えいがざっし /映画雑誌/
えいがしじょう /映画史上/
えいがしゅだいきょく /映画主題曲/
えいがしょう /映画賞/
えいがじたい /映画自体/
えいがじょうえいかい /映画上映会/
えいがじん /映画人/
えいがじんこう /映画人口/
えいがせいさくしゃ /映画製作者/
えいがぜんたい /映画全体/
えいがだいぜんしゅう /映画大全集/
えいがてき /映画的/
えいがないえいが /映画内映画/
えいがはいゆう /映画俳優/
えいがばん /映画版/
えいがひゃっか /映画百科/
えいがひょうろん /映画評論/
えいがひょうろんか /映画評論家/
えいがびじゅつ /映画美術/
えいがぶもん /映画部門/
えいがむら /映画村/
えいがや /映画屋/
えいがよう /映画用/
えいがらん /映画欄/
えいき /鋭気/英気/永記/
えいきち /永吉/栄吉/
えいきゅう /永久/
えいきゅうかいいん /永久会員/
えいきゅうきかん /永久機関/
えいきゅうけつばん /永久欠番/
えいきゅうし /永久歯/
えいきゅうじしゃく /永久磁石/
えいきゅうついほう /永久追放/
えいきゅうていし /永久停止/
えいきゅうてき /永久的/
えいきゅうほうき /永久放棄/
えいきゅうほしょう /永久保証/
えいきゅうほぞん /永久保存/
えいきゅうほぞんばん /永久保存版/
えいきょう /影響/
えいきょうか /影響下/
えいきょうけんちょ /影響顕著/
えいきょうだい /影響大/
えいきょうちょうさ /影響調査/
えいきょうど /影響度/
えいきょうりょく /影響力/
えいぎょう /営業/
えいぎょうあんない /営業案内/
えいぎょういん /営業員/
えいぎょううんてん /営業運転/
えいぎょううんてんび /営業運転日/
えいぎょうか /営業課/
えいぎょうかいし /営業開始/
えいぎょうかちょう /営業課長/
えいぎょうかつどう /営業活動/
えいぎょうかんりか /営業管理課/
えいぎょうがい /営業外/
えいぎょうがいしゅうえき /営業外収益/
えいぎょうがいひよう /営業外費用/
えいぎょうがわ /営業側/
えいぎょうきそく /営業規則/
えいぎょうきゅうし /営業休止/
えいぎょうきょか /営業許可/
えいぎょうけい /営業系/
えいぎょうけいすう /営業係数/営業系数/
えいぎょうけん /営業権/
えいぎょうこうい /営業行為/
えいぎょうしゃ /営業者/営業車/
えいぎょうしゃぜんいん /営業者全員/
えいぎょうしゃてき /営業車的/
えいぎょうしゅうにゅう /営業収入/
えいぎょうしゅうりょう /営業終了/
えいぎょうしゅうりょうご /営業終了後/
えいぎょうしょ /営業所/
えいぎょうしょく /営業職/
えいぎょうしょすう /営業所数/
えいぎょうしょめい /営業所名/
えいぎょうじ /営業時/
えいぎょうじかん /営業時間/
えいぎょうじかんがい /営業時間外/
えいぎょうじょう /営業上/
えいぎょうせいさく /営業政策/
えいぎょうせん /営業線/
えいぎょうたんとう /営業担当/
えいぎょうたんとうしゃ /営業担当者/
えいぎょうちゅう /営業中/
えいぎょうていし /営業停止/
えいぎょうていししょぶん /営業停止処分/
えいぎょうてき /営業的/
えいぎょうてん /営業店/
えいぎょうにっすう /営業日数/
えいぎょうばたけ /営業畑/
えいぎょうひみつ /営業秘密/
えいぎょうび /営業日/
えいぎょうぶ /営業部/
えいぎょうぶちょう /営業部長/
えいぎょうほんぶ /営業本部/
えいぎょうぼうがい /営業妨害/
えいぎょうめん /営業面/
えいぎょうよう /営業用/
えいぎょうりえき /営業利益/
えいぎょうりょく /営業力/
えいぎょうれっしゃ /営業列車/
えいぐん /英軍/
えいけい /鋭形/
えいけん /英検/
えいげん /永源/
えいげんじ /永源寺/
えいこ /英子/栄子/永子/瑛子/暎子/栄枯/江威子/映子/
えいこう /栄光/曳航/栄孝/曳光/曳行/栄幸/
えいこうき /曳航機/
えいこうだん /曳光弾/曳光彈/
えいこく /英国/
えいこくかいぐん /英国海軍/
えいこくがた /英国型/
えいこくがわ /英国側/
えいこくき /英国旗/
えいこくきかく /英国規格/
えいこくこうくう /英国航空/
えいこくこうし /英国公使/
えいこくこっきょうかい /英国国教会/
えいこくご /英国語/
えいこくしき /英国式/
えいこくしゃ /英国車/
えいこくしゅっしん /英国出身/
えいこくしんれいきょうかい /英国心霊協会/
えいこくじん /英国人/
えいこくじんぎじゅつしゃ /英国人技術者/
えいこくせい /英国製/
えいこくたいざいしゃ /英国滞在者/
えいこくない /英国内/
えいこくはつ /英国発/
えいこくばん /英国盤/英国版/
えいこくぶつりがっかい /英国物理学会/
えいこくりゅう /英国流/
えいこくりょう /英国領/
えいこせいすい /栄枯盛衰/
えいこもじ /英小文字/
えいご /英語/英五/
えいごあんない /英語案内/
えいごいがい /英語以外/
えいごう /永劫/
えいごか /英語化/英語科/
えいごかいわ /英語会話/
えいごがく /英語学/
えいごがくしゅう /英語学習/
えいごがっこう /英語学校/
えいごきじ /英語記事/
えいごきょういく /英語教育/
えいごきょういくばんぐみ /英語教育番組/
えいごきょく /英語局/
えいごけん /英語圏/
えいごげき /英語劇/
えいごじしょ /英語辞書/
えいごじてん /英語辞典/
えいごじん /英語人/
えいごだい /英語題/
えいごてき /英語的/
えいごとうろん /英語討論/
えいごにゅうりょく /英語入力/
えいごのうりょく /英語能力/
えいごはつおん /英語発音/
えいごばん /英語版/
えいごひょうき /英語表記/
えいごひょうげん /英語表現/
えいごひょうじ /英語表示/
えいごふう /英語風/
えいごぶん /英語文/
えいごぶんか /英語文化/
えいごほうそう /英語放送/
えいごめい /英語名/
えいごめいしょう /英語名称/
えいごめん /英語面/
えいごやく /英語訳/
えいごよう /英語用/
えいごりょく /英語力/
えいごろんぶん /英語論文/
えいさい /英才/穎才/
えいさいきょういく /英才教育/
えいさく /栄作/栄策/英作/
えいさくぶん /英作文/
えいさつ /縊殺/
えいざぶろう /栄三郎/
えいざん /叡山/
えいざんてつどうせん /叡山鉄道線/
えいざんでんしゃ /叡山電車/
えいざんでんてつ /叡山電鉄/
えいざんほんせん /叡山本線/
えいしゃ /映写/営舎/
えいしゃき /映写機/
えいしゅ /英主/
えいしゅつ /映出/
えいしょ /英書/
えいしょう /詠唱/
えいしん /栄進/詠進/
えいじ /英字/英治/英二/栄次/栄治/栄二/永二/英司/英次/嬰児/英志/英児/鋭二/英史/英嗣/
えいじしじ /英字指示/
えいじしんぶん /英字新聞/
えいじせんたく /英字選択/
えいじにゅうりょく /英字入力/
えいじへんかん /英字変換/
えいじゅ /衛戍/
えいじゅう /永住/
えいじゅうけん /永住権/
えいじよう /英字用/
えいじろう /栄次郎/
えいじん /英人/
えいすう /英数/
えいすうかなもじ /英数仮名文字/
えいすうこく /英数国/
えいすうじ /英数字/
えいすうもじ /英数文字/
えいすけ /英介/英輔/栄介/
えいず /エイズ/
えいせい /衛生/衛星/永世/永逝/衞星/衞生/
えいせいおうしょう /永世王将/
えいせいかいせん /衛星回線/
えいせいかん /衛星間/
えいせいがく /衛生学/
えいせいきょく /衛生局/
えいせいけいゆう /衛星経由/
えいせいこう /衛生工/
えいせいこうがく /衛生工学/
えいせいこく /衛星国/
えいせいし /衛生士/
えいせいじょう /衛生上/
えいせいじょうたい /衛生状態/
えいせいせつび /衛生設備/
えいせいぞう /衛星像/
えいせいだい /衛星第/
えいせいだいいち /衛星第一/
えいせいだいに /衛星第二/
えいせいちゅうけい /衛星中継/
えいせいつうしんけいゆ /衛星通信経由/
えいせいつうしんけいゆう /衛星通信経由/
えいせいてき /衛生的/
えいせいなまちゅうけい /衛星生中継/
えいせいほうそう /衛星放送/
えいせいめいじん /永世名人/
えいせいめん /衛生面/
えいせん /曳船/鋭尖/
えいぜん /営繕/
えいそう /営倉/営巣/
えいぞう /映像/栄三/栄蔵/英三/営造/影像/
えいぞうか /映像化/
えいぞうかいはつぶもん /映像開発部門/
えいぞうかいろ /映像回路/
えいぞうきき /映像機器/
えいぞうきょうりょく /映像協力/
えいぞうぎじゅつ /映像技術/
えいぞうけんきゅうかい /映像研究会/
えいぞうけんきゅうしょ /映像研究所/
えいぞうごうせいかいろ /映像合成回路/
えいぞうごらくさくひん /映像娯楽作品/
えいぞうさい /映像祭/
えいぞうさくひん /映像作品/
えいぞうさくひんぜんぱん /映像作品全般/
えいぞうしゅつりょく /映像出力/
えいぞうしりょう /映像資料/
えいぞうしんごう /映像信号/
えいぞうしんごうよう /映像信号用/
えいぞうじょうほう /映像情報/
えいぞうせいさくぶ /映像制作部/
えいぞうせかい /映像世界/
えいぞうそうち /映像装置/
えいぞうたいしょう /映像大賞/
えいぞうたんし /映像端子/
えいぞうてき /映像的/
えいぞうてんじ /映像展示/
えいぞうとくてん /映像特典/
えいぞうとし /映像都市/
えいぞうはくぶつかん /映像博物館/
えいぞうひょうげん /映像表現/
えいぞうぶつ /営造物/
えいぞうぶんか /映像文化/
えいぞうぶんぽう /映像文法/
えいぞうよう /映像用/
えいぞうようひん /映像用品/
えいぞうりょく /映像力/
えいぞうろん /映像論/
えいぞく /永続/
えいぞくせい /永続性/
えいぞくてき /永続的/
えいた /英太/
えいたい /永代/
えいたつ /栄達/英達/
えいたろう /永太朗/栄太郎/英太郎/
えいたん /詠嘆/詠歎/
えいたんご /英単語/
えいだ /栄田/英田/
えいだい /英題/
えいだいさんぎょう /永大産業/
えいだん /営団/英断/帝都高速度交通営団/
えいだんえき /営団駅/
えいだんかんざん /営団換算/
えいだんぎんざせん /営団銀座線/
えいだんしゃ /営団車/
えいだんちかてつ /営団地下鉄/
えいだんちよだ /営団千代田/
えいだんちよだせん /営団千代田線/
えいだんとうざいせん /営団東西線/
えいだんなんぼくせん /営団南北線/
えいだんひびやせん /営団日比谷線/
えいだんゆうらくちょうせん /営団有楽町線/
えいだんりょうきん /営団料金/
えいち /英知/叡知/叡智/睿智/
えいちしゅっぱん /英知出版/
えいちだいがく /英知大学/
えいてい /営庭/
えいてん /栄転/栄典/
えいでん /叡電/
えいでんいでまちやなぎえき /叡電出町柳駅/
えいでんでまちやなぎ /叡電出町柳/
えいとう /衛陶/
えいど /エイド/
えいどう /栄道/泳動/
えいにち /英日/
えいねん /永年/
えいばん /英盤/
えいびん /鋭敏/
えいふく /永福/
えいふくちょう /永福町/
えいぶん /英文/
えいぶんか /英文科/
えいぶんかいしゃく /英文解釈/
えいぶんかいせつしょ /英文解説書/
えいぶんがく /英文学/
えいぶんがくせんしゅう /英文学専修/
えいぶんざっし /英文雑誌/
えいぶんし /英文誌/
えいぶんしゅっぱんぶつ /英文出版物/
えいぶんせつめい /英文説明/
えいぶんひょうき /英文表記/
えいぶんぽう /英文法/
えいぶんめい /英文名/
えいぶんもくろく /英文目録/
えいへい /衛兵/
えいへいじ /永平寺/
えいべい /英米/
えいべいぐん /英米軍/
えいべいじん /英米人/
えいべいほう /英米法/
えいべいりょうこく /英米両国/
えいべつてき /性別的/
えいほう /泳法/
えいみ /詠美/
えいみん /永眠/
えいめい /英名/
えいめいかん /穎明館/
えいめいかんこうこう /穎明館高校/
えいもじ /英文字/
えいもじにゅうりょくじ /英文字入力時/
えいもじひょうき /英文字表記/
えいもり /栄森/
えいもん /営門/
えいやく /英訳/
えいゆう /英雄/
えいゆうぐんぞう /英雄群像/
えいゆうしゅだい /英雄主題/
えいゆうでんせつ /英雄伝説/
えいゆうれつでん /英雄列伝/
えいよ /栄誉/
えいよう /栄養/栄耀/
えいようえいが /栄耀栄画/
えいようか /栄養価/
えいようかけいさん /栄養価計算/
えいようかてい /栄養過程/
えいようがく /栄養学/
えいようがくしゃ /栄養学者/
えいようき /栄養期/
えいようきかん /栄養器官/
えいようきけいちょう /栄養期茎頂/
えいようけいちょう /栄養茎頂/
えいようげん /栄養源/
えいようざい /栄養剤/
えいようし /栄養士/栄養枝/
えいようしっちょう /栄養失調/
えいようしどうかんり /栄養指導管理/
えいようしゅーと /栄養シュート/
えいようしょく /栄養食/
えいようじょうたい /栄養状態/
えいようそ /栄養素/
えいようはんしょく /栄養繁殖/
えいようぶん /栄養分/
えいようほきゅう /栄養補給/
えいようほきゅうしょくひん /栄養補給食品/
えいようほじょしょくひん /栄養補助食品/
えいようりょう /栄養量/
えいらく /永楽/
えいり /営利/鋭利/絵入り/
えいりあん /エイリアン/
えいりか /営利化/
えいりかつどう /営利活動/
えいりきぎょう /営利企業/
えいりこうい /営利行為/
えいりしゅぎ /営利主義/
えいりせい /営利性/
えいりだんたい /営利団体/
えいりてき /営利的/
えいりもくてき /営利目的/
えいりもくてきか /営利目的可/
えいりもくてききじ /営利目的記事/
えいりもくてききんし /営利目的禁止/
えいりもくてきこうい /営利目的行為/
えいりもくてきふか /営利目的不可/
えいりもくてきりよう /営利目的利用/
えいりもんだい /営利問題/
えいりょ /叡慮/
えいりょう /英領/
えいりりよう /営利利用/
えいりん /営林/映倫/英鈴/
えいりんしょ /営林署/
えいりんしょちょう /営林署長/
えいれい /英霊/
えいれんぽう /英連邦/
えいろんぶん /英論文/
えいわ /英和/
えいわじしょ /英和辞書/
えいわじてん /英和辞典/英和辞書/
えいわだいじてん /英和大辞典/
えいわちゅうじてん /英和中辞典/
えうぽまちあか /エウポマチア科/Eupomatiaceae/
ええた /η/Η/
えかき /絵描き/絵書き/
えがお /笑顔/
えがしら /江頭/
えがみ /江上/
えがら /絵柄/
えがわ /江川/
えがわすぐる /江川卓/
えき /駅/益/液/疫/役/易/繹/伯/腋/奕/懌/掖/蜴/驛/依帰/亦/
えきあつぷれす /液圧プレス/
えきあんない /駅案内/
えきいん /駅員/
えきいんじしん /駅員自身/
えきいんはいちえき /駅員配置駅/
えきうら /駅裏/
えきうり /駅売り/
えきおん /液温/
えきおんちょうせつ /液温調節/
えきか /液化/腋窩/液果/
えきかかりいん /駅係員/
えきかがす /液化ガス/
えきかちっそ /液化窒素/
えきかん /駅間/
えきかんきょり /駅間距離/
えきが /腋芽/
えきがく /疫学/
えきがくしゃ /疫学者/
えきがくてきちょうさ /疫学的調査/
えきがわ /駅側/
えききょう /易経/
えききん /益金/
えきげしゃ /駅下車/
えきこうない /駅構内/
えきごと /駅毎/
えきしせつ /駅施設/
えきしゃ /易者/駅舎/
えきしゃあと /駅舎跡/
えきしゅうへん /駅周辺/
えきしゅうへんかくしょ /駅周辺各所/
えきしゅうへんちず /駅周辺地図/
えきしょう /液晶/
えきしょうがめん /液晶画面/
えきしょうぱねる /液晶パネル/
えきしょうひょうじ /液晶表示/
えきしょうひょうじしき /液晶表示式/
えきじたい /駅自体/
えきじょう /液状/
えきすう /駅数/
えきすぱーと /エキスパート/
えきせい /液性/
えきせいぎょそうち /駅制御装置/
えきせん /易占/
えきぜんぶ /駅全部/
えきそんしつじかん /駅損失時間/
えきたい /液体/
えきたいすいしょう /液体水晶/
えきたいせんざい /液体洗剤/
えきたいちっそ /液体窒素/
えきたいにんげん /液体人間/
えきたいねんりょう /液体燃料/
えきたいはみがき /液体歯磨/
えきだん /易断/
えきちゅう /益虫/液中/
えきちょう /駅長/益鳥/
えきちょうあて /駅長宛/
えきちょうしつ /駅長室/
えきてき /液滴/
えきてきか /液滴化/
えきでん /駅伝/驛傳/
えきでんたいかい /駅伝大会/
えきとう /駅頭/
えきどめ /駅止/駅止め/
えきない /駅内/
えきね /駅寝/
えきばいてん /駅売店/
えきばしゃ /駅馬車/
えきばしゃていりゅうじょ /駅馬車停留所/
えきひょうじ /駅表示/
えきびょう /疫病/
えきびょうがみ /疫病神/
えきびる /駅ビル/
えきふきん /駅付近/
えきべん /駅弁/
えきべんぎょうしゃ /駅弁業者/
えきべんや /駅弁屋/
えきほんや /駅本屋/
えきまえ /駅前/
えきまえさいかいはつ /駅前再開発/
えきまえしょうてんがい /駅前商店街/
えきまえどおり /駅前通り/
えきまえひろば /駅前広場/
えきまえりょかん /駅前旅館/
えきむ /役務/
えきめい /駅名/
えきめいかいしょう /駅名改称/
えきめいかしょう /駅名仮称/
えきめいしょういん /駅名小印/
えきめいばん /駅名板/
えきめいひょう /駅名標/駅名票/駅名表/
えきめいひょうきばん /駅名表記板/
えきめいひょうじ /駅名表示/
えきや /駅家/
えきり /疫痢/
えきりようしゃ /駅利用者/
えきれい /液冷/
えくすおーじゃん /XO醤/
えくぼ /エクボ/靨/
えぐち /江口/
えけい /恵瓊/
えこ /依怙/
えこー /エコー/
えこう /回向/
えこじ /依怙地/
えこだ /江古田/
えこのみすと /エコノミスト/
えころじ /エコロジ/
えごいずむ /エゴイズム/
えごころ /絵心/
えさ /餌/
えさか /江坂/
えさかてん /江坂店/
えさき /江崎/
えさぎ /餌木/
えさし /江差/江刺/枝幸/江指/
えさだい /餌代/
えさづり /餌釣り/
えさば /餌場/
えさばこ /餌箱/
えさや /餌屋/
えさん /恵山/
えざき /江崎/
えざきぐりこ /江崎グリコ/
えざきれおな /江崎玲於奈/
えざら /絵皿/
えざわ /江沢/江澤/
えし /壊死/画師/絵師/
えしゃく /会釈/
えじ /衛士/江地/
えじき /餌食/
えじぷと /埃及/
えじま /江島/江嶋/
えすえすせいやく /エスエス製薬/
えすかれーと /エスカレート/
えすがた /絵姿/
えすしき /S式/
えすせき /Ｓ席/
えすびーしょくひん /ヱスビー食品/
えすぺらんと /エスペラント/
えず /絵図/
えずみ /江角/
えずりこ /江釣子/
えせ /似非/似而非/
えそ /壊疽/
えそらごと /絵空事/
えぞ /蝦夷/
えぞえ /江副/
えぞら /江面/
えた /穢多/
えたい /得体/
えたじま /江田島/
えだ /枝/江田/荏田/
えだがり /枝刈り/
えだげ /枝毛/
えだじょう /枝状/
えだずみ /枝炭/
えだせん /枝線/
えだなみ /枝並/
えだは /枝葉/
えだばり /枝針/
えだばん /枝番/
えだぶり /枝振り/
えだまつ /枝松/
えだまめ /枝豆/
えだみち /枝道/
えだわかれ /枝わかれ/枝分かれ/
えち /乢/
えちがわ /愛知川/
えちけっと /エチケット/
えちご /越後/
えちごこうつう /越後交通/
えちごせん /越後線/
えちごや /越後屋/
えちごゆざわ /越後湯沢/
えちごゆざわえき /越後湯沢駅/
えちぜん /越前/
えちぜんかいがん /越前海岸/
えちぜんみさき /越前岬/
えっきょう /越境/
えっきょうしゃ /越境者/
えっきょうろせん /越境路線/
えっけん /越権/謁見/
えっけんこうい /越権行為/
えっせい /エッセイ/
えっせいすと /エッセイスト/
えっちゅう /越中/
えっちゅうじま /越中島/
えっちゅうだいもんえき /越中大門駅/
えっとう /越冬/
えっとういちねんせいそうほん /越冬一年生草本/
えっとうたい /越冬隊/
えっぺい /閲兵/
えっぺいしき /閲兵式/
えつ /越/悦/閲/謁/噎/戉/粤/鉞/咽/
えつお /悦夫/
えつこ /悦子/えつ子/恵津子/英津子/絵津子/
えつじ /悦司/悦次/
えつたろう /悦太郎/
えつねん /越年/
えつや /悦哉/悦也/
えつよ /悦代/
えつらく /悦楽/
えつらん /閲覧/
えつらんかのう /閲覧可能/
えつらんきょひ /閲覧拒否/
えつらんしつ /閲覧室/
えつらんせいきゅう /閲覧請求/
えつろう /悦朗/
えづくり /絵作り/
えて /得手/
えてき /絵的/
えてこう /猿猴/
えてして /得てして/
えてふえて /得手不得手/
えでぃた /エディタ/
えと /干支/
えとう /衛藤/江藤/江頭/恵藤/
えとく /会得/
えとろふ /択捉/
えど /江戸/穢土/
えどがわ /江戸川/
えどがわく /江戸川区/
えどがわくみん /江戸川区民/
えどがわじょし /江戸川女子/
えどがわばし /江戸川橋/
えどがわらんぽ /江戸川乱歩/
えどがわらんぽしょう /江戸川乱歩賞/
えどき /江戸期/
えどくら /江戸蔵/
えどさき /江戸崎/
えどざき /江戸崎/
えどじだい /江戸時代/
えどじだいこうき /江戸時代後期/
えどじょう /江戸城/
えどっこ /江戸っ子/
えどてん /江戸展/
えどばくふ /江戸幕府/
えどひがん /江戸彼岸/
えどむらさき /江戸紫/
えどや /江戸屋/
えどやまてべん /江戸山手弁/
えな /恵那/絵奈/
えなざくら /恵那櫻/
えなじー /エナジー/
えなつ /江夏/
えなみ /榎並/
えなり /江成/
えにし /縁/
えにっき /絵日記/
えにわ /恵庭/
えぬえちけいほーる /ＮＨＫホール/
えぬかっけい / n 角形/
えぬきょう /Ｎ響/
えぬこ /Ｎ個/
えぬじげん /Ｎ次元/
えぬじげんくうかん /Ｎ次元空間/
えぬま /江沼/
えねるぎ /エネルギ/
えねるぎー /エネルギー/
えねるぎーぐん /エネルギー群/
えねるぎーそんしつ /エネルギー損失/
えの /榎/
えのき /榎/榎木/
えのきだ /榎田/
えのきど /榎戸/
えのぐ /絵の具/絵具/
えのしま /江の島/江ノ島/
えのぞの /榎園/
えのでん /江の電/
えのと /榎戸/
えのもと /榎本/
えはがき /絵葉書/絵はがき/
えはた /江幡/江畑/
えはら /江原/荏原/
えばた /江端/
えばら /江原/
えばらこ /桧原湖/
えひめ /愛媛/
えひめけん /愛媛県/
えひめしんぶんしゃ /愛媛新聞社/
えひめだい /愛媛大/
えひめだいがく /愛媛大学/
えび /海老/蛯/蝦/鰕/エビ/
えびさわ /海老沢/海老澤/
えびす /恵比寿/夷/恵比須/戎/狄/貊/ヱビス/蛭子/胡/
えびすがお /恵比寿顔/
えびすこうじょう /恵比寿工場/
えびすちょう /恵比寿町/
えびすばし /戎橋/
えびすほうこう /恵比寿方向/
えびすほうめん /恵比寿方面/
えびすや /蛭子屋/
えびづか /海老塚/
えびな /海老名/蝦名/蛯名/
えびなきんぺん /海老名近辺/
えびなし /海老名市/
えびね /恵比根/
えびはら /蛯原/海老原/
えびふらい /海老フライ/
えぴそーど /エピソード/
えふだ /絵札/
えふで /絵筆/
えべ /江辺/
えべつ /江別/
えべつえき /江別駅/
えべつしはつ /江別始発/
えべつはつ /江別発/
えほん /絵本/
えぼし /烏帽子/
えぽ /ＥＰＯ/
えま /絵麻/絵馬/
えまき /絵巻/
えみ /恵美/栄美/絵美/映見/恵実/笑/笑み/江民/エミ/
えみか /恵美香/
えみこ /英美子/絵己子/絵美子/恵美子/栄美子/江美子/
えみり /恵美里/
えむかえ /江迎/
えむけのばーん /MKENO-BURN/
えむら /江村/
えめらるど /エメラルド/
えもじ /絵文字/
えもと /江本/絵本/柄本/
えもの /獲物/得物/
えもん /衣紋/衛門/
えら /鰓/江良/腮/
えらー /エラー/
えらさ /偉さ/
えらびかた /選び方/
えらぼう /選ぼう/
えり /襟/絵里/恵利/恵里/エリ/衣理/英理/愛理/恵理/絵莉/えり/衿/江利/惠理/絵理/枝里/愛莉/
えりーと /エリート/
えりあ /エリア/
えりか /恵理香/絵里花/惠理香/江利香/
えりくび /襟首/
えりぐり /襟刳り/
えりこ /英里子/絵理子/えり子/英理子/絵梨子/江梨子/恵理子/江利子/江里子/恵里子/
えりごのみ /えり好み/選り好み/
えりさ /恵利沙/
えりしょう /衿章/襟章/
えりな /江理奈/
えりまき /襟巻/
えりみ /恵里美/
えりもと /襟元/
えりもみさき /襟裳岬/
えるなーど /エルナード/
えれくとろにくす /エレクトロニクス/
えれべーた /エレベータ/
えん /円/園/延/演/宛/煙/縁/遠/塩/援/鉛/炎/苑/宴/淵/鴛/薗/艶/焔/沿/燕/猿/厭/掩/怨/奄/堰/￥/焉/偃/冤/嚥/圓/圜/婉/嫣/寃/悁/捐/掾/檐/櫞/衍/淹/渕/渊/湲/烟/爰/筵/篶/簷/臙/艷/蜒/蜿/袁/覃/讌/轅/閻/閹/魘/鹽/黶/閼/垣/鳶/媛/
えんい /遠位/
えんいん /遠因/
えんうんどう /円運動/
えんえい /遠泳/
えんえき /演繹/
えんえきかのう /演繹可能/
えんえききこう /演繹機構/
えんえきぎ /演繹木/
えんえきけい /演繹系/
えんえきたいけい /演繹体系/
えんえきてき /演繹的/
えんえきてきどうしゅつ /演繹的導出/
えんえきてきどうしゅつほう /演繹的導出法/
えんえきほう /演繹法/
えんえん /延々/奄奄/蜿蜒/蜿々/
えんか /演歌/塩化/円価/円貨/怨歌/嚥下/
えんかあえん /塩化亜鉛/
えんかい /宴会/沿海/遠海/
えんかいおう /塩化硫黄/
えんかいがかり /宴会係/
えんかいげい /宴会芸/
えんかいしゅう /沿海州/
えんかいしゅうりょうちょくご /宴会終了直後/
えんかいじょう /宴会場/
えんかいもくてき /宴会目的/
えんかいや /宴会屋/
えんかいよう /宴会用/
えんかかしゅ /演歌歌手/
えんかく /遠隔/沿革/
えんかくかんし /遠隔監視/
えんかくしゅうちゅうかんり /遠隔集中管理/
えんかくそうさ /遠隔操作/
えんかくち /遠隔地/
えんかくりょく /遠隔力/
えんかけい /演歌系/
えんかしょうじょ /演歌少女/
えんかちょう /演歌調/
えんかつ /円滑/
えんかつうんてん /円滑運転/
えんかつか /円滑化/
えんかつせい /円滑性/
えんかぶつ /塩化物/
えんかぶもん /演歌部門/
えんかる /遠軽/
えんかわせ /円為替/
えんかん /鉛管/円環/煙管/
えんかんさん /円換算/
えんかんじょう /円環状/
えんがい /円外/塩害/煙害/鉛害/
えんがる /遠軽/
えんがわ /縁側/
えんがん /沿岸/
えんがんゆうしょう /沿岸湧昇/
えんき /延期/塩基/
えんきごう /円記号/
えんきどう /円軌道/
えんきどううんどう /円軌道運動/
えんきどうそくど /円軌道速度/
えんきはいれつ /塩基配列/
えんきょう /燕京/円鏡/
えんきょく /婉曲/
えんきょり /遠距離/
えんきょりがわ /遠距離側/
えんきょりこうげき /遠距離攻撃/
えんきょりじゅしん /遠距離受信/
えんきょりたいしょう /遠距離対象/
えんきょりつうがくしゃ /遠距離通学者/
えんきょりつうきん /遠距離通勤/
えんきょりつうきんきゃく /遠距離通勤客/
えんきょりつうきんしゃ /遠距離通勤者/
えんきょりりようしゃ /遠距離利用者/
えんきり /縁切り/
えんきりでら /縁切り寺/
えんきん /遠近/
えんきんかん /遠近感/
えんきんほう /遠近法/
えんぎ /演技/縁起/
えんぎかい /演技会/
えんぎしょ /縁起書/
えんぎは /演技派/
えんぎもの /縁起物/
えんぎりょく /演技力/
えんぐみ /縁組/
えんぐん /援軍/
えんけい /円形/遠景/冤刑/
えんけいげきじょう /円形劇場/
えんけいだんめん /円形断面/
えんけいひょうしき /円形標識/
えんげ /嚥下/
えんげい /園芸/演芸/園藝/
えんげいか /園芸家/
えんげいざっし /園芸雑誌/
えんげいしゅ /園芸種/
えんげいたいしょう /演芸大賞/
えんげいてん /園芸店/
えんげいぶ /園芸部/
えんげいめい /園芸名/
えんげいよう /園芸用/
えんげき /演劇/
えんげきかつどう /演劇活動/
えんげきかんけい /演劇関係/
えんげきしゅうだん /演劇集団/
えんげきてき /演劇的/
えんげきぶ /演劇部/
えんげきよう /演劇用/
えんげきりろん /演劇理論/
えんげきろん /演劇論/
えんげん /淵源/
えんこ /円弧/縁故/塩湖/
えんこうるい /円口類/
えんこく /遠国/
えんこけい /円弧形/
えんこじょう /円弧上/
えんこん /怨恨/
えんご /援護/掩護/
えんごか /援護下/
えんごしゃげき /援護射撃/掩護射撃/
えんさ /怨嗟/
えんさん /塩酸/演算/
えんさんし /演算子/
えんざい /冤罪/寃罪/
えんざん /演算/塩山/圓山/
えんざんか /演算化/
えんざんかいすう /演算回数/
えんざんかいろ /演算回路/
えんざんき /演算器/演算機/
えんざんきごう /演算記号/
えんざんけっか /演算結果/
えんざんこうがく /演算工学/
えんざんこうそくか /演算高速化/
えんざんごさ /演算誤差/
えんざんし /演算子/
えんざんしき /演算式/
えんざんじかん /演算時間/
えんざんじゅんい /演算順位/
えんざんじゅんじょ /演算順序/
えんざんすう /演算数/
えんざんせいど /演算精度/
えんざんせいのう /演算性能/
えんざんそくど /演算速度/
えんざんのうりょく /演算能力/
えんざんぶ /演算部/
えんざんほう /演算法/
えんざんめい /演算名/
えんざんりょう /演算量/
えんし /遠視/
えんしつ /煙室/
えんしゃ /演者/
えんしゃっかん /円借款/
えんしゅう /演習/円周/遠州/
えんしゅうおおはし /遠州大橋/
えんしゅうしえん /演習支援/
えんしゅうしつ /演習室/
えんしゅうしょ /演習書/
えんしゅうじょう /円周上/演習場/
えんしゅうてつどう /遠州鉄道/
えんしゅうはまかいがん /遠州浜海岸/
えんしゅうはままつじょう /遠州浜松城/
えんしゅうべん /遠州弁/
えんしゅうもんだい /演習問題/
えんしゅうりつ /円周率/
えんしゅつ /演出/
えんしゅついと /演出意図/
えんしゅつか /演出家/
えんしゅつしゃ /演出者/
えんしゅつじ /演出時/
えんしゅつじょう /演出上/
えんしゅつたいしょう /演出対象/
えんしゅつてき /演出的/
えんしゅつめん /演出面/
えんしょ /炎暑/
えんしょう /炎症/延焼/煙硝/艶笑/円生/
えんしょうこばなし /艶笑小噺/
えんしょうじ /円勝寺/
えんしん /遠心/延伸/
えんしんか /延伸化/
えんしんしき /遠心式/
えんしんせい /遠心性/
えんしんちゅうぞうき /遠心鋳造機/
えんしんてき /遠心的/
えんしんぶぶん /延伸部分/
えんしんぶんり /遠心分離/
えんしんぶんりき /遠心分離機/遠心分離器/
えんしんりょく /遠心力/
えんじ /園児/臙脂/槐/
えんじぇるす /エンジェルス/
えんじぇるず /エンジェルズ/
えんじたち /園児達/
えんじつてん /遠日点/
えんじにあ /エンジニア/
えんじにありんぐ /エンジニアリング/
えんじゃ /縁者/演者/
えんじゅく /円熟/
えんじゅくみ /円熟味/
えんじょ /援助/
えんじょい /エンジョイ/
えんじょう /遠城/炎上/円状/
えんじょうじ /円城寺/
えんじょきん /援助金/
えんじょだんたい /援助団体/
えんじょひ /援助費/
えんじょぶき /援助武器/
えんじょぶっし /援助物資/
えんじん /エンジン/猿人/円陣/
えんすい /円錐/塩水/
えんすいけい /円錐形/
えんすいこう /塩水港/
えんすいじょう /円錐状/
えんすいせきそう /円錐積層/
えんすいだい /円錐台/
えんすいめん /円錐面/
えんずい /延髄/
えんずいぎり /延髄斬/
えんせい /遠征/厭世/縁生/
えんせいがい /袁世凱/
えんせいさき /遠征先/
えんせいたい /遠征隊/
えんせいちゅう /遠征中/
えんせいてき /厭世的/
えんせいひ /遠征費/
えんせき /縁石/宴席/遠戚/
えんせきがいせん /遠赤外線/
えんせきがいせんばいせん /遠赤外線倍煎/
えんせん /沿線/厭戦/
えんせんかくし /沿線各市/
えんせんじゅうみん /沿線住民/
えんせんじんこう /沿線人口/
えんせんず /円線図/
えんせんぜんたい /沿線全体/
えんせんちいき /沿線地域/
えんぜつ /演説/演舌/
えんぜつしゅう /演説集/
えんぜつほう /演説法/
えんぜん /艶然/婉然/嫣然/
えんそ /塩素/
えんそう /演奏/
えんそうあいこうか /演奏愛好家/
えんそうか /演奏家/
えんそうかい /演奏会/
えんそうかいけいしき /演奏会形式/
えんそうかいし /演奏開始/
えんそうかつどう /演奏活動/
えんそうかのう /演奏可能/
えんそうきかい /演奏機会/
えんそうきょく /演奏曲/
えんそうきょくもく /演奏曲目/
えんそうぎじゅつ /演奏技術/
えんそうけいしき /演奏形式/
えんそうけいたい /演奏形態/
えんそうけん /演奏権/
えんそうこうか /演奏効果/
えんそうご /演奏後/
えんそうごうせい /演奏合成/
えんそうしゃ /演奏者/
えんそうしゃめい /演奏者名/
えんそうしゅうりょうご /演奏終了後/
えんそうじ /演奏時/
えんそうじかん /演奏時間/
えんそうじかんひょうじ /演奏時間表示/
えんそうじたい /演奏自体/
えんそうじょう /演奏上/
えんそうじょうほう /演奏情報/
えんそうせいぎょ /演奏制御/
えんそうちゅう /演奏中/
えんそうないよう /演奏内容/
えんそうのうりょく /演奏能力/
えんそうば /円相場/
えんそうひょうげん /演奏表現/
えんそうふのう /演奏不能/
えんそうほう /演奏法/
えんそうようしき /演奏様式/
えんそうりょく /演奏力/
えんそうりょこう /演奏旅行/
えんそうれい /演奏例/
えんそうれんしゅう /演奏練習/
えんそく /遠足/
えんそけい /塩素系/
えんそけいさっきんざい /塩素系殺菌剤/
えんそけいひょうはくざい /塩素系漂白剤/
えんそさん /塩素酸/
えんそしょうどく /塩素消毒/
えんそひょうはく /塩素漂白/
えんぞう /円蔵/
えんた /遠田/苑田/
えんたーていめんと /エンターテイメント/
えんたい /延滞/掩体/淹滞/
えんたいきん /延滞金/
えんたいぶん /延滞分/
えんたいりそく /延滞利息/
えんたいりょう /延滞料/
えんたく /円卓/
えんたんい /円単位/
えんだ /苑田/遠田/
えんだい /演題/遠大/円台/演台/縁台/
えんだか /円高/
えんだかさえきかんげん /円高差益還元/
えんだて /円建て/
えんだま /円玉/
えんだん /演壇/縁談/
えんち /遠地/
えんちくでんち /鉛蓄電池/
えんちてん /遠地点/
えんちゃく /延着/
えんちゅう /円柱/
えんちゅうじょう /円柱状/
えんちゅうめん /円柱面/
えんちょう /延長/園長/
えんちょううんてん /延長運転/
えんちょうきかんちゅう /延長期間中/
えんちょうきゅう /円頂丘/
えんちょうくかん /延長区間/
えんちょうけいかく /延長計画/
えんちょうこうじ /延長工事/
えんちょうじょう /延長上/
えんちょうせん /延長線/延長戦/
えんちょうせんじょう /延長線上/
えんちょうぜんはん /延長前半/
えんちょうぶ /延長部/
えんちょうぶぶん /延長部分/
えんちょく /鉛直/
えんちょくこうぞう /鉛直構造/
えんちょくこうぞうほうていしき /鉛直構造方程式/
えんちょくせん /鉛直線/
えんちょくほうこう /鉛直方向/
えんちん /遠沈/
えんてい /園丁/堰堤/
えんてつ /遠鉄/
えんてつでんしゃ /遠鉄電車/
えんてつはままつ /遠鉄浜松/
えんてん /遠点/炎天/
えんてんか /炎天下/
えんでぃんぐ /エンディング/
えんでん /塩田/
えんとう /円筒/遠投/
えんとうけい /円筒形/円筒型/
えんとうじょう /円筒状/
えんとつ /煙突/
えんとり /エントリ/
えんとりー /エントリー/
えんとろぴいさいだいりろん /エントロピー最大理論/
えんど /エンド/塩度/
えんどーちぇーん /エンドーチェーン/
えんどう /遠藤/沿道/豌豆/
えんどうしゅうさく /遠藤周作/
えんどうまめ /豌豆豆/
えんない /園内/円内/
えんないあんない /園内案内/
えんにち /縁日/
えんねつ /炎熱/
えんのした /縁の下/
えんのすけ /猿之助/
えんばん /円板/円盤/
えんばんがた /円盤型/
えんばんじょう /円盤状/
えんばんぶ /円盤部/
えんぱく /延泊/
えんぱくかのう /延泊可能/
えんぱくぶん /延泊分/
えんぱくりょうきん /延泊料金/
えんぱつ /延発/
えんび /燕尾/
えんびふく /燕尾服/
えんぴつ /鉛筆/
えんぶ /円舞/演武/
えんぶきょく /円舞曲/
えんぶん /塩分/艶聞/
えんぶんのうど /塩分濃度/
えんぶんれん /遠文連/
えんへんこう /円偏光/
えんべつ /遠別/
えんべろーぷ /エンベロープ/
えんぺい /掩蔽/
えんぺん /縁辺/
えんぺんたいざ /縁辺胎座/
えんぼう /遠望/
えんぽう /遠方/演報/
えんぽうば /遠方場/
えんま /閻魔/
えんまく /煙幕/
えんまくはっせいそうち /煙幕発生装置/
えんまん /円満/
えんまんかいけつ /円満解決/
えんみらい /遠未来/
えんむすび /縁結び/
えんめい /延命/
えんめいこうじ /延命工事/
えんめいほうほう /延命方法/
えんもく /演目/
えんやす /円安/
えんゆうかい /園遊会/宴遊会/
えんよう /援用/遠洋/
えんようこうかい /遠洋航海/
えんらい /遠雷/遠来/
えんらく /猿楽/円楽/
えんらくちょう /猿楽町/
えんり /厭離/
えんりゃくじ /延暦寺/
えんりょ /遠慮/
えんろ /遠路/
お /尾/夫/汚/御/於/雄/男/小/生/織/緒/央/牡/桜/穂/勇/朗/郎/唹/嗚/塢/淤/悪/乎/将/苧/麻/和/
お> /御/
おーけすとら /オーケストラ/
おーすとらりあ /濠太剌利/
おーすとりあ /墺太利/
おーだー /オーダー/
おーでぃお /オーディオ/
おーとばい /オートバイ/
おーとめーしょん /オートメーション/
おーな /オーナ/
おーなー /オーナー/
おーばー /オーバー/
おーばーらっぷ /オーバーラップ/
おーぷん /オープン/
おーむ /Ω/王蟲/
おーやんふぃふぃ /欧陽菲菲/
おーる /オール/
おーれ /ＯＲＥ/
おあいそ /お愛想/
おあいて /お相手/御相手/
おあしす /オアシス/
おあずけ /お預け/
おあそび /お遊び/
おあふとう /オアフ島/
おあらため /お改め/
おい /甥/追/及/笈/老い/
おいえ /尾家/
おいえげい /お家芸/御家芸/御家藝/
おいえそうどう /御家騒動/
おいおい /追々/
おいかぜ /追い風/
おいかわ /及川/追川/生川/
おいけ /御池/
おいこし /追い越し/追越/追越し/
おいこしえき /追越駅/
おいこししゃせん /追越車線/
おいこししゃせんがわ /追越車線側/
おいこみ /追い込み/
おいこん /追いコン/
おいしゃ /お医者/
おいしんぼ /美味しんぼ/
おいすたー /オイスター/
おいそがしい /お忙しい/
おいそぎ /お急ぎ/
おいた /置いた/
おいたち /生い立ち/
おいだし /追出/
おいち /尾市/
おいつ /老津/
おいて /於/於て/
おいのり /お祈り/
おいはま /追浜/生浜/
おいべ /及部/
おいまつ /老松/
おいまわし /追廻/
おいまわしじゅうたく /追廻住宅/
おいめ /負い目/
おいめい /甥姪/
おいらせ /奥入瀬/
おいらん /花魁/
おいる /オイル/
おいろなおし /お色直し/御色直し/
おいわい /お祝い/御祝い/御祝/
おいわけ /追分/
おいわけちょう /追分町/
おう /応/欧/横/王/黄/鴬/往/鴎/桜/皇/旺/襖/央/押/翁/凹/殴/奥/應/凰/嘔/嚶/墺/奧/媼/徃/怏/懊/枉/櫻/歐/殃/毆/汪/泱/泓/浤/澳/瓮/甌/秧/罌/蓊/謳/鏖/閘/鞅/鸚/悒/惶/姶/鴨/邑/
おうあ /歐亞/
おうい /王位/
おういけいしょう /王位継承/
おういけいしょうしゃ /王位継承者/
おういせん /王位戦/
おういつ /横溢/汪溢/
おういん /押印/桜蔭/
おういんこうこう /桜蔭高校/
おういんご /欧印語/
おうう /奥羽/
おううせん /奥羽線/
おううせんやまがた /奥羽線山形/
おううほんせんけいゆう /奥羽本線経由/
おううほんせんほくぶ /奥羽本線北部/
おうえん /応援/
おうえんえんぜつ /応援演説/
おうえんか /応援歌/
おうえんかいせつ /応援解説/
おうえんせき /応援席/
おうえんだん /応援団/
おうえんだんいん /応援団員/
おうえんだんちょう /応援団長/
おうえんぶ /応援部/
おうえんぶいん /応援部員/
おうえんよう /応援用/
おうおう /往々/
おうか /桜花/謳歌/押下/欧化/応化/櫻花/
おうかく /旺角/
おうかくまく /横隔膜/横膈膜/
おうかしょう /桜花賞/
おうかしょうぐみ /桜花賞組/
おうかしょうば /桜花賞馬/
おうかじ /押下時/
おうからんまん /桜花爛漫/
おうかん /王冠/往還/
おうが /横臥/
おうがい /鴎外/
おうき /王妃/
おうきゅう /応急/王宮/
おうきゅうきゅうごしょち /応急救護処置/
おうきゅうしゅうり /応急修理/
おうきゅうしょち /応急処置/
おうきゅうそち /応急措置/
おうきゅうたいさく /応急対策/
おうきゅうてあて /応急手当/
おうきゅうてき /応急的/
おうぎ /扇/奥義;極意。「おくぎ」ともいう/奥儀;「奥義」と同じ/横議;勝手に論議すること/
おうぎがた /扇形/
おうぎがやつ /扇ヶ谷/
おうぎさわ /扇沢/
おうぎや /扇谷/
おうけ /王家/
おうけとり /お受け取り/
おうこう /横行/往航/王侯/
おうこく /王国/
おうご /朷/
おうごん /黄金/
おうごんき /黄金期/
おうごんしゅうかん /黄金週間/
おうごんじだい /黄金時代/
おうごんちゅう /黄金虫/
おうごんひ /黄金比/
おうごんものがたり /黄金物語/
おうさか /大坂/逢坂/
おうさだはる /王貞治/
おうさつ /鏖殺/殴殺/応札/
おうさま /王様/
おうざ /王座/
おうざけってい /王座決定/
おうざけっていせん /王座決定戦/
おうざせん /王座戦/
おうざだっかい /王座奪回/
おうざだっしゅ /王座奪取/
おうざてんらく /王座転落/
おうざとういつせん /王座統一戦/
おうざぼうえい /王座防衛/
おうし /牡牛/横死/雄牛/
おうしざ /牡牛座/
おうしつ /王室/
おうしゃ /王者/
おうしゅ /応手/
おうしゅう /応酬/欧州/押収/奥州/歐州/歐洲/欧洲/
おうしゅうかっこく /欧州各国/
おうしゅうけい /欧州系/
おうしゅうしじょう /欧州市場/
おうしゅうしゃ /欧州車/
おうしゅうしょこく /欧州諸国/
おうしゅうしよう /欧州仕様/
おうしゅうせい /欧州製/
おうしゅうせんしゅけん /欧州選手権/
おうしゅうぜい /欧州勢/
おうしゅうなみ /欧州並/
おうしゅうばん /欧州版/
おうしゅうふじわら /奥州藤原/
おうしゅうふじわらし /奥州藤原氏/
おうしゅうほうめん /欧州方面/
おうしょう /王将/応召/
おうしょうかい /王将会/
おうしょうぎむ /応召義務/
おうしょうせん /王将戦/
おうしょく /黄色/応嘱/
おうしん /往信/往診/
おうじ /王子/往時/皇子/欧字/王寺/
おうじえき /王子駅/王寺駅/
おうじさま /王子様/
おうじせいし /王子製紙/
おうじせん /王子線/
おうじゃ /王者/
おうじゃてんらく /王者転落/
おうじゃにちだい /王者日大/
おうじやま /皇子山/
おうじやまきゅうじょう /王子山球場/
おうじょ /王女/皇女/
おうじょう /往生/応情/王城/
おうじょうぎわ /往生際/
おうじょうけん /応情研/応用情報学研究センター/
おうじょさま /王女様/
おうすい /王水/
おうすう /応数/
おうせ /逢瀬/
おうせい /旺盛/王政/王制/
おうせいこっか /王政国家/
おうせいもう /黄青盲/
おうせつ /応接/
おうせつしつ /応接室/
おうせつま /応接間/
おうせん /応戦/鏖戦/
おうぜんじ /王禅寺/
おうそ /応訴/
おうそうじ /大掃除/
おうそうだん /応相談/
おうぞく /王族/
おうた /桜多/
おうたい /応対/横隊/黄体/
おうだ /殴打/
おうだく /応諾/
おうだん /横断/黄胆/応談/黄疸/
おうだんか /応談可/
おうだんかのう /応談可能/
おうだんきょう /横断橋/
おうだんちゅう /横断中/
おうだんてき /横断的/
おうだんほこうしゃ /横断歩行者/
おうだんほどう /横断歩道/
おうだんまく /横断幕/
おうだんめん /横断面/
おうち /尾内/邑智/欒/相知/
おうちゃく /横着/
おうちゃくもの /横着者/
おうちょう /王朝/
おうて /王手/
おうてい /奥底/
おうてひしゃ /王手飛車/
おうてびしゃ /王手飛車/
おうてん /横転/
おうでん /応電/
おうでんけん /応電研/
おうと /嘔吐/王都/
おうとう /応答/桜桃/櫻桃/鴨東/大塔/
おうとうかんすう /応答関数/
おうとうきょくせん /応答曲線/
おうとうしゃ /応答者/
おうとうしゅっぱん /桜桃出版/
おうとうしょぼう /桜桃書房/
おうとうしんごう /応答信号/
おうとうじかん /応答時間/
おうとうせい /応答性/
おうとうそくど /応答速度/
おうとうちょう /応答長/
おうとうてき /応答的/
おうとうぶん /応答文/
おうとうや /応答野/
おうとつ /凹凸/
おうどいろ /黄土色/
おうどう /王道/横道/黄道/横動/
おうどうこう /黄銅鉱/黄道光/
おうどうこうたい /黄道光帯/
おうどうざひょう /黄道座標/
おうどうたい /黄道帯/
おうな /媼/嫗/翁/
おうなつ /押捺/
おうねつびょう /黄熱病/
おうねん /往年/
おうのう /懊悩/
おうはん /凹版/
おうばんが /凹版画/
おうばんぶるまい /椀飯振舞/椀飯振舞い/椀飯振る舞い/
おうひ /王妃/
おうびりん /桜美林/
おうびりんこうこう /桜美林高校/
おうびりんだいがく /桜美林大学/
おうふう /欧風/
おうふく /往復/
おうふくえんちょう /往復延長/
おうふくきっぷ /往復切符/
おうふくこうくうけん /往復航空券/
おうふくじかん /往復時間/
おうふくじかんさ /往復時間差/
おうふくじょうしゃけん /往復乗車券/
おうふくていきれっしゃ /往復定期列車/
おうふくにじかん /往復二時間/
おうふくはがき /往復葉書/
おうふくはん /往復半/
おうふくぶんうんちん /往復分運賃/
おうふくよう /往復用/
おうふくわり /往復割/
おうふくわりびき /往復割引/
おうふくわりびききかん /往復割引期間/
おうふくわりびききっぷ /往復割引切符/
おうぶつ /応物/応用物理/
おうぶん /欧文/応分/
おうぶんし /欧文誌/
おうぶんしゃ /旺文社/
おうぶんしゃぶんこ /旺文社文庫/
おうぶんしょりきのう /欧文処理機能/
おうへい /横柄/
おうへん /応変/
おうべい /欧米/
おうべいがた /欧米型/
おうべいけい /欧米系/
おうべいしき /欧米式/
おうべいしょこく /欧米諸国/
おうべいじん /欧米人/
おうべいば /欧米馬/
おうべいれっきょう /欧米列強/
おうほう /応報/應報/
おうぼ /応募/
おうぼう /横暴/
おうぼきかん /応募期間/
おうぼけん /応募券/
おうぼさくひん /応募作品/
おうぼしかく /応募資格/
おうぼしめきり /応募締切/
おうぼしめきりご /応募締切後/
おうぼしゃ /応募者/
おうぼしゃしめい /応募者氏名/
おうぼしゃぜんいん /応募者全員/
おうぼしゃたすう /応募者多数/
おうぼしゃたち /応募者達/
おうぼしゃふくすう /応募者複数/
おうぼしょるい /応募書類/
おうぼしょるいざいちゅう /応募書類在中/
おうぼじょうきょう /応募状況/
おうぼすう /応募数/
おうぼそうすう /応募総数/
おうぼたすう /応募他数/応募多数/
おうぼないよう /応募内容/
おうぼはがき /応募葉書/
おうぼばこ /応募箱/
おうぼほうほう /応募方法/
おうぼよう /応募用/
おうぼようこう /応募要項/
おうぼようし /応募用紙/
おうぼりゆう /応募理由/
おうま /逢魔/
おうまがとき /逢魔が刻/
おうみ /近江/青海/
おうみいまずえき /近江今津駅/
おうみいまづ /近江今津/
おうみいまづえき /近江今津駅/
おうみしおつ /近江塩津/
おうみしおつかん /近江塩津間/
おうみしおづ /近江塩津/
おうみじ /近江路/
おうみじかいそく /近江路快速/
おうみちょうしじょう /近江町市場/
おうみてつどう /近江鉄道/
おうみはちまん /近江八幡/
おうみまいこ /近江舞子/
おうむ /鸚鵡/雄武/王蟲/
おうむがえし /おうむ返し/
おうむちょう /雄武町/
おうめ /青梅/
おうめえき /青梅駅/
おうめかいどう /青梅街道/
おうめし /青梅市/
おうめしゃこ /青梅車庫/
おうめせん /青梅線/
おうめせんけいゆ /青梅線経由/
おうめせんけいゆう /青梅線経由/
おうめとっかい /青梅特快/
おうめん /凹面/
おうめんきょう /凹面鏡/
おうもんきん /横紋筋/
おうゆう /鴎友/
おうゆうがくえん /鴎友学園/
おうよう /応用/鷹揚/應用/
おうようおんきょう /応用音響/
おうようか /応用可/
おうようかいせき /応用解析/
おうようかいはつしつ /応用開発室/
おうようかがく /応用科学/
おうようかがくか /応用化学科/
おうようかんれん /応用関連/
おうようがっかい /応用学会/
おうようきのう /応用機能/
おうようぎじゅつ /応用技術/
おうようぎじゅつしつ /応用技術室/
おうようぎじゅつぶ /応用技術部/
おうようけんきゅう /応用研究/
おうようけんきゅうしつ /応用研究室/
おうようけんきゅうじょ /応用研究所/
おうようげんば /応用現場/
おうようこうがくせんこう /応用工学専攻/
おうようじゅつごけいさん /応用述語計算/
おうようじょう /応用上/
おうようじょうほう /応用情報/
おうようじょうほうがく /応用情報学/
おうようすいしんか /応用推進課/
おうようすうがく /応用数学/
おうようすうがくか /応用数学科/
おうようすうがくてき /応用数学的/
おうようすうがっか /応用数学科/
おうようすうり /応用数理/
おうようせい /応用性/
おうようせいひん /応用製品/
おうようせいめい /応用生命/
おうようそう /応用層/
おうようてき /応用的/
おうようてきのうりょく /応用的能力/
おうようでんし /応用電子/
おうようでんしぶ /応用電子部/
おうようでんしぶだい /応用電子部第/
おうようはんい /応用範囲/
おうようぶつり /応用物理/
おうようぶつりがく /応用物理学/
おうようぶつりがっか /応用物理学科/
おうようぶつりがっかい /応用物理学会/
おうようぶんや /応用分野/
おうようへん /応用編/
おうようめん /応用面/
おうようもんだい /応用問題/
おうようりきがく /応用力学/
おうようりょういき /応用領域/
おうようりょうしこうがく /応用量子光学/
おうようりょく /応用力/
おうようれい /応用例/
おうら /邑楽/
おうらい /往来/
おうりつがっかい /王立学会/
おうりょう /横領/
おうりょうし /押領使/
おうりょく /応力/
おうりょくしょく /黄緑色/
おうりょくど /応力度/
おうりん /黄燐/
おうれつか /横裂果/
おうれんあか /オウレン亜科/Coptidoideae/
おうろ /往路/
おえかき /お絵書き/お絵描き/お絵かき/
おえつ /嗚咽/
おえらがた /お偉方/
おお /大/多/夛/
おお> /大/
おおあかじ /大赤字/
おおあさ /大朝/
おおあざ /大字/
おおあし /大足/
おおあじ /大味/
おおあせ /大汗/
おおあたり /大当たり/
おおあな /大穴/
おおあばれ /大暴れ/
おおあま /大甘/
おおあみ /大網/
おおあみえき /大網駅/
おおあめ /大雨/
おおあめこうずいけいほう /大雨洪水警報/
おおあらい /大洗/
おおあれ /大荒れ/
おおい /大井/大飯/
おおいえ /大家/
おおいがわ /大井川/
おおいがわてつどう /大井川鉄道/
おおいけ /大池/
おおいけいば /大井競馬/
おおいけしぜんこうえん /大池自然公園/
おおいし /大石/
おおいしだ /大石田/
おおいしゃりょうこうじょう /大井車両工場/
おおいずみ /大泉/
おおいずみがくえん /大泉学園/
おおいずみがくえんちょう /大泉学園町/
おおいずみむらやくば /大泉村役場/
おおいそ /大磯/
おおいそがし /大忙し/
おおいそぎ /大急ぎ/
おおいた /大分/
おおいたかん /大分間/
おおいたけん /大分県/
おおいたけんみん /大分県民/
おおいたこうつう /大分交通/
おおいたし /大分市/
おおいたしない /大分市内/
おおいたたいかい /大分大会/
おおいただい /大分大/
おおいただいがく /大分大学/
おおいたほうそう /大分放送/
おおいち /大市/
おおいちばん /大一番/
おおいちょう /大井町/大堰町/大銀杏/
おおいと /大糸/
おおいとせん /大糸線/
おおいに /大いに/
おおいのかみ /大炊頭/
おおいまち /大井町/
おおいまちかん /大井町間/
おおいまちせん /大井町線/
おおいまちはつ /大井町発/
おおいまちほうめん /大井町方面/
おおいむさしのかん /大井武蔵野館/
おおいり /大入/
おおいわ /大岩/
おおう /奥羽/
おおうえ /大上/
おおうずまき /大渦巻/
おおうせんけいゆ /奥羽線経由/
おおうそ /大嘘/
おおうだ /大宇陀/
おおうち /大内/
おおうちどおり /大内通/
おおうちやま /大内山/
おおうほんせん /奥羽本線/
おおうら /大浦/
おおうらてんしゅどう /大浦天主堂/
おおうらわざ /大裏技/
おおうりだし /大売出し/大売り出し/
おおえ /大江/
おおえせんり /大江千里/
おおえちょう /大江町/
おおえど /大江戸/
おおえどそうさもう /大江戸捜査網/
おおえどはなび /大江戸花火/
おおえのき /大榎/
おおえやま /大江山/
おおえん /応援/
おおおか /大岡/
おおおかえちぜん /大岡越前/
おおおかやま /大岡山/
おおおかやまえき /大岡山駅/
おおおかやまえきいりぐち /大岡山駅入口/
おおおかやまえきしゅうへん /大岡山駅周辺/
おおおかやまかん /大岡山間/
おおおかやまけいゆ /大岡山経由/
おおおかやまけいゆう /大岡山駅経由/
おおおかやましゅっぱつ /大岡山出発/
おおおかやまとうちゃく /大岡山到着/
おおおく /大奥/
おおおとこ /大男/
おおおやぶん /大親分/
おおかじ /大火事/
おおかぜ /大風/
おおかた /大方/大片/
おおかぶぬし /大株主/
おおかみ /狼/
おおかみおとこ /狼男/
おおかみおんな /狼女/
おおかみしょうねん /狼少年/
おおかれ /多かれ/
おおかわ /大川/大河/
おおかわかん /大川間/
おおかわこうぎょう /大川興業/
おおかわばた /大川畑/
おおかわら /大河原/
おおかんだ /大神田/
おおが /大賀/
おおがえし /大返し/
おおがき /大垣/大書/大柿/
おおがきえき /大垣駅/
おおがきほうめん /大垣方面/
おおがきやこう /大垣夜行/
おおがきゆき /大垣行き/大垣行/
おおがけ /大駆/
おおがた /大型/大形/大潟/大方/
おおがたうちゅうせん /大型宇宙船/
おおがたえいぞう /大型映像/
おおがたか /大型化/
おおがたかもつ /大型貨物/
おおがたかもつしゃ /大型貨物車/
おおがたかんせつぜい /大型間接税/
おおがたき /大型機/
おおがたきかい /大型機械/
おおがたきょうたい /大型筐体/
おおがたぎょ /大型魚/
おおがたけいさんき /大型計算機/大形計算機/
おおがたけいさんきせんたー /大型計算機センター/
おおがたけん /大型犬/
おおがたけんいん /大型牽引/
おおがたさんきゃく /大型三脚/
おおがたしゃ /大型車/
おおがたしゃとうにゅう /大型車投入/
おおがたしゃりょう /大型車両/
おおがたしょてん /大型書店/
おおがたじどう /大型自動/
おおがたじどうにりん /大型自動二輪/
おおがたじゃぐちちょっけつ /大型蛇口直結/
おおがたじゅう /大型獣/
おおがたじょうようしゃ /大型乗用車/
おおがたすいはんき /大型炊飯器/
おおがたすうち /大型数値/
おおがたせん /大型船/
おおがたせんしゅ /大型選手/
おおがたせんぱく /大型船舶/
おおがただつぜい /大型脱税/
おおがたちゅうしゃじょう /大型駐車場/
おおがたつりぐてん /大型釣具店/
おおがたてん /大型店/
おおがたとくしゅ /大型特殊/
おおがたにりん /大型二輪/
おおがたはんようき /大型汎用機/
おおがたはんようたんまつ /大型汎用端末/
おおがたば /大型馬/
おおがたひこうき /大型飛行機/
おおがたまど /大型窓/
おおがためんきょ /大型免許/
おおがたれんきゅう /大型連休/
おおがたろじょうしけん /大型路上試験/
おおがね /大金/大鐘/
おおがねもち /大金持/
おおがみ /大神/
おおがめ /鰲/
おおがら /大柄/
おおがらす /大鴉/
おおがわた /大河原/
おおがわら /大河原/
おおき /大木/大城/
おおきかいがん /大岐海岸/
おおきさ /大きさ/
おおきた /大北/
おおきに /大きに/
おおきめ /大き目/
おおぎ /仰木/扇/青木/
おおぎがた /扇型/
おおぎがはら /扇ヶ原/
おおぎし /大岸/
おおぎたに /扇谷/
おおぎばし /扇橋/
おおぎまち /扇町/
おおぎまちこうえん /扇町公園/
おおぎみ /大宜味/
おおぎょう /大仰/
おおぎり /大喜利/
おおくずれ /大崩れ/
おおくち /大口/
おおくにぬしのみこと /大国主命/
おおくぼ /大久保/大窪/
おおくぼえき /大久保駅/
おおくぼちゃく /大久保着/
おおくぼどおり /大久保通り/
おおくぼはつ /大久保発/
おおくま /大熊/大隈/逢隈/
おおくまざ /大熊座/
おおくら /大倉/大蔵/
おおくらしょう /大蔵省;2001年1月の中央省庁再編で財務省に再編された/
おおくらしょうぎょう /大倉商業/
おおくらだいじん /大蔵大臣/
おおくらやま /大倉山/
おおくり /お送り/
おおくわ /大桑/
おおぐし /大串/
おおぐす /大楠/
おおぐち /大口/
おおぐちこうにゅう /大口購入/
おおぐちさいけんしゃ /大口債権者/
おおぐちしゅっししゃ /大口出資者/
おおぐろ /大黒/
おおけが /大怪我/
おおげさ /大袈裟/
おおげつひめのかみ /大気津比売神/大宜津比売神/
おおげんか /大喧嘩/
おおこうち /大河内/
おおこし /大越/
おおこめ /大米/
おおご /大胡/大湖/
おおごえ /大声/大越/
おおごしょ /大御所/
おおごと /大事/
おおごま /大駒/
おおごんはくぶつかん /黄金博物館/
おおさ /大佐/
おおさか /大阪/大坂/逢坂/
おおさかいかだいがく /大阪医科大学/
おおさかいがい /大阪以外/
おおさかいき /大阪行/
おおさかいだい /大阪医大/
おおさかいだいびょうり /大阪医大病理/
おおさかいちりつだいがく /大阪市立大学/
おおさかうめだ /大阪梅田/
おおさかえき /大阪駅/
おおさかえきこうない /大阪駅構内/
おおさかえきまえ /大阪駅前/
おおさかおうしょう /大阪王将/
おおさかかん /大阪間/
おおさかかんじょうせん /大阪環状線/
おおさかがくいん /大阪学院/
おおさかがす /大阪ガス/大阪瓦斯/
おおさかがわ /大阪側/
おおさかきたこう /大阪北港/
おおさかきゅうじょう /大阪球場/
おおさかきょういくだい /大阪教育大/
おおさかきょういくだいがく /大阪教育大学/
おおさかきんこう /大阪近郊/
おおさかきんぺん /大阪近辺/
おおさかぎじゅつ /大阪技術/
おおさかくうこう /大阪空港/
おおさかけい /大阪系/
おおさかけいざいだいがく /大阪経済大学/
おおさかけんきゅうしょ /大阪研究所/
おおさかげいだい /大阪芸大/
おおさかげいにん /大阪芸人/
おおさかこう /大阪校/大阪港/
おおさかこうえん /大阪公演/
おおさかこうぎょうだいがく /大阪工業大学/
おおさかこうせいねんきん /大阪厚生年金/
おおさかこうだい /大阪工大/
おおさかこうだいふぞく /大阪工大付属/
おおさかこうべかん /大阪神戸間/
おおさかこうれい /大阪恒例/
おおさかこくさいくうこう /大阪国際空港/
おおさかこくさいこうりゅう /大阪国際交流/
おおさかさんぎょうだい /大阪産業大/
おおさかさんぎょうだいがく /大阪産業大学/
おおさかさんだい /大阪産大/
おおさかざいじゅう /大阪在住/
おおさかし /大阪市/
おおさかしえい /大阪市営/
おおさかしがい /大阪市街/
おおさかしこう /大阪市交/
おおさかししゃ /大阪支社/
おおさかしだい /大阪市大/
おおさかしちかてつ /大阪市地下鉄/
おおさかしてん /大阪支店/
おおさかしでん /大阪市電/
おおさかしない /大阪市内/
おおさかしゃかいぶ /大阪社会部/
おおさかしゅうへん /大阪周辺/
おおさかしゅっしん /大阪出身/
おおさかしょうぎょうだいがく /大阪商業大学/
おおさかしょうちくざ /大阪松竹座/
おおさかしょうばいにん /大阪商売人/
おおさかしょてん /大阪書店/
おおさかじぎょうしょ /大阪事業所/
おおさかじゅうたい /大阪渋滞/
おおさかじょう /大阪城/
おおさかじょうこうえん /大阪城公園/
おおさかじん /大阪人/
おおさかせめんと /大阪セメント/
おおさかせん /大阪線/
おおさかそーだ /大阪曹達/
おおさかたいいくだいがく /大阪体育大学/
おおさかたいかい /大阪大会/
おおさかだい /大阪大/
おおさかだいがく /大阪大学/
おおさかちかてつ /大阪地下鉄/
おおさかちほう /大阪地方/
おおさかちゃく /大阪着/
おおさかつうきんけん /大阪通勤圏/
おおさかてき /大阪的/
おおさかてん /大阪店/
おおさかでんつうだい /大阪電通大/
おおさかとういん /大阪桐蔭/
おおさかなんば /大阪難波/
おおさかなんばいき /大阪難波行/
おおさかなんばゆき /大阪難波行/
おおさかなんぶ /大阪南部/
おおさかにほんばし /大阪日本橋/
おおさかねやがわ /大阪寝屋川/
おおさかはい /大阪杯/
おおさかはつ /大阪発/
おおさかばしょ /大阪場所/
おおさかばん /大阪版/
おおさかばんぱく /大阪万博/
おおさかふ /大阪府/
おおさかふいけだし /大阪府池田市/
おおさかふう /大阪風/
おおさかふかたのし /大阪府交野市/
おおさかふけい /大阪府警/
おおさかふさかいし /大阪府堺市/
おおさかふたかつきし /大阪府高槻市/
おおさかふだい /大阪府大/
おおさかふとよなかし /大阪府豊中市/
おおさかふみしまぐん /大阪府三島郡/
おおさかふみん /大阪府民/
おおさかふりつ /大阪府立/
おおさかふりつだい /大阪府立大/
おおさかふりつだいがく /大阪府立大学/
おおさかぶんかけん /大阪文化圏/
おおさかべん /大阪弁/
おおさかべんわしゃ /大阪弁話者/
おおさかほうめん /大阪方面/
おおさかほか /大阪他/
おおさかほんしゃ /大阪本社/
おおさかみやげ /大阪土産/
おおさかめいぶつ /大阪名物/
おおさかやま /逢坂山/
おおさかゆき /大阪行/
おおさき /大崎/
おおさきでんしゃく /大崎電車区/
おおさきひろこうじかん /大崎広小路間/
おおさこ /大迫/
おおさと /大里/大郷/
おおさま /王様/
おおさわ /大沢/大澤/
おおさわぎ /大騒ぎ/
おおさわの /大沢野/
おおさんばし /大棧橋/
おおざけのみ /大酒飲み/
おおざっぱ /大雑把/
おおざと /大里/
おおざはた /大座畑/
おおざら /大皿/
おおしお /大潮/
おおしか /大鹿/
おおしげ /大重/
おおしごと /大仕事/
おおした /大下/
おおしば /大芝/大柴/
おおしま /大嶋/大島/
おおしましょうせんこうせん /大島商船高専/
おおしまちょう /大島町/
おおしみず /大清水/
おおしょうぎ /大将棋/
おおしょうぶ /大勝負/
おおしろ /大城/
おおじ /大路/王寺/
おおじだい /大時代/
おおじぬし /大地主/
おおじま /大島/
おおじょたい /大所帯/大世帯/
おおす /大須/
おおすか /大須賀/
おおすが /大須賀/
おおすぎ /大杉/
おおすじ /大筋/
おおすみ /大住/大隅/大角/
おおすみせん /大隅線/
おおず /大洲/
おおずもう /大相撲/
おおずわ /大諏訪/
おおせ /大瀬/仰せ/
おおせざき /大瀬崎/
おおせと /大瀬戸/
おおぜい /大勢/多勢/
おおぜき /大関/
おおぜきしょうしん /大関昇進/
おおぜきしょうしんまえ /大関昇進前/
おおそうじ /大掃除/
おおそうじちゅう /大掃除中/
おおそうどう /大騒動/
おおそが /大曽我/
おおそとわく /大外枠/
おおその /大園/
おおぞこ /大底/
おおぞね /大曽根/
おおぞら /大空/
おおぞん /大損/
おおた /太田/大田/
おおたいさん /太田胃散/
おおたか /大高/
おおたがわ /太田川/
おおたがわばし /太田川橋/
おおたき /大滝/大瀧/王滝/大多喜/
おおたきむら /王滝村/
おおたく /大田区/
おおたくざいじゅう /大田区在住/
おおたくたいいくかん /大田区体育館/
おおたくたいかい /太田区大会/
おおたくひがしゆきがや /大田区東雪谷/
おおたぐろ /太田黒/
おおたけ /大竹/大丈/大嶽/大武/
おおたけしのぶ /大竹しのぶ/
おおたし /太田市/
おおたしゅっぱん /太田出版/
おおたち /大立/
おおたてもの /大立者/
おおたに /大谷/
おおたひろみ /太田裕美/
おおたま /大玉/
おおたわら /大田原/
おおたわらし /大田原市/
おおだ /大田/
おおだい /大台/
おおだいこ /大太鼓/
おおだか /大高/
おおだけ /大岳/
おおだこ /大ダコ/
おおだち /大立/大館/
おおだて /大館/
おおだま /大玉/
おおだんえん /大団円/
おおだんな /大旦那/
おおち /邑智/
おおちがい /大違い/
おおつ /大津/
おおつか /大塚/
おおつかあきら /大塚明/
おおつかえき /大塚駅/
おおつかかん /大塚間/
おおつかせいやく /大塚製薬/
おおつかほんちょうえき /大塚本町駅/
おおつが /大津賀/
おおつき /大槻/大月/大附/大規/
おおつきしょてん /大月書店/
おおつこうしゅうへん /大津港周辺/
おおつごもり /大晦日/大晦/
おおつし /大津市/
おおつしがい /大津市街/
おおつしない /大津市内/
おおつせん /大津線/
おおつせんぜんせん /大津線全線/
おおつち /大槌/
おおつちわん /大槌湾/
おおつなみ /大津波/
おおつの /大角/
おおつぶ /大粒/
おおつぼ /大坪/
おおつま /大妻/
おおつまこうこう /大妻高校/
おおつまじょしだい /大妻女子大/
おおつまじょしだいなかのこうこう /大妻女子大中野高校/
おおつやま /大津山/
おおつる /大鶴/
おおづ /大津/
おおづめ /大詰め/大詰/
おおて /大手/
おおてきぎょう /大手企業/
おおてぐんじゅさんぎょう /大手軍需産業/
おおてしてつ /大手私鉄/
おおてしゅっぱんしゃ /大手出版社/
おおてしょうよう /大手商用/
おおてしょてん /大手書店/
おおてしんぶん /大手新聞/
おおてせきゆがいしゃ /大手石油会社/
おおてでんきがいしゃ /大手電気会社/
おおてとしぎん /大手都市銀/
おおてまち /大手町/
おおてみんてつ /大手民鉄/
おおてゆうり /大手有利/
おおてら /大寺/
おおてりょこうがいしゃ /大手旅行会社/
おおてる /大照/
おおで /大手/
おおとう /大塔/大任/
おおとかげ /大蜥蜴/
おおとね /大利根/
おおとのさま /大殿様/
おおとも /大友/大伴/
おおとよ /大豊/
おおとり /鴻/鳳/鵬/
おおとりい /大鳥居/
おおとりじんじゃ /大鳥神社/
おおとりじんじゃまえ /大鳥神社前/
おおどうぐ /大道具/
おおどおり /大通り/大通/
おおどけい /大時計/
おおなえ /大苗/
おおなき /大泣き/
おおなべ /大鍋/
おおなみ /大波/大浪/
おおなんじ /大汝/
おおにし /大西/
おおにしまち /大西町/
おおにた /大仁田/
おおにもつ /大荷物/
おおにんずう /多人数/大人数/
おおぬき /大貫/
おおぬま /大沼/
おおぬまこうえん /大沼公園/
おおね /大根/
おおねじめ /大根占/
おおねだ /大根田/
おおの /大野/
おおのくに /大乃国/
おおのけん /大野研/
おおのみ /大野見/
おおはさ /大迫/
おおはざま /大間/
おおはし /大橋/
おおはしえいぎょうしょ /大橋営業所/
おおはしきょせん /大橋巨泉/
おおはじ /大恥/
おおはた /大畑/大畠/
おおはたせん /大畑線/
おおはば /大幅/
おおはばげんぜい /大幅減税/
おおはばさいしゅつさくげん /大幅歳出削減/
おおはばねびき /大幅値引き/
おおはばひきさげ /大幅引下げ/
おおはばへんこう /大幅変更/
おおはま /大浜/大濱/
おおはやり /大流行/
おおはら /大原/
おおはらさんぜんいん /大原三千院/
おおはらそうどう /大原騒動/
おおはらほうめん /大原方面/
おおはる /大治/
おおば /大場/大庭/
おおばか /大馬鹿/
おおばかもの /大馬鹿者/大莫迦者/
おおばかやろう /大馬鹿野郎/
おおばけ /大化け/
おおばこ /大箱/
おおばたけ /大畠/
おおばやし /大林/
おおばん /大判/大版/大番/大盤/
おおばんぶるまい /大盤振舞/大盤振舞い/大盤振る舞い/
おおばんやき /大判焼/
おおばんよう /大判用/
おおひさ /大久/
おおひと /大仁/
おおひとちょう /大仁町/
おおひら /大平/大衡/
おおひらしゅしょう /大平首相/
おおひらだい /大平台/
おおひらちょう /大平町/
おおひらむら /大衡村/
おおひろま /大広間/
おおびけ /大引け/
おおびん /大壜/大瓶/
おおふか /大深/
おおふく /大福/
おおふな /大船/
おおふなえき /大船駅/
おおふなえきかいさつ /大船駅改札/
おおふなでんしゃく /大船電車区/
おおふなと /大船渡/
おおふなとせん /大船渡線/
おおふね /大舟/
おおふろしき /大風呂敷/
おおぶ /大府/
おおぶえき /大府駅/
おおぶくろ /大袋/
おおぶち /大淵/大渕/
おおぶね /大船/
おおべや /大部屋/
おおほ /大穂/
おおほり /大堀/大濠/
おおほりこうえん /大濠公園/
おおぼけ /大ボケ/大ぼけ/大歩危/
おおま /大間/
おおまえ /大前/
おおまか /大まか/
おおまがり /大曲/
おおまがりかん /大曲間/
おおまがりせん /大曲線/
おおまき /大蒔/
おおまじめ /大真面目/
おおまた /大股/
おおまち /大町/
おおまちえき /大町駅/
おおまちがい /大間違い/
おおまつ /大松/
おおまど /大窓/
おおまぬけ /大間抜/
おおまま /大間々/
おおまみゅうだ /大豆生田/
おおまわり /大回り/
おおみ /大見/
おおみか /大甕/
おおみず /大水/
おおみそか /大晦日/
おおみぞ /大溝/
おおみだし /大見出し/
おおみつ /大光/
おおみなと /大湊/
おおみなとせん /大湊線/
おおみね /大峰/
おおみや /大宮/
おおみやえき /大宮駅/
おおみやえきまえ /大宮駅前/
おおみやかん /大宮間/
おおみやこうじょう /大宮工場/
おおみやし /大宮市/
おおみやしゅうへん /大宮周辺/
おおみやせん /大宮線/
おおみやちょう /大宮町/
おおみやにっせきびょういん /大宮日赤病院/
おおむかし /大昔/
おおむぎ /大麦/
おおむた /大牟田/
おおむたはつ /大牟田発/
おおむね /概/大旨/概ね/
おおむら /大村/
おおむらいなん /大村以南/
おおむらけいゆ /大村経由/
おおむらせん /大村線/
おおむらわん /大村湾/
おおむろ /大室/
おおめ /大目/多目/
おおめだま /大目玉/
おおもじ /大文字/
おおもじえいじ /大文字英字/
おおもじえいすうじ /大文字英数字/
おおもじか /大文字化/
おおもじこもじ /大文字小文字/
おおもと /大元/大本/
おおもときじ /大元記事/
おおもときょう /大本教/
おおもの /大物/
おおものかしゅ /大物歌手/
おおものかん /大物感/
おおものじょせい /大物女性/
おおもも /大桃/
おおもり /大森/大盛り/大盛/
おおもりえき /大森駅/
おおもりく /大森区/
おおや /大矢/大谷/大家/大屋/大宅/
おおやぎ /大谷木/大八木/
おおやけ /公/
おおやけど /大火傷/
おおやす /大保/
おおやすうり /大安売り/大安売/
おおやち /大矢知/
おおやの /大矢野/
おおやま /大山/
おおやまえき /大山駅/
おおやまぐち /大山口/
おおやまだ /大山田/
おおやまちょう /大山町/
おおやままち /大山町/
おおやまやすはる /大山康晴/
おおやん /欧陽/
おおゆ /大湯/
おおゆき /大雪/
おおゆみ /大弓/
おおよせ /大寄/
おおよそ /大凡/凡そ/
おおよど /大淀/
おおよろこび /大喜び/
おおよわり /大弱り/
おおわき /大脇/
おおわく /大枠/大和久/
おおわざ /大技/
おおわだ /大和田/大輪田/
おおわだかん /大和田間/
おおわだちょう /大和田町/
おおわだばく /大和田獏/
おおわに /大鰐/
おおわらい /大笑い/
おおわらわ /大童/
おか /岡/丘/岳/陵/峻/阜/崗/
おかあさま /お母さま/お母様/
おかあさん /お母さん/
おかい /小粥/汚怪/
おかいあげ /お買上/
おかいどく /お買い得/
おかうち /岡内/
おかえ /岡江/
おかえくみこ /岡江久美子/
おかえし /お返し/
おかがき /岡垣/
おかがきちょう /岡垣町/
おかがみ /岡上/
おかげ /御陰/お蔭/御蔭/お陰/
おかげさま /お蔭様/御蔭様/
おかげん /お加減/御加減/
おかさか /岡坂/
おかさん /岡三/
おかさんしょうけん /岡三証券/
おかざき /岡崎/丘咲/
おかざきえき /岡崎駅/
おかざきし /岡崎市/
おかざわ /岡澤/
おかざわちょう /岡沢町/
おかし /お菓子/
おかしい /可笑しい/
おかしま /岡島/
おかしや /お菓子屋/
おかじま /岡島/岡嶋/
おかせっけい /岡設計/
おかぞえ /岡添/
おかた /岡田/お方/
おかたに /岡谷/
おかだ /岡田/
おかだい /岡大/
おかだいじょうほう /岡大情報/
おかだいぞう /岡田以蔵/
おかだせん /岡多線/
おかだま /丘珠/
おかだや /岡田屋/
おかちまち /御徒町/
おかちめんこ /オカチメンコ/
おかって /お勝手/
おかつ /雄勝/
おかと /岡登/
おかどめ /岡留/
おかね /お金/
おかねもち /お金持ち/
おかの /岡野/
おかはし /岡橋/
おかはち /岡八/
おかはら /岡原/
おかはる /岡原/
おかばやし /岡林/
おかひさ /岡久/
おかひら /岡平/
おかふじ /岡藤/
おかぶ /御株/
おかべ /岡部/
おかべちょう /岡部町/
おかみ /御上/女将/
おかむら /岡村/
おかむろ /岡室/
おかめ /傍目/
おかめはちもく /傍目八目/
おかもち /岡持/
おかもと /岡本/岡元/
おかもとあやこ /岡本綾子/
おかや /岡谷/
おかやす /岡安/
おかやすこう /岡安高/
おかやま /岡山/
おかやまえき /岡山駅/
おかやまえきまえ /岡山駅前/
おかやまかん /岡山間/
おかやまがわ /岡山側/
おかやまきゅうじょう /岡山球場/
おかやまくうこう /岡山空港/
おかやまけん /岡山県/
おかやまけんじん /岡山県人/
おかやまし /岡山市/
おかやましゅっしん /岡山出身/
おかやまじょう /岡山城/
おかやまだい /岡山大/
おかやまだいがく /岡山大学/
おかやまちほう /岡山地方/
おかやまひがし /岡山東/
おかやまべん /岡山弁/
おかやまほうそうきょく /岡山放送局/
おかやまめいぶつ /岡山名物/
おかゆ /小粥/
おからだ /お身体/
おかりな /オカリナ/
おかわり /お変り/
おかん /悪寒/お燗/惡寒/
おかんがえ /お考え/
おが /男鹿/
おがい /小粥/
おがくず /大鋸屑/
おがさ /小笠/
おがさか /小賀坂/
おがさはら /小笠原/
おがさわら /小笠原/
おがさわらきんかい /小笠原近海/
おがさわらしょとう /小笠原諸島/
おがた /小方/尾形/緒方/緒形/小形/
おがたけん /緒形拳/緒方拳/
おがつ /雄勝/
おがの /小鹿野/
おがはんとう /男鹿半島/
おがみ /尾上/
おがゆ /小粥/
おがら /麻幹/
おがわ /小川/小河/尾川/緒川/尾河/
おがわえき /緒川駅/
おがわちょう /小川町/
おがわな /小川名/
おがわまち /小川町/
おき /沖/隠岐/置き/煕/お気/興/熈/
おきあい /沖合い/沖合/
おきあがりこぼし /起き上がり小法師/
おきいし /置き石/
おきかえ /置き換え/置換え/
おきかた /置き方/
おきがさ /置き傘/
おきがる /御気軽/
おきくら /沖倉/
おきこうぎょう /沖工業/
おきご /置き碁/
おきごたつ /置き炬燵/
おきざり /置き去り/
おきそ /小木曽/
おきた /沖田/小木田/
おきつ /興津/
おきつうしん /沖通信/
おきつち /置き土/
おきづき /お気付き/
おきて /掟/諚/沖手/
おきてがみ /置き手紙/
おきでんき /沖電気/
おきでんきこうぎょう /沖電気工業/
おきとちょう /置戸町/
おきどけい /置き時計/
おきな /翁/奥菜/
おきなか /沖中/
おきなかし /沖仲士/
おきなわ /沖縄/沖繩/
おきなわかいはつちょう /沖縄開発庁;2001年1月の中央省庁再編で内閣府に再編された/
おきなわけん /沖縄県/
おきなわけんえいてつどう /沖縄県営鉄道/
おきなわけんてつどう /沖縄県鉄道/
おきなわご /沖縄語/
おきなわさん /沖縄産/
おきなわし /沖縄市/
おきなわしゅっしん /沖縄出身/
おきなわじん /沖縄人/
おきなわすいさん /沖縄水産/
おきなわてつどう /沖縄鉄道/
おきなわふう /沖縄風/
おきなわふじつう /沖縄富士通/
おきなわべん /沖縄弁/
おきなわほうげん /沖縄方言/
おきなわほんとう /沖縄本島/
おきなわほんとうない /沖縄本島内/
おきなわみんよう /沖縄民謡/
おきなわもの /沖縄物/
おきなわりょうりや /沖縄料理屋/
おきにいり /お気に入り/
おきのしま /隠岐島/
おきば /置場/置き場/
おきばしょ /置き場所/置場所/
おきび /燠火/
おきふじ /沖藤/
おきまつしま /沖松島/
おきまゆみ /沖まゆみ/
おきまり /お決まり/
おきみ /沖美/
おきみやげ /置き土産/
おきめ /沖目/
おきもち /お気持/お気持ち/
おきもと /沖本/
おきもの /置物/
おきゃく /お客/
おきゃくさま /お客様/御客様/
おきゃくさん /お客さん/
おきゃん /お侠/御侠/
おきや /置き屋/
おきょう /お経/
おきわたし /沖渡し/
おぎ /荻/小城/小木/尾木/蒹/
おぎうえ /荻上/
おぎくぼ /荻窪/
おぎくぼかん /荻窪間/
おぎくぼししゃ /荻窪支社/
おぎしま /荻島/
おぎそ /小木曽/
おぎた /小木田/荻田/
おぎつ /荻津/
おぎにしき /小城錦/
おぎの /荻野/荻布/
おぎのめ /荻野目/萩目/萩野目/
おぎのめようこ /荻野目洋子/
おぎはら /荻原/
おぎゅうそらい /荻生徂徠/
おぎわら /荻原/
おく /億/奥/臆/憶/屋/邑久/奧/檍/尾久/
おくい /奥井/奥居/
おくいずも /奥出雲/
おくいぶき /奥伊吹/
おくえん /億円/
おくかい /億回/
おくかわ /奥川/
おくがい /屋外/
おくがいよう /屋外用/
おくきょうと /奥京都/
おくぎ /奥義;「おうぎ」ともいう/奥儀;「おうぎ」ともいう/
おくこ /億個/
おくさがみ /奥相模/
おくさき /奥崎/
おくさま /奥様/
おくさわ /奥沢/奥澤/
おくさわほうめん /奥沢方面/
おくさん /奥さん/
おくしが /奥志賀/
おくしり /奥尻/
おくしりとう /奥尻島/
おくじょう /屋上/
おくじょうおく /屋上屋/
おくせ /奥瀬/
おくせつ /憶説/
おくそく /憶測/臆測/
おくそこ /奥底/
おくただみ /奥只見/
おくたに /奥谷/
おくたま /奥多摩/
おくたまいき /奥多摩行/
おくたまえき /奥多摩駅/
おくたまほうめん /奥多摩方面/
おくたまゆき /奥多摩行/
おくたんい /億単位/
おくだ /奥田/
おくだいら /奥平/
おくだて /奥立/
おくち /奥地/
おくつ /奥津/
おくづけ /奥付/
おくで /奥出/
おくでら /奥寺/
おくでん /奥伝/
おくとね /奥利根/
おくとみ /奥富/
おくない /屋内/奥内/
おくないしせつ /屋内施設/
おくないせつぞくよう /屋内接続用/
おくないはいせん /屋内配線/
おくなが /奥永/
おくにっかわ /奥新川/
おくにっこう /奥日光/
おくにん /億人/
おくぬき /奥貫/
おくねん /億年/
おくの /奥野/奥乃/
おくのて /奥の手/
おくのと /奥能登/
おくはら /奥原/
おくば /奥歯/
おくひえいがわ /奥比叡側/
おくひだ /奥飛騨/
おくびょう /臆病/
おくびょうもの /臆病者/
おくほ /奥穂/
おくほうこう /奥方向/
おくぼいん /奥母音/
おくまつしま /奥松島/
おくまんちょうじゃ /億万長者/
おくみかわ /奥三河/
おくみの /奥美濃/
おくみのちほう /奥美濃地方/
おくむら /奥村/
おくめん /憶面/臆面/
おくもと /納本/奥本/
おくやま /奥山/
おくやみ /お悔やみ/
おくゆき /奥行き/奥行/
おくゆきかん /奥行感/
おくら /憶良/
おくらいり /お蔵入り/
おくりかな /送り仮名/
おくりがな /送り仮名/
おくりさき /送り先/贈り先/
おくりじょう /送り状/
おくりたおし /送り倒し/
おくりだし /送り出し/
おくりて /送り手/
おくりてしゅどう /送り手主導/
おくりな /諡/
おくりぬし /送り主/贈り主/送主/
おくりび /送り火/
おくりむかえ /送り迎え/
おくりもと /送り元/
おくりもの /贈り物/贈物/賻/饋/
おくれ /遅れ/
おくれじかん /遅れ時間/
おくればせ /遅れ馳せ/遅馳/
おくればせながら /遅ればせながら/
おくわざ /奥技/
おぐし /小串/
おぐち /小口/
おぐに /小国/
おぐにまち /小国町/
おぐま /小熊/
おぐら /小倉/小椋/
おぐらけい /小椋佳/
おぐらにっけいしょう /小倉日経賞/
おぐり /小栗/
おぐるま /小車/
おぐろ /小黒/
おけ /桶/
おけいこ /お稽古/
おけがやぬま /桶ケ谷沼/
おけがわ /桶川/
おけがわし /桶川市/
おけと /置戸/
おけはざま /桶狭間/
おけや /桶屋/
おけら /螻蛄/
おげひん /お下品/
おげれつ /お下劣/
おげんき /御元気/お元気/
おこうでん /御香典/
おこえ /御声/
おこころ /御心/
おこさま /お子様/
おこさん /お子さん/
おこし /お越し/小越/
おこたえ /お答え/御答え/
おこたち /御子達/
おこっぺ /興部/
おこっぺちょう /興部町/
おことば /御言葉/
おことわり /お断り/
おこない /行い/行ない/
おこのぎ /小此木/
おこのみ /お好み/
おこのみやき /お好み焼き/
おこめ /御米/お米/
おこり /瘧/
おこりかた /怒り方/
おごうりかん /小郡間/
おごおり /小郡/
おごおりし /小郡市/
おごおりちょう /小郡町/
おごせ /越生/
おごと /雄琴/
おごり /奢り/傲り/驕り/
おさ /長/
おさえかた /押え方/
おさか /小坂/尾坂/苧坂/
おさきに /お先に/
おさくひん /御作品/
おさけ /お酒/
おさそい /お誘い/
おさだ /長田/
おさだみほ /長田美穂/
おさと /長都/
おさない /長内/小山内/小内山/
おさないころ /幼い頃/
おさないみえこ /小山内美江子/
おさながお /幼顔/
おさなご /幼子/
おさなさ /幼さ/
おさなづま /幼妻/
おさななじみ /幼なじみ/幼馴染み/
おさふね /長船/
おさべ /長部/
おさみ /修美/
おさむ /修/治虫/治/収/理/納/
おさめ /納め/
おさめこみ /納込/
おさわがせ /お騒がせ/
おざ /尾座/
おざき /尾崎/小崎/尾前/
おざきなおみち /尾崎直道/
おざきまさし /尾崎将司/
おざきゆたか /尾崎豊/
おざく /小作/
おざさ /小笹/
おざわ /小沢/小澤/尾沢/
おざわりゅう /小沢流/
おし /唖/押し/鴛/忍/
おしあげ /押上/
おしあげかん /押上間/
おしあげせん /押上線/
おしあわせ /お幸せ/
おしい /押井/
おしいれ /押し入れ/押入/
おしうり /押売/
おしえ /教え/押絵/
おしえかた /教え方/
おしえご /教え子/
おしお /押尾/
おしか /牡鹿/牝鹿/
おしかせん /男鹿線/
おしかわ /押川/
おしきせ /御仕着せ/
おしきり /押切/
おしくま /押熊/
おしくも /惜しくも/
おしごと /お仕事/
おしたおし /押し倒し/
おしだ /押田/
おしだし /押し出し/
おしつけ /押し付け/
おしどり /鴛鴦/鴦/
おしなべて /押し並べて/
おしの /忍野/
おしのむら /忍野村/
おしばな /押し花/
おしべ /雄蕊/
おしま /小島/
おしまはんとう /渡島半島/
おしみず /押水/
おしめ /繦/襁/
おしゃか /お釈迦/
おしゃべり /お喋り/
おしゃまんべ /長万部/
おしゃれ /おシャレ/お洒落/
おしょう /和尚/
おしょうがつ /お正月/
おしょく /汚職/
おしょくぎいん /汚職議員/
おしょくじ /お食事/御食事/
おしらせ /お知らせ/
おしり /お尻/
おしろ /お城/
おしろい /白粉/
おしん /悪心/
おじ /叔父;父・母の弟/伯父;父・母の兄/小父;よその年配の男性/
おじいさん /お爺さん/
おじおば /叔父叔母/
おじか /牡鹿/牝鹿/小値賀/
おじかせん /男鹿線/
おじさま /叔父様/
おじま /小島/尾島/
おじまちょう /小島町/
おじゃま /御邪魔/お邪魔/
おじゃまむし /お邪魔虫/
おじょうさま /お嬢様/
おじょうさん /お嬢さん/
おじょく /汚辱/
おじろ /尾白/
おす /♂/牡/雄/
おすい /汚水/
おすいしょりき /汚水処理機/
おすうし /雄牛/
おすうま /牡馬/
おすかぶ /雄株/
おすがた /御姿/
おすき /お好き/
おすごし /お過ごし/
おすし /お寿司/
おすすめ /お勧め/お薦め/
おすたかやま /御巣鷹山/
おすだ /小須田/
おすとめす /雄と雌/
おすねこ /雄猫/
おすまい /お住い/
おすみ /お済み/
おすみつき /御墨付/
おすめす /雄雌/牡牝/
おず /小津/
おせ /尾瀬/
おせいぼ /御歳暮/
おせざき /大瀬崎/
おせじ /御世辞/お世辞/
おせっかい /お節介/御節介/
おせわ /お世話/御世話/
おせん /汚染/
おせんじょうきょう /汚染状況/
おせんちたい /汚染地帯/
おせんぶっしつ /汚染物質/
おぜ /尾瀬/
おぜき /小関/尾関/
おぜぬま /尾瀬沼/
おぜん /お膳/
おぜんだて /お膳立て/
おそ /遅/遲/
おそうじ /お掃除/
おそくとも /遅くとも/
おそざき /遅咲き/
おそばん /遅番/遅版/
おそまつ /御粗末/
おそめ /遅目/
おそらく /恐らく/
おそる /惶/
おそるべし /恐るべし/
おそれ /恐れ/虞/畏れ/
おそれざん /恐山/
おそれる /惶/
おそん /汚損/
おた /織田/
おたがい /お互い/
おたがいさま /お互い様/
おたく /お宅/オタク/
おたけび /雄叫び/
おたじま /小田島/小田嶋/
おたずね /お尋ね/
おたち /お発ち/
おたっし /お達し/
おたのしみ /お楽しみ/
おたのしみぶくろ /お楽しみ袋/
おたべ /小田部/
おたま /御玉/
おたまじゃくし /蝌蚪/御玉杓子/
おたまや /霊屋/
おたまやした /御霊屋下/霊屋下/
おたより /お便り/
おたり /小谷/
おたる /小樽/
おたるえき /小樽駅/
おたるし /小樽市/
おたるしょうかだいがく /小樽商科大学/
おたんじょうび /お誕生日/
おだ /織田/小田/纓田/
おだい /小田井/お題/御題/お代/
おだいとう /尾岱沼/
おだいもく /御題目/
おだか /小高/尾高/
おだかしょう /尾高賞/
おだかずまさ /小田和正/
おだがわ /小田川/
おだきゅう /小田急/小田原急行電鉄/
おだきゅうえんせん /小田急沿線/
おだきゅうけいゆ /小田急経由/
おだきゅうけいゆう /小田急経由/
おだきゅうしゃりょう /小田急車両/
おだきゅうしんじゅく /小田急新宿/
おだきゅうしんじゅくえき /小田急新宿駅/
おだきゅうじこくひょう /小田急時刻表/
おだきゅうせん /小田急線/
おだきゅうせんえんせん /小田急線沿線/
おだきゅうせんけいゆ /小田急線経由/
おだきゅうせんけいゆう /小田急線経由/
おだきゅうせんない /小田急線内/
おだきゅうたません /小田急多摩線/
おだきゅうりようしゃ /小田急利用者/
おだきゅうれんらく /小田急連絡/
おだぎ /小田木/
おだぎり /小田切/小田桐/
おだく /汚濁/
おだくら /小田倉/
おだけ /織田家/
おださかえちょう /小田栄町/
おだしま /小田嶋/
おだじま /小田島/小田嶋/
おだて /煽て/
おだなか /小田中/
おだのぶなが /織田信長/
おだのぶひで /織田信秀/
おだべ /小田部/
おだまり /お黙り/
おだわら /小田原/
おだわらいき /小田原行/
おだわらかん /小田原間/
おだわらがた /小田原方/
おだわらきんぺん /小田原近辺/
おだわらしはつ /小田原始発/
おだわらしゅうへん /小田原周辺/
おだわらはつ /小田原発/
おだわらほうめん /小田原方面/
おだわらゆき /小田原行/
おだん /オ段/
おち /落/越智/落ち/越知/尾知/
おちあい /落合/
おちいし /落石/
おちえ /御知恵/
おちかた /墜ち方/
おちから /御力/
おちこぼれ /落ちこぼれ/
おちこみ /落ちこみ/
おちど /落度/越度/
おちば /落葉/落ち葉/
おちばたき /落葉焚き/
おちみず /落水/落ち水/
おちむしゃ /落ち武者/
おちめ /落ち目/
おちゃ /お茶/御茶/
おちゃかい /お茶会/
おちゃがし /お茶菓子/
おちゃしつ /お茶室/
おちゃだい /お茶大/お茶代/
おちゃづけ /お茶漬/
おちゃづけのり /御茶漬海苔/
おちゃのま /御茶乃間/お茶の間/
おちゃのみず /御茶の水/御茶ノ水/お茶の水/
おちゃのみば /お茶飲み場/
おちゃめ /お茶目/
おちゅうげん /御中元/
おっかけ /追っかけ/
おっきな /大っきな/
おっくう /億劫/
おって /追っ手/追手/
おっと /夫/
おっとせい /膃肭臍/
おっぱま /追浜/
おっぱまえき /追浜駅/
おつ /乙/榲/膃/
おつあん /乙案/
おつかい /お使い/
おつかれさま /お疲れ様/
おつがわ /乙川/
おつがわえき /乙川駅/
おつきさま /お月様/
おつげ /お告げ/御告げ/
おつざいよう /乙剤用/
おつじ /尾辻/
おつたえ /お伝え/
おつぼねさま /お局様/
おつや /御通夜/
おつり /お釣/
おづ /小津/
おづき /小月/
おづつ /尾筒/
おて /お手/
おてあげ /お手あげ/
おてあらい /御手洗/お手洗/
おてかず /お手数/
おてがみ /御手紙/
おてがる /お手軽/
おてすう /お手数/御手数/
おてつだい /お手伝い/
おてほん /お手本/
おてま /お手間/
おてまえ /お点前/
おてもと /お手元/
おてもり /お手盛り/
おてら /お寺/
おてん /汚点/
おてんき /お天気/
おてんとうさま /お天道様/
おてんとさま /お天道様/御天道様/
おてんば /お転婆/御転婆/
おでい /汚泥/
おでいはっせいりょう /汚泥発生量/
おでかけ /お出かけ/
おでし /御弟子/
おでら /小寺/
おでんわ /お電話/
おと /音/乙/
おといあわせ /お問い合わせ/
おといち /音一/
おとうさん /お父さん/
おとうす /音薄/
おとうと /弟/
おとうとでし /弟弟子/
おとうとぶん /弟分/
おとおんかい /音音階/
おとかず /音数/
おとかわ /乙川/
おとぎ /御伽/
おとぎばなし /お伽話/御伽話/
おとぎりそう /弟切草/
おとぎりそうもく /オトギリソウ目/Dilleniales/Guttiferales/Hypericales/
おとぎりそうもくぐん /オトギリソウ目群/Hypericales/
おとくい /お得意/
おとくうかん /音空間/
おとくに /乙訓/
おとけんしゅつ /音検出/
おとこ /男/♂/
おとこあいて /男相手/
おとこうぞう /音構造/
おとこおとこ /男男/
おとこがみ /男神/
おとこがわ /男側/
おとこきょうだい /男兄弟/
おとこぐみ /男組/
おとこげいしゃ /男芸者/
おとこことば /男言葉/
おとこごころ /男心/
おとこしゃかい /男社会/
おとこじゅく /男塾/
おとこたち /男達/
おとこだて /男伊達/
おとこで /男手/
おとこどうし /男同士/
おとこなまえ /男名前/
おとこのこ /男の子/
おとこのひと /男の人/
おとこひとり /男一人/
おとこべんじょ /男便所/
おとこまさり /男勝/
おとこみち /男道/
おとこもの /男物/
おとこやく /男役/
おとこやま /男山/
おとこゆ /男湯/
おとさた /音沙汰/
おとし /お年/
おとしあな /落し穴/落とし穴/
おとしかた /落し方/
おとしげき /音刺激/
おとしだま /お年玉/おとし玉/
おとしなちょう /音更町/
おとしもの /落し物/落とし物/
おとしんごう /音信号/
おとしんごうでんそう /音信号伝送/
おとじたい /音自体/
おとじょうほう /音情報/
おとじろう /音二郎/
おとせってい /音設定/
おとそ /お屠蘇/
おとそしき /音組織/
おとだ /音田/
おとだし /音出し/
おとつい /一昨日/
おとてき /音的/
おととい /一昨日/
おととし /一昨年/
おととり /音取り/音取/
おとな /大人/
おとなけいかく /大人計画/
おとなげ /大人気/
おとなし /音無/
おとなしく /大人しく/
おとなせんよう /大人専用/
おとなたち /大人達/
おとなひとり /大人一人/
おとなよう /大人用/
おとにゅうりょく /音入力/
おとひめ /乙姫/
おとひめさま /乙姫様/
おとふけ /音更/
おとふじ /乙藤/
おとべ /乙部/
おとべちょう /乙部町/
おとべつ /音別/
おとめ /乙女/少女/
おとめざ /乙女座/
おとめじゅく /乙女塾/
おとめたい /乙女隊/
おともだち /お友達/
おともれ /音洩れ/
おとり /囮/
おとりあつかい /お取り扱い/
おとりこみちゅう /お取り込み中/
おとりしらべ /お取り調べ/
おとりはからい /お取り計らい/
おとりひき /お取り引き/
おとろえ /衰え/
おとわ /音羽/
おどし /縅/脅し/
おどり /踊り/
おどりこ /踊り子/
おどりば /踊り場/
おどろき /驚き/
おない /尾内/小内/
おないどし /同い歳/
おなか /お腹/
おなが /翁長/尾長/
おながわ /女川/
おなご /女子/
おなじ /同じ/々/〃/ゝ/
おなじく /々/同じく/
おなじみ /お馴染/
おなにー /オナニー/
おなはま /小名浜/
おなべ /小鍋/
おなまえ /御名前/お名前/
おなもみ /葹/
おなりもん /御成門/
おなれそめ /御馴染/
おに /鬼/
おにあい /お似合い/
おにいさん /お兄さん/
おにいちゃん /お兄ちゃん/
おにうだ /鬼生田/
おにがわ /鬼皮/
おにがわら /鬼瓦/
おにけいじ /鬼刑事/
おにこうべ /鬼首/
おにざわ /鬼沢/
おにし /鬼石/
おにつか /鬼塚/鬼束/
おにづか /鬼塚/
おにはは /鬼母/
おにばば /鬼婆/
おにび /鬼火/
おにへい /鬼平/
おにへいはんかちょう /鬼平犯科帳/
おにまろ /鬼磨呂/
おにもつ /お荷物/
おぬま /小沼/
おね /尾根/
おねえさま /お姉さま/お姉様/
おねえさん /お姉さん/
おねがい /お願い/
おねがいいたします /お願いいたします/
おねせん /尾根線/
おねだん /お値段/
おねてん /尾根点/
おねみち /尾根道/
おの /小野/斧/尾野/
おのうえ /尾上/
おのうえおんせんえき /小野上温泉駅/
おのえ /尾上/
おのお /小野尾/
おのおか /小野岡/
おのおの /各々/各/
おのかわ /小野川/
おのがくえん /小野学園/
おのがみ /小野上/
おのがわ /小野川/
おのがわこ /小野川湖/
おのき /小野木/
おのぎ /小野木/
おのけん /小野研/
おのこ /男子/
おのさと /小野里/
おのざき /小野崎/
おのざわ /小野沢/
おのずから /自ら/自ずから/
おのずと /自と/
おのそっき /小野測器/
おのぞみ /お望み/
おのだ /小野田/
おのだか /小野高/
おのだせめんと /小野田セメント/
おのだせん /小野田線/
おのづか /小野塚/
おのでら /小野寺/
おのみち /尾道/
おのむら /小野村/
おのやま /小野山/
おのれ /己/
おはこ /十八番/
おはし /御箸/
おはせ /小長谷/生長谷/
おはな /お花/
おはなし /お話/
おはなしちゅう /お話中/
おはなみ /お花見/
おはやめ /お早め/
おはら /小原/尾原/
おはらい /お赦い/
おば /伯母/叔母/尾羽/小母/小場/
おばあさん /お婆さん/
おばけ /オバケ/お化け/
おばさん /小母さん/
おばすて /姨捨/
おばた /小幡/小畑/小俣/
おばたやま /小畑山/
おばたりあん /オバタリアン/
おばな /雄花/
おばなざわ /尾花沢/
おばま /小浜/
おばまおんせん /小浜温泉/
おばません /小浜線/
おばら /小原/
おばらりゅうかいかん /小原流会館/
おひきうけ /お引受け/
おひきたて /お引き立て/
おひさしぶり /お久しぶり/
おひざもと /お膝元/
おひつじ /牡羊/
おひつじざ /牡羊座/
おひま /御暇/お暇/
おひめさま /お姫様/
おひる /お昼/
おひるころ /お昼頃/
おひるまえ /お昼前/
おひるやすみ /お昼休み/
おひれ /尾ひれ/
おひろめ /お披露目/御披露目/
おび /帯/小尾/帶/飫肥/
おびいた /帯板/
おびえ /怯え/
おびかわ /帯川/
おびがき /帯書/
おびがね /帯金/
おびきおく /帯記憶/
おびぎょうれつ /帯行列/
おびこうこく /帯広告/
おびじょう /帯状/
おびつ /帯津/小櫃/
おびとけ /帯解/
おびなた /大日方/
おびなど /帯等/
おびのこ /帯鋸/
おびはば /帯幅/
おびばんぐみ /帯番組/
おびひろ /帯広/
おびひろえき /帯広駅/
おびひろはくようこうこう /帯広柏葉高校/
おびふう /帯封/
おびら /小平/
おびれ /尾鰭/
おふ /オフ/
おふぃす /オフィス/
おふせ /御布施/
おふたかた /御二方/
おふたり /お二人/御二人/
おふゆ /雄冬/
おふる /お古/
おふれこ /オフレコ/
おふろ /お風呂/
おぶき /小吹/
おぶじぇくと /オブジェクト/
おぶじぇくとしこう /オブジェクト指向/
おぶせ /小布施/
おぶち /小渕/
おぶちざわ /小淵沢/
おぶつ /汚物/
おぷしょん /オプション/
おへや /お部屋/
おへんじ /お返事/御返事/
おべんきょう /お勉強/
おべんとう /お弁当/
おぺ /手術/
おぺら /オペラ/
おぺれーしょん /オペレーション/
おぺれーた /オペレータ/
おぺれーたー /オペレーター/
おぺれーてぃんぐしすてむ /オペレーティングシステム/
おぼうさん /お坊さん/
おぼえ /覚え/憶え/
おぼえがき /覚書/覚え書き/
おぼろ /朦/朧/
おぼろづき /朧月/
おぼろづきよ /朧月夜/
おぼん /お盆/
おぼんやすみ /お盆休み/
おまーん /オマーン/
おまいり /お参り/御参り/
おまえ /お前/御前/
おまえざき /御前崎/
おまえざきおき /御前崎沖/
おまごさん /お孫さん/
おまた /小俣/尾股/尾又/
おまち /お待ち/
おまちがい /お間違い/
おまつり /お祭り/
おまもり /お守り/御守り/
おまわり /お巡り/
おみ /臣/尾美/麻績/
おみあい /お見合い/
おみあし /御御足/
おみおくり /お見送り/
おみがわ /小見川/
おみき /御神酒/
おみごと /御見事/
おみず /お水/
おみせ /お店/御店/
おみそれ /御見逸/
おみつもり /御見積/
おみなえし /女郎花/
おみまい /お見舞い/御見舞い/お見舞/御見舞/
おみまいきん /御見舞い金/
おみまいひ /お見舞い費/
おみやげ /お土産/御土産/
おむつ /繦/
おむにばす /オムニバス/
おむらいす /オムライス/
おむろ /御室/
おめあて /お目あて/
おめい /汚名/
おめいこう /御命講/
おめいし /お名刺/
おめいばんかい /汚名挽回/
おめいへんじょう /汚名返上/
おめが /Ω/ω/
おめがもう /オメガ網/
おめみえ /お目見え/御目見得/
おめんじょう /御免状/
おも /主/面/重/
おもい /思/思い/想い/重茂/
おもいいれ /思い入れ/
おもいきり /思い切り/
おもいこみ /思い込み/
おもいちがい /思い違い/
おもいっきり /思いっきり/
おもいつき /思い付き/
おもいで /思い出/想い出/
おもいでばなし /思い出話/
おもいやり /思いやり/
おもうつぼ /思う壷/
おもかげ /面影/俤/
おもかじ /面舵/
おもご /面河/
おもさ /重さ/
おもしろ /面白/
おもしろい /面白い/
おもしろさ /面白さ/
おもしろはんぶん /面白半分/
おもしろみ /面白味/面白み/
おもしろやま /面白山/
おもしろやまこうげん /面白山高原/
おもしろやまこうげんえき /面白山高原駅/
おもたに /面谷/
おもだかもく /オモダカ目/Alismatales/
おもだかもくぐん /オモダカ目群/
おもちゃ /玩具/
おもて /表/面/
おもてあみ /表編み/
おもてうら /表裏/
おもてうらいったい /表裏一体/
おもてかんばん /表看板/
おもてがき /表書き/
おもてがわ /表側/
おもてぐち /表口/
おもてぐみ /表組/
おもてげんかん /表玄関/
おもてごう /表郷/
おもてさんどう /表参道/
おもてさんどうえき /表参道駅/
おもてさんどうこうさてん /表参道交差点/
おもてさんどうてん /表参道店/
おもてざた /表ざた/表沙汰/
おもてじ /表地/
おもてせんけ /表千家/
おもてどおり /表通り/
おもてにほん /表日本/
おもてばんく /表バンク/
おもてぶた /表蓋/
おもてぶたい /表舞台/
おもてまんざ /表万座/
おもてむき /表向き/表向/
おもてろっこう /表六甲/
おもな /主な/
おもなが /面長/
おもに /重荷/主に/
おものがわ /雄物川/
おもばば /重馬場/
おもみ /重み/重味/
おもみけいすう /重み係数/
おもむき /趣/趣き/
おもむろ /徐/
おももち /面持ち/面持/
おもや /母屋/
おもり /重り/錘/お守り/
おもわく /思惑/
おもわず /思わず/
おや /親/
おやいず /小柳津/
おやいづ /小柳津/
おやいで /小柳出/
おやかく /親核/
おやかた /親方/お館/
おやかたさま /お館様/
おやかためい /親方名/
おやかぶ /親株/
おやがいしゃ /親会社/
おやがめ /親亀/
おやき /親器/親機/
おやきじ /親記事/
おやきゅうだん /親球団/
おやく /御役/
おやくそく /お約束/御約束/
おやくそくどおり /お約束どおり/お約束通り/御約束どおり/御約束通り/
おやけ /小宅/
おやこ /親子/母子/
おやこうこう /親孝行/
おやこかん /親子間/
おやこかんけい /親子関係/
おやこたか /親子鷹/
おやこどん /親子丼/
おやこなべ /親子鍋/
おやご /親御/
おやごころ /親心/
おやしお /親潮/
おやしおいき /親潮域/
おやしらず /親不知/
おやじ /親父/親字/親爺/
おやじしん /親自身/
おやすみ /お休み/
おやたち /親達/
おやだま /親玉/
おやど /御宿/
おやなぎ /小柳/
おやばか /親馬鹿/
おやひとりこひとり /親一人子一人/
おやふこう /親不幸/親不孝/
おやぶん /親分/
おやぶんこぶん /親分子分/
おやぶんやく /親分役/
おやべ /小矢部/
おやま /尾山/小山/女形/雄山/
おやまえき /小山駅/
おやまかん /小山間/
おやまこうじょう /小山工場/
おやまし /小山市/
おやまだ /小山田/
おやまゆうえんち /小山遊園地/
おやむすめ /親娘/
おやもと /親元/
おやゆずり /親譲り/
おやゆび /親指/拇/
おやゆびがわ /親指側/
おやゆびくん /親指君/
おゆ /お湯/
おゆずり /御譲り/
おゆるし /お許し/
およそ /凡そ/
および /及び/及/
およびごし /及び腰/
およめさん /お嫁さん/
およろこび /お喜び/お慶び/
おらんうーたん /オランウータン/
おらんだ /和蘭/
おり /折/澱/織/檻/
おりお /折尾/
おりおえき /折尾駅/
おりおり /折々/
おりかえし /折り返し/
おりかえしてん /折り返し点/
おりかさ /折笠/織笠/
おりがさ /織笠/
おりがみ /折り紙/
おりくち /降り口/
おりこみ /折込/
おりしげ /折茂/
おりしも /折しも/
おりじなる /オリジナル/
おりた /織田/
おりたて /折立/
おりづめ /折り詰め/折詰/
おりどしき /折戸式/
おりはし /折橋/
おりはら /折原/織原/
おりばこ /折り箱/
おりめ /折り目/織り目/折目/
おりも /織茂/折茂/
おりもの /織物/
おりものきじ /織物生地/
おりよく /折よく/
おりんぴっく /オリンピック/
おるごーる /オルゴール/
おれ /俺/
おれい /御礼/お礼/
おれいきじ /御礼記事/
おれいきん /お礼金/
おれさま /俺様/
おれせん /折線/折れ線/
おれたち /俺達/
おれめ /折れ目/
おれんじ /オレンジ/
おろ /悪露/
おろか /愚か/
おろかもの /愚か者/
おろし /卸/颪/
おろしうり /卸売/卸売り/
おろしうりてん /卸売店/
おろししょう /卸商/
おろしそうば /卸相場/
おろしどんや /卸問屋/
おろしね /卸値/
おろしまち /卸町/
おろそか /疎か/
おろち /大蛇/
おわ /尾羽/
おわい /浄穢/汚穢/
おわかれかい /お別れ会/
おわせ /尾鷲/
おわだ /小和田/
おわだまさこ /小和田雅子/
おわび /お詫び/
おわらい /お笑い/
おわり /終/終わり/尾張/終り/
おわりいちのみや /尾張一宮/
おわりこまき /尾張小牧/
おわりごろ /終頃/
おわりね /終値/
おわりもりおか /尾張盛岡/
おん /音/御/温/穏/恩/オン/遠/園/怨/瘟/穩/隱/
おん> /御/
おんあい /恩愛/
おんあつ /音圧/
おんあつけいど /音圧傾度/
おんあつさ /音圧差/
おんあつち /音圧値/
おんあつひ /音圧比/
おんあつぶんぷ /音圧分布/
おんあつぶんぷず /音圧分布図/
おんあつへんか /音圧変化/
おんあつれべる /音圧レベル/
おんい /恩威/
おんいき /音域/
おんいん /音韻/
おんいんかん /音韻間/
おんいんかんきょり /音韻間距離/
おんいんがくてき /音韻学的/
おんいんしきべつ /音韻識別/
おんいんじょう /音韻上/
おんいんじょうほう /音韻情報/
おんいんせい /音韻性/
おんいんせいくうかん /音韻性空間/
おんいんせいじょうほう /音韻性情報/
おんいんたいけい /音韻体系/
おんいんたんい /音韻単位/
おんいんてき /音韻的/
おんいんにんしき /音韻認識/
おんえい /恩栄/
おんか /音価/恩化/恩仮/恩暇/
おんかい /音階/
おんかいれんしゅう /音階練習/
おんかた /御方/
おんかん /音感/
おんが /遠賀/
おんがえし /恩返し/
おんがく /音楽/
おんがくあいこうしゃ /音楽愛好者/
おんがくいがい /音楽以外/
おんがくいちばんかん /音楽壱番館/
おんがくいん /音楽院/
おんがくえいが /音楽映画/
おんがくえんそう /音楽演奏/
おんがくおんきょう /音楽音響/
おんがくか /音楽家/音楽化/
おんがくかい /音楽会/音楽界/
おんがくかつどう /音楽活動/
おんがくかん /音楽観/音楽館/
おんがくかんけい /音楽関係/
おんがくかんけいしゃ /音楽関係者/
おんがくかんしょう /音楽鑑賞/
おんがくかんとく /音楽監督/
おんがくがく /音楽学/
おんがくがくいん /音楽学院/
おんがくがくしゃ /音楽学者/
おんがくがくせいよう /音楽学生用/
おんがくがくぶ /音楽学部/
おんがくがっかい /音楽学会/
おんがくがわ /音楽側/
おんがくきかいろん /音楽機械論/
おんがくきき /音楽機器/
おんがくきょういく /音楽教育/
おんがくきょうし /音楽教師/
おんがくきょうしつ /音楽教室/
おんがくぎょうかい /音楽業界/
おんがくぎょうかいようご /音楽業界用語/
おんがくぎょうしゃ /音楽業者/
おんがくけい /音楽系/
おんがくけいしき /音楽形式/
おんがくけんきゅう /音楽研究/
おんがくげいじゅつ /音楽芸術/
おんがくげき /音楽劇/
おんがくこうぎょう /音楽工業/
おんがくこうぼう /音楽工房/
おんがくこくさいかいぎ /音楽国際会議/
おんがくさい /音楽祭/
おんがくさいせいき /音楽再生機/
おんがくさいぜんせん /音楽最前線/
おんがくさくひん /音楽作品/
おんがくさんぎょう /音楽産業/
おんがくざっし /音楽雑誌/
おんがくし /音楽史/
おんがくしこう /音楽指向/
おんがくしじょう /音楽市場/
おんがくしつ /音楽室/
おんがくしゅう /音楽集/
おんがくしゅうだん /音楽集団/
おんがくしゅっぱん /音楽出版/
おんがくしゅっぱんしゃ /音楽出版社/
おんがくしょう /音楽賞/
おんがくしょしんしゃ /音楽初心者/
おんがくしょせんもん /音楽書専門/
おんがくしょり /音楽処理/
おんがくしんごう /音楽信号/
おんがくしんりがく /音楽心理学/
おんがくじしょう /音楽事象/
おんがくじたい /音楽自体/
おんがくじてん /音楽辞典/
おんがくじむしょ /音楽事務所/
おんがくじむしょなど /音楽事務所等/
おんがくじょうきょう /音楽状況/
おんがくじょうほう /音楽情報/
おんがくじょうほうかがく /音楽情報科学/
おんがくじょうほうけんさく /音楽情報検索/
おんがくじょうほうしょり /音楽情報処理/
おんがくずかん /音楽図鑑/
おんがくせい /音楽性/
おんがくせいさく /音楽制作/
おんがくせいじたい /音楽性自体/
おんがくぜんしゅう /音楽全集/
おんがくそうほう /音楽双方/
おんがくたい /音楽隊/
おんがくたいけん /音楽体験/
おんがくたんとう /音楽担当/
おんがくだいがく /音楽大学/
おんがくちかく /音楽知覚/
おんがくづくり /音楽作り/
おんがくてき /音楽的/
おんがくてききそ /音楽的基礎/
おんがくてきけいしき /音楽的形式/
おんがくてきこうぞう /音楽的構造/
おんがくてきしゅほう /音楽的手法/
おんがくてきようと /音楽的用途/
おんがくどう /音楽堂/
おんがくにんち /音楽認知/
おんがくのとも /音楽之友/音樂之友/
おんがくのともしゃ /音楽之友社/
おんがくは /音楽派/
おんがくばたけ /音楽畑/
おんがくばんぐみ /音楽番組/
おんがくひょうろんか /音楽評論家/
おんがくびがく /音楽美学/
おんがくふう /音楽風/
おんがくぶ /音楽部/
おんがくぶんか /音楽文化/
おんがくへん /音楽編/音楽篇/
おんがくほんらい /音楽本来/
おんがくや /音楽屋/
おんがくよう /音楽用/
おんがくようご /音楽用語/
おんがくりかい /音楽理解/
おんがくりょこう /音楽旅行/
おんがくりょだん /音楽旅団/
おんがくりろん /音楽理論/
おんがくれき /音楽歴/
おんがくろん /音楽論/
おんがくろんぎ /音楽論議/
おんがぐん /遠賀郡/
おんがっか /音学家/
おんがっかい /音楽会/
おんがっかん /音楽館/
おんがん /温顔/
おんき /恩紀/
おんきごう /音記号/
おんきゅう /恩給/
おんきょう /音響/音強/
おんきょうかん /音響管/
おんきょうがいしょう /音響外傷/
おんきょうがく /音響学/
おんきょうがっかい /音響学会/
おんきょうがっかいし /音響学会誌/
おんきょうきき /音響機器/
おんきょうぎじゅつ /音響技術/
おんきょうくうかん /音響空間/
おんきょうけい /音響系/
おんきょうけん /音響研/
おんきょうげんしょう /音響現象/
おんきょうこうか /音響効果/
おんきょうこうがく /音響工学/
おんきょうこうけん /音響工研/
おんきょうごうせい /音響合成/
おんきょうしんごう /音響信号/
おんきょうしんごうしょり /音響信号処理/
おんきょうしんり /音響心理/
おんきょうじゅしん /音響受信/
おんきょうじょう /音響上/
おんきょうじょうほう /音響情報/
おんきょうじょうほうかがく /音響情報科学/
おんきょうせっけい /音響設計/
おんきょうせっけいがっか /音響設計学科/
おんきょうせつび /音響設備/
おんきょうつうしん /音響通信/
おんきょうてき /音響的/
おんきょうてきこうい /音響的行為/
おんきょうとくせい /音響特性/
おんきょうはいぶん /音強配分/
おんきょうばくろれべる /音響暴露レベル/
おんきょうふか /音響負荷/
おんきょうぶ /音響部/
おんきょうぶんせき /音響分析/
おんきょうほうそく /音響法則/
おんぎ /恩義/恩誼/御義/音義/
おんぎみしょう /音義未詳/
おんくん /音訓/
おんくんさくいん /音訓索引/
おんくんみしょう /音訓未詳/
おんぐう /恩遇/
おんぐん /音群/
おんけい /恩恵/音型/
おんけつ /温血/
おんけん /穏健/
おんけんは /穏健派/
おんげん /音源/
おんげんいがい /音源以外/
おんげんいち /音源位置/
おんげんがわ /音源側/音現側/
おんげんすう /音源数/
おんげんぜんたい /音源全体/
おんげんとくせい /音源特性/
おんげんはいち /音源配置/
おんげんばん /音源版/
おんげんぶ /音源部/
おんげんぶぶん /音源部分/
おんげんほうこう /音源方向/
おんげんほうしき /音源方式/
おんげんもぎ /音源模擬/
おんげんよう /音源用/
おんこ /恩顧/
おんこう /温厚/音高/恩光/恩幸/音効/
おんこうろん /音講論/
おんこうろんしゅう /音講論集/
おんこちしん /温故知新/
おんごく /遠国/
おんさ /音叉/
おんさいと /オンサイト/
おんさく /音作/
おんさん /音産/
おんし /恩師/恩賜/恩旨/恩私/
おんしつ /音質/温室/
おんしつかいぜん /音質改善/
おんしつかいぜんこうか /音質改善効果/
おんしつこうか /温室効果/
おんしつこうじょう /音質向上/
おんしつこうじょうほう /音質向上法/
おんしつさ /音質差/
おんしつてき /音質的/
おんしつど /温湿度/
おんしつどけい /温湿度計/
おんしつめん /音質面/
おんしつれっか /音質劣化/
おんしゃ /御社/恩赦/音写/
おんしゃく /恩借/
おんしゅう /恩讐/恩讎/
おんしょう /温床/恩賞/恩詔/恩奨/
おんしょく /音色/
おんしょくすう /音色数/
おんしょくはいれつ /音色配列/
おんしょくめい /音色名/
おんしん /音信/
おんしんふつう /音信不通/
おんじゅく /御宿/
おんじゅつ /恩恤/
おんじゅん /音順/温順/
おんじょう /音情/温情/音場/恩情/
おんじょうかいせき /音場解析/
おんじょうかん /音場感/
おんじょうけん /音情研/
おんじょうさいせい /音場再生/
おんじょうしょり /音情処理/
おんじょうせいぎょ /音場制御/
おんじょうない /音場内/
おんじん /恩人/
おんすい /温水/
おんすいき /温水機/
おんすう /音数/
おんせい /音声/
おんせいか /音声化/
おんせいかいせき /音声解析/
おんせいかんけい /音声関係/
おんせいがく /音声学/
おんせいがくてき /音声学的/
おんせいきごう /音声記号/
おんせいきょうちょう /音声強調/
おんせいきょうちょうきこう /音声強調機構/
おんせいきょうちょうけっか /音声強調結果/
おんせいきょうちょうこうか /音声強調効果/
おんせいきょうちょうしゅほう /音声強調手法/
おんせいきょうちょうしょり /音声強調処理/
おんせいきょうちょうしょりご /音声強調処理後/
おんせいきょうちょうほう /音声強調法/
おんせいくかん /音声区間/
おんせいけん /音声研/
おんせいけんきゅう /音声研究/
おんせいけんきゅうかい /音声研究会/
おんせいけんきゅうしつ /音声研究室/
おんせいけんきゅうしゃ /音声研究者/
おんせいげんご /音声言語/
おんせいげんごしょり /音声言語処理/
おんせいごうせい /音声合成/
おんせいごうせいそうち /音声合成装置/
おんせいさんぷる /音声サンプル/
おんせいしゅうろく /音声収録/
おんせいしゅつりょく /音声出力/
おんせいしゅつりょくき /音声出力機/
おんせいしょり /音声処理/
おんせいしょりかいろ /音声処理回路/
おんせいしりょう /音声試料/
おんせいしんごう /音声信号/
おんせいしんごうしょり /音声信号処理/
おんせいじょうほう /音声情報/
おんせいじょうほうけんきゅうぶ /音声情報研究部/
おんせいじょうほうしょり /音声情報処理/
おんせいせいせい /音声生成/
おんせいせいせいかてい /音声生成過程/
おんせいたいいき /音声帯域/
おんせいたいおう /音声対応/
おんせいたじゅう /音声多重/
おんせいちかく /音声知覚/
おんせいてき /音声的/
おんせいてきたいおう /音声的対応/
おんせいでんたつ /音声伝達/
おんせいとくちょうりょう /音声特徴量/
おんせいにゅうりょく /音声入力/
おんせいにゅうりょくたんし /音声入力端子/
おんせいにんしき /音声認識/
おんせいにんしきかんけい /音声認識関係/
おんせいにんしきそうち /音声認識装置/
おんせいは /音声波/
おんせいはけい /音声波形/
おんせいひょうき /音声表記/
おんせいひんしつ /音声品質/
おんせいふごうか /音声符号化/
おんせいぶ /音声部/
おんせいぶぶん /音声部分/
おんせいぶんせき /音声分析/
おんせいりかい /音声理解/
おんせいりょうかいど /音声了解度/
おんせいろくさいきのう /音声録再機能/
おんせき /恩錫/
おんせつ /音節/応接/
おんせつこうぞう /音節構造/
おんせつすう /音節数/
おんせつたいおう /音節対応/
おんせつちょう /音節長/
おんせつもじ /音節文字/
おんせん /温泉/音線/
おんせんえき /温泉駅/
おんせんかんこうち /温泉観光地/
おんせんがい /温泉街/
おんせんじょうほう /温泉情報/
おんせんじるし /温泉印/
おんせんち /温泉地/
おんせんほう /音線法/
おんせんやど /温泉宿/
おんせんよくじょう /温泉浴場/
おんせんりょかん /温泉旅館/
おんせんりょこう /温泉旅行/
おんそ /音素/
おんそいちょうひょう /音素異聴表/
おんそく /音速/音束/
おんそくいか /音速以下/
おんそくひこう /音速飛行/
おんそぐん /音素群/
おんそたんい /音素単位/
おんそてき /音素的/
おんそべんべつそせい /音素弁別素性/
おんそめい /音素名/
おんそもじ /音素文字/
おんそれつ /音素列/
おんそろん /音素論/
おんぞう /音像/
おんぞういち /音像位置/
おんぞうきょり /音像距離/
おんぞうきょりていい /音像距離定位/
おんぞうし /御曹司/御曹子/
おんぞうせいぎょ /音像制御/
おんぞうていい /音像定位/
おんぞん /温存/
おんたい /御大/温帯/恩貸/
おんたいしょう /御大将/
おんたく /恩沢/
おんたけ /御岳/
おんたけさんえき /御嶽山駅/
おんだ /恩田/音田/
おんだい /音大/
おんだいせい /音大生/
おんだいそつ /音大卒/
おんだん /温暖/
おんだんか /温暖化/
おんだんかさよう /温暖化作用/
おんだんかよういん /温暖化要因/
おんだんき /温暖期/
おんち /音痴/
おんちく /音蓄/
おんちくけい /音蓄系/
おんちけん /音知研/
おんちゅう /御中/
おんちょう /恩寵/音長/音調/
おんてい /音程/
おんていかん /音程感/
おんていがい /音程外/
おんていぶん /音程分/
おんてき /怨敵/
おんてん /恩典/
おんでこざ /鬼太鼓座/
おんと /音吐/
おんとう /穏当/
おんど /温度/音頭/音戸/
おんどかんり /温度管理/
おんどく /音読/
おんどけい /温度計/
おんどこうばい /温度勾配/
おんどさ /温度差/
おんどしつど /温度湿度/
おんどじょうしょう /温度上昇/
おんどせってい /温度設定/
おんどちょうせつ /温度調節/
おんどてん /温度点/
おんどはんい /温度範囲/
おんどへんか /温度変化/
おんどほしょう /温度補償/
おんどほせい /温度補正/
おんどやくそう /温度躍層/
おんどり /雄鳥/
おんどる /温突/
おんな /女/音奈/♀/恩納/恩名/
おんない /恩愛/
おんながわ /女側/
おんなきょうだい /女姉妹/
おんなけいず /婦系図/
おんなげいしゃ /女芸者/
おんなことば /女言葉/
おんなごころ /女心/
おんなざちょう /女座長/
おんなしまい /女姉妹/
おんなしゃかい /女社会/
おんなしゅじん /女主人/
おんなじしん /女自身/
おんなじゅうどうか /女柔道家/
おんなずき /女好き/
おんなずもう /女相撲/
おんなせんし /女戦士/
おんなそうばし /女相場師/
おんなたち /女達/
おんなたらし /女誑/女誑し/
おんなっけ /女っ気/
おんなともだち /女友達/
おんなどうし /女同士/
おんなのこ /女の子/
おんなのひと /女の人/
おんなばん /女版/
おんなひとり /女一人/
おんなへん /媚/
おんなべんごし /女弁護士/
おんなもじ /女文字/
おんなもの /女物/
おんなゆ /女湯/
おんにん /穏忍/
おんねつ /温熱/
おんねん /怨念/
おんのじ /恩の字/御の字/
おんはいすい /温排水/
おんば /音場/穏婆/
おんばこうか /音場効果/
おんばん /音盤/
おんぱ /音波/恩波/
おんひ /音飛/
おんひょう /音標/
おんび /音尾/
おんびき /ー/
おんびん /穏便/音便/
おんびんけい /音便形/
おんぴょう /音表/
おんぷ /音符/♪/音譜/
おんぷう /温風/
おんぷふごうか /音符符号化/
おんべつ /音別/
おんみ /御身/
おんみつ /隠密/
おんみつどうしん /隠密同心/
おんみょう /陰陽/
おんみょうじ /陰陽師/
おんみょうどう /陰陽道/
おんめい /音名/恩命/恩名/
おんやく /音訳/
おんやさい /温野菜/
おんよう /陰陽/温容/恩養/
おんようじ /陰陽師/
おんようどう /陰陽道/
おんよく /温浴/
おんよみ /音読み/音読/
おんらいん /オンライン/
おんり /厭離/
おんりえど /厭離穢土/
おんりつ /音律/
おんりょう /音量/怨霊/
おんりょうちょうせい /音量調整/
おんりょうちょうせつ /音量調節/
おんれい /御礼/恩礼/
おんれつ /音列/
おんわ /温和/
か /化/可/火/日/下/家/加/課/果/歌/過/蚊/夏/仮/花/科/香/暇/個/貨/華/荷/霞/嘩/佳/箇/価/迦/菓/蝦/嘉/靴/茄/稼/河/賀/架/珂/何/苛/禍/禾/嫁/寡/ケ/伽/ヶ/鹿/窩/蝸/顆/馨/假/價/厦/呵/咼/哥/啝/堝/墟/夥/崋/廈/戈/枷/柯/渮/珈/痂/笳/罅/舸/苟/葭/萪/蝌/訶/謌/譁/譌/賈/跏/踝/軻/遐/ヵ/渦/掛/卦/袈/彼/耶/个/
か> /可/
かー /カー/
かーそる /カーソル/
かーとりっじ /カートリッジ/
かーど /カード/
かーにばる /カーニバル/
かーぶ /カーブ/
かーる /カール/
かあ /母/
かあさん /母さん/
かあちゃん /母ちゃん/
かあつ /加圧/
かあつき /加圧器/
かい /回/会/階/開/解/貝/下位/改/懐/壊/海/界/甲斐/怪/介/魁/皆/絵/快/戒/悔/獪/蟹/廻/芥/拐/械/晦/灰/恢/塊/隗/徊/垣/飼/潰/丐/乖/价/會/偕/傀/囘/匯/咼/喙/壞/夬/嵬/廨/恠/懷/懈/揩/枴/椢/楷/槐/榿/櫂/瑰/畍/疥/繪/茴/蛔/蠏/褂/觧/詼/誨/誡/諧/迴/邂/醢/
かい> /開/改/
かいあく /改悪/
かいい /怪異/魁偉/会意/
かいいき /海域/
かいいきがい /海域外/
かいいぬ /飼犬/
かいいれさいむ /買入債務/
かいいん /会員/改印/海員/開院/
かいいんいがい /会員以外/
かいいんか /会員課/
かいいんかかく /会員価格/
かいいんかくしゃ /会員各社/
かいいんかん /会員間/
かいいんかんゆう /会員勧誘/
かいいんがい /会員外/
かいいんがっこう /海員学校/
かいいんきやく /会員規約/
かいいんけん /会員権/
かいいんし /会員誌/
かいいんしかく /会員資格/
かいいんしゅべつ /会員種別/
かいいんしょう /会員証/
かいいんしょうかい /会員紹介/
かいいんすう /会員数/
かいいんせい /会員制/
かいいんせいど /会員制度/
かいいんせんよう /会員専用/
かいいんせんようでんわ /会員専用電話/
かいいんぜんいん /会員全員/
かいいんそしき /会員組織/
かいいんとくてん /会員特典/
かいいんどうし /会員同士/
かいいんないがい /会員内外/
かいいんはんばい /会員販売/
かいいんばしゅ /会員馬主/
かいいんばんごう /会員番号/
かいいんぼ /会員簿/
かいいんぼしゅう /会員募集/
かいいんめいぼ /会員名簿/
かいいんゆうし /会員有志/
かいいんよう /会員用/
かいいんりょうきん /会員料金/
かいいんわりびき /会員割引/
かいうん /海運/開運/
かいうんしょう /海軍省/
かいえいまえ /開映前/
かいえだ /海江田/
かいえん /開演/開園/開宴/快演/
かいえんじかん /開演時間/
かいえんちゅう /開演中/
かいえんばん /開円板/
かいえんまえ /開演前/
かいおうせい /海王星/
かいおうせいきどう /海王星軌道/
かいおうまる /海王丸/
かいおき /買い置き/
かいおんじ /海音寺/
かいおんせつ /開音節/
かいか /開花/開化/階下/開果/開架/
かいかい /開会/恢恢/
かいかいあいさつ /開会挨拶/
かいかいいん /会会員/
かいかいしき /開会式/
かいかいしきちょくご /開会式直後/
かいかいせんげん /開会宣言/
かいかいそう /下位階層/
かいかえ /買換え/買い換え/
かいかく /改革/開核/
かいかくあん /改革案/
かいかくがわ /改革側/
かいかくど /開角度/
かいかくは /改革派/
かいかけ /買掛/
かいかけきん /買掛金/
かいかた /買方/
かいかつ /快活/
かいかつどう /会活動/
かいかわ /會川/
かいかん /快感/会館/会舘/開管/開館/會舘/
かいかんがわ /会館側/
かいかんじ /怪幹事/
かいかんすう /下位関数/
かいが /絵画/繪畫/
かいがい /海外/
かいがいあて /海外宛/
かいがいえんせい /海外遠征/
かいがいかいせん /海外回線/
かいがいがっしゅくちゅう /海外合宿中/
かいがいきんむ /海外勤務/
かいがいけいけん /海外経験/
かいがいけしょうひん /海外化粧品/
かいがいさいしんじょうほう /海外最新情報/
かいがいさくひん /海外作品/
かいがいざいじゅうかいいん /海外在住会員/
かいがいしじょう /海外市場/
かいがいしてん /海外支店/
かいがいしゅぎょうちゅう /海外修行中/
かいがいしゅっちょう /海外出張/
かいがいしゅっちょうちゅう /海外出張中/
かいがいしゅぼば /海外種牡馬/
かいがいしんしゅつ /海外進出/
かいがいじんじ /海外人事/
かいがいせい /海外製/
かいがいせいかつ /海外生活/
かいがいせいさん /海外生産/
かいがいせいひん /海外製品/
かいがいそうきん /海外送金/
かいがいたいおうがた /海外対応型/
かいがいてんかい /海外展開/
かいがいとうぼう /海外逃亡/
かいがいとくはいん /海外特派員/
かいがいはいたつ /海外配達/
かいがいはけん /海外派遣/
かいがいはっけん /海外発券/
かいがいはっちゅう /海外発注/
かいがいはつ /海外発/
かいがいはつたいけん /海外初体験/
かいがいばん /海外版/海外盤/
かいがいふにん /海外赴任/
かいがいへん /海外編/
かいがいほうろう /海外放浪/
かいがいむけ /海外向け/海外向/
かいがいもんだい /海外問題/
かいがいよう /海外用/
かいがいりゅうがく /海外留学/
かいがいりょこう /海外旅行/
かいがいりょこうしゃ /海外旅行者/
かいがいりょこうほけん /海外旅行保険/
かいがいりょこうよう /海外旅行用/
かいがいれいかい /海外例会/
かいがく /開学/
かいがさくひん /絵画作品/
かいがてき /絵画的/
かいがてん /絵画展/
かいがもり /貝が森/貝ヶ森/
かいがら /貝殻/
かいがん /海岸/開眼/
かいがんきょく /海岸局/
かいがんせん /海岸線/
かいがんぞい /海岸沿/
かいがんだんきゅう /海岸段丘/
かいがんどおり /海岸通/
かいがんぶ /海岸部/
かいがんぼうはてい /海岸防波堤/
かいき /怪奇/快気/回帰/会期/回忌/皆既/改軌/買い気/回歸/
かいきがた /回帰型/
かいききょくせん /回帰曲線/
かいきくかん /改軌区間/
かいきげっしょく /皆既月食/
かいきげんそう /怪奇幻想/
かいきしゅ /下位機種/
かいきしょうせつ /怪奇小説/
かいきしょうせつしゅう /怪奇小説集/
かいきしょく /皆既食/
かいきせん /回帰線/
かいきだいさくせん /怪奇大作戦/
かいきちゅう /会期中/
かいきてき /回帰的/
かいきてきかいろ /回帰的回路/
かいきてきこうぞう /回帰的構造/
かいきにっしょく /皆既日食/皆既日蝕/
かいきへん /怪奇編/
かいきゃく /開脚/
かいきゅう /階級/懐旧/開球/海丘/
かいきゅういしき /階級意識/
かいきゅうかん /階級間/
かいきゅうこうぞう /階級構造/
かいきゅうさべつ /階級差別/
かいきゅうしょう /階級章/
かいきゅうせい /階級制/
かいきゅうたいりつ /階級対立/
かいきゅうてき /階級的/
かいきゅうべつ /階級別/
かいきょ /快挙/
かいきょう /回教/海峡/懐郷/
かいきょうせん /海峡線/
かいきょく /開局/
かいきょくいご /開局以後/
かいきょくしんせい /開局申請/
かいきょくじ /開局時/
かいきょくどういしょ /開局同意書/
かいきょくねんがっぴ /開局年月日/
かいきん /解禁/皆勤/開襟/
かいきんしょう /皆勤賞/
かいきんび /解禁日/
かいぎ /会議/懐疑/回議/
かいぎあんない /会議案内/
かいぎしつ /会議室/
かいぎしゅぎ /懐疑主義/
かいぎしゅっせきしゃ /会議出席者/
かいぎしょ /会議所/
かいぎしりょう /会議資料/
かいぎじたい /会議自体/
かいぎじょう /会議場/
かいぎじろく /会議事録/
かいぎちゅう /会議中/
かいぎてき /懐疑的/
かいぎないよう /会議内容/
かいぎは /懐疑派/
かいぎばしょ /会議場所/
かいぎひ /会議費/
かいぎめい /会議名/
かいぎゃく /諧謔/詼謔/
かいぎょう /改行/開業/
かいぎょうい /開業医/
かいぎょういち /改行位置/
かいぎょういちへんこう /改行位置変更/
かいぎょうかんかく /改行間隔/
かいぎょうご /改行後/
かいぎょうしょにち /開業初日/
かいぎょうじ /開業時/
かいぎょうちゅう /開業中/
かいぎょうとうしょ /開業当初/
かいぎょうとうじ /開業当時/
かいぎょうび /開業日/
かいぎょうまえ /改行前/開業前/
かいぎょうもじ /改行文字/
かいぎょうよてい /開業予定/
かいぎろく /会議録/
かいく /皆苦/
かいくうかん /開空間/解空間/
かいくかん /開区間/
かいぐん /海軍/
かいぐんきち /海軍基地/
かいぐんしょうさ /海軍少佐/
かいけい /会計/会稽/塊茎/
かいけいかんさ /会計監査/
かいけいざん /会稽山/
かいけいし /会計士/
かいけいしゅさ /会計主査/
かいけいしょり /会計処理/
かいけいしょりよう /会計処理用/
かいけいのはじ /会稽の恥/
かいけいほうこく /会計報告/
かいけいほうこくしょ /会計報告書/
かいけつ /解決/快傑/怪傑/
かいけつあん /解決案/
かいけつかてい /解決過程/
かいけつさく /解決策/
かいけつしきもんだい /解決式問題/
かいけつしゅだん /解決手段/
かいけつびょう /壊血病/
かいけつふかのう /解決不可能/
かいけつへん /解決篇/
かいけつほう /解決法/解決方/
かいけつほうほう /解決方法/
かいけん /会見/改憲/海研/
かいげん /戒厳/改元/開眼/
かいげんしょう /怪現象/
かいげんじ /甲斐源氏/
かいげんれい /戒厳令/
かいげんれいか /戒厳令下/
かいこ /蚕/懐古/解雇/回顧/蠶/解顧/回雇/廻顧/蚕儚/
かいこう /開校/開講/改稿/開口/回航/海港/海溝/開港/邂逅/回行/開項/開高/
かいこういちばん /開口一番/
かいこうきねんび /開校記念日/
かいこうこうけいひ /開口口径比/
かいこうしき /開講式/
かいこうしゃ /階行社/
かいこうしょうがい /開口障害/
かいこうたけし /開高健/
かいこうたん /開口端/
かいこうぶ /開口部/
かいこうめん /開口面/
かいこうりつ /開口率/
かいこきじ /回顧記事/
かいこく /戒告/海国/開国/会告/
かいこくらん /会告欄/
かいこしゅぎしゃ /懐古主義者/
かいこしゅみ /懐古趣味/
かいこちょう /回顧調/
かいこてき /懐古的/
かいことば /買い言葉/
かいこは /懐古派/
かいこま /甲斐駒/
かいころく /回顧録/
かいこん /開梱/開墾/悔恨/塊根/
かいご /介護/改悟/
かいごう /会合/蟹螯/
かいごうしゅうき /会合周期/
かいごにん /介護人/
かいごろし /飼い殺し/
かいさ /海佐/
かいさい /開催/快哉/
かいさいあんない /開催案内/
かいさいきかん /開催期間/
かいさいきかんちゅう /開催期間中/
かいさいきかんない /開催期間内/
かいさいきじつ /開催期日/
かいさいきねん /開催記念/
かいさいけいけん /開催経験/
かいさいこく /開催国/
かいさいしんせい /開催申請/
かいさいじ /開催時/
かいさいじき /開催時期/
かいさいじゅんび /開催準備/
かいさいじょうけん /開催条件/
かいさいせきにんしゃ /開催責任者/
かいさいち /開催地/
かいさいちゅう /開催中/
かいさいちゅうし /開催中止/
かいさいちょくぜん /開催直前/
かいさいつうち /開催通知/
かいさいと /下位サイト/
かいさいとし /開催都市/
かいさいにちじ /開催日時/
かいさいにっすう /開催日数/
かいさいにってい /開催日程/
かいさいねん /開催年/
かいさいばしょ /開催場所/
かいさいび /開催日/
かいさいようこう /開催要項/
かいさいよてい /開催予定/
かいさく /改作/怪作/
かいさつ /改札/
かいさつがかり /改札係/
かいさつき /改札機/
かいさつぐち /改札口/
かいさん /解散/海産/
かいさんかい /解散会/
かいさんけん /解散権/
かいさんご /解散後/
かいさんしょうしょ /解散詔書/
かいさんじたい /解散自体/
かいさんじょうたい /解散状態/
かいさんせつ /解散説/
かいさんぶつ /海産物/
かいざい /介在/
かいざいく /貝細工/
かいざいせいちょう /介在生長/
かいざいぶんれつそしき /介在分裂組織/
かいざん /改竄/
かいざんじけん /改竄事件/
かいし /開始/会誌/海士/壊死/
かいしいち /開始位置/
かいしいらい /開始以来/
かいしき /開式/
かいしきごう /開始記号/
かいしきねん /開始記念/
かいしぎょう /開始行/
かいしご /開始後/
かいしじ /開始時/
かいしじかん /開始時間/
かいしじこく /開始時刻/
かいしじてん /開始時点/
かいしたん /開始端/
かいしち /開始値/
かいしちょくご /開始直後/
かいしつ /開室/
かいしつび /開室日/
かいしてん /開始点/
かいしとうしょ /開始当初/
かいしねん /開始年/
かいしひづけ /開始日付/
かいしび /開始日/
かいしまえ /開始前/
かいしめ /買占め/
かいしめい /会誌名/
かいしゃ /会社/會社/膾炙/
かいしゃいん /会社員/
かいしゃいんせいかつ /会社員生活/
かいしゃかん /会社間/
かいしゃかんけい /会社関係/
かいしゃかんけいしゃ /会社関係者/
かいしゃがえり /会社帰り/
かいしゃがわ /会社側/
かいしゃく /解釈/介錯/解釋/
かいしゃくかのう /解釈可能/
かいしゃくけい /解釈系/
かいしゃくしゃ /解釈者/
かいしゃくじたい /解釈自体/
かいしゃくじっこう /解釈実行/
かいしゃくほう /解釈法/
かいしゃくほうほう /解釈方法/
かいしゃけいえい /会社経営/
かいしゃこうせいほう /会社更正法/会社更生法/
かいしゃしゃかい /会社社会/
かいしゃしゃちょう /会社社長/
かいしゃしょうかい /会社紹介/
かいしゃじたい /会社自体/
かいしゃじん /会社人/
かいしゃせい /会社製/
かいしゃせいかつ /会社生活/
かいしゃせつめいかい /会社説明会/
かいしゃせん /会社線/
かいしゃぜんたい /会社全体/
かいしゃそしき /会社組織/
かいしゃぞう /開写像/
かいしゃたんい /会社単位/
かいしゃない /会社内/
かいしゃないぶ /会社内部/
かいしゃにんげん /会社人間/
かいしゃほうもん /会社訪問/
かいしゃめい /会社名/
かいしゃもち /会社もち/
かいしゃろく /会社録/
かいしゅう /回収/改修/会衆/改宗/回收/
かいしゅうこうじ /改修工事/
かいしゅうこうじちゅう /改修工事中/
かいしゅうごう /開集合/
かいしゅうごうけい /開集合系/
かいしゅうさき /回収先/
かいしゅうしゃ /回収車/
かいしゅうちゅう /改修中/回収中/
かいしゅうばこ /回収箱/
かいしゅうばしょ /回収場所/
かいしゅうりつ /回収率/
かいしゅん /回春/悔悛/改悛/
かいしょ /会所/楷書/開所/
かいしょう /解消/改称/甲斐性/快勝/介紹/
かいしょうかん /解消感/
かいしょうぎじゅつ /解消技術/
かいしょうさく /解消策/
かいしょうほう /解消法/
かいしょく /会食/解職/
かいしょしき /開所式/
かいしよてい /開始予定/
かいしん /改新/会心/回診/改心/快心/
かいしんげき /快進撃/
かいじ /開示/快事/海事/解字/甲斐路/怪事/
かいじがく /解字学/
かいじつうしんえいせい /海事通信衛星/
かいじむきょく /会事務局/
かいじゅ /槐樹/解呪/
かいじゅう /怪獣/懐柔/晦渋/海獣/
かいじゅうえいが /怪獣映画/
かいじゅうご /怪獣語/
かいじゅうさく /懐柔策/
かいじゅうだいずかい /怪獣大図解/
かいじゅうだいひゃっか /怪獣大百科/
かいじゅうめい /怪獣名/
かいじゅんびかい /会準備会/
かいじょ /解除/介助/
かいじょう /会場/階乗/海上/開場/開錠/階上/回状/開城/階状/塊状/塊上/
かいじょうあんないず /会場案内図/
かいじょううけつけ /会場受付/
かいじょうかさいほけん /海上火災保険/
かいじょうがい /会場外/
かいじょうがかり /会場係/
かいじょうがわ /会場側/
かいじょうきんぺん /会場近辺/
かいじょうけん /海上権/
かいじょうげんていひん /会場限定品/
かいじょうこうえん /海上公園/
かいじょうこうつう /海上交通/
かいじょうごえい /海上護衛/
かいじょうじ /開場時/
かいじょうじえいたい /海上自衛隊/
かいじょうじかん /開場時間/
かいじょうじゅう /会場中/
かいじょうじゅんび /会場準備/
かいじょうせいり /会場整理/
かいじょうぜんたい /会場全体/
かいじょうだい /会場代/
かいじょうていいん /会場定員/
かいじょうない /会場内/
かいじょうひ /会場費/
かいじょうふきん /会場付近/
かいじょうほあんたい /海上保安隊/
かいじょうほあんちょう /海上保安庁/
かいじょうほう /怪情報/
かいじょうぼうえい /海上防衛/
かいじょうまえ /開場前/会場前/
かいじょうめい /会場名/
かいじょうゆそうろ /海上輸送路/
かいじょしゃ /介助者/
かいじり /海尻/
かいじん /怪人/灰塵/灰燼/
かいすい /海水/
かいすいおん /海水温/
かいすいおんど /海水温度/
かいすいぎょ /海水魚/
かいすいさんぶつ /海水産物/
かいすいちゅう /海水中/
かいすいめん /海水面/
かいすいよく /海水浴/
かいすいよくじょう /海水浴場/
かいすいよくれっしゃ /海水浴列車/
かいすう /回数/階数/
かいすうけん /回数券/
かいすうじたい /回数自体/
かいすうじゅん /回数順/
かいず /海津/海図/
かいずか /貝塚/
かいせ /貝瀬/
かいせい /快晴/改正/回生/開成/改姓/海星/海棲/
かいせいあん /改正案/開盛庵/
かいせいいぜん /改正以前/
かいせいきてい /改正規定/
かいせいげんあん /改正原案/
かいせいこうこう /開成高校/
かいせいご /改正後/
かいせいごう /改正号/
かいせいしっこう /回生失効/
かいせいしゃ /偕成社/階成社/
かいせいじ /改正時/回生時/
かいせいじょうほう /改正情報/
かいせいせいどう /回生制動/
かいせいてん /改正点/
かいせいでんりゅう /回生電流/
かいせいでんりょく /回生電力/
かいせいばん /改正版/
かいせいび /改正日/
かいせいまえ /改正前/
かいせき /解析/会席/懐石/階席/
かいせきかい /解析解/
かいせきかのうせい /解析可能性/
かいせきかんすう /解析関数/
かいせきがく /解析学/
かいせきき /解析器/
かいせききかん /解析機関/
かいせきぎ /解析木/
かいせきぎじゅつ /解析技術/
かいせきぎほう /解析技法/
かいせきけい /解析系/
かいせきけいかく /解析計画/
かいせきけっか /解析結果/
かいせきけんきゅうか /解析研究課/
かいせきけんきゅうしつ /解析研究室/
かいせきしゃ /解析者/
かいせきしゅほう /解析手法/解析しゅほう/
かいせきしんごう /解析信号/
かいせきじ /解析時/
かいせきじょう /解析上/
かいせきせつぞく /解析接続/
かいせきたいしょう /解析対象/
かいせきちゅう /解析中/
かいせきてき /解析的/
かいせきてじゅん /解析手順/
かいせきほう /解析法/
かいせきほうほう /解析方法/
かいせきぼん /解析本/
かいせきりきがく /解析力学/
かいせきりょうり /懐石料理/
かいせきろん /解析論/
かいせつ /解説/開設/回折/
かいせつかい /解説会/
かいせつきじ /解説記事/
かいせつげんしょう /回折現象/
かいせつこうし /回折格子/
かいせつしゃ /解説者/
かいせつしゃたち /解説者達/
かいせつしゅう /解説集/
かいせつしょ /解説書/
かいせつじん /解説陣/
かいせつず /解説図/
かいせつてき /解説的/
かいせつとうしょ /開設当初/
かいせつふよう /解説不要/
かいせつぶさんしょう /解説部参照/
かいせつぶん /解説文/
かいせつぶんしょ /解説文書/
かいせつへん /解説編/
かいせつぼん /解説本/
かいせつめい /解説名/
かいせつもくろく /解説目録/
かいせつらん /解説欄/
かいせつりつ /会設立/
かいせつりつじゅんびかい /会設立準備会/
かいせつりつそうかい /会設立総会/
かいせん /回線/開栓/回戦/会戦/回旋/改選/海鮮/開戦/疥癬/海戦/回船/
かいせんいじょう /回線異常/
かいせんいちば /海鮮市場/
かいせんきほんりょうきん /回線基本料金/
かいせんけいゆ /回線経由/
かいせんこうかん /回線交換/
かいせんご /開栓後/
かいせんじじょう /回線事情/
かいせんすう /回線数/
かいせんせんようりょう /回線専用料/
かいせんぜんや /開戦前夜/
かいせんそくど /回線速度/
かいせんぞくせい /回線属性/
かいせんだい /回線代/
かいせんだん /回線断/
かいせんちゅう /改選中/
かいせんでんわ /回線電話/
かいせんどうとう /回線同等/
かいせんひ /回線費/
かいせんひんしつ /回線品質/
かいせんへんけい /回旋変形/
かいせんもう /回線網/
かいせんりょうきん /回線料金/
かいせんりよう /回線利用/
かいぜん /改善/
かいぜんあん /改善案/
かいぜんいけん /改善意見/
かいぜんかのう /改善可能/
かいぜんかんこく /改善勧告/
かいぜんこうか /改善効果/
かいぜんこうもく /改善項目/
かいぜんさく /改善策/
かいぜんしゅほう /改善手法/
かいぜんていあん /改善提案/
かいぜんてん /改善点/
かいぜんど /改善度/
かいぜんまえ /改善前/
かいぜんようきゅう /改善要求/
かいぜんりつ /改善率/
かいそ /改組/開祖/
かいそう /階層/改装/回想/回送/下位層/海草/会葬/快走/海藻/回走/回漕/潰走/
かいそううちゅう /階層宇宙/
かいそううんてん /回送運転/
かいそうか /階層化/階層下/
かいそうかん /階層間/
かいそうかんけい /階層関係/
かいそうがた /階層型/
かいそうがたねっとわあく /階層型ネットワーク/
かいそうがたひょうか /階層型評価/
かいそうこうじ /改装工事/
かいそうこうぞう /階層構造/
かいそうご /改装後/
かいそうごと /階層毎/
かいそうしゃ /改宗者/回送車/
かいそうじ /回送時/
かいそうせい /階層性/
かいそうちゅう /改装中/階層中/回送中/
かいそうてき /階層的/
かいそうてきこうぞう /階層的構造/
かいそうてきこうぞうふごうか /階層的構造符号化/
かいそうてきそくめん /階層的側面/
かいそうでんしゃ /回送電車/
かいそうない /階層内/
かいそうば /買相場/
かいそうばなし /回想話/
かいそうひ /改装費/
かいそうべつ /階層別/
かいそうめい /階層名/
かいそうれっしゃ /回送列車/
かいそうろく /回想録/
かいそく /快速/会則/快足/
かいそくうんこう /快速運行/
かいそくうんてん /快速運転/
かいそくうんてんくかん /快速運転区間/
かいそくか /快速化/
かいそくきゅうこう /快速急行/
かいそくじゅんきゅう /快速準急/
かいそくせん /快速線/
かいそくつうか /快速通過/
かいそくていしゃ /快速停車/
かいそくていしゃえき /快速停車駅/
かいそくでんしゃ /快速電車/
かいそくとっきゅう /快速特急/
かいそくねむろいき /快速根室行/
かいそくねむろゆき /快速根室行/
かいそくば /快速馬/
かいそくよう /快速用/
かいそくれっしゃ /快速列車/
かいそしき /下位組織/
かいぞう /改造/解像/海三/
かいぞうあん /改造案/
かいぞうき /改造機/
かいぞうきじ /改造記事/
かいぞうこうじ /改造工事/
かいぞうこうひ /改造工費/
かいぞうご /改造後/
かいぞうしゃ /改造車/
かいぞうしゃけん /改造車検/
かいぞうしゅじゅつ /改造手術/
かいぞうちゃくしゅご /改造着手後/
かいぞうてん /改造点/
かいぞうど /解像度/
かいぞうどてき /解像度的/
かいぞうにんげん /改造人間/
かいぞうばん /改造版/
かいぞうひ /改造費/
かいぞうほう /改造法/
かいぞうよう /改造用/
かいぞうりょう /改造量/
かいぞうりょく /解像力/
かいぞうれき /改造歴/
かいぞえ /介添/
かいぞく /海賊/
かいぞくおとこ /海賊男/
かいぞくせん /海賊船/
かいぞくてき /海賊的/
かいぞくばん /海賊版/海賊盤/
かいぞくばんたいさく /海賊版対策/
かいぞん /買い損/
かいた /頴田/海田/
かいたい /解体/
かいたいぎょうしゃ /解体業者/
かいたいさぎょう /解体作業/
かいたいしゅうり /解体修理/
かいたいしんしょ /解体新書/
かいたいせつび /解体設備/
かいたいち /海田市/
かいたいや /解体屋/
かいたく /開拓/
かいたくし /開拓史/
かいたくしゃ /開拓者/
かいたくしゃせいしん /開拓者精神/
かいたくち /開拓地/
かいたくのうみん /開拓農民/
かいたん /海単/
かいだ /改田/快打/貝田/開田/海田/
かいだい /解題/改題/
かいだく /快諾/
かいだこうげん /開田高原/
かいだし /買い出し/
かいだて /階建/
かいだめ /買い貯め/買いだめ/
かいだん /階段/会談/怪談/戒壇/
かいだんご /会談後/
かいだんし /快男子/
かいだんじょう /階段状/
かいだんせんこう /階段穿孔/階段せん孔/
かいだんのぼり /階段登り/
かいだんばなし /怪談話/
かいだんふきん /階段付近/
かいだんよこ /階段横/
かいち /嘉一/
かいちく /改築/
かいちくあん /改築案/
かいちくこうじ /改築工事/
かいちくじ /改築時/
かいちくまえ /改築前/
かいちゅう /海中/回虫/懐中/界中/蛔虫/懷中/蛔蟲/
かいちゅうこうえん /海中公園/
かいちゅうでんとう /懐中電灯/
かいちゅうどけい /懐中時計/
かいちょう /会長/快調/階調/怪鳥/開帳/諧調/回腸/
かいちょうしつ /会長室/
かいちん /開陳/
かいつう /開通/
かいつういらい /開通以来/
かいつうご /開通後/
かいつうしき /開通式/
かいつうじょうほう /開通情報/
かいつうとうしょ /開通当初/
かいつうび /開通日/
かいつうぶぶん /開通部分/
かいつうまえ /開通前/
かいつうよてい /開通予定/
かいつうよていび /開通予定日/
かいつけ /買付け/買付/
かいつぶり /鳰/
かいづ /海津/
かいづか /貝塚/
かいづかし /貝塚市/
かいて /買い手/
かいてい /改訂/海底/改定/開廷/階梯/
かいていぐんかん /海底軍艦/
かいていさぎょう /改定作業/改訂作業/
かいていしんでん /海底神殿/
かいていじ /改訂時/
かいていじしんけい /海底地震計/
かいていだいにはん /改訂第二版/
かいていちけい /海底地形/
かいていてじゅん /改定手順/
かいていてつづき /改定手続/改定手続き/改訂手続/改訂手続き/
かいていにまんり /海底二万里/
かいていばん /改訂版/改定版/
かいていぶん /改訂文/
かいていほうほう /改定方法/
かいていりれき /改訂履歴/
かいてき /快適/会的/
かいてきか /快適化/
かいてきくうかん /快適空間/
かいてきせい /快適性/
かいてん /回転/開店/廻天/廻転/廻轉/
かいてんあしばらい /回転足払い/
かいてんいか /回転以下/
かいてんいき /回転域/
かいてんいす /回転椅子/
かいてんうんどう /回転運動/
かいてんうんどういがい /回転運動以外/
かいてんうんどうりょう /回転運動量/
かいてんおん /回転音/
かいてんかく /回転角/
かいてんかくそくど /回転角速度/
かいてんきゅうぎょう /開店休業/
かいてんけい /回転系/回転計/
かいてんさ /回転差/
かいてんざひょうけい /回転座標系/
かいてんし /回転子/
かいてんしき /回転式/
かいてんしこう /回転指向/
かいてんじ /回転時/開店時/
かいてんじかい /回転磁界/
かいてんじく /回転軸/
かいてんじくほうこう /回転軸方向/
かいてんじしん /回転自身/
かいてんじょ /回転所/
かいてんじょうきょう /回転状況/
かいてんすう /回転数/
かいてんすういってい /回転数一定/
かいてんすうけい /回転数計/
かいてんすうせいぎょ /回転数制御/
かいてんすうへんどうりつ /回転数変動率/
かいてんすしや /回転寿司屋/
かいてんずし /回転寿司/
かいてんせいのう /回転性能/
かいてんせんい /回転遷移/
かいてんそくせつ /回転足折/
かいてんそくど /回転速度/
かいてんたい /回転体/
かいてんたいしょう /回転対称/
かいてんちゅう /回転中/
かいてんちょくご /開店直後/
かいてんていしよう /回転停止用/
かいてんていすう /回転定数/
かいてんとう /回転灯/
かいてんはんけい /回転半径/
かいてんば /回転刃/回転場/
かいてんばん /回転板/
かいてんぶぶん /回転部分/
かいてんほうこう /回転方向/
かいてんほうほう /回転方法/
かいてんまえ /開店前/
かいてんまんじゅう /回転饅頭/
かいてんめん /回転面/
かいてんもくば /回転木馬/
かいてんやき /回転焼/
かいてんようりょう /回転要領/
かいてんよく /回転翼/
かいてんりつ /回転率/
かいてんりょう /回転量/
かいてんりょく /回転力/
かいてんれいき /回転励起/
かいでん /皆伝/海田/
かいでんぱ /怪電波/
かいとう /回答/解凍/解答/快盗/会頭/怪盗/解糖/
かいとうあん /回答案/
かいとういがい /回答以外/
かいとうきかん /回答期間/
かいとうぐん /回答群/解答群/
かいとうけっか /回答結果/
かいとうけん /解答権/
かいとうご /解凍後/
かいとうしだい /回答次第/
かいとうしゃ /回答者/解答者/
かいとうしゃこじん /回答者個人/
かいとうしゃすう /回答者数/
かいとうしゃぜんいん /回答者全員/
かいとうしゃちゅう /回答者中/
かいとうしゅう /解答集/回答集/
かいとうしょ /回答書/
かいとうじ /解凍時/
かいとうすう /回答数/
かいとうせき /解答席/
かいとうちゅう /解凍中/
かいとうない /回答内/
かいとうぶん /回答文/
かいとうぶんしょちゅう /回答文書中/
かいとうほうしんあん /解答方針案/
かいとうもと /回答元/
かいとうようし /解答用紙/回答用紙/
かいとうらん /回答欄/解答欄/
かいとうらんま /快刀乱麻/
かいとうれい /解答例/回答例/
かいとくしながわいき /快特品川行/
かいとくしながわゆき /快特品川行/
かいとくていしゃ /快特停車/
かいとり /買取/買い取り/貝取/貝取り/買取り/
かいとりかかく /買取価格/
かいとりて /買取手/
かいど /開度/
かいどいってい /開度一定/
かいどう /街道/会堂/海道/皆藤/
かいどうあと /街道跡/
かいどうけいびたい /街道警備隊/
かいどき /買い時/
かいどく /解読/買得/回読/
かいどくのうりょく /解読能力/
かいどくふかのう /解読不可能/
かいどくほうほう /解読方法/
かいどくほん /解読本/
かいどくぼん /解読本/
かいどくよう /解読用/
かいな /腕/
かいなひねり /腕捻り/
かいなん /海南/海難/
かいなんきゅうじょ /海難救助/
かいなんとう /海南島/
かいにゅう /介入/
かいにゅうりゆう /介入理由/
かいにん /解任/懐妊/
かいにんじょう /解任状/
かいぬし /飼い主/買い主/
かいぬま /海沼/
かいね /買値/
かいねこ /飼猫/
かいのう /戒能/
かいは /会派/
かいはい /改廃/
かいはくしつ /灰白質/
かいはくしょく /灰白色/
かいはつ /開発/
かいはついっか /開発一課/
かいはつか /開発課/
かいはつかんきょう /開発環境/
かいはつがいしゃ /開発会社/
かいはつがわ /開発側/
かいはつき /開発機/
かいはつきかくぶ /開発企画部/
かいはつきかん /開発期間/
かいはつきぼ /開発規模/
かいはつきょうそう /開発競争/
かいはつきょか /開発許可/
かいはつきょく /開発局/
かいはつぎじゅつ /開発技術/
かいはつぎじゅつしゃ /開発技術者/
かいはつぎょうむ /開発業務/
かいはつけいかく /開発計画/
かいはつけんきゅうしつ /開発研究室/
かいはつけんきゅうじょ /開発研究所/
かいはつげんご /開発言語/
かいはつげんば /開発現場/
かいはつこうがく /開発工学/
かいはつこうがくか /開発工学科/
かいはつこうてい /開発工程/
かいはつこうりつ /開発効率/
かいはつさぎょう /開発作業/
かいはつしえん /開発支援/
かいはつしえんぶ /開発支援部/
かいはつしきん /開発資金/
かいはつしつ /開発室/
かいはつしゃ /開発者/
かいはつしゃかん /開発者間/
かいはつしゃがわ /開発者側/
かいはつしゃむきけ /開発者向け/
かいはつしゅだん /開発手段/
かいはつしゅほう /開発手法/
かいはつしょく /開発職/
かいはつじ /開発時/
かいはつじかん /開発時間/
かいはつじぎょう /開発事業/
かいはつじぎょうぶ /開発事業部/
かいはつじじょう /開発事情/
かいはつじっけんしつ /開発実験室/
かいはつじょう /開発上/
かいはつじょうきょう /開発状況/
かいはつじれいこうえん /開発事例講演/
かいはつじん /開発陣/
かいはつすいしん /開発推進/
かいはつすいしんか /開発推進課/
かいはつすいしんしつ /開発推進室/
かいはつすいしんぶ /開発推進部/
かいはつせいさく /開発製作/
かいはつぞう /開発像/
かいはつたいしょう /開発対象/
かいはつたんとうしゃ /開発担当者/
かいはつだいいちぶ /開発第一部/
かいはつだいいっか /開発第一課/
かいはつだいごぶ /開発第五部/
かいはつだいさんぶ /開発第三部/
かいはつだいろくぶ /開発第六部/
かいはつだんかい /開発段階/
かいはつち /開発値/
かいはつちゅう /開発中/
かいはつちゅうし /開発中止/
かいはつとうかつぶ /開発統括部/
かいはつとうしょ /開発当初/
かいはつとじょう /開発途上/
かいはつとじょうこく /開発途上国/
かいはつとちゅう /開発途中/
かいはつにか /開発二課/
かいはつのうりょく /開発能力/
かいはつひ /開発費/
かいはつぶ /開発部/
かいはつぶかいはつか /開発部開発課/
かいはつぶだい /開発部第/
かいはつぶちょくつう /開発部直通/
かいはつぶぶんさん /開発部分散/
かいはつぶもん /開発部門/
かいはつほう /開発法/
かいはつほうしき /開発方式/
かいはつほうほう /開発方法/
かいはつほうほうろん /開発方法論/
かいはつほんぶ /開発本部/
かいはつめん /開発面/
かいはつもくてき /開発目的/
かいはつもと /開発元/
かいはつよう /開発用/
かいはつよういん /開発要員/
かいはつよてい /開発予定/
かいはつよていひょう /開発予定表/
かいはつりょう /開発量/
かいはつりょく /開発力/
かいはら /開原/
かいはん /改版/
かいはんつうちしょ /改版通知書/
かいば /海馬/
かいばしら /貝柱/
かいばつ /海抜/皆伐/
かいばら /開原/海原/柏原/
かいばん /改版/改番/
かいばんさぎょう /改版作業/
かいひ /回避/会費/廻避/
かいひぎむ /回避義務/
かいひこうどう /回避行動/
かいひさく /回避策/
かいひせい /会費制/
かいひそくど /回避速度/
かいひちょうしゅう /会費徴収/
かいひどうさ /回避動作/
かいひなど /会費等/
かいひにゅうきん /会費入金/
かいひのうこう /回避濃厚/
かいひば /回避馬/
かいひふく /開被覆/
かいひほう /回避法/
かいひほうほう /回避方法/
かいひむりょう /会費無料/
かいひょう /開票/回表/解氷/
かいひょうけっか /開票結果/
かいひょうさぎょう /開票作業/
かいひょうじょ /開票所/
かいひょうじょうほう /開票情報/
かいひょうそくほう /開票速報/
かいひょうりつ /開票率/
かいひよう /回避用/
かいひよてい /回避予定/
かいひりょく /回避力/
かいひん /海浜/
かいひんまくはり /海浜幕張/
かいひんまくはりえき /海浜幕張駅/
かいひんまくはりほうめん /海浜幕張方面/
かいひんりょくち /海浜緑地/
かいびゃく /開闢/
かいふ /海部/回付/
かいふう /開封/
かいふうちょくご /開封直後/
かいふうつうち /開封通知/
かいふかい /快不快/
かいふく /回復/快復/恢復/開福/開腹/
かいふくかんけい /回復関係/
かいふくき /回復期/
かいふくきちょう /回復基調/
かいふくご /回復後/
かいふくざい /回復剤/
かいふくじ /回復時/
かいふくじゅもん /回復呪文/
かいふくそち /回復措置/
かいふくふのう /回復不能/
かいふくほう /回復法/
かいふくよてい /回復予定/
かいふくりつ /回復率/
かいふくりょく /回復力/
かいぶったい /怪物体/
かいぶつ /怪物/
かいぶつたち /怪物達/
かいぶん /回文/回分/
かいぶんしょ /怪文書/
かいぶんだけ /開聞岳/
かいへい /開閉/海兵/
かいへいおん /開閉音/
かいへいたい /海兵隊/
かいへん /改変/改編/拐騙/壊変/
かいへんき /改編期/
かいへんこうい /改変行為/
かいへんていあんしゃ /改編提案者/
かいへんぶぶん /改変部分/
かいべくとる /解ベクトル/
かいぺーじ /改頁/改ページ/
かいぺいじ /改頁/
かいほう /解放/開放/解法/会報/介抱/快方/快報/
かいほううんてんしつ /開放運転室/
かいほうかん /解放感/開放感/
かいほうがた /解放型/
かいほうきょうど /開放強度/
かいほうぐん /開放軍/解放軍/
かいほうけい /開放系/
かいほうげん /開放弦/解放弦/
かいほうこうざ /開放講座/
かいほうさく /開放策/
かいほうじ /開放時/
かいほうせい /開放性/
かいほうせいさく /開放政策/
かいほうせんせん /解放戦線/
かいほうだい /開放台/
かいほうち /解放値/開放値/
かいほうてき /開放的/解放的/
かいほうどうめい /解放同盟/
かいほうふきん /開放付近/
かいほうやく /介抱役/
かいほうよう /会報用/
かいほうれい /解放令/
かいぼう /解剖/海防/海膨/
かいぼうかん /海防艦/
かいぼうがく /解剖学/
かいぼうがくてき /解剖学的/
かいぼうじっしゅう /解剖実習/
かいぼうよう /解剖用/
かいま /垣間/
かいまく /開幕/
かいまくけん /開幕権/
かいまくご /開幕後/
かいまくしゅう /開幕週/
かいまくせん /開幕戦/
かいまくちょくご /開幕直後/
かいまくとうしょ /開幕当初/
かいまくまえ /開幕前/
かいみょう /戒名/
かいみん /快眠/
かいむ /皆無/会務/
かいめ /回目/
かいめい /解明/改名/晦明/晦暝/開明/
かいめいじゅう /開明獣/
かいめいほうほう /解明方法/
かいめいもんだい /改名問題/
かいめつ /壊滅/潰滅/
かいめつじょうたい /壊滅状態/
かいめつてき /壊滅的/
かいめん /界面/海綿/海面/
かいめんか /海面下/
かいめんかっせい /界面活性/
かいめんかっせいか /界面活性化/
かいめんかっせいざい /界面活性剤/
かいめんじょう /海面上/海綿状/
かいめんじょうじゅうそしき /海綿状柔組織/
かいめんじょうそしき /海綿状組織/
かいめんたい /海綿体/
かいめんは /界面波/
かいもうぶ /回盲部/
かいもく /皆目/
かいもくけんとう /皆目見当/
かいもの /買物/買い物/買いもの/
かいものちゅう /買物中/
かいものぶくろ /買物袋/
かいものゆうたいけん /買物優待券/
かいもん /開門/階紋/
かいもんせんこう /階紋穿孔/階紋せん孔/
かいもんだけ /開聞岳/
かいや /海谷/
かいやく /解約/改訳/
かいやくてすうりょう /解約手数料/
かいゆ /快癒/
かいゆう /回遊/回游/
かいゆうかん /海遊館/
かいゆうぎょ /回遊魚/
かいゆうせい /回遊性/
かいよう /潰瘍/海洋/
かいようかいはつ /海洋開発/
かいようかんきょう /海洋環境/
かいようかんそく /海洋観測/
かいようがっかい /海洋学会/
かいようきしょう /海洋気象/
かいようきしょうぶ /海洋気象部/
かいようけん /海洋研/
かいようこうえんない /海洋公園内/
かいようさいしゅう /海洋採集/
かいようじっしゅう /海洋実習/
かいようじゅんかん /海洋循環/
かいようせいぶつ /海洋生物/
かいようせいぶつがくしゃ /海洋生物学者/
かいようちけいがく /海洋地形学/
かいようちしつがく /海洋地質学/
かいようちゅう /海洋中/
かいようぶつり /海洋物理/
かいようぶつりがく /海洋物理学/
かいようみんぞく /海洋民族/
かいようりきがく /海洋力学/
かいらい /傀儡/
かいらいせいけん /傀儡政権/
かいらく /快楽/海楽/皆楽/偕楽/
かいらくえん /偕楽園/
かいらくげんそく /快楽原則/
かいらくもくてき /快楽目的/
かいらん /回覧/解纜/廻覽/潰乱/介卵/
かいらんきぼう /回覧希望/
かいらんきぼうしゃ /回覧希望者/
かいらんし /回覧誌/
かいらんしゃ /回覧者/
かいらんしゅうりょう /回覧終了/
かいらんじゅん /回覧順/
かいらんじょうきょう /回覧状況/
かいらんばん /回覧板/
かいらんぶつ /回覧物/
かいらんほうほう /回覧方法/
かいらんもと /回覧元/
かいらんよう /回覧用/
かいり /浬/乖離/海里/解離/
かいりき /怪力/
かいりきし /下位力士/
かいりきしょうじょ /怪力少女/
かいりく /海陸/
かいりつ /戒律/
かいりど /解離度/
かいりゅう /海流/
かいりゅうがく /海流学/
かいりょう /改良/
かいりょうあん /改良案/
かいりょういき /開領域/
かいりょうがた /改良型/
かいりょうせいひん /改良製品/
かいりょうてん /改良点/
かいりょうにんげん /改良人間/
かいりょうばん /改良版/
かいりょうひん /改良品/
かいりょうほう /改良法/
かいりょくらんしん /怪力乱神/
かいるい /貝類/
かいれい /海嶺/
かいれき /改暦/
かいれつ /開裂/
かいれつか /開裂果/
かいろ /回路/海路/懐炉/
かいろいじょう /回路異常/
かいろう /回廊/
かいろきじゅつ /回路記述/
かいろぎじゅつか /回路技術課/
かいろけい /回路系/
かいろけんしょう /回路検証/
かいろこうせい /回路構成/
かいろず /回路図/
かいろずせっけいしえん /回路図設計支援/
かいろせっけい /回路設計/
かいろせんよう /回路専用/
かいろちゅう /回路中/
かいろていすう /回路定数/
かいろてき /回路的/
かいろぶんかつ /回路分割/
かいろぶんかつほう /回路分割法/
かいろへんこう /回路変更/
かいろめい /回路名/
かいろもう /回路網/
かいろもうがく /回路網学/
かいろや /回路屋/
かいろろん /回路論/
かいわ /会話/海和/會話/
かいわい /界隈/
かいわがた /会話型/
かいわご /会話語/
かいわごえ /会話声/
かいわしゅう /会話集/
かいわしゅうせい /会話修正/
かいわそうさ /会話操作/
かいわたい /会話体/
かいわちゅう /会話中/
かいわてき /会話的/
かいわとう /会話等/
かいわのうりょく /会話能力/
かいわひょうげん /会話表現/
かいわぶん /会話文/
かいわほうほう /会話方法/
かいわれ /貝割/
かいわれい /会話例/
かいん /課員/下院/
かう /買う/斯う/
かうんた /カウンタ/
かうんと /カウント/
かえ /替/佳枝/華絵/替え/
かえうた /替え歌/替歌/替へ歌/
かえし /返し/
かえしうた /返歌/
かえしうま /返馬/
かえしわざ /返し技/
かえち /替え地/
かえって /却って/
かえつ /嘉悦/加越/
かえつじょし /嘉悦女子/
かえつのうてつどう /加越能鉄道/
かえで /楓/
かえでぞく /カエデ属/
かえり /帰り/返り/
かえりうち /返り討ち/
かえりぎわ /帰り際/
かえりぐるま /帰り車/
かえりざき /返り咲き/
かえりち /返り値/返値/返り血/
かえりびと /帰人/帰り人/
かえりみち /帰り道/帰り路/
かえる /蛙/
かえん /火焔/火炎/花園/
かえんこうげき /火炎攻撃/
かえんざん /火焔山/
かえんじごく /火炎地獄/
かえんびん /火炎瓶/
かお /顔/顏/貌/
かおあわせ /顔合わせ/顔合せ/
かおいろ /顔色/
かおう /花王/花押/鹿央/
かおうかぶしきがいしゃ /花王株式会社/
かおかたち /顔容/
かおく /家屋/
かおこうげき /顔攻撃/
かおじゃしん /顔写真/
かおす /カオス/
かおだし /顔出し/
かおだち /顔立ち/
かおぢゅう /顔中/
かおつき /顔付き/
かおはんぶん /顔半分/
かおぶれ /顔ぶれ/
かおみ /顔見/
かおみしり /顔見知り/
かおむけ /顔向け/
かおもじ /顔文字/
かおやく /顔役/
かおり /香織/香/佳央理/佳央里/香里/歌織/薫理/香り/
かおる /馨/薫/カオル/香/
かおるこ /薫子/
かおん /加温/
かおんばん /加温盤/
かか /嬶/窩家/仮果/
かかあ /嚊/嬶/
かかあてんか /嚊天下/
かかい /可解/下界/下階/課会/科会/
かかいせい /可解性/
かかく /価格/過客/
かかくおうだん /価格応談/
かかくかんさん /価格換算/
かかくかんざん /価格換算/
かかくきょうそう /価格競争/
かかくこうしょう /価格交渉/
かかくさ /価格差/
かかくじょうげん /価格上限/
かかくせいさく /価格政策/
かかくせいのうひ /価格性能比/
かかくせってい /価格設定/
かかくたい /価格帯/
かかくたいせきひ /価格体積比/
かかくちょうさ /価格調査/
かかくちょうさいん /価格調査員/
かかくてき /価格的/
かかくとう /価格等/
かかくとうせい /価格統制/
かかくはかい /価格破壊/
かかくはかいてき /価格破壊的/
かかくひょう /価格表/
かかくひょうじ /価格表示/
かかくみてい /価格未定/
かかくめん /価格面/
かかくらんくうらん /価格欄空欄/
かかし /案山子/
かかたいしょう /呵々大笑/
かかぢ /香々地/
かかと /踵/
かかとおとし /踵落し/
かかみがはら /各務原/
かかり /係/掛/係り/
かかりいん /係員/係り員/
かかりかん /係官/
かかりじょし /係助詞/
かかりちょう /係長/掛長/
かかりなし /係無/
かかん /日間/果敢/可換/花冠/
かかんかん /可換環/
かかんぐん /可換群/
かかんしゅうそく /可換収束/
かかんず /可換図/
かかんせい /可換性/
かかんぜん /過完全/
かかんそく /可観測/
かかんそくせい /可観測性/
かが /加賀/加我/花芽/鹿賀/
かがい /加害/課外/
かがいしゃ /加害者/
かがいしゃいしき /加害者意識/
かがいしゃがわ /加害者側/
かがいじゅぎょう /課外授業/
かがいちのみや /加賀一の宮/
かがいみつせん /花外蜜腺/
かがおんせん /加賀温泉/
かがおんせんえき /加賀温泉駅/
かがきくざけ /加賀菊酒/
かがく /科学/化学/価額/下顎/
かがくあさひ /科学朝日/
かがくえいご /科学英語/
かがくか /科学科/化学科/
かがくかい /科学会/科学界/化学会/
かがくかいかいいん /科学会会員/
かがくかいじむきょく /科学会事務局/
かがくかいせつ /科学解説/
かがくかいせつしょ /科学解説書/
かがくかいだい /科学会第/
かがくかん /科学館/化学館/科学舘/
かがくかんけい /科学関係/
かがくかんれん /科学関連/化学関連/
かがくかんれんわだい /科学関連話題/
かがくがくじゅつ /化学学術/
かがくがわ /科学側/
かがくきかい /化学機械/
かがくきこう /化学機構/
かがくきじ /科学記事/
かがくきゅうかん /化学旧館/
かがくぎじゅつ /科学技術/
かがくぎじゅつかん /科学技術館/
かがくぎじゅつけい /科学技術系/
かがくぎじゅつけいさん /科学技術計算/
かがくぎじゅつしんこうちょうせいひ /科学技術振興調整費/
かがくぎじゅつせいさく /科学技術政策/
かがくぎじゅつちょう /科学技術庁;2001年1月の中央省庁再編で文部科学省と経済産業省に再編された/
かがくぎじゅつぶ /科学技術部/
かがくぎじゅつぶんや /科学技術分野/
かがくぎろん /科学議論/
かがくけい /化学系/科学系/
かがくけいがくぶ /化学系学部/
かがくけいさん /科学計算/
かがくけいそくけんきゅうじょ /科学計測研究所/
かがくけいとう /科学系統/
かがくけいもう /科学啓蒙/
かがくけいもうしょ /科学啓蒙書/
かがくけつごう /化学結合/
かがくけんきゅう /化学研究/科学研究/
かがくけんきゅうかい /化学研究会/
かがくけんきゅうしつ /科学研究室/
かがくけんきゅうしゃ /科学研究者/
かがくけんきゅうじょ /科学研究所/
かがくけんきゅうひ /科学研究費/
かがくげんろん /科学原論/
かがくこうがく /化学工学/
かがくこうがくか /化学工学科/
かがくこうぎょう /化学工業/
かがくこうざ /科学講座/
かがくこうしょうてき /科学考証的/
かがくこうじょう /化学工場/
かがくこうぞう /化学構造/
かがくこうぞうしき /化学構造式/
かがくごうせい /化学合成/
かがくごうせいひん /化学合成品/
かがくざっし /科学雑誌/
かがくし /科学史/
かがくしか /科学史家/
かがくしき /化学式/
かがくしせつ /化学施設/
かがくしそう /科学思想/
かがくしつもんばこ /科学質問箱/
かがくしゃ /科学者/化学者/科学社/
かがくしゃじしん /科学者自身/
かがくしゃぜんたい /科学者全体/
かがくしゃたち /科学者達/
かがくしゅぎ /科学主義/
かがくしゅっぱん /科学出版/
かがくしゅほう /科学手法/
かがくしょ /科学書/
かがくしょう /科学賞/化学賞/
かがくしょうねん /科学少年/
かがくしんこうきょうかい /科学振興協会/
かがくじっけんしつ /化学実験室/
かがくじょう /科学上/
かがくじょうほう /科学情報/
かがくじょうほうだいがく /科学情報大学/
かがくせい /科学性/
かがくせいさく /科学政策/
かがくせいぶつ /化学生物/
かがくせいぶん /化学成分/
かがくせんこう /化学専攻/科学専攻/
かがくそうさ /科学捜査/
かがくだいじてん /化学大辞典/
かがくちしき /科学知識/
かがくちょうみりょう /化学調味料/
かがくていぎ /科学定義/
かがくてき /科学的/化学的/
かがくてきかいせき /科学的解析/
かがくてきがいねん /科学的概念/
かがくてききょういく /科学的教育/
かがくてきけい /化学的系/
かがくてきげんり /科学的原理/
かがくてきこうさつ /科学的考察/
かがくてきこんきょ /科学的根拠/
かがくてきごうりせい /科学的合理性/
かがくてきしこう /科学的思考/
かがくてきしゅちょう /科学的主張/
かがくてきしゅほう /科学的手法/
かがくてきじじつ /科学的事実/
かがくてきじっけん /科学的実験/
かがくてきせいしつ /化学的性質/
かがくてきそくめん /科学的側面/
かがくてきたいど /科学的態度/
かがくてきどくせい /化学的毒性/
かがくてきはっけん /科学的発見/
かがくてきはっそう /科学的発想/
かがくてきひょうか /科学的評価/
かがくてきほうそく /科学的法則/
かがくてきほうほう /科学的方法/化学的方法/
かがくてきほうほうろん /科学的方法論/
かがくてつがく /科学哲学/
かがくてつがくかい /科学哲学会/
かがくてつがっかい /科学哲学会/
かがくどくせい /化学毒性/
かがくにんじゃたい /科学忍者隊/
かがくはく /科学博/
かがくはくぶつかん /科学博物館/
かがくはんのう /化学反応/
かがくはんのうろん /化学反応論/
かがくばたけ /科学畑/
かがくばなれ /科学離れ/
かがくばんぐみ /科学番組/
かがくばんのうげんそう /科学万能幻想/
かがくばんのうしそう /科学万能思想/
かがくばんのうしゅぎ /科学万能主義/
かがくひりょう /化学肥料/
かがくひん /化学品/
かがくびんらん /化学便覧/
かがくぶ /科学部/化学部/
かがくぶっしつ /化学物質/
かがくぶつり /化学物理/
かがくぶつりてき /化学物理的/
かがくぶもん /科学部門/
かがくぶんめい /科学文明/
かがくぶんや /科学分野/
かがくへいき /化学兵器/
かがくへいこう /化学平衡/
かがくへんか /化学変化/
かがくほうそく /科学法則/
かがくほうほうろん /科学方法論/
かがくまんが /科学漫画/
かがくもの /科学物/
かがくや /化学屋/
かがくやよう /化学屋用/
かがくらん /科学欄/
かがくりょう /化学量/
かがくりょく /科学力/
かがくりろん /科学理論/
かがくろん /科学論/
かがくろんぶん /科学論文/
かがごう /加賀号/
かがじ /加賀寺/
かがじょう /加賀城/
かがたいりょうなべ /加賀大漁鍋/
かがたけし /鹿賀丈史/
かがっか /科学科/化学科/
かがっかい /科学会/
かがっかん /化学館/
かがみ /鏡/鑑/加賀見/加賀美/鑒/鏡味/香我美/各務/
かがみいし /鏡石/
かがみじごく /鏡地獄/
かがみぬま /鏡沼/
かがみの /鏡野/
かがみのくに /鏡の国/
かがみやま /鏡山/
かがや /加賀谷/加賀屋/
かがやき /輝き/
かがり /炬/
かがりび /篝火/炬火/
かがりょうり /加賀料理/
かがわ /香川/加川/嘉川/
かがわけん /香川県/
かがわけんない /香川県内/
かがわしゅっしん /香川出身/
かがわだいがく /香川大学/
かがわちょう /香川町/
かき /下記/書/柿/垣/蛎/夏期/夏季/書き/牡蛎/牡蠣/火気/花器/堵/夏記/火器/硴/蠣/
かきあげ /掻揚げ/掻上げ/掻き揚げ/かき揚げ/
かきあじ /書き味/
かきあて /下記宛/
かきいれどき /書入れ時/書き入れ時/
かきいろ /柿色/
かきうち /垣内/
かきお /柿生/
かきおうぼようし /下記応募用紙/
かきおか /柿岡/
かきおき /書き置き/書置/
かきおろし /書き下ろし/書下し/描き下ろし/
かきかえ /書き換え/書換え/書き替え/書換/
かきかえかた /書き換え方/
かきかえきそく /書き換え規則/
かきかえけい /書き換え系/
かきかえけっか /書き換え結果/
かきかた /書き方/
かきからちょう /蛎殻町/
かききゅうか /夏期休暇/夏季休暇/
かききゅうぎょう /夏季休業/
かききゅうぎょうちゅう /夏期休業中/夏季休業中/
かきぎ /柿木/
かきぎんこうこうざ /下記銀行口座/
かきげんきん /火気厳禁/
かきことば /書き言葉/
かきこみ /書きこみ/書き込み/書込/
かきこみじ /書き込み時/
かきこむ /書き込む/
かきごう /夏季号/
かきごおり /かき氷/
かきざき /柿崎/
かきした /柿下/
かきしょうかいさき /下記照会先/
かきじゅん /書き順/
かきぞめ /書初め/書き初め/
かきた /柿田/
かきたかわ /柿田川/
かきたがわ /柿田川/
かきたに /垣谷/柿谷/
かきだがわ /柿田川/
かきだし /書き出し/
かきちょう /蠣殻町/
かきつけ /書付け/
かきて /書き手/描き手/
かきとめ /書留/
かきとり /書取/
かきなおし /書き直し/
かきなべ /蛎鍋/
かきなみ /柿並/
かきにってい /下記日程/
かきぬま /柿沼/
かきね /垣根/墻/牆/
かきの /柿野/垣野/
かきのうち /垣野内/
かきのき /柿木/
かきのきもく /Elanales/カキノキ目/
かきのもとひとまろ /柿本人麻呂/
かきはちねん /柿八年/
かきはら /垣原/柿原/
かきはん /書判/花押/
かきぶっけん /下記物件/
かきもうしこみさき /下記申込先/
かきもく /カキ目/Ebenales/
かきもと /柿本/
かきもの /書き物/
かきやすさ /書き易さ/
かきゅう /下級/可及/過給/下丘/火急/加給/火球/苛求/
かきゅうかいいん /下級会員/
かきゅうき /過給機/過給器/
かきゅうきぞく /下級貴族/
かきゅうさいばんしょ /下級裁判所/
かきゅうせい /下級生/
かきゅうてき /可及的/
かきょ /科挙/火炬/
かきょう /佳境/家教/架橋/華僑/
かきょういん /花京院/
かきょく /佳曲/歌曲/
かきょくしゅう /歌曲集/
かきようし /下記用紙/
かきようりょう /下記要領/
かきれんらくさき /下記連絡先/
かきわき /垣脇/
かきわけ /書き分け/
かきん /課金/瑕瑾/家禽/
かきんしょり /課金処理/
かきんじょうほう /課金情報/
かきんせい /課金制/
かきんたいけい /課金体系/
かきんど /火金土/
かぎ /鍵/鈎/』/『/「/」/カギ/「」/『』/鉤/
かぎあな /鍵穴/
かぎかっこ /『/】/【/「/」/』/
かぎかっことじ /』/
かぎざき /鉤裂き/
かぎじたい /鍵自体/
かぎたんだい /科技短大/
かぎだい /東京都立科学技術大学/科技大/
かぎちょう /科技庁;2001年1月の中央省庁再編で文部科学省に再編された/科学技術庁;2001年1月の中央省庁再編で文部科学省に再編された/
かぎづめ /鈎爪/鉤爪/
かぎの /鍵野/
かぎばり /鉤針/
かぎほっく /鉤ホック/
かぎもと /鍵本/
かぎもとけいこ /鍵本景子/
かぎゃく /可逆/加虐/
かぎゃくあっしゅく /可逆圧縮/
かぎゃくせい /可逆性/
かぎゃくてき /可逆的/
かぎゅう /蝸牛/
かぎょう /稼業/下行/家業/課業/カ行/
かぎり /限/限り/
かく /各/格/確/覚/革/隔/核/獲/角/廓/較/客/閣/殻/郭/穫/赫/画/嚇/撹/劃/拡/賀来/斯く/掴/鶴/喀/咯/埆/壑/寉/幗/恪/愨/挌/攪/擱/擴/攫/椁/槨/殼/狢/畫/癨/矍/膈/膕/茖/蠖/覈/覺/貉/霍/馘/骼/∠/恁く/加来/
かく< /各/
かく> /各/
かくあげ /格上げ/
かくい /各位/角井/
かくいいん /各委員/
かくいえ /各家/
かくいがく /核医学/
かくいち /各位置/
かくいちだい /各一台/
かくいつ /画一/劃一/
かくいつか /画一化/
かくいつせい /画一性/
かくいつてき /画一的/
かくいでんし /各遺伝子/
かくいりぐち /各入口/
かくいん /各員/客員/
かくう /架空/
かくうえ /格上/
かくうんどう /角運動/
かくうんどうりょう /角運動量/
かくうんどうりょうほぞん /角運動量保存/
かくえい /角栄/角榮/
かくえいががいしゃ /各映画会社/
かくえいぎょうしょ /各営業所/
かくえき /各駅/
かくえきかんそうご /各駅間相互/
かくえきそうご /各駅相互/
かくえきていしゃ /各駅停車/隔駅停車/
かくえきていしゃろせん /各駅停車路線/
かくえきふきん /各駅付近/
かくえんそうか /各演奏家/
かくおうざん /覚王山/
かくおち /角落/
かくおん /各音/核音/
かくおんいん /各音韻/
かくおんせつ /各音節/
かくおんていごと /各音程毎/
かくか /各課/核果/角化/格下/
かくかい /各回/各階/各界/
かくかいいん /各会員/
かくかいきゅう /各階級/
かくかいせつ /各解説/
かくかいそう /各階層/
かくかいだん /各階段/
かくかいひょうじょ /各開票所/
かくかく /各々/赫赫/赫々/
かくかくさん /核拡散/
かくかそくど /角加速度/
かくかぞく /核家族/
かくかぞくか /核家族化/
かくかぞくしゃかい /核家族社会/
かくかてい /各家庭/
かくかでん /各家電/
かくかん /各間/各艦/各巻/
かくかんくほんぶ /各管区本部/
かくかんごと /各巻毎/
かくかんすう /各関数/
かくかんりしゃ /各管理者/
かくかんりにん /各管理人/
かくがい /格外/核外/
かくがくねん /各学年/
かくがくぶ /各学部/
かくがた /角型/
かくがっか /各学科/
かくがっかい /各学会/
かくがめん /各画面/
かくがり /角刈り/角刈/
かくがわ /角川/
かくがん /各眼/
かくき /各期/各機/
かくきー /各キー/
かくきかん /各機関/各期間/
かくきき /各機器/
かくきぎょう /各企業/
かくきごう /各記号/
かくきしゅ /各機種/各騎手/
かくきしゅきょうつう /各機種共通/
かくきしゅべつ /各機種別/
かくきじ /各記事/
かくきそく /各規則/
かくきたい /各機体/
かくきち /各基地/
かくきのう /各機能/
かくきゃくしつ /各客室/
かくきゅうじょう /各球場/
かくきゅうだん /各球団/
かくきょうか /各教科/
かくきょうし /各教師/
かくきょうじゅ /各教授/
かくきょく /各曲/
かくきょくせん /各曲線/
かくぎ /閣議/
かくぎょう /各行/角行/
かくぎょうかい /各業界/
かくぎょうごと /各行毎/
かくぎょうまつ /各行末/
かくぎんこう /各銀行/
かくく /各区/
かくくかん /各区間/
かくぐう /角隅/
かくぐうこうかくそしき /角隅厚角組織/
かくぐるーぷ /各グループ/
かくけい /角形/
かくけいさん /核計算/
かくけいしき /各形式/
かくけいすう /各係数/
かくけいとうべつ /各系統別/
かくけん /核研/各県/
かくけんきゅうきかん /各研究機関/
かくけんきゅうしつ /各研究室/
かくげき /核撃/
かくげっかん /隔月刊/
かくげっかんか /隔月刊化/
かくげつ /隔月/
かくげつかん /隔月刊/
かくげつはっこう /隔月発行/
かくげん /格言/確言/
かくげんご /各言語/
かくこ /確固/加久子/
かくこう /各項/各校/
かくこうかん /角交換/
かくこうくうがいしゃ /各航空会社/
かくこうざ /各講座/
かくこうせいいん /各構成員/
かくこうせいてん /各構成点/
かくこうぞう /核構造/
かくこうつうきかん /各交通機関/
かくこうほ /各候補/
かくこうほしゃ /各候補者/
かくこうもく /各項目/
かくこうりてん /各小売店/
かくこきゃく /各顧客/
かくこく /各国/
かくこくご /各国語/
かくこくごか /各国語化/
かくこじん /各個人/
かくこたい /各個体/
かくこゆう /各個有/
かくご /覚悟/各語/
かくごう /各号/
かくごうしゃ /各号車/
かくごび /格語尾/
かくさ /隔差/格差/
かくさいぼう /各細胞/
かくさく /画策/
かくさくひん /各作品/
かくさげ /格下げ/
かくさもんだい /格差問題/
かくさん /拡散/核酸/
かくさんおんじょう /拡散音場/
かくさんかしゃ /各参加者/
かくさんがた /拡散型/
かくさんけいすう /拡散係数/
かくさんはんしゃ /拡散反射/
かくさんぶんし /核酸分子/
かくさんめん /拡散面/
かくざ /擱坐/擱座/
かくざい /角材/
かくざせき /各座席/
かくざっし /各雑誌/
かくざとう /角砂糖/
かくし /各氏/各市/各紙/各誌/客死/核子/隠し/
かくしあい /各試合/
かくしあじ /隠し味/
かくしえいちかてつ /各市営地下鉄/
かくしき /格式/
かくしけんじょうけん /各試験条件/
かくしげい /隠し芸/
かくしごと /隠し事/
かくしせつ /核施設/各施設/
かくした /格下/
かくしだま /隠し玉/
かくしつ /各室/確執/角質/革質/
かくして /斯くして/
かくしとりで /隠し砦/
かくしどり /隠し撮り/
かくしぬの /隠し布/
かくしゃ /各社/各車/覚者/
かくしゃいん /各社員/
かくしゃかくよう /各社各様/
かくしゃかん /各者間/各社間/
かくしゃく /矍鑠/
かくしゃどくじ /各社独自/
かくしゃほ /各社保/
かくしゃりょう /各車両/
かくしゃりょうばんごう /各車両番号/
かくしゃりん /各車輪/
かくしやくしょ /各市役所/
かくしゅ /各種/馘首/鶴首/核種/
かくしゅいいんかい /各種委員会/
かくしゅう /隔週/各週/
かくしゅうかん /隔週刊/
かくしゅうはすう /角周波数/各周波数/
かくしゅうはすうせいぶん /各周波数成分/
かくしゅうほう /隔週報/
かくしゅおんがく /各種音楽/
かくしゅかいはつかんきょう /各種開発環境/
かくしゅかがく /各種科学/
かくしゅかつどう /各種活動/
かくしゅがぞう /各種画像/
かくしゅがぞうえんざん /各種画像演算/
かくしゅがっこう /各種学校/
かくしゅきき /各種機器/
かくしゅく /拡縮/
かくしゅけんきゅうよう /各種研究用/
かくしゅけんりじょうこう /各種権利条項/
かくしゅこうじょ /各種控除/
かくしゅさぎょう /各種作業/
かくしゅさんぎょう /各種産業/
かくしゅしせつ /各種施設/
かくしゅしゅうきょうだんたい /各種宗教団体/
かくしゅしゅっぱんぶつ /各種出版物/
かくしゅしょせき /各種書籍/
かくしゅじむ /各種事務/
かくしゅじょうちゅう /各種常駐/
かくしゅじょうほう /各種情報/
かくしゅじょうやく /各種条約/
かくしゅせいやく /各種制約/
かくしゅたよう /各種多様/
かくしゅちょうせい /各種調整/
かくしゅっぱんしゃ /各出版社/
かくしゅとどけでひよう /各種届出費用/
かくしゅにほんご /各種日本語/
かくしゅぶんけん /各種文献/
かくしゅほう /各手法/
かくしゅほうりつ /各種法律/
かくしゅぼば /名種牡馬/
かくしゅめいし /各種名詞/
かくしゅるい /各種類/
かくしょ /各所/各署/角所/
かくしょう /確証/各章/各賞/各省/
かくしょうじょう /各症状/
かくしょうちょう /各省庁/
かくしょうめいしょ /各証明書/
かくしょく /各色/
かくしょくいき /各職域/
かくしょぞくがくぶ /各所属学部/
かくしょてん /各書店/
かくしょり /各処理/
かくしよう /各仕様/
かくしん /確信/革新/核心/確診/
かくしんかてい /革新過程/
かくしんかんせん /各新幹線/
かくしんけい /革新系/
かくしんせい /革新性/
かくしんせいりょく /革新勢力/
かくしんてき /革新的/
かくしんど /確信度/
かくしんどうすう /角振動数/
かくしんはん /確信犯/
かくしんはんてき /確信犯的/
かくしんぶんしゃ /各新聞社/
かくじ /各自/覚治/
かくじかん /各時間/
かくじき /各時期/
かくじぎょうしょ /各事業所/
かくじく /各軸/
かくじけん /各事件/
かくじこく /各時刻/
かくじしよう /各自使用/
かくじすう /各次数/
かくじちたい /各自治体/
かくじっけん /核実験/
かくじつ /確実/隔日/
かくじついか /各自追加/
かくじつし /確実視/
かくじつせい /確実性/
かくじどうしゃどう /各自動車道/
かくじふたん /各自負担/
かくじゅいん /鶴寿院/
かくじゅう /拡充/
かくじゅんびいいん /各準備委員/
かくじょうけん /各条件/
かくじょうほう /各情報/
かくじょし /格助詞/
かくじん /各人/核仁/
かくじんかく /各人格/
かくじんこゆう /各人固有/
かくじんちゅうい /各人注意/
かくすい /角錐/
かくすう /画数/
かくすうしき /各数式/
かくすうじ /各数字/
かくすうじゅん /画数順/
かくすうにゅうりょく /画数入力/
かくず /各図/
かくせい /覚醒/隔世/郭清/拡声/
かくせいき /拡声器/
かくせいけい /拡声系/
かくせいざい /覚醒剤/
かくせいざいおせん /覚醒剤汚染/
かくせいじ /覚醒時/
かくせいじょうたい /覚醒状態/
かくせいそうち /拡声装置/
かくせいひん /各製品/
かくせいひんごと /各製品毎/
かくせいぶん /各成分/
かくせいぶんごと /各成分毎/
かくせいよう /拡声用/
かくせいりとく /拡声利得/
かくせきにんしゃ /各責任者/
かくせだい /各世代/
かくせってん /各節点/
かくせつ /各節/
かくせつもん /各設問/
かくせん /各線/
かくせんきょく /各選挙区/
かくせんこう /各専攻/
かくせんざい /各洗剤/
かくせんしつ /各船室/
かくせんしゅ /各選手/
かくせんそう /核戦争/
かくせんとう /角先頭/
かくせんもんぶんや /各専門分野/
かくぜつ /隔絶/
かくぜん /画然/
かくそう /各層/
かくそうさ /各操作/
かくそうち /各装置/
かくそくど /角速度/
かくそし /各素子/
かくそしき /各組織/
かくそしきない /各組織内/
かくぞう /覚三/
かくぞうふくだん /各増幅段/
かくた /角田/
かくたい /各隊/
かくたいいき /各帯域/
かくたいかい /各大会/
かくたししょ /角田支所/
かくたに /角谷/
かくたん /喀痰/
かくたんけんさ /喀痰検査/
かくたんげん /各単元/
かくたんご /各単語/
かくたんとうしゃ /各担当者/
かくたんまつ /各端末/
かくだ /角田/
かくだい /拡大/
かくだいうんよう /拡大運用/
かくだいかいしゃく /拡大解釈/
かくだいがく /各大学/
かくだいがめん /拡大画面/
かくだいきょう /拡大鏡/
かくだいけいこう /拡大傾向/
かくだいさいせいさん /拡大再生産/
かくだいさつえい /拡大撮影/
かくだいしゃしん /拡大写真/
かくだいしゅぎ /拡大主義/
かくだいしゅくしょう /拡大縮小/
かくだいず /拡大図/
かくだいせいさん /拡大生産/
かくだいばん /拡大版/
かくだいひょうじ /拡大表示/
かくだいもじ /拡大文字/
かくだいりつ /拡大率/
かくだん /格段/各段/
かくだんい /各段位/
かくだんかい /各段階/
かくだんたい /各団体/
かくだんとう /核弾頭/
かくだんらく /各段落/
かくち /各地/隔地/
かくちいき /各地域/
かくちおみやげ /各地御土産/
かくちく /各地区/
かくちくだいひょう /各地区代表/
かくちじ /各知事/
かくちぶんり /廓地分利/
かくちほう /各地方/
かくちゅう /角柱/
かくちょう /拡張/格調/各町/
かくちょうあん /拡張案/
かくちょういき /拡張域/
かくちょうか /拡張可/
かくちょうかのう /拡張可能/
かくちょうがいねん /拡張概念/
かくちょうきき /拡張機器/
かくちょうきのう /拡張機能/
かくちょうくかく /拡張区画/
かくちょうくかん /拡張区間/
かくちょうけい /拡張形/
かくちょうこうじ /拡張工事/
かくちょうし /拡張子/
かくちょうしゅう /拡張集/
かくちょうしゅぎ /拡張主義/
かくちょうしよう /拡張使用/
かくちょうじじょうへいきんごさ /拡張二乗平均誤差/
かくちょうせい /拡張性/
かくちょうせいぎょ /拡張制御/
かくちょうてん /各頂点/
かくちょうてんざひょう /各頂点座標/
かくちょうばん /拡張版/
かくちょうぶぶん /拡張部分/
かくちょうほう /拡張法/
かくちょうもじ /拡張文字/
かくちょうよう /拡張用/
かくつう /格通/
かくつき /隔月/各月/
かくつけ /格付/
かくづけ /格付け/
かくてあて /各手当/
かくてい /確定/各停/
かくていい /各定位/
かくていおだわらいき /各停小田原行/
かくていおだわらゆき /各停小田原行/
かくていご /確定後/
かくていしゅうりょう /確定終了/
かくていしんこく /確定申告/
かくていしんこくしょ /確定申告書/
かくていじ /確定時/
かくていじき /確定時期/
かくていずみ /確定済/
かくていせい /確定性/
かくていせつ /確定節/
かくていちゅうもんそうすう /確定注文総数/
かくていてき /確定的/
かくていにゅうりょく /確定入力/
かくていばん /確定版/
かくていまえ /確定前/
かくていめい /確定名/
かくていりつ /確定率/
かくていわくじゅん /確定枠順/
かくていわくばん /確定枠番/
かくてつどう /各鉄道/
かくてん /各点/各店/
かくてんきょうつう /各店共通/
かくてんぽ /各店舗/
かくでーた /核データ/
かくでん /各伝/
かくでんききょうめい /核電気共鳴/
かくでんしゃく /各電車区/
かくでんてつがいしゃ /各電鉄会社/
かくとう /格闘/各党/確答/各棟/挌闘/
かくとうか /格闘家/
かくとうかたち /格闘家達/
かくとうぎ /格闘技/
かくとうぎしょく /格闘技色/
かくとうぎたんけんたい /格闘技探検隊/
かくとうぎだんたい /格闘技団体/
かくとうじゅつ /格闘術/
かくとうせん /格闘戦/
かくとうちゅう /格闘中/
かくとうひょうしゃ /各投票者/
かくとうもの /格闘物/
かくとか /殻斗果/
かくとく /獲得/
かくとくかのう /獲得可能/
かくとくけい /獲得形/
かくとくけいしつ /獲得形質/
かくとくしえん /獲得支援/
かくとくしゃ /獲得者/
かくとくしょうきん /獲得賞金/
かくとくしょうきんがく /獲得賞金額/
かくとくすう /獲得数/
かくとくせいこう /獲得成功/
かくとくぶつ /獲得物/
かくとくりつ /獲得率/
かくとし /各都市/
かくとしかん /各都市間/
かくとどうふけん /各都道府県/
かくとりしまりやく /各取締役/
かくど /角度/確度/
かくどうきしんごう /各同期信号/
かくどうさ /各動作/
かくどうりん /各動輪/
かくどけんしゅつ /角度検出/
かくどちょうせい /角度調整/
かくない /閣内/核内/
かくに /角煮/
かくにゅうりょく /各入力/
かくにん /確認/
かくにんきかん /確認期間/
かくにんきかんちゅう /確認期間中/
かくにんこうもく /確認項目/
かくにんご /確認後/
かくにんさぎょう /確認作業/
かくにんしょ /確認書/
かくにんしょり /確認処理/
かくにんじ /確認時/
かくにんじっけん /確認実験/
かくにんずみ /確認済/
かくにんせいぎょ /確認制御/
かくにんせいぎょぶ /確認制御部/
かくにんたんまつ /確認端末/
かくにんたんまつぶ /確認端末部/
かくにんだんたい /確認団体/
かくにんていど /確認程度/
かくにんでんわ /確認電話/
かくにんぶそく /確認不足/
かくにんよう /確認用/
かくねん /隔年/各年/核燃/
かくねんだい /各年代/
かくねんりょう /核燃量/核燃料/
かくねんりょうさいくる /核燃料サイクル/
かくねんりょうちゅう /核燃料中/
かくねんりょうゆそう /核燃料輸送/
かくねんれい /各年齢/
かくの /角野/
かくのーど /各ノード/
かくのう /格納/
かくのういき /格納域/
かくのうけいしき /格納形式/
かくのうけいしきじたい /格納形式自体/
かくのうこ /格納庫/
かくのうど /各濃度/
かくのうばん /格納版/
かくのうほう /格納法/
かくのうりょく /核能力/
かくのだて /角館/
かくは /各派/
かくはいきぶつ /核廃棄物/
かくはく /攫搏/
かくはさい /核破砕/
かくはん /各班/各般/各版/撹拌/拡販/攪拌/
かくはんのう /核反応/
かくはんばいてん /各販売店/
かくば /各馬/
かくばくだん /核爆弾/
かくばくはつ /核爆発/
かくばしょ /各場所/
かくばん /各晩/
かくひけんじゃ /各被験者/
かくひつ /擱筆/
かくひょう /各表/
かくひょうしき /格標識/
かくひんし /各品詞/
かくふ /角歩/
かくふうとう /角封筒/
かくふく /拡幅/
かくふくこうじ /拡幅工事/
かくぶ /各部/
かくぶい /各部位/
かくぶきょく /各部局/
かくぶしょ /各部署/
かくぶたい /各部隊/
かくぶっしつ /核物質/
かくぶつり /核物理/
かくぶつりがく /核物理学/
かくぶつりけんきゅう /核物理研究/
かくぶひん /各部品/
かくぶぶん /各部分/
かくぶもん /各部門/
かくぶん /各文/
かくぶんかかい /各分科会/
かくぶんさつ /各分冊/
かくぶんたい /各分隊/
かくぶんたいちょう /各分隊長/
かくぶんぽう /格文法/
かくぶんや /各分野/
かくぶんやいいん /各分野委員/
かくぶんやごと /各分野毎/
かくぶんやじょうい /各分野上位/
かくぶんれつ /核分裂/
かくぶんれつしゅうりつ /核分裂収率/
かくぶんれつせい /核分裂性/
かくぶんれつせいせいぶつ /核分裂生成物/
かくぶんれつだんめんせき /核分裂断面積/
かくぶんれつはんのう /核分裂反応/
かくへいき /核兵器/
かくへいきさんぎょう /核兵器産業/
かくへき /隔壁/
かくへや /各部屋/
かくへん /各辺/
かくへんか /格変化/
かくへんすう /各変数/
かくへんせい /各編成/
かくべえじし /角兵衛獅子/
かくべつ /格別/各別/
かくほ /確保/
かくほう /確報/
かくほうこう /各方向/
かくほうしき /各方式/
かくほうめん /各方面/
かくほこんなん /確保困難/
かくほずみ /確保済/
かくぼいん /各母音/
かくま /角間/
かくまく /角膜/隔膜/
かくまくいしょく /角膜移植/
かくまくえん /角膜炎/
かくまくせんこう /角膜穿孔/
かくまくないひふぜん /角膜内皮不全/
かくまくはくり /角膜剥離/
かくまち /各街/
かくまる /核マル/角丸/革マル/
かくみんぞく /各民族/
かくむ /各務/
かくめ /各目/
かくめい /革命/
かくめいか /革命家/
かくめいご /革命後/
かくめいじ /革命児/
かくめいせい /革命性/
かくめいせんそう /革命戦争/
かくめいちゅう /革命中/
かくめいてき /革命的/
かくめいまえ /革命前/
かくめいれい /各命令/
かくめいろん /革命論/
かくめん /各面/
かくめんきょじどうしゃ /各免許自動車/
かくもじ /各文字/
かくもじしゅうごう /各文字集合/
かくもじれつ /各文字列/
かくやく /確約/核薬/
かくやくしょ /各役所/
かくやくぶん /確約文/
かくやす /格安/
かくやすけん /格安券/
かくやすこうくうけん /格安航空券/
かくやすてん /格安店/
かくゆうごう /核融合/
かくゆうごうけん /核融合研/
かくゆうごうけんきゅう /核融合研究/
かくゆうごうけんきゅうじょ /核融合研究所/
かくゆうごうろ /核融合炉/
かくよう /各様/
かくようそ /各要素/
かくよくし /核抑止/
かくら /加倉/
かくらい /加倉井/
かくらん /各欄/撹乱/攪乱/霍乱/
かくり /隔離/核理/郭李/
かくりきし /各力士/
かくりけん /核理研/
かくりしいく /隔離飼育/
かくりっこうほしゃ /各立候補者/
かくりつ /確立/確率/格律/
かくりつかいしゃく /確率解釈/
かくりつかてい /確率過程/
かくりつがくしゅう /確率学習/
かくりつぎょうれつ /確率行列/
かくりつじしょう /確率事象/
かくりつすいていかてい /確率推定過程/
かくりつせいぎょ /確率制御/
かくりつだい /確率大/
かくりつてき /確率的/
かくりつてきせいちょうほう /確率的成長法/
かくりつとうけい /確率統計/
かくりつとうけいがく /確率統計学/
かくりつぶんぷ /確率分布/
かくりつぶんぷかんすう /確率分布関数/
かくりつぶんぷきょくせん /確率分布曲線/
かくりつぶんぽう /確率文法/
かくりつへんすう /確率変数/
かくりつへんどう /確率変動/確立変動/
かくりつへんどうき /確率変動期/確率変動機/
かくりつへんどうちゅう /確率変動中/
かくりつみつど /確率密度/
かくりつみつどぶんぷ /確率密度分布/
かくりつもでる /確率モデル/
かくりつろん /確率論/
かくりつろんてき /確率論的/
かくりょう /閣僚/
かくりょういき /各領域/
かくりょく /核力/
かくりようしゃ /各利用者/
かくれ /隠れ/
かくれいわ /礁/
かくれが /隠れ家/
かくれそう /隠れ層/
かくれっしゃ /各列車/
かくれつ /各列/
かくれんけつせい /各連結性/
かくろせん /各路線/
かくろん /各論/
かくわ /各話/
かくわしゃ /各話者/
かくん /家訓/
かぐ /家具/
かぐちょう /家具調/
かぐや /家具屋/
かぐやひめ /かぐや姫/輝夜姫/
かぐら /神楽/
かぐらざか /神楽坂/
かぐん /加群/下郡/
かけ /掛/賭/賭け/×/
かけあし /駆け足/
かけい /家系/筧/家計/火刑/花形/
かけいかんり /家計管理/
かけいず /家系図/
かけいひ /家計費/
かけいぼ /家計簿/
かけいぼこうかい /家計簿公開/
かけいぼよう /家計簿用/
かけうり /掛売/
かけおち /駆け落ち/駆落/
かけかえ /掛替え/
かけかわしがい /掛川市街/
かけがえ /掛け替え/掛替/
かけがね /掛け金/
かけがわ /掛川/
かけがわいせい /掛川以西/
かけがわえき /掛川駅/
かけがわしえいきゅうじょう /掛川市営球場/
かけきん /掛金/掛け金/賭金/
かけごえ /かけ声/掛け声/掛聲/
かけごと /賭事/賭け事/
かけざん /かけ算/掛け算/
かけした /掛下/
かけしょうぎ /賭将棋/
かけじく /掛軸/掛け軸/
かけず /掛図/掛け図/
かけぞり /掛け反り/
かけつ /可決/可欠/
かけつかばし /掛塚橋/
かけつご /可決後/
かけつじょうけん /可決条件/
かけなげ /掛け投げ/
かけはし /架け橋/懸け橋/棧/
かけはた /欠畑/欠端/
かけひ /筧/
かけひき /駆け引き/駆引き/
かけふ /掛布/
かけぶとん /掛布団/
かけまーじゃん /賭麻雀/
かけまま /欠真間/
かけもち /掛持ち/
かけや /掛合/
かけら /破片/
かけりつ /賭け率/掛率/
かける /×/＊/
かけん /科研/科学計測研究所/化研/家憲/
かけんかがく /科研科学/
かけんせいやく /科研製薬/
かけんひ /科研費/科学研究費/
かげ /陰/影/景/蔭/鹿毛/翳/
かげうら /影浦/
かげえ /影絵/
かげかつ /景勝/
かげき /過激/歌劇/
かげききょう /蔭桔梗/
かげきじょう /歌劇場/
かげきは /過激派/
かげぐち /陰口/蔭口/
かげさわ /影沢/
かげぜん /陰膳/
かげつ /ヶ月/箇月/花月/荷月/ケ月/カ月/か月/ヵ月/
かげつえん /花月園/
かげひこ /景彦/
かげぼうし /影法師/
かげぼし /陰干し/
かげまる /影丸/
かげむしゃ /影武者/
かげもと /影本/
かげやま /蔭山/影山/陰山/景山/
かげやまこうえん /景山公園/
かげろう /陽炎/蜉蝣/蜻蛉/
かげん /加減/下限/下弦/⊃/仮言/
かげんさん /加減算/
かげんさんき /加減算器/
かげんざん /加減算/
かげんじょうじょ /加減乗除/
かげんそく /加減速/
かげんそくじ /加減速時/
かげんそくじょうたい /加減速状態/
かげんち /下限値/
かげんほう /加減法/
かげんめいほう /仮言命法/
かこ /過去/加古/苛湖/
かこい /十六/
かこう /加工/河口/下降/火口/化工/河港/
かこういき /河口域/
かこうおんけい /下降音形/
かこうかいはつ /加工開発/
かこうかいはつぶ /加工開発部/
かこうがた /下降型/
かこうがん /花崗岩/
かこうき /下降期/
かこうぎじゅつ /加工技術/
かこうけいれつ /下降系列/
かこうげん /火口原/
かこうこ /河口湖/
かこうこしゅうへん /河口湖周辺/
かこうこほうめん /河口湖方面/
かこうし /加工紙/
かこうせい /加工性/
かこうせいど /加工精度/
かこうせき /河口堰/
かこうせん /下降線/
かこうぜき /河口堰/
かこうちゅう /加工中/
かこうちん /加工賃/
かこうづけ /加工付/
かこうなべ /加工鍋/
かこうにく /加工肉/
かこうはんおんかい /下降半音階/
かこうひん /加工品/
かこうへん /下降辺/
かこがた /過去型/
かこがわ /加古川/
かこがわし /加古川市/
かこがわしみん /加古川市民/
かこがわせん /加古川線/
かこきじ /過去記事/
かこく /苛酷/ヶ国/過酷/苛刻/カ国/
かこくな /過酷な/
かこけい /過去形/
かこさいてい /過去最低/
かこすうねん /過去数年/
かこすうねんかん /過去数年間/
かこそこう /過去遡航/
かこなんど /過去何度/
かこはんとしかん /過去半年間/
かこぶんし /過去分詞/
かこもん /過去問/
かこん /過恨/禍根/
かご /篭/籠/過誤/加護/花後/駕籠/
かごう /化合/
かごうぶつ /化合物/
かごさか /籠坂/
かごしま /鹿児島/
かごしまかん /鹿児島間/
かごしまくうこう /鹿児島空港/
かごしまけん /鹿児島県/
かごしまこう /鹿児島港/
かごしまご /鹿児島語/
かごしまし /鹿児島市/
かごしましがい /鹿児島市街/
かごしましでん /鹿児島市電/
かごしましゅっしん /鹿児島出身/
かごしましょうこう /鹿児島商工/
かごしまじつぎょう /鹿児島実業/
かごしまじん /鹿児島人/
かごしません /鹿児島線/
かごしまだいがく /鹿児島大学/
かごしまべん /鹿児島弁/
かごしまほうそう /鹿児島放送/
かごしまほうめん /鹿児島方面/
かごしまほんせん /鹿児島本線/
かごしまゆき /鹿児島行/
かごしまわん /鹿児島湾/
かごせ /篭瀬/籠瀬/
かごたに /籠谷/篭谷/
かごはら /篭原/
かごん /過言/
かさ /傘/笠/加佐/嵩/疽/瘡/暈/
かさい /火災/笠井/家裁/葛西/加西/河西/家栽/
かさいえき /葛西駅/
かさいかいじょうほけん /火災海上保険/
かさいきょうさい /火災共済/
かさいしゃりょう /火災車両/
かさいしゃりょうすう /火災車両数/
かさいじこぼうし /火災事故防止/
かさいちょうさかん /家裁調査官/
かさいほうちき /火災報知器/
かさいほうめん /葛西方面/
かさいほけん /火災保険/
かさいよぼう /火災予防/
かさいりゅう /火砕流/
かさおか /笠岡/
かさかけ /笠懸/
かさぎ /笠置/
かさく /佳作/家作/寡作/企策/
かさくら /笠倉/
かさくらしゅっぱん /笠倉出版/
かささ /笠沙/
かささぎ /鵲/
かさした /傘下/
かさしただんたい /傘下団体/
かさしま /笠島/
かさじぞう /笠地蔵/
かさじま /笠島/
かさじょう /傘状/
かさたて /傘立/
かさだか /嵩高/
かさだかひん /嵩高品/
かさつ /苛察/
かさでら /笠寺/
かさど /笠戸/
かさなり /重なり/
かさね /重ね/
かさねあわせ /重ね合わせ/
かさねうち /重ね打ち/
かさねがき /重ね描き/
かさねぎ /重ね着/
かさねどり /重ね録り/
かさはら /笠原/
かさぶくろ /傘袋/
かさま /笠間/
かさまつ /笠松/
かさまつけいばじょう /笠松競馬場/
かさみ /嵩/
かさり /笠利/
かさん /加算/可算/
かさんうんちん /加算運賃/
かさんか /過酸化/
かさんかいすう /加算回数/
かさんかいだん /可算階段/
かさんかいろ /加算回路/
かさんかすいそ /過酸化水素/
かさんかすいそすい /過酸化水素水/
かさんき /加算機/加算器/
かさんこ /可算個/
かさんごうせい /加算合成/
かさんしゅうごう /可算集合/
かさんせい /加算性/
かさんせんたくこうり /可算選択公理/
かさんそうさ /加算操作/
かさんへいきん /加算平均/
かさんほうしき /加算方式/
かさんほうそく /加算法則/
かさんむげん /加算無限/
かさんむげんこ /可算無限個/
かさんめいれい /加算命令/
かざ /風/
かざい /家財/夏材/
かざいどうぐ /家財道具/
かざかみ /風上/
かざきり /風切り/
かざぐるま /風車/
かざごえ /風邪声/
かざしも /風下/
かざしもがわ /風下側/
かざばな /風花/
かざま /風間/
かざまち /風街/
かざまつり /風祭/
かざみ /風見/
かざみどり /風見鶏/
かざむき /風向き/風向/
かざりまど /飾り窓/飾窓/
かざるすほーる /カザルスホール/
かざわ /鹿沢/
かざん /火山/加算/華山/
かざんかつどう /火山活動/
かざんたい /火山体/
かざんだん /火山弾/
かざんばい /火山灰/
かざんみゃく /火山脈/
かざんむげん /可算無限/
かし /歌詞/菓子/橿/可視/樫/貸し/仮死/華氏/下肢/河岸/貸/瑕疵/下賜/槝/花糸/
かしい /香椎/
かしいかえん /香椎花園/
かしいきぜんたい /可視域全体/
かしいしょう /貸し衣裳/
かしいせん /香椎線/
かしお /加塩/
かしおか /柏岡/
かしおけいさんき /カシオ計算機/
かしおり /菓子折り/
かしか /可視化/
かしかた /貸方/
かしかぶ /貸株/
かしかり /貸し借り/
かしかん /下士官/
かしき /下式/
かしきり /貸し切り/貸切り/貸切/
かしきりれっしゃ /貸切列車/
かしきん /貸し金/
かしこう /可視光/
かしこうせん /可視光線/
かしこうせんいがい /可視光線以外/
かしこし /貸越/
かしこじまかん /賢島間/
かしざお /貸竿/
かししつ /貸室/
かしじょうたい /仮死状態/
かしせい /可視性/
かしせいきそく /可視性規則/
かしせき /貸席/
かしそうこ /貸倉庫/
かしたいやく /歌詞対訳/
かしたんぽせきにん /瑕疵担保責任/
かしだ /樫田/
かしだし /貸し出し/貸出/
かしだしちゅう /貸し出し中/貸出中/
かしだしぼ /貸し出し簿/
かしだしよう /貸出用/
かしち /貸し地/貸地/
かしちょう /可視聴/
かしちん /貸賃/
かしつ /過失/加執/加湿/呵叱/
かしつき /加湿器/加湿機/
かしつきのう /加湿機能/
かしつけ /貸付/
かしつせきにん /過失責任/
かしつせきにんわりあい /過失責任割合/
かしつちょくぜん /過失直前/
かしつにんてい /過失認定/
かしつのうりょく /加湿能力/
かしつぶん /過失分/
かしつほうじょ /過失幇助/
かしつよう /加湿用/
かしつわりあい /過失割合/
かして /貸手/
かしてき /可視的/
かしてんぽ /貸店舗/
かしど /可視度/
かしの /柏野/
かしはら /橿原/樫原/
かしはらじんぐうまえ /橿原神宮前/
かしはらせん /橿原線/
かしば /香芝/
かしぱん /菓子パン/
かしびる /貸しビル/
かしべっそう /貸別荘/
かしほん /貸本/
かしほんや /貸本屋/
かしま /鹿島/鹿嶋/貸間/加島/加嶋/嘉島/
かしまこう /鹿島港/
かしまじんぐう /鹿島神宮/
かしません /鹿島戦/
かしまだ /鹿島田/
かしまだい /鹿島台/
かしまちょう /鹿島町/
かしまやり /鹿島槍/
かしまりんかいてつどう /鹿島臨海鉄道/
かしみせ /貸し店/
かしむら /樫村/鹿志村/
かしも /加子母/
かしもと /貸元/
かしもり /樫森/
かしゃ /貨車/加者/火車/
かしゃく /苛責/呵責/仮借/
かしゃけんいん /貨車牽引/
かしや /貸家/菓子屋/
かしやま /樫山/
かしゅ /歌手/
かしゅう /歌集/加州/
かしゅうきくざけ /加州菊酒/
かしゅかつどう /歌手活動/
かしゅく /可縮/
かしゅめい /歌手名/
かしょ /個所/箇所/ヶ所/カ所/
かしょう /仮称/過小/歌唱/過少/加商/寡少/火傷/華宵/花床/
かしょうさんぜん /菓匠三全/
かしょうしどう /歌唱指導/
かしょうしょう /歌唱賞/
かしょうしんこく /過小申告/
かしょうひょうか /過小評価/
かしょうほう /歌唱法/
かしょうりょく /歌唱力/
かしょく /過食/華燭/河蝕/
かしょくぶぶん /可食部分/
かしょぜんたい /箇所全体/
かしょぶんしょとく /可処分所得/
かしら /頭/
かしらもじ /頭文字/
かしりょう /貸料/
かしるい /菓子類/
かしれこ /貸しレコ/
かしれこや /貸しレコ屋/
かしろ /嘉代/
かしわ /栢/柏/
かしわぎ /柏木/
かしわくら /柏倉/
かしわざき /柏崎/
かしわし /柏市/
かしわしみん /柏市民/
かしわで /膳/
かしわば /柏葉/
かしわばら /柏原/
かしわぶち /柏渕/
かしわほうめん /柏方面/
かしわまち /柏町/
かしわら /柏原/
かしん /過信/家臣/加振/歌神/仮身;BTRON のファイルシステム上の概念/
かしんがわ /加振側/
かしんてん /加振点/
かしんりょく /加振力/
かじ /梶/家事/火事/鍛冶/柁/舵/鍛治/加持/加治/加地/加冶/嘉事/
かじい /梶井/
かじいいもとじろう /梶井基次郎/
かじいくじ /家事育児/
かじうら /梶浦/
かじお /梶尾/
かじか /鰍/鮖/梶賀/
かじかざわ /鰍沢/
かじかわ /舵川/加冶川/
かじがや /梶ケ谷/
かじき /梶木/加治木/
かじく /仮軸/
かじくぶんし /仮軸分枝/
かじげんば /火事現場/
かじしごと /家事仕事/
かじせいけい /下自成蹊/
かじた /梶田/
かじたに /梶谷/
かじたんとう /家事担当/
かじつ /果実/過日/佳日/
かじつあじ /果実味/
かじの /梶野/
かじはら /梶原/
かじば /火事場/
かじひょうか /家事評価/
かじぶんたん /家事分担/
かじま /鹿島/鹿嶋/梶真/
かじまけんせつ /鹿島建設/
かじもと /梶本/
かじゃ /冠者/
かじや /鍛冶屋/鍛治屋/梶谷/
かじやちょう /加治屋町/
かじゅ /果樹/
かじゅう /加重/果汁/荷重/過重/
かじゅういどう /荷重移動/
かじゅうこうほうへんざい /荷重後方偏在/
かじゅうこうりんへんざい /荷重後輪偏在/
かじゅうじたい /荷重自体/
かじゅうぞうか /荷重増加/
かじゅうでん /過充電/
かじゅうのうど /果汁濃度/
かじゅうぶん /果汁分/
かじゅうへいきん /加重平均/
かじゅうへんか /荷重変化/
かじゅうへんざい /荷重偏在/
かじゅうりょう /下重量/
かじゅえん /果樹園/
かじゅし /果樹試/
かじゅしけんじょう /果樹試験場/
かじょ /加除/花序/
かじょう /過剰/箇条/
かじょうがき /箇条書/個条書き/
かじょうがきけいしき /箇条書形式/
かじょうきじゅつけいしき /箇条記述形式/
かじょうきょういく /過剰教育/
かじょうざいこ /過剰在庫/
かじょうしんりょう /過剰診療/
かじょうじんこう /過剰人口/
かじょうせいさん /過剰生産/
かじょうせっしゅ /過剰摂取/
かじょうてきおう /過剰適応/
かじょうとうし /過剰投資/
かじょうとうよ /過剰投与/
かじょうねつ /過剰熱/
かじょうのうにゅう /過剰納入/
かじょうはんのう /過剰反応/
かじょうほせい /過剰補正/
かじょうぼうえい /過剰防衛/
かじょしき /加除式/
かじろうどう /家事労働/
かじろうどうしゃ /家事労働者/
かじわら /梶原/
かじわらいっき /梶原一騎/
かじん /家人/歌人/佳人/寡人/
かじんはくめい /佳人薄命/
かす /糟/粕/滓/
かすい /下垂/河水/火水/加水/
かすいたい /下垂体/
かすいてきりょう /加水適量/
かすいど /火水土/
かすいぶんかい /加水分解/
かすいもく /火水木/
かすいもくきんど /火水木金土/
かすう /仮数/価数/
かすうぶ /仮数部/
かすかべ /春日部/
かすかべきょうえい /春日部共栄/
かすかべきんぺん /春日部近辺/
かすかべし /春日部市/
かすかわ /粕川/
かすが /春日/
かすがい /春日井/鎹/春日居/
かすががわ /春日川/
かすががわかん /春日川間/
かすがきゅうぎじょう /春日球技場/
かすがし /春日市/
かすがたいしゃ /春日大社/
かすがちょう /春日町/
かすがどおり /春日通り/
かすがの /春日野/
かすがのつぼね /春日局/
かすがのみち /春日野道/
かすがばる /春日原/
かすがふじ /春日富士/
かすじる /粕汁/
かすじるじたて /粕汁仕立て/
かすたに /糟谷/
かすたむ /カスタム/
かすたむか /カスタム化/
かすだ /粕田/
かすてら /カステラ/
かすなべ /粕鍋/
かすぴかい /カスピ海/
かすみ /霞/香澄/香純/香住/
かすみがうら /霞浦/
かすみがせき /霞ヶ関/霞が関/霞ケ関/
かすみがせきびる /霞が関ビル/
かすみさい /霞祭/
かすみちょう /香澄町/
かすみのめ /霞目/
かすや /粕屋/粕谷/糟谷/
かすり /絣/綛/纃/緕/飛白/
かすりきず /かすり傷/
かず /数/和/一/下図/一寿/香鶴/數/
かずあき /和明/一晃/一明/和昭/一章/和晶/和晃/
かずい /花蘂/
かずえ /和枝/一恵/主計/一枝/和恵/
かずえのかみ /主計頭/
かずお /和夫/一穂/一夫/一男/一雄/和男/和雄/和生/和郎/一生/
かずおおく /数多く/
かずおか /数岡/
かずおみ /和臣/
かずかず /数々/
かずき /一機/一起/一樹/一喜/和紀/和樹/
かずこ /和子/加純子/佳寿子/加寿子/数子/量子/
かずさ /上総/
かずさいちのみや /上総一宮/
かずさなかの /上総中野/
かずさんしょう /下図参照/
かずし /一司/和士/一志/和志/一至/数史/和司/
かずしげ /和茂/和重/一茂/一繁/
かずしれず /数知れず/
かずじたい /数自体/
かずすくない /数少ない/
かずすけ /一助/
かずたか /和貴/一任/一貴/一隆/
かずてる /一輝/一晃/
かずと /和人/一人/
かずとし /一利/和利/一敏/一寿/一世/和淑/数敏/和敏/
かずなり /一成/
かずね /和音/
かずの /数野/
かずのこ /鯑/
かずのみや /和宮/
かずのり /一憲/和紀/和憲/一範/和典/和徳/一孔/主紀/和則/千典/
かずひこ /和彦/一彦/和比古/
かずひさ /和久/一久/数久/一寿/
かずひで /和秀/一英/和英/一秀/
かずひと /和人/和仁/一人/一仁/
かずひろ /一博/和宏/和広/一浩/和浩/和博/一弘/和弘/一宏/一裕/一広/一洋/和裕/一寛/
かずふみ /和史/一文/
かずほ /一穂/
かずほど /数程/
かずま /和磨/一磨/數間/和馬/
かずまさ /和正/一正/和政/数正/一昌/和昌/
かずまる /一丸/
かずまろ /和麻呂/
かずみ /和美/香津美/一美/和巳/一三/一味/和実/香樹実/
かずみち /一路/
かずもと /一元/
かずや /和也/一哉/一也/和哉/一弥/数也/和弥/一八/
かずやす /一泰/
かずゆき /一幸/和行/一行/一之/和幸/和之/数幸/和恭/
かずよ /和世/和代/一代/
かずよし /和義/一義/和美/和芳/和好/和良/和由/
かずら /葛/鬘/蔓/
かずわり /数割/
かせ /加瀬/枷/加世/綛/加勢/
かせい /火星/化成/仮性/加勢/家政/苟性/苛性/Mars/
かせいか /家政科/
かせいかり /苛性カリ/苛性加里/
かせいがく /家政学/
かせいがくいん /家政学院/
かせいがん /火成岩/
かせいきょういく /家政教育/
かせいきんし /仮性近視/
かせいぎょ /可制御/
かせいぎょせい /可制御性/
かせいこうぎょう /化成工業/
かせいじん /火星人/
かせいそーだ /苛性ソーダ/
かせいだい /家政大/
かせいねんだいき /火星年代記/
かせいひょうめん /火星表面/
かせいひりょう /化成肥料/
かせいひん /化成品/
かせいふ /家政婦/
かせいふちょう /家政婦長/
かせいめん /火星面/
かせき /化石/可積/
かせきか /化石化/
かせきさい /過積載/
かせきさいしゃりょう /過積載車両/
かせきねんりょう /化石燃料/
かせきぶん /可積分/
かせきぶんかんすう /可積分関数/
かせだ /加世田/
かせっと /カセット/
かせつ /仮説/仮設/架設/
かせつか /仮説化/
かせつきょう /仮設橋/
かせつけいせい /仮説形成/
かせつこうかせん /仮設高架線/
かせつしょうがいぶつ /仮設障害物/
かせつすいろん /仮説推論/
かせん /下線/寡占/加線/河川/化繊/架線/
かせんか /寡占化/
かせんしき /河川敷/
かせんした /架線下/
かせんじ /架線事/
かせんじき /河川敷/
かせんじきどうろ /河川敷道路/
かせんじこ /架線事故/
かせんじょうたい /寡占状態/
かせんせつだん /架線切断/
かせんせつだんくかん /架線切断区間/
かせんちゅう /架線柱/
かせんでんあつ /架線電圧/
かせんぶ /下線部/
かせんほうしき /架線方式/
かせんよう /架線用/
かせんよこ /河川横/
かぜ /風邪/風/
かぜあたり /風当たり/
かぜい /課税/
かぜいがく /課税額/
かぜいしょうめいしょ /課税証明書/
かぜいたいしょう /課税対象/
かぜいたいしょうがく /課税対象額/
かぜいひょうじゅん /課税標準/
かぜいぶん /課税分/
かぜいりつ /課税率/
かぜおき /風興/
かぜきた /風北/
かぜぎみ /風邪気味/
かぜぐすり /風邪薬/カゼ薬/
かぜごえ /風邪声/
かぜたち /風立/
かぜつかい /風使い/
かぜとおし /風通し/
かぜのたに /風の谷/
かぜむき /風向き/
かぜよけ /風よけ/
かぜん /果然/
かそ /可塑/過疎/
かそう /仮想/下層/仮装/火葬/家相/価層/
かそうおんげん /仮想音源/
かそうか /仮想化/
かそうかいきゅう /下層階級/
かそうかいきゅうしゅっしん /下層階級出身/
かそうかそうきおく /仮想仮想記憶/
かそうかんすう /仮想関数/
かそうがめん /仮想画面/
かそうきおく /仮想記憶/
かそうきおくきこう /仮想記憶機構/
かそうきかい /仮想機械/
かそうきじ /仮想記事/
かそうきてい /仮想基底/
かそうくうかん /仮想空間/
かそうけいさんき /仮想計算機/
かそうげんじつ /仮想現実/
かそうげんじつかん /仮想現実感/
かそうこうし /仮想光子/
かそうさ /可操作/
かそうさせい /可操作性/
かそうさど /可操作度/
かそうじょう /仮想上/
かそうせかい /仮想世界/
かそうせん /仮想戦/
かそうたいしょう /仮装大賞/
かそうたんまつ /仮想端末/
かそうてき /仮想的/
かそうてきかくちょう /仮想的拡張/
かそうてきこく /仮想敵国/
かそうば /火葬場/
かそうへいれつけいさんき /仮想並列計算機/
かそうへんい /仮想変位/
かそうりゅうし /仮想粒子/
かそく /加速/可測/
かそくうんどう /加速運動/
かそくかのう /加速可能/
かそくかん /加速感/
かそくかんすう /可測関数/
かそくき /加速器/
かそくくうかん /可測空間/
かそくくかん /加速区間/
かそくけい /加速系/
かそくげんそく /加速減速/
かそくざい /加速剤/
かそくしゃせん /加速車線/
かそくしゃぞう /可測写像/
かそくしゅうごう /可測集合/
かそくしゅうそく /加速収束/
かそくじ /加速時/
かそくじっけん /加速実験/
かそくせい /加速性/
かそくせいのう /加速性能/
かそくそうち /加速装置/
かそくちゅう /加速中/
かそくてき /加速的/
かそくど /加速度/
かそくどいってい /加速度一定/
かそくどうんどう /加速度運動/
かそくどけい /加速度系/
かそくどけいさん /加速度計算/
かそくどけいないぶ /加速度系内部/
かそくどてき /加速度的/
かそくのうりょく /加速能力/
かそくふりょう /加速不良/
かそくよう /加速用/
かそくりょく /加速力/
かそせい /可塑性/
かそちいき /過疎地域/
かそてき /可塑的/
かそり /加曽利/
かぞ /数/加須/數/
かぞう /家蔵/
かぞえあげ /数え上げ/
かぞえうた /数え歌/
かぞえかた /数え方/
かぞえやくまん /数え役満/
かぞく /家族/華族/
かぞくいがい /家族以外/
かぞくいしき /家族意識/
かぞくかいぎ /家族会議/
かぞくかん /家族間/
かぞくかんけい /家族関係/
かぞくけいかく /家族計画/
かぞくこうい /家族行為/
かぞくこうせい /家族構成/
かぞくしょゆう /家族所有/
かぞくすう /家族数/
かぞくぜんいん /家族全員/
かぞくづれ /家族連れ/
かぞくてき /家族的/
かぞくどうし /家族同士/
かぞくない /家族内/
かぞくはっけい /家族八景/
かぞくぶろ /家族風呂/
かぞくよう /家族用/
かぞくりょこう /家族旅行/
かぞくわりびき /家族割引/
かた /方/型/形/肩/片/潟/過多/沫/
かたあし /片足/
かたあしかじゅう /片足加重/
かたあやまり /型誤り/
かたい /難/下腿/
かたいきん /過怠金/
かたいっぽう /片一方/
かたいと /片糸/
かたいなか /片田舎/
かたいれ /肩入れ/肩入/
かたうで /片腕/
かたうんてんだい /片運転台/
かたお /片尾/
かたおか /片岡/
かたおかつるたろう /片岡鶴太郎/
かたおもい /片思い/片想い/
かたおや /片親/
かたかいそう /型階層/
かたかな /片仮名/カタカナ/片假名/
かたかなこうほ /片仮名候補/
かたかなひょうき /片仮名表記/
かたかなへんかん /片仮名変換/
かたかんせつ /肩関節/
かたがい /片貝/
かたがき /肩書/肩書き/
かたがた /方々/旁/旁々/
かたがみ /型紙/
かたがみてつどう /片上鉄道/
かたがわ /片側/
かたがわいっしゃせん /片側一車線/
かたがわにかしょ /片側二箇所/
かたがわはんぶん /片側半分/
かたがわり /肩代り/肩代わり/
かたき /敵/仇/
かたきうち /仇討ち/敵討/
かたきやく /敵役/
かたぎ /気質/堅気/
かたぎし /片岸/
かたぎのしゅう /堅気の衆/
かたぎり /片桐/
かたく /仮託/家宅/火宅/花托/
かたくしんにゅう /家宅侵入/
かたくずれ /型くずれ/
かたくそうさく /家宅捜索/
かたくな /頑な/頑/
かたくら /片倉/
かたくらちょう /片倉町/
かたくりこ /片栗粉/
かたぐち /肩口/片口/
かたぐるま /肩車/
かたけんさ /型検査/
かたげんご /型言語/
かたこう /型項/
かたこうせいし /型構成子/
かたこと /片言/
かたことことば /片言言葉/
かたこり /肩こり/肩凝り/
かたしき /型式/
かたしきばんごう /型式番号/
かたしすてむ /型システム/
かたしていし /型指定子/
かたしな /片品/
かたしなむら /片品村/
かたじょうほう /型情報/
かたすいろん /型推論/
かたすかし /肩透かし/肩透し/
かたすみ /片隅/
かたず /固唾/
かたせ /片瀬/
かたせんげん /型宣言/
かたそで /片袖/
かたた /堅田/
かたたいけい /型体系/
かたたいすう /片対数/
かたたがえ /方違え/
かたたそう /型多相/
かたたち /方達/
かたち /形/容/貌/型/
かたちじたい /形自体/
かたちぜんたい /形全体/
かたっぱし /片っ端/
かたつ /下達/可達/
かたつき /型付/肩付き/型つき/肩付/可達木/
かたつきかんすうがたげんご /型付関数型言語/
かたつけ /型付/
かたつばさ /肩翼/
かたつむり /蝸牛/蝸/
かたづ /固唾/
かたづけ /片付け/型付け/
かたづけま /片付け魔/
かたて /片手/
かたていぎ /型定義/
かたていすう /型定数/
かたておち /片手落/
かたてきようき /型適用基/
かたてなべ /片手鍋/
かたてま /片手間/
かたとき /片時/
かたな /刀/
かたなや /刀屋/
かたぬき /型抜/
かたの /片野/
かたのし /交野市/
かたはい /片肺/
かたはし /片端/
かたはじ /片端/
かたはば /肩幅/
かたはま /片浜/
かたはまえき /片浜駅/
かたばかり /形許り/
かたばみか /カタバミ科/Oxalidaceae/
かたばん /型番/型版/型板/
かたばんごう /型番号/
かたばんふめい /型番不明/
かたばんみてい /型番未定/
かたひがし /潟東/
かたひも /肩紐/
かたひら /片平/
かたびら /帷子/
かたびらのつじ /帷子ノ辻/
かたぶつ /堅物/
かたへんかん /型変換/
かたへんすう /型変数/
かたほう /片方/
かたほうこう /片方向/
かたぼう /片棒/
かたまち /片町/
かたまちせん /片町線/
かたまり /塊/
かたみ /肩身/形見/形身/肩見/片見/
かたみち /片道/
かたみちいちじかん /片道一時間/
かたみちいっしゃせん /片道一車線/
かたみちうんちん /片道運賃/
かたみちきっぷ /片道切符/
かたみちこうくうけん /片道航空券/
かたみちせいきりょうきん /片道正規料金/
かたみみ /片耳/
かたみわけ /形見わけ/
かたむき /傾き/
かたむきほせい /傾き補正/
かため /片目/片眼/固め/
かためい /型名/
かためん /片面/
かためんきろく /片面記録/
かためんはくし /片面白紙/
かたもと /片本/
かたもみ /肩揉み/
かたもり /容保/
かたやま /片山/
かたやまづ /片山津/
かたよせ /片寄/
かたり /語り/騙り/
かたりくち /語り口/
かたりぐさ /語り草/
かたりべ /語り部/
かたりろん /型理論/
かたりん /片輪/
かたりんそうこう /片輪走行/
かたる /拐/
かたろぐ /カタログ/
かたわ /片輪/
かたわら /傍ら/傍/旁/
かたわれ /片割れ/
かたん /下端/加担/加胆/荷担/可鍛/
かだ /伽陀/伽佗/
かだい /課題/過大/仮題/荷台/架台/
かだいおん /過大音/
かだいきょく /課題曲/
かだいせいきゅう /過大請求/
かだいばんごう /課題番号/
かだいひょうか /過大評価/
かだいひょうかぎみ /過大評価気味/
かだいめい /課題名/
かだん /下段/花壇/歌壇/
かち /価値/勝/磆/可知/勝ち/徒/加地/
かちいくさ /勝ち戦/
かちうま /勝馬/
かちうまとうひょうけん /勝馬投票券/
かちうん /勝運/
かちかん /価値観/価値感/
かちかんねん /価値観念/
かちき /勝気/
かちきじゅん /価値基準/
かちきはん /価値規範/
かちく /家畜/家蓄/
かちくえいせいしけんじょう /家畜衛生試験場/
かちくか /家畜化/
かちくにん /家畜人/
かちこし /勝ち越し/
かちすう /勝数/
かちたいけい /価値体系/
かちてん /勝点/
かちどき /勝鬨/勝ちどき/
かちどきばし /勝鬨橋/
かちにげ /勝ち逃げ/
かちはんだん /価値判断/
かちぼし /勝ち星/
かちまけ /勝ち負け/
かちめ /勝ち目/勝目/
かちゅう /渦中/火中/家中/花柱/
かちょう /課長/可聴/掛長/科長/家長/蚊帳/花鳥/課徴/
かちょういき /可聴域/
かちょういん /課長印/
かちょうおん /可聴音/
かちょうがた /可聴型/
かちょうきん /課徴金/
かちょうげんかい /可聴限界/
かちょうしゅうはすう /可聴周波数/
かちょうせいど /家長制度/
かちょうせん /花蝶扇/
かちょうたいいき /可聴帯域/
かちょうたいいきない /可聴帯域内/
かちょうだいり /課長代理/
かちょうち /可聴値/
かちょうづき /課長付/
かちょうふうげつ /花鳥風月/
かぢ /加治/加地/鍛冶/
かっ /合/渇/
かっか /閣下/角化/
かっかい /各回/各界/
かっかく /赫々/
かっかざん /活火山/
かっかそうよう /隔靴掻痒/
かっき /活気/画期/各期/
かっきてき /画期的/劃期的/
かっきゅう /割球/
かっきょ /割拠/
かっきょう /活況/
かっきょく /各局/各曲/
かっきょくめん /各局面/
かっくう /滑空/
かっくうき /滑空機/
かっくうこうちゃく /滑空降着/
かっくうじょう /滑空場/
かっくうせいのう /滑空性能/
かっくうひ /滑空比/
かっけ /脚気/
かっけた /各桁/
かっけつ /喀血/
かっこ /【/括弧/】/『/』/（/）/［/］/確固/〉/〈/カッコ/「/」/各個/‘/’/“/”/（）/〔/〔〕/〕/［］/｛/｛｝/｝/〈〉/《/《》/》/「」/『』/【】/‘’/“”/
かっこう /格好/滑行/滑降/恰好/郭公/
かっこうきょうぎ /滑降競技/
かっこきそく /括弧規則/
かっこく /各国/
かっこくかん /各国間/
かっこくきょうかい /各国協会/
かっこくご /各国語/
かっこくだいひょう /各国代表/
かっことじ /〉/》/】/
かっこない /括弧内/
かっこんとう /葛根湯/
かっさい /喝采/葛西/
かっしゃ /滑車/活写/
かっしょう /滑翔/
かっしょく /褐色/
かっすい /渇水/活水/
かっすいじょがくいん /活水女学院/
かっすいじょしだい /活水女子大/
かっせい /活性/
かっせいか /活性化/活生化/
かっせいがた /活性型/
かっせいざい /活性剤/
かっせいそう /活性層/
かっせいそくど /活性速度/
かっせいたん /活性炭/
かっせいち /活性値/
かっせいど /活性度/
かっせん /合戦/活線/合戰/
かっそう /滑走/
かっそうか /滑走可/
かっそうかのう /滑走可能/
かっそうかのうくかん /滑走可能区間/
かっそうきょり /滑走距離/
かっそうきんし /滑走禁止/
かっそうしゃ /滑走者/
かっそうじかん /滑走時間/
かっそうせい /滑走性/
かっそうちゅう /滑走中/
かっそうにっすう /滑走日数/
かっそうふか /滑走不可/
かっそうふかのう /滑走不可能/
かっそうめん /滑走面/
かっそうめんか /滑走面下/
かっそうもくひょう /滑走目標/
かっそうよう /滑走用/
かっそうろ /滑走路/
かった /刈田/勝田/
かったー /カッター/
かったぐん /刈田郡/
かっちゃく /活着/
かっちゅう /甲胄/甲冑/
かって /勝手/
かってつけ /勝手付/
かっと /カット/
かっとう /葛藤/
かっぱ /河童/喝破/合羽/κ/川童/Κ/
かっぱつ /活発/活溌/
かっぱつか /活発化/
かっぱばし /河童橋/合羽橋/
かっぱばしふきん /河童橋付近/
かっぱん /活版/
かっぱんいんさつ /活版印刷/
かっぱんいんさつぶつ /活版印刷物/
かっぷ /割賦/カップ/
かっぷきん /割賦金/
かっぷく /恰幅/割腹/
かっぷる /カップル/
かっぺい /勝平/
かっぽ /濶歩/闊歩/
かっぽう /割烹/
かっぽうぎ /割烹着/
かっぽうりょうり /割烹料理/
かつ /割/滑/轄/且/括/活/勝/葛/克/褐/渇/喝/恰/捷/刮/劼/戛/戞/曷/猾/瞎/磆/羯/聒/蛞/蝎/蠍/豁/闊/濶/鞨/黠/カツ/且つ/∧/筈/剋/
かつあい /割愛/
かつあいねがい /割愛願い/
かつあき /克明/勝昭/勝章/
かついち /勝一/
かつうら /勝浦/
かつうらかん /勝浦間/
かつうらこう /勝浦港/
かつうらし /勝浦市/
かつえ /勝恵/勝江/
かつお /鰹/勝男/勝夫/勝雄/克夫/勝生/
かつおぶし /鰹ぶし/鰹節/
かつかじゅう /活荷重/
かつかつ /戛戛/
かつかんれんじょうほう /活関連情報/
かつき /勝木/克己/香月/
かつきち /勝吉/
かつぎひこうじょう /厚木飛行場/
かつくら /勝鞍/勝倉/
かつげき /活劇/
かつこ /勝子/克子/
かつさい /勝斉/
かつし /克志/且/克/克史/勝志/
かつしか /葛飾/
かつしかく /葛飾区/
かつしま /勝島/
かつしろう /勝四郎/
かつしんたろう /勝新太郎/
かつじ /活字/勝次/勝治/功至/
かつじけい /活字系/
かつじしょくにん /活字職人/
かつじたい /活字体/
かつじばん /活字版/
かつじぶんか /活字文化/
かつじょう /割譲/
かつじょうほう /活情報/
かつぜつ /活舌/
かつぞう /勝三/
かつた /勝田/
かつたし /勝田市/
かつたに /勝谷/
かつたろう /勝太郎/
かつだんそう /活断層/
かつて /嘗て/曾て/曽て/
かつとし /勝敏/勝利/克俊/勝俊/克年/克敏/
かつどう /活動/
かつどういき /活動域/
かつどうか /活動家/活動化/
かつどうかいし /活動開始/
かつどうがいよう /活動概要/
かつどうきかん /活動期間/
かつどうきゅうし /活動休止/
かつどうきゅうしちゅう /活動休止中/
かつどうきょてん /活動拠点/
かつどうけいかく /活動計画/
かつどうけいひ /活動経費/
かつどうげん /活動源/
かつどうさいかい /活動再開/
かつどうさんか /活動参加/
かつどうしゃしん /活動写真/
かつどうしゅうにゅう /活動収入/
かつどうじょうきょう /活動状況/
かつどうたい /活動体/
かつどうちゅう /活動中/
かつどうてき /活動的/
かつどうないよう /活動内容/
かつどうねんすう /活動年数/
かつどうはんい /活動範囲/
かつどうび /活動日/
かつどうほうこく /活動報告/
かつどうほうしん /活動方針/
かつどうほじょきん /活動補助金/
かつどうよてい /活動予定/
かつどうりょく /活動力/
かつどん /カツ丼/
かつなり /勝成/
かつぬま /勝沼/
かつぬまちょう /勝沼町/
かつの /鹿角/勝野/
かつのぶ /克亘/
かつのり /克則/克典/勝典/勝則/
かつはた /勝畑/
かつば /活馬/
かつひこ /克彦/勝彦/捷彦/
かつひさ /勝久/克久/
かつひで /勝秀/
かつひと /克仁/
かつひら /勝平/
かつひろ /克宏/克博/克裕/勝広/克洋/克弘/勝弘/勝寛/勝宏/勝洋/勝浩/
かつふみ /克文/
かつべ /勝部/
かつぼう /渇望/
かつま /勝間/克馬/
かつまく /滑膜/
かつまさ /勝正/
かつまた /勝又/勝亦/勝間田/勝股/勝俣/
かつみ /香津美/克己/克美/克巳/勝美/勝巳/勝己/克実/
かつもく /刮目/割目/
かつもと /勝元/勝本/
かつや /克哉/克也/勝谷/勝也/克弥/勝哉/勝弥/
かつやく /活躍/括約/
かつやくきん /括約筋/
かつやくしだい /活躍次第/
かつやくちゅう /活躍中/
かつやくば /活躍馬/
かつやま /勝山/
かつやまこうえん /勝山公園/
かつやません /勝山線/
かつゆき /克幸/勝之/克行/勝幸/克之/勝行/勝征/
かつよう /活用/
かつようけい /活用形/
かつようご /活用語/
かつようごび /活用語尾/
かつようじゅ /闊葉樹/
かつようじゅつ /活用術/
かつようひょう /活用表/
かつようほう /活用法/
かつよし /勝義/克義/勝吉/克能/
かつより /勝頼/
かつら /桂/蘰/
かつらお /葛尾/
かつらか /カツラ科/Cercidiphyllaceae/
かつらかわ /桂川/
かつらがわ /桂川/
かつらぎ /葛城/桂木/
かつらく /滑落/
かつらさんし /桂三枝/
かつらだ /桂田/
かつらはま /桂浜/
かつらばやし /桂林/
かつらぶんちん /桂文珍/
かつらゆみ /桂由美/
かつらりきゅう /桂離宮/
かつりょく /活力/
かつりょくげん /活力源/
かつれい /割礼/
かつれん /勝連/
かつろ /活路/
かつろう /克朗/
かづき /香月/
かづけ /日付/
かづさ /加津佐/
かづさえきまえ /加津佐駅前/
かづさちょう /加津佐町/
かづさちょうない /加津佐町内/
かづの /鹿角/
かづみ /香津美/
かて /糧/
かてい /仮定/過程/課程/家庭/
かていか /家庭科/
かていかんきょう /家庭環境/
かていがい /家庭外/
かていきょういく /家庭教育/
かていきょうし /家庭教師/
かていきょうしさき /家庭教師先/
かていさいえん /家庭菜園/
かていさいばんしょ /家庭裁判所/
かていしき /仮定式/
かていじたい /仮定自体/
かていせいかつ /家庭生活/
かていちょうさ /家庭調査/
かていつき /仮定付/
かていてき /家庭的/仮定的/
かていでんき /家庭電器/
かていとう /家庭等/
かていない /家庭内/
かていないふわ /家庭内不和/
かていないりこん /家庭内離婚/
かていはかせ /課程博士/
かていぶ /仮定部/
かていぶそく /仮定不足/
かていへんすう /仮定変数/
かていほう /仮定法/
かていほうもん /家庭訪問/
かていむけ /家庭向け/
かていよう /家庭用/
かていようき /家庭用機/
かていようひん /家庭用品/
かていりょうり /家庭料理/
かてきおう /過適応/
かてごりー /カテゴリー/
かてつ /科哲/
かてん /加点/
かてんようそ /加点要素/
かでな /嘉手納/
かでん /家電/家伝/荷電/瓜田/
かでんこうりてん /家電小売店/
かでんし /価電子/
かでんしょうひん /家電商品/
かでんせいひん /家電製品/
かでんひん /家電品/
かでんや /家電屋/
かでんよう /家電用/
かでんりゅうし /荷電粒子/
かでんりょうはんてん /家電量販店/
かと /過渡/加登/過度/
かとう /加藤/下等/加糖/寡頭/果糖/加登/加東/賀藤/花筒/
かとうきょうそうか /過当競争下/
かとうきょうそうじょうたい /過当競争状態/
かとうぎ /加藤木/
かとかい /過渡解/
かとき /過渡期/
かときち /加ト吉/
かとく /家督/
かとくせい /可読性/
かとくたい /科特隊/
かとてき /過渡的/
かととくせい /過渡特性/
かとり /鹿取/香取/蚊取り/
かとりせんこう /蚊取線香/蚊取り線香/
かとりっく /カトリック/
かとりんかい /過渡臨界/
かど /角/過度/┘/┐/┌/└/門/賀戸/加登/柧/過渡/
かどいけ /門池/
かどう /稼働/華道/可動/稼動/可導/火道/
かどうかん /仮導管/
かどうしき /可動式/
かどうしきざせき /可動式座席/
かどうじかん /稼働時間/
かどうじょうきょう /稼働状況/
かどうせい /可動性/可導性/
かどうそう /稼動相/稼働相/
かどうちゅう /稼働中/
かどうぶ /華道部/
かどうぶぶん /可動部分/
かどうりつ /稼働率/
かどおか /角岡/
かどかり /下土狩/
かどかわ /角川/
かどかわえいが /角川映画/
かどかわしょてん /角川書店/
かどかわはるき /角川春樹/
かどかわばん /角川版/
かどかわぶんこ /角川文庫/
かどかわぶんこばん /角川文庫版/
かどがき /門垣/
かどがわ /門川/
かどく /可読/
かどくか /可読化/
かどくせい /可読性/
かどくら /門倉/
かどさき /門崎/
かどさわ /門澤/
かどた /角田/門田/
かどち /角地/
かどてき /過度的/
かどで /門出/
かどなか /門仲/
かどなが /門長/
かどの /門野/
かどばやし /門林/
かどま /門真/
かどまし /門真市/
かどまつ /角松/門松/
かどみうむ /カドミウム/
かどわき /門脇/
かな /仮名/カナ/加奈/華奈/哉/金/假名/佳奈/華菜/香奈/
かなあしのう /金足農/
かなあみ /金網/
かなあみでんりゅう /金網電流/
かない /金井/課内/家内/科内/
かないあんぜん /家内安全/
かないかいぎ /課内会議/
かないけ /金池/
かないし /金石/
かなう /叶/
かなえ /鬲/鼎/彝/彜/叶え/香苗/
かなかん /かな漢/仮名漢字変換プログラム/仮名漢/
かなかんじ /仮名漢字/かな漢字/
かなかんじへんかん /仮名漢字変換/かな漢字変換/
かながき /カナ書き/仮名書き/金垣/
かながた /金型/
かながわ /神奈川/金川/
かながわえき /神奈川駅/
かながわく /神奈川区/
かながわけん /神奈川県/
かながわけんけい /神奈川県警/
かながわけんげんてい /神奈川県限定/
かながわけんざいじゅう /神奈川県在住/
かながわけんしゅっしん /神奈川県出身/
かながわけんじん /神奈川県人/
かながわけんとうぶ /神奈川県東部/
かながわけんない /神奈川県内/
かながわけんみん /神奈川県民/
かながわしんぶん /神奈川新聞/
かながわしんまち /神奈川新町/
かながわせんしゅけん /神奈川選手権/
かながわだい /神奈川大/
かながわだいがく /神奈川大学/
かながわだいひらつか /神奈川大平塚/
かながわちいき /神奈川地域/
かながわちほう /神奈川地方/
かながわほうしき /神奈川方式/
かながわほうめん /神奈川方面/
かなぎ /金城/金木/
かなくぎ /金釘/
かなぐ /金具/
かなぐつき /金具付き/
かなこ /加奈子/嘉奈子/佳奈子/可奈子/香奈子/佳那子/
かなさき /金崎/
かなさし /金指/
かなざき /加奈崎/
かなざわ /金沢/金澤/
かなざわいせい /金沢以西/
かなざわいなん /金沢以南/
かなざわえき /金沢駅/
かなざわかん /金沢間/
かなざわく /金沢区/
かなざわこうぎょうだいがく /金沢工業大学/
かなざわこうだい /金沢工大/
かなざわし /金沢市/
かなざわしぜんこうえん /金沢自然公園/
かなざわしない /金沢市内/
かなざわしゅっしん /金沢出身/
かなざわだい /金沢大/
かなざわだいがく /金沢大学/
かなざわだいり /金沢大理/
かなざわはっけい /金沢八景/
かなざわほうめん /金沢方面/
かなざわゆき /金沢行/
かなしばり /金縛り/
かなしま /金島/
かなしみ /悲しみ/
かなた /彼方/華薙刀/
かなたに /金谷/
かなだ /金田/加奈陀/カナダ/片田/
かなだこく /カナダ国/
かなちゅう /神奈中/
かなつじ /金辻/
かなづ /金津/
かなづかい /仮名遣い/
かなづち /金槌/金鎚/
かなで /金出/
かなでほん /仮名手本/
かなにゅうりょく /仮名入力/
かなひょうき /仮名表記/
かなぶつ /金仏/
かなぶぶん /仮名部分/
かなへんかん /仮名変換/
かなまじり /かな交じり/かな混じり/仮名交じり/仮名混じり/
かなまち /金町/
かなまちせん /金町線/
かなまり /鋺/
かなまる /金丸/
かなまるしん /金丸信/
かなみつ /金光/
かなむら /金村/
かなめ /要/
かなめちょう /要町/
かなもじ /仮名文字/
かなもじきょうかい /仮名文字協会/
かなもと /金本/
かなもの /金物/
かなものや /金物屋/
かなもり /金森/
かなや /金谷/金屋/
かなやえき /金谷駅/
かなやま /金山/
かなやまえき /金山駅/
かなやまちょう /金山町/
かなやまばし /金山橋/
かならず /必ず/必らず/
かならずしも /必ずしも/
かならずや /必ずや/
かなり /金成/可成/
かなん /河南/華南/伽南/
かに /蟹/可児/カニ/蠏/
かにえ /蟹江/
かにえじょう /蟹江城/
かにく /果肉/
かにざ /蟹座/
かにた /蟹田/
かにゅう /加入/
かにゅうきぼう /加入希望/
かにゅうきん /加入金/
かにゅうけん /加入権/
かにゅうしゃ /加入者/
かにゅうしゃばんごう /加入者番号/
かにゅうしゃめい /加入者名/
かにゅうぼしゅう /加入募集/
かにゅうまえ /加入前/
かにゅうりつ /加入率/
かにゅうりょう /加入料/
かにゅうりょく /過入力/
かにゅうれい /加入例/
かぬき /香貫/
かぬま /鹿沼/
かね /金/兼/鐘/
かねあい /兼ね合い/兼合/兼合い/
かねいがい /金以外/
かねいし /金石/
かねいそ /金磯/
かねおか /金岡/兼岡/
かねかし /金貸/
かねかんじょう /金勘定/
かねがさき /金ヶ崎/
かねがふち /鐘淵/
かねきち /兼吉/
かねきよ /兼清/
かねこ /金子/金児/兼子/
かねざき /金崎/鐘崎/
かねしたけんせつ /金下建設/
かねしだい /金次第/
かねしま /金嶋/
かねしろちょう /金城町/
かねじゃく /矩尺/
かねずく /金ずく/
かねぞう /兼蔵/
かねた /金田/兼太/
かねたか /兼貴/
かねたに /金谷/
かねだ /金田/
かねつ /加熱/過熱/火熱/金津/
かねつおんど /加熱温度/
かねつご /加熱後/
かねつさっきん /加熱殺菌/
かねつじかん /加熱時間/
かねつたいしょう /加熱対象/
かねつへんけい /加熱変形/
かねつほう /加熱法/
かねづか /金塚/
かねづかい /金遣い/
かねづる /金蔓/
かねて /予て/
かねと /兼人/
かねなし /金無し/
かねなり /金成/
かねはた /金畑/
かねはま /金浜/
かねはら /金原/
かねひさ /金久/
かねひと /兼人/
かねぼう /鐘紡/
かねまち /金町/
かねまつ /兼松/
かねまつごうしょう /兼松江商/
かねまる /金丸/
かねまわり /金回り/
かねみつ /金光/
かねめ /金目/
かねもうけ /金儲け/
かねもち /金持ち/
かねもと /金本/
かねもり /兼森/
かねや /金谷/
かねやま /金山/兼山/
かねらか /カネラ科/Canellaceae/
かねん /可燃/
かねんせい /可燃性/
かねんぶつ /可燃物/
かの /彼/狩野/鹿野/彼の/
かのあし /鹿足/
かのい /鹿井/
かのう /可能/化膿/叶/狩野/加納/納/嘉納/
かのうじしょう /可能事象/
かのうせい /可能性/
かのうせいけんとう /可能性検討/
かのうせいだい /可能性大/可能正大/
かのうせかい /可能世界/
かのうどうし /可能動詞/
かのうひょうげん /可能表現/
かのえ /庚/
かのえいぬ /庚戌/
かのえうま /庚午/
かのえさる /庚申/
かのえたつ /庚辰/
かのえとら /庚寅/
かのえね /庚子/
かのじょ /彼女/
かのじょじしん /彼女自身/
かのじょたち /彼女達/
かのじょひとり /彼女一人/
かのじょら /彼女等/
かのせ /鹿瀬/
かのと /辛/
かのとい /辛亥/
かのとう /辛卯/
かのとうし /辛丑/
かのととり /辛酉/
かのとひつじ /辛未/
かのとみ /辛巳/
かのや /鹿屋/
かはい /加配/
かはいじく /下胚軸/
かはいらん /過排卵/
かはらい /過払い/
かはん /可搬/過半/河畔/
かはんがた /可搬型/
かはんしき /可搬式/
かはんしん /下半身/
かはんしんふずい /下半身不随/
かはんすう /過半数/
かはんすうぎけつ /過半数議決/
かはんすうさいけつ /過半数採決/
かはんせい /可搬性/
かはんぶ /下半部/
かば /樺/椛/蒲/河馬/
かばー /カバー/
かばさん /加波山/
かばしま /樺嶋/
かばと /樺戸/
かばね /屍/
かばん /鞄/花盤/花盤状/カバン/
かばんじょう /花盤状/
かひ /可否/下肥/果皮/花被/下卑/瑕疵/痂皮/下皮/
かひつ /加筆/
かひつさいはん /加筆再販/
かひつしゅうせい /加筆修正/
かひつていせい /加筆訂正/
かひはんだん /可否判断/
かひへん /花被片/
かひょう /下表/
かび /カビ/華美/黴/
かびぶん /可微分/
かびん /花瓶/過敏/
かびんせい /過敏性/
かふ /下付/寡婦/
かふう /家風/
かふぇいん /カフェイン/
かふぇてりあ /カフェテリア/
かふか /過負荷/可不可/
かふく /下腹/禍福/
かふくぶ /下腹部/
かふそく /過不足/
かふちょうせい /家父長制/
かふちょうせいど /家父長制度/
かふん /花粉/花紛/
かふんしょう /花粉症/
かぶ /株/(株)/下部/蕪/（株）/
かぶか /株価/
かぶかきゃっしゅふろーひりつ /株価キャッシュフロー比率/
かぶかこうとう /株価高騰/
かぶかしすう /株価指数/
かぶかしゅうえきりつ /株価収益率/
かぶかじゅんしさんばいりつ /株価純資産倍率/
かぶかへんどう /株価変動/
かぶき /歌舞伎/
かぶきかい /歌舞伎会/
かぶきこうえん /歌舞伎公演/
かぶきざ /歌舞伎座/
かぶきちょう /歌舞伎町/
かぶけん /株券/
かぶこうぞう /下部構造/
かぶしき /株式/
かぶしきかいしゃ /株式会社/
かぶしきがいしゃ /株式会社/株式會社/(株)/
かぶしきがいしゃすずか /株式会社鈴鹿/
かぶしきがいしゃとうしば /株式会社東芝/
かぶしきこうかい /株式公開/
かぶしきしじょう /株式市場/
かぶしきそうばじょうほう /株式相場情報/
かぶしきとうし /株式投資/
かぶそく /過不足/
かぶそしき /下部組織/
かぶだん /歌舞団/
かぶと /兜/甲/加太/
かぶとえび /兜海老/
かぶとちょう /兜町/
かぶとやま /甲山/
かぶぬし /株主/
かぶぬしけん /株主権/
かぶぬしそうかい /株主総会/
かぶぬしゆうたい /株主優待/
かぶぬしゆうたいけん /株主優待券/
かぶばいきゃく /株売却/
かぶや /株屋/
かぶら /鏑/蕪/
かぶらぎ /鏑木/
かぶわけ /株分け/
かぶん /寡聞/過分/可分/
かぶんすう /仮分数/
かぷせる /カプセル/
かぷせるか /カプセル化/
かへい /貨幣/貨弊/加平/花柄/
かへいかち /貨幣価値/
かへいしゃかい /貨幣社会/
かへいた /嘉平太/
かへえ /嘉兵衛/
かへん /可変/下辺/佳篇/
かへんかそく /可変加速/
かへんこ /可変個/
かへんご /可変語/
かへんしき /可変式/
かへんそく /可変速/
かへんそくくどう /可変速駆動/
かへんちょう /可変長/
かへんていこう /可変抵抗/
かへんてき /可変的/
かへんはば /可変幅/
かへんらんくほう /可変ランク法/
かべ /壁/璧/可部/
かべいちめん /壁一面/
かべかけ /壁掛け/
かべがみ /壁紙/
かべがわ /壁側/
かべぎわ /壁際/
かべぎわしき /壁際式/
かべせん /可部線/
かべもと /河部本/
かべん /花弁/
かほ /果歩/嘉穂/
かほう /下方/果報/加法/家宝/火砲/
かほうこう /下方向/
かほうしゅうせい /下方修正/
かほうせい /加法性/
かほうちゅうおう /下方中央/
かほうていり /加法定理/
かほうてき /加法的/
かほうでん /過放電/
かほうもの /果報者/
かほうわ /過飽和/
かほく /河北/可北/華北/香北/鹿北/
かほくしゅっしん /華北出身/
かほくしょう /河北省/
かほくしんぽう /河北新報/
かほくしんりゃく /華北侵略/
かほくじへん /華北事変/
かほくじん /華北人/
かほくちほう /華北地方/
かほこうつう /嘉穂交通/
かほご /過保護/
かほり /佳保里/
かぼう /苛暴/
かぼちゃ /南瓜/
かま /鎌/釜/蒲/竃/窯/竈/窰/罐/釡/
かまい /釜井/
かまいし /釜石/
かまいたち /鎌鼬/
かまえ /釜江/鎌江/構え/蒲江/
かまがさき /釜ケ崎/
かまがた /鎌形/
かまがや /鎌谷/鎌ヶ谷/
かまがやし /鎌ヶ谷市/
かまがり /蒲刈/
かまきり /螳螂/蟷螂/
かまくら /鎌倉/
かまくらえき /鎌倉駅/
かまくらがくえんこうこう /鎌倉学園高校/
かまくらげんじ /鎌倉源氏/
かまくらこ /鎌倉湖/
かまくらし /鎌倉市/
かまくらしゅうへん /鎌倉周辺/
かまくらじだい /鎌倉時代/
かまくらばくふ /鎌倉幕府/
かまくらぼり /鎌倉彫/
かます /鰤/叺/
かまた /鎌田/蒲田/
かまたえき /蒲田駅/
かまたがわ /蒲田側/
かまたこうしんきょく /蒲田行進曲/
かまたじょし /蒲田女子/
かまたせん /蒲田線/
かまたほうめん /蒲田方面/
かまたり /鎌足/
かまだ /鎌田/
かまち /蒲地/框/蒲池/
かまとと /蒲魚/
かまとり /鎌取/
かまど /竃/竈/
かまはら /鎌原/
かまふさ /釜房/
かまべ /鎌部/
かまぼこ /蒲鉾/
かまぼこや /蒲鉾屋/
かまもと /窯元/釜本/鎌本/
かみ /紙/神/髪/上/加味/可美/加美/香美/守/帋/髮/祇/
かみい /神居/
かみいいざか /上飯坂/
かみいいだ /上飯田/
かみいけだい /上池台/
かみいしづ /上石津/
かみいしはら /上石原/
かみいずみ /神泉/
かみいそ /上磯/
かみいた /上板/
かみいち /上市/
かみいな /上伊那/
かみうけな /上浮穴/
かみうま /上馬/
かみうら /上浦/
かみえしゅう /上江洲/
かみお /神尾/
かみおおおか /上大岡/
かみおか /上岡/神岡/
かみおかりゅうたろう /上岡龍太郎/
かみおだいえき /上小田井駅/
かみおぼろ /上尾幌/
かみかくし /神隠/神隠し/
かみかざり /髪飾り/
かみかせだ /上加世田/
かみかぜ /神風/
かみかつ /上勝/
かみかやく /紙火薬/
かみかわ /上川/神川/
かみかわち /上河内/
かみがかり /神懸/神懸り/神憑/
かみがた /髪型/髪形/上方/紙型/
かみがみ /神々/
かみがや /神ケ谷/
かみき /上期/
かみきた /上北/
かみきたざわ /上北沢/
かみきたやま /上北山/
かみきょうく /上京区/
かみきれ /紙切/紙切れ/
かみぎょう /上京/
かみぎれ /紙切れ/
かみくいしき /上九一色/
かみくいしきむら /上九一色村/
かみくず /紙屑/
かみくずどうぜん /紙屑同然/
かみくまもとえきまえ /上熊本駅前/
かみぐみ /上組/
かみこうす /上口洲/
かみこうち /上高地/
かみこしき /上甑/
かみこっぷ /紙コップ/
かみごうり /上郡/
かみごおり /上郡/
かみごとう /上五島/
かみさいばら /上斉原/
かみさかえまち /上栄町/
かみさと /上郷/上里/
かみさま /神様/
かみさんごう /上参郷/
かみざ /上座/
かみざき /神崎/
かみざわ /上澤/
かみしつ /紙質/
かみしばい /紙芝居/
かみしばいてき /紙芝居的/
かみしばいなみ /紙芝居並/
かみしひ /上志比/
かみしほろ /上士幌/
かみしま /上島/
かみしも /裃/上下/
かみしゃちょう /神社長/
かみしろ /上代/神代/神城/
かみしろえき /神城駅/
かみじま /上島/
かみじゅうじょう /上十条/
かみじょう /上條/神城/上条/
かみす /神栖/
かみすぎ /上杉/
かみすながわ /上砂川/
かみすわ /上諏訪/
かみすわえき /上諏訪駅/
かみずる /上水流/
かみせい /紙製/
かみせいひん /紙製品/
かみそうやぎ /上草柳/
かみそり /剃刀/
かみた /上田/
かみたいせん /神大戦/
かみたいら /上平/
かみたかい /上高井/
かみたから /上宝/
かみだい /紙代/
かみだな /神棚/
かみだのみ /神頼み/
かみつ /上津/過密/
かみつか /神塚/
かみつが /上都賀/
かみつしま /上対馬/
かみつせん /花蜜腺/
かみつな /上綱/
かみつるま /上鶴間/
かみづか /神塚/
かみづる /上水流/
かみて /上手/
かみてきせかい /神的世界/
かみで /上出/
かみとばぐち /上鳥羽口/
かみとり /神取/
かみとんだ /上富田/
かみなか /上中/上那賀/
かみなが /神永/神長/
かみなべ /神鍋/
かみなり /雷/
かみにいかわ /上新川/
かみにいかわぐん /上新川郡/
かみにし /上西/
かみにんぎょう /紙人形/
かみぬま /上沼/
かみねんど /紙粘土/
かみのかわ /上三川/
かみのく /上の句/
かみのくに /上ノ国/
かみのけ /髪の毛/
かみのげ /上野毛/
かみのこ /神の子/
かみのせき /上関/
かみのほ /上之保/
かみのやま /上山/
かみのやまけいゆ /上山経由/
かみはやし /神林/
かみはら /神原/
かみはんき /上半期/
かみはんきえいが /上半期映画/
かみはんきしゃしんしゅう /上半期写真集/
かみばこ /紙箱/
かみばやし /上林/
かみひこうき /紙飛行機/
かみひとえ /紙一重/
かみふうせん /紙ふうせん/紙風船/
かみふくおか /上福岡/
かみふぶき /紙吹雪/
かみふらの /上富良野/
かみぶくろ /紙袋/
かみへい /上閉伊/
かみまえづ /上前津/
かみまき /紙巻/紙巻き/
かみみず /上水/
かみみぞ /上溝/
かみみね /上峰/
かみむ /上無/
かみむら /上村/神村/
かみもと /神本/
かみや /神谷/紙屋/上谷/
かみやく /上屋久/
かみやしろ /上社/
かみやちょう /紙屋町/神谷町/
かみやま /神山/上山/
かみやまだ /上山田/
かみやまだせん /上山田線/
かみやまちしゅうへん /紙屋町周辺/
かみゆい /髪結い/
かみゆうべつ /上湧別/
かみゆそうれっしゃ /紙輸送列車/
かみよ /神余/
かみよもじ /神世文字/
かみわざ /神技/
かみわざてき /神技的/
かみん /仮眠/
かみんきゅうけい /仮眠休憩/
かみんしつ /仮眠室/
かみんじょ /仮眠所/
かみんちゅう /仮眠中/
かむい /神居/
かめ /亀/日目/龜/瓶/甕/
かめあり /亀有/
かめい /仮名/加盟/亀井/下命/家名/下名/課名/
かめいがいしゃ /加盟会社/
かめいきじゅん /加盟基準/
かめいこく /加盟国/
かめいし /亀石/
かめいしんせい /加盟申請/
かめいちょう /亀井町/
かめいてん /加盟店/
かめいど /亀戸/
かめいの /亀井野/
かめいりょう /加盟料/
かめお /亀夫/
かめおか /亀岡/
かめがた /亀型/
かめきち /亀吉/
かめさき /亀崎/
かめじま /亀島/
かめじろう /亀次郎/
かめたろう /亀太郎/
かめだ /亀田/
かめの /亀野/
かめのすけ /亀之助/
かめまん /亀萬/
かめや /亀谷/亀屋/
かめやま /亀山/
かめやまかん /亀山間/
かめやまこ /亀山湖/
かめやまんねんどう /亀屋万年堂/
かめら /カメラ/
かめん /仮面/下面/
かめんげき /仮面劇/
かめんぶとうかい /仮面舞踏会/
かも /鴨/加茂/賀茂/鳧/鳬/
かもい /鴨居/神威/鴨井/
かもう /蒲生/
かもえ /鴨江/
かもえない /神恵内/
かもがた /鴨方/
かもがわ /鴨川/賀茂川/
かもく /科目/寡黙/課目/
かもくきん /火木金/
かもくすう /科目数/
かもくど /火木土/
かもくべつ /科目別/
かもくめい /科目名/
かもしか /羚羊/
かもした /鴨下/
かもしだ /鴨志田/
かもじ /髢/
かもじま /鴨島/
かもだ /加守田/
かもつ /貨物/
かもつうんちん /貨物運賃/
かもつえき /貨物駅/
かもつしつ /貨物室/
かもつしゃ /貨物車/
かもつしゃとうろく /貨物車登録/
かもつしゃりょう /貨物車両/
かもつじこくひょう /貨物時刻表/
かもつせん /貨物船/貨物線/
かもつせんけいゆ /貨物線経由/
かもつせんようせん /貨物専用線/
かもつでんしゃ /貨物電車/
かもつはいし /貨物廃止/
かもつびん /貨物便/
かもつゆそう /貨物輸送/
かもつよう /貨物用/
かもつる /賀茂鶴/
かもつれっしゃ /貨物列車/
かもつれっしゃはいし /貨物列車廃止/
かもづる /賀茂鶴/
かもと /鹿本/
かもなくふかもなく /可もなく不可もなく/
かもにく /鴨肉/
かもねぎ /鴨葱/
かものみや /鴨宮/
かもみーる /カモミール/
かもみや /鴨宮/
かもめ /鴎/カモメ/
かもん /嘉門/家紋/厦門/家門/
かもんのかみ /掃部頭/
かや /萱/茅/蚊帳/榧/伽耶/加悦/栢/
かやく /火薬/化薬/可約/
かやくき /可約基/
かやしま /萱島/萱嶋/
かやつりぐさもく /カヤツリグサ目/Cyperales/
かやなま /金山/
かやの /栢野/
かやはら /栢原/
かやばちょう /茅場町/
かやべ /茅部/
かやま /加山/香山/
かやまゆうぞう /加山雄三/
かやもり /萱森/
かゆ /粥/糜/
かゆかん /粥羹/
かよ /佳世/佳代/加代/香代/嘉代/
かよう /火曜/歌謡/加陽/可容/斯樣/賀陽/花葉/
かようかい /歌謡界/
かようきくざけ /加陽菊酒/
かようきょく /歌謡曲/
かようきょくかんけい /歌謡曲関係/
かようきょくふう /歌謡曲風/
かようさい /歌謡祭/
かようしゅう /歌謡集/
かようせい /可用性/可溶性/
かようせんしゅけん /歌謡選手権/
かようばんぐみ /歌謡番組/
かようび /火曜日/
かよこ /佳代子/加世子/夏代子/加代子/佳世子/
から /〜/空/唐/殻/柄/殼/→/伽羅/
から> /空/
からー /カラー/
からーえきしょう /カラー液晶/
からあげ /空揚げ/唐揚げ/唐揚/
からうま /空馬/
からおけ /カラオケ/
からかね /唐銅/
からかわ /唐川/
からき /唐木/
からきだ /唐木田/
からぎょう /空行/
からくさ /唐草/
からくさもよう /唐草模様/
からくち /辛口/
からくわ /唐桑/
からけん /空券/
からげいき /空景気/
からげんき /空元気/
からこるむ /和林/
からさき /唐崎/
からさわ /唐沢/柄沢/唐澤/
からさわぎ /空騒ぎ/
からし /辛子/芥子/
からしじょうゆ /辛子醤油/
からしま /辛島/
からしまちょう /辛島町/
からじし /唐獅子/
からす /烏/カラス/鴉/香良洲/
からすま /烏丸/
からすまきたおおじ /烏丸北大路/
からすまごじょう /烏丸五条/
からすましじょう /烏丸四条/
からすましゃこ /烏丸車庫/
からすません /烏丸線/
からすまななじょう /烏丸七条/
からすままつばら /烏丸松原/
からすままるたまち /烏丸丸太町/
からすやま /烏山/
からすやまとしょかん /烏山図書館/
からぜき /空咳/
からそうば /空相場/
からたけわり /幹竹割り/
からたち /枳殻/
からだ /体/身体/躯/躰/軆/體/
からだき /空焚き/
からだじたい /体自体/
からだじゅう /体中/
からだぜんたい /体全体/
からだつき /身体つき/
からだづくり /体作り/
からっぽ /空っぽ/
からつ /唐津/
からつきたまご /殻付卵/
からつせん /唐津線/
からつゆ /空梅雨/
からづみ /空積み/
からて /空手/
からてか /空手家/
からてがた /空手形/
からてばか /空手バカ/
からてばかいちだい /空手バカ一代/
からてわざ /空手技/
からてんじく /唐天竺/
からでんぴょう /空伝票/
からとりひき /空取引/
からなみだ /空涙/
からに /空荷/
からはし /唐橋/
からはふ /唐破風/
からばこ /空箱/
からびん /空瓶/
からふと /樺太/
からぶり /空振/空振り/
からまつ /唐松/
からまつそうあか /カラマツソウ亜科/Thalictoideae/
からまつだけ /唐松岳/
からまわり /空回り/
からみ /絡み/
からみそ /辛味噌/
からむ /カラム/
からめ /辛目/
からめて /搦め手/搦手/
からもじ /空文字/
からもじれつ /空文字列/
からもの /唐物/
からやくそく /空約束/
からやま /唐山/
からやまちょう /唐山町/
からようき /空容器/
からん /下欄/
かり /仮/刈/狩/苅/雁/借り/狩り/猟/加里/假/獵/鴈/鳫/
かり> /仮/
かりあげ /借り上げ/刈り上げ/
かりあげしゃたく /借り上げ社宅/
かりいれ /借入れ/
かりいれきん /借入金/
かりいれきんかんけい /借入金関係/
かりうけ /借受け/借受/
かりうど /狩人/
かりえき /仮駅/
かりかいいんしょう /仮会員証/
かりかし /借り貸し/
かりかた /借方/
かりかぶ /借株/
かりかんじ /仮幹事/
かりかんじょう /仮勘定/
かりきん /借り金/
かりけっさん /仮決算/
かりけんていじっし /仮検定実施/
かりこ /雁子/
かりこし /借り越し/借越/
かりこみ /刈込/苅込/
かりさかとうげ /雁坂峠/
かりしっこう /仮執行/
かりしどう /仮始動/
かりしゃくほう /仮釈放/
かりしゅひ /仮種皮/
かりしょぶん /仮処分/
かりすま /カリスマ/
かりずまい /仮住い/仮住まい/
かりせいさん /仮精算/
かりた /苅田/
かりたこう /苅田港/
かりだ /刈田/
かりだな /仮柵/
かりち /借り地/
かりちゅうしん /仮中心/
かりちょういん /仮調印/
かりちん /借り賃/
かりて /借り手/借手/
かりていも /訶梨帝母/
かりてんぽ /仮店舗/
かりとうき /仮登記/
かりとりき /刈取機/
かりに /仮に/
かりにゅうもん /仮入門/
かりぬい /仮縫い/
かりぬし /借り主/
かりはいせん /仮配線/
かりはいぞく /仮配属/
かりはく /仮泊/
かりば /狩場/
かりばら /借腹/
かりばらい /仮払/仮払い/
かりばらいきん /仮払金/
かりひきすう /仮引数/
かりぶかい /カリブ海/
かりへんすう /仮変数/
かりめん /仮免/
かりめんきょ /仮免許/
かりもの /借り物/
かりゃく /下略/
かりや /刈谷/狩谷/雁屋/借り家/仮屋/苅屋/
かりやし /刈谷市/
かりゅう /下流/顆粒/渦流/河流/火竜/
かりゅういき /下流域/
かりゅうかい /花柳界/花柳街/
かりゅうしほう /加粒子砲/
かりゅうじょう /顆粒状/
かりゅうせい /顆粒性/
かりゅうど /狩人/
かりょう /科料/加療/
かりょく /火力/
かりょくせん /火力船/
かりょくはつでん /火力発電/
かりょくはつでんき /火力発電機/
かりょくはつでんしょ /火力発電所/
かりょくぶそく /火力不足/
かりよやく /仮予約/
かりわ /刈羽/
かりわたし /仮渡し/
かりわりあて /仮割当/
かりん /華鈴/花櫚/可憐/
かる /軽/刈/苅/輕/狩/
かるい /科類/
かるいさわ /軽井沢/
かるいざわ /軽井沢/
かるいざわか /軽井沢化/
かるいざわちゃく /軽井沢着/
かるいざわちょう /軽井沢町/
かるいざわはつ /軽井沢発/
かるいし /軽石/
かるがる /軽々/
かるくち /軽口/
かるさ /軽さ/
かるた /骨牌/歌留多/
かるひと /狩人/
かるまい /軽米/
かるめ /軽目/
かるめん /カルメン/
かるら /迦楼羅/
かるわざ /軽業/
かれ /彼/涸/
かれー /カレー/
かれーこ /カレー粉/
かれーや /カレー屋/
かれあて /彼宛/
かれい /華麗/鰈/鰔/加齢/
かれいい /餉/
かれいきゃく /過冷却/
かれいけん /加齢研/
かれいすい /加冷水/
かれいせい /加齢性/
かれいど /カレイド/
かれき /枯れ木/枯木/
かれくさ /枯れ草/
かれさわ /涸沢/
かれさんすい /枯山水/
かれし /彼氏/
かれしかのじょ /彼氏彼女/
かれじしん /彼自身/
かれつ /苛烈/
かれは /枯葉/
かれはいろ /枯葉色/
かれはざい /枯葉剤/
かれひとり /彼一人/
かれら /彼等/彼ら/彼達/
かれん /可憐/苛斂/
かれんだー /カレンダー/
かれんちゅうきゅう /苛斂誅求/
かれんと /カレント/
かろう /過労/家老/
かろううんてん /過労運転/
かろうぎみ /過労気味/
かろうし /過労死/
かろうじょうたい /過労状態/
かろりー /カロリー/
かわ /川/皮/河/側/革/巛/
かわい /川合/河合/可愛/河井/川井/可哀/川相/
かわいい /可愛い/
かわいがっき /河合楽器/
かわいじゅく /河合塾/
かわいそう /可哀想/可愛いそう/可愛相/可哀相/
かわいだ /川井田/
かわいちょう /河合町/
かわいで /河出/
かわうえ /川上/
かわうそ /川獺/
かわうち /川内/河内/
かわうちじゅうたく /川内住宅/
かわうちちく /川内地区/
かわうら /川浦/河浦/
かわかぜ /川風/
かわかつ /川勝/
かわかみ /川上/河上/
かわがわ /川側/
かわきた /川北/河北/
かわきゅう /川久/
かわぎし /川岸/
かわくぼ /川久保/
かわくら /川倉/
かわぐち /川口/河口/
かわぐちえきまえ /川口駅前/
かわぐちこ /河口湖/
かわぐちこせん /河口湖線/
かわぐちこふきん /河口湖付近/
かわぐちし /川口市/
かわぐちとつか /川口戸塚/
かわぐつ /革靴/
かわけ /河毛/
かわげ /河芸/
かわごえ /川越/川越え/
かわごえかいどう /川越街道/
かわごえし /川越市/
かわごえせん /川越線/
かわごえでんしゃく /川越電車区/
かわごえほうめん /川越方面/
かわごえゆき /川越行/
かわごけそうもく /カワゴケソウ目/Podostemonales/
かわさき /川崎/河崎/川嵜/
かわさきえき /川崎駅/
かわさきえききたぐち /川崎駅北口/
かわさきかいどう /川崎街道/
かわさきかせい /川崎化成/
かわさきかん /川崎間/
かわさきがわ /川崎側/
かわさききゅうじょう /川崎球場/
かわさききんぺん /川崎近辺/
かわさきく /川崎区/
かわさきくない /川崎区内/
かわさきけいばじょう /川崎競馬場/
かわさきけいゆう /川崎経由/
かわさきけんきゅうじょ /川崎研究所/
かわさきこう /川崎港/
かわさきこうえん /川崎公演/
かわさきこうじょう /川崎工場/
かわさきざいじゅう /川崎在住/
かわさきし /川崎市/
かわさきしあそうく /川崎市麻生区/
かわさきしえい /川崎市営/
かわさきしさいわいく /川崎市幸区/
かわさきしざいじゅう /川崎市在住/
かわさきししんまるこ /川崎市新丸子/
かわさきしたまく /川崎市多摩区/
かわさきしでん /川崎市電/
かわさきしない /川崎市内/
かわさきしないえき /川崎市内駅/
かわさきしなかはらく /川崎市中原区/
かわさきしほくぶ /川崎市北部/
かわさきしみん /川崎市民/
かわさきしりつ /川崎市立/
かわさきじゅうこう /川崎重工/
かわさきじゅうこうぎょう /川崎重工業/
かわさきせいてつ /川崎製鉄/川崎製鐵/
かわさきせきゆ /川崎石油/
かわさきせん /川崎戦/
かわさきぞうせん /川崎造船/
かわさきだいし /川崎大師/
かわさきちょう /川崎町/
かわさきてん /川崎店/
かわさきはつとうきょういき /川崎発東京行/
かわさきはつとうきょうゆき /川崎発東京行/
かわさきほうめん /川崎方面/
かわさと /川里/
かわざかな /川魚/
かわざんよう /皮算用/
かわしげ /川重/
かわしま /川島/川嶋/河嶋/河島/
かわしまおりもの /川島織物/
かわしも /川下/
かわしもがわ /川下側/
かわじ /川路/川治/
かわじおんせん /川治温泉/
かわじま /川島/
かわじり /川尻/
かわすぎ /川杉/
かわず /川津/蛙/河津/
かわせ /為替/川瀬/河瀬/川背/
かわせい /革製/
かわせいひん /皮製品/革製品/
かわせてがた /為替手形/
かわせみ /カワセミ/翡/
かわそえ /川副/
かわぞい /河沿/
かわぞえ /川添/河添/
かわぞこ /川底/
かわた /川田/河田/
かわたな /川棚/
かわたび /川渡/川旅/
かわだ /川田/河田/
かわだいら /川平/
かわだちょう /河田町/
かわち /河内/
かわちおんど /河内音頭/
かわちながの /河内長野/
かわちべん /河内弁/
かわちや /河内谷/河内屋/
かわつ /川津/
かわつこう /川津港/
かわづ /川津/河津/
かわづがけ /河津掛け/
かわづはな /川津花/
かわてつ /川鉄/
かわで /河出/
かわでしょぼう /河出書房/
かわでしょぼうしんしゃ /河出書房新社/
かわでぶんこ /河出文庫/
かわと /川人/
かわとう /川東/川藤/
かわな /川名/川奈/
かわなか /川中/
かわなかじま /川中島/
かわなざき /川奈崎/
かわなべ /川辺/川鍋/
かわなみ /川波/
かわにし /川西/河西/
かわにしがわりゅういき /川西側流域/
かわにしし /川西市/
かわにしのせぐち /川西能勢口/
かわにしひこうき /川西飛行機/
かわぬま /河沼/
かわね /川根/
かわの /河野/川野/
かわのえ /川之江/
かわのべ /河之邊/
かわはた /河鰭;姓。かわばた、とも/
かわはば /川幅/
かわはま /川浜/
かわはら /川原/河原/
かわば /川場/
かわばた /川端;姓/川畑;姓/川幡;姓/河端;姓/河鰭;姓。かわはた、とも/
かわばり /皮張り/
かわひがし /河東/川東/
かわひと /川人/
かわひも /皮紐/
かわひら /川平/
かわふく /川副/川福/
かわふじ /川藤/
かわぶくろ /革袋/皮袋/
かわぶち /川淵/
かわべ /河辺/川邉/川辺/川部/川邊/河邊/川連/
かわまえちょう /川前町/
かわまた /川又/川俣/
かわまたせん /川俣線/
かわみ /川見/
かわみなみ /川南/
かわみや /河宮/
かわむら /川村/河村/
かわむらこうこう /川村高校/
かわも /川面/
かわもと /川本/河本/川元/
かわもり /川森/
かわや /厠/廁/
かわよう /革用/川用/
かわら /川原/河原/瓦/磧/香春/
かわらい /河原井/
かわらがはま /瓦ケ浜/
かわらけ /土器/
かわらだ /河原田/
かわらばん /かわら版/
かわらまち /河原町/
かわらまちいまでがわ /河原町今出川/
かわらまちごじょう /河原町五条/
かわらまちせん /河原町線/
かわらもの /河原者/
かわり /代わり/変わり/
かわりだね /変わり種/
かわりめ /変り目/変わり目/
かわりやく /代役/
かわわ /川和/
かわわせん /河和線/
かわわちょう /川和町/
かわん /下腕/
かん /間/館/感/巻/管/関/観/完/換/甘/寛/鑑/貫/還/緩/艦/缶/陥/函/簡/環/舘/閑/肝/歓/看/監/官/勘/漢/韓/幹/汗/刊/莞/諌/慣/姦/翰/桓/菅/竿/潅/澗/乾/干/患/敢/甲/柑/款/憾/棺/勧/寒/煥/冠/堪/喚/侃/浣/杆/丱/凾/勸/卷/厂/咸/啣/喊/坎/坩/奐/奸/嫺/嫻/宦/寰/嵌/悍/懽/戡/扞/拑/捍/揀/撼/旱/柬/桿/橄/樌/歛/歡/涵/淦/渙/灌/澣/瀚/燗/疳/癇/皖/盥/瞰/稈/箝/篏/繝/罐/罕/羹/羮/艱/莟/蒄/觀/諫/讙/豢/轗/邯/酣/鉗/鐶/鑒/鑵/關/陷/駻/驩/骭/鰥/鸛/鹹/槓/潤/神/康/
かん< /間/
かん> /間/
かんあく /奸悪/
かんあつ /缶圧/感圧/
かんあつしき /感圧式/
かんあつどうでんそし /感圧導電素子/
かんあん /勘案/
かんい /簡易/官位/簡意/
かんいか /簡易化/
かんいかぜいせいど /簡易課税制度/
かんいがた /簡易型/
かんいけいたいでんわ /簡易携帯電話/
かんいけんさ /簡易検査/
かんいこうしゅう /簡易講習/
かんいさいせいきこう /簡易再生機構/
かんいさいばん /簡易裁判/
かんいしき /簡易式/
かんいしんぱん /簡易新版/
かんいち /貫一/乾一/
かんいっぱつ /間一髪/
かんいてき /簡易的/
かんいばん /簡易版/
かんいほうしき /簡易方式/
かんいほけん /簡易保険/
かんいほけんきょく /簡易保険局/
かんいほけんほーる /簡易保険ホール/
かんいむきょうしつ /簡易無響室/
かんいむせん /簡易無線/
かんいり /缶入/
かんいれいぼう /簡易冷房/
かんいん /館員/姦淫/
かんいんりょう /缶飲料/
かんう /関羽;三国時代・蜀漢の武将/
かんえい /寛永/官営/
かんえいてつどう /官営鉄道/
かんえいにち /漢英日/
かんえつ /関越/観閲/
かんえつこうそく /関越高速/
かんえつじどうしゃどう /関越自動車道/
かんえつどう /関越道/
かんえん /肝炎/
かんおう /陥凹/
かんおけ /棺桶/
かんおん /感音/漢音/
かんおんけい /感音系/
かんおんけいなんちょう /感音系難聴/
かんおんじ /観音寺/
かんか /感化/看過/干戈/管下/坩堝/旱戈/乾果/柑果/閑暇/
かんかく /間隔/感覚/　/
かんかくき /感覚器/
かんかくきかん /感覚器官/
かんかくけい /感覚系/
かんかくさいぼう /感覚細胞/
かんかくしょうせつ /感覚小説/
かんかくしんけい /感覚神経/
かんかくじゅよう /感覚受容/
かんかくじょう /感覚上/
かんかくじょうほう /感覚情報/
かんかくせい /感覚性/
かんかくだいこう /感覚代行/
かんかくてき /感覚的/
かんかくてきいみ /感覚的意味/
かんかくてきりかい /感覚的理解/
かんかくにゅうりょく /感覚入力/
かんかくもう /感覚毛/
かんかくもじ /間隔文字/
かんかつ /管轄/管割/寛闊/
かんかつえいぎょうしょ /管轄営業所/
かんかつか /管轄下/
かんかつがい /管轄外/
かんかつじこう /管轄事項/
かんかん /灌灌/
かんかんがくがく /侃々諤々/侃侃諤諤/
かんが /官衙/
かんがい /感慨/潅がい/寒害/干害/潅漑/灌漑/館外/
かんがいむりょう /感慨無量/
かんがえ /考え/
かんがえかた /考え方/
かんがえちゅう /考え中/
かんがく /関学/漢学/
かんがくがわ /関学側/
かんがくこう /関学高/
かんがくせん /関学戦/
かんがくで /関学出/
かんがっき /管楽器/
かんがっきかんけい /管楽器関係/
かんがっきそうしゃ /管楽器奏者/
かんがん /宦官/汗顔/
かんき /歓喜/換気/乾期/寒気/喚起/乾季/間期/
かんきこう /換気孔/
かんきせん /換気扇/
かんきだん /歓喜団/寒気団/
かんきち /乾吉/
かんきつ /柑橘/
かんきつけい /柑橘系/
かんきつるい /柑橘類/
かんきのう /肝機能/
かんきゃく /観客/
かんきゃくすう /観客数/
かんきゃくせき /観客席/
かんきゃくどういん /観客動員/
かんきゃくどういんすう /観客動員数/
かんきゃくにんずう /観客人数/
かんきゅう /緩急/
かんきゅうけつごう /緩急結合/
かんきゅうけつごうがた /緩急結合型/
かんきゅうしゃ /緩急車/
かんきゅうじざい /緩急自在/
かんきゅうせつぞく /緩急接続/
かんきゅうぶんり /緩急分離/
かんきゅうほう /緩急法/
かんきゅうれんらく /緩急連絡/
かんきょ /官許/閑居/
かんきょう /環境/感興/艦橋/
かんきょうあっか /環境悪化/
かんきょうえいきょうち /環境影響値/
かんきょうおせん /環境汚染/
かんきょうおん /環境音/
かんきょうか /環境下/
かんきょうかいぜん /環境改善/
かんきょうかいはつ /環境開発/
かんきょうかいはつか /環境開発課/
かんきょうかいはつけいかく /環境開発計画/
かんきょうかいはつぶ /環境開発部/
かんきょうかんれん /環境関連/
かんきょうがくけんきゅうか /環境学研究科/
かんきょうきじゅん /環境基準/
かんきょうきょういくばんぐみ /環境教育番組/
かんきょうけい /環境系/
かんきょうけいかくがっか /環境計画学科/
かんきょうけん /環境研/
かんきょうけんきゅうじょ /環境研究所/
かんきょうこう /環境光/
かんきょうこうがい /環境公害/
かんきょうこうがく /環境工学/
かんきょうこうがくこうざ /環境工学講座/
かんきょうこうげん /環境抗原/
かんきょうこうせきしょう /環境功績賞/
かんきょうさ /環境差/
かんきょうざつおん /環境雑音/
かんきょうしだい /環境次第/
かんきょうしょう /環境省;環境庁、厚生省が2001年1月の中央省庁再編で再編されたもの/
かんきょうじゅうし /環境重視/
かんきょうじょう /環境上/
かんきょうじょうか /環境浄化/
かんきょうじょうけん /環境条件/
かんきょうじょうほう /環境情報/
かんきょうじょうほうがくぶ /環境情報学部/
かんきょうせいび /環境整備/
かんきょうせってい /環境設定/
かんきょうせっていち /環境設定値/
かんきょうせっていちゅう /環境設定中/
かんきょうせっていよう /環境設定用/
かんきょうせん /関京戦/
かんきょうそうおん /環境騒音/
かんきょうたいけつ /関京対決/
かんきょうたいさく /環境対策/
かんきょうちゅう /環境中/
かんきょうちょう /環境庁;2001年1月の中央省庁再編で環境省に再編された/
かんきょうちょうかん /環境長官/
かんきょうちょうこくじ /環境庁告示/
かんきょうちょうちょうかん /環境庁長官/
かんきょうてき /環境的/
かんきょうはかい /環境破壊/
かんきょうはかいかつどう /環境破壊活動/
かんきょうびか /環境美化/
かんきょうへんか /環境変化/
かんきょうへんすう /環境変数/
かんきょうへんすういき /環境変数域/
かんきょうへんすうせってい /環境変数設定/
かんきょうへんすうめい /環境変数名/
かんきょうへんすうりょういき /環境変数領域/
かんきょうほご /環境保護/
かんきょうほごうんどう /環境保護運動/
かんきょうほごきょく /環境保護局/
かんきょうほごぜい /環境保護税/
かんきょうほごたいさく /環境保護対策/
かんきょうほごだんたい /環境保護団体/
かんきょうほごもんだい /環境保護問題/
かんきょうほぜん /環境保全/
かんきょうめい /環境名/
かんきょうもんだい /環境問題/
かんきょうもんだいいっぱん /環境問題一般/
かんきり /缶切り/
かんきりょう /換気量/
かんきん /換金/監禁/桿菌/看経/
かんきんか /換金化/
かんきんかのう /換金可能/
かんきんきゃく /換金客/
かんきんきんし /換金禁止/
かんきんこうい /換金行為/
かんきんご /換金後/
かんきんごや /換金小屋/
かんきんじょ /換金所/
かんきんせい /換金性/
かんきんせいど /換金制度/
かんきんとばく /換金賭博/
かんきんばいりつ /換金倍率/
かんきんばしょ /換金場所/
かんきんもんだい /換金問題/
かんきんよう /換金用/
かんきんりつ /換金率/
かんぎく /観菊/
かんぎてん /歓喜天/
かんぎょう /勧業/官業/鑑行/
かんぎん /勧銀/
かんく /管区/
かんくう /管腔/関空/
かんくうかいそく /関空快速/
かんくうはつ /関空発/
かんぐん /官軍/
かんけい /関係/奸計/換刑/環形/
かんけいあっか /関係悪化/
かんけいあり /関係有/
かんけいいがい /関係以外/
かんけいえんざんし /関係演算子/
かんけいかいしょうご /関係解消後/
かんけいかくい /関係各位/
かんけいかくしょ /関係各所/
かんけいかくほうめん /関係各方面/
かんけいかんちょう /関係官庁/
かんけいがいしゃ /関係会社/
かんけいがた /関係型/
かんけいがっかい /関係学会/
かんけいきかん /関係機関/
かんけいけいさん /関係計算/
かんけいさき /関係先/
かんけいざっし /関係雑誌/
かんけいし /関係詞/
かんけいしき /関係式/
かんけいしつど /関係湿度/
かんけいしゃ /関係者/
かんけいしゃかくい /関係者各位/
かんけいしゃそうご /関係者相互/
かんけいしゃふう /関係者風/
かんけいしゅうふく /関係修復/
かんけいしょうちょう /関係省庁/
かんけいしょかんちょう /関係諸官庁/
かんけいしょこく /関係諸国/
かんけいしょし /関係諸氏/
かんけいしょせき /関係書籍/
かんけいしょるい /関係書類/
かんけいじちたい /関係自治体/
かんけいじょう /関係上/
かんけいすう /関係数/
かんけいず /関係図/
かんけいせい /関係性/
かんけいせつ /関係節/
かんけいだいすう /関係代数/
かんけいだいめいし /関係代名詞/
かんけいだんたい /関係団体/
かんけいてき /関係的/
かんけいどうぶつ /環形動物/
かんけいひん /関係品/
かんけいぶしょ /関係部所/
かんけいぶんけん /関係文献/
かんけいほうき /関係法規/
かんけいろん /関係論/
かんけつ /簡潔/完結/間欠/観血/間歇/
かんけつおん /間欠音/
かんけつか /簡潔化/
かんけつきねん /完結記念/
かんけつせい /簡潔性/
かんけつせん /間欠泉/
かんけつてき /間欠的/
かんけつへん /完結編/
かんけつほうにょう /間歇放尿/
かんけん /官憲/換券/
かんげい /歓迎/
かんげいかい /歓迎会/
かんげき /感激/観劇/間隙/
かんげきかい /観劇会/
かんげきこうかくそしき /間隙厚角組織/
かんげきてき /感激的/
かんげきど /感激度/
かんげん /還元/管弦/換言/甘言/諌言/管絃/
かんげんかのうせい /還元可能性/
かんげんがく /管弦楽/
かんげんがくきょく /管弦楽曲/
かんげんがくさくひん /管弦楽作品/
かんげんがくしょほう /管弦楽書法/
かんげんがくだん /管弦楽団/
かんげんがくばん /管弦楽版/
かんげんがくへんきょく /管弦楽編曲/
かんげんがくほう /管弦楽法/
かんげんがっき /管弦楽器/
かんげんがっきょく /管弦楽曲/
かんげんこうか /還元効果/
かんげんさよう /還元作用/
かんげんしゅぎ /還元主義/
かんげんしゅぎひはん /還元主義批判/
かんげんぶん /還元分/
かんげんろん /還元論/
かんげんろんてき /還元論的/
かんこ /歓呼/喚呼/
かんこう /観光/刊行/官公/感光/完工/慣行/敢行/緩行/艦攻/箝口/還向/刊稿/
かんこうあんない /観光案内/
かんこうあんないじょ /観光案内所/
かんこうか /観光課/観光化/
かんこうかいはつ /観光開発/
かんこうきせん /観光汽船/
かんこうきゃく /観光客/
かんこうきゃくあいて /観光客相手/
かんこうきゃくかかく /観光客価格/
かんこうきゃくねだん /観光客値段/
かんこうきょうかい /観光協会/
かんこうきょく /観光局/
かんこうぎょう /観光業/
かんこうさんぎょう /観光産業/
かんこうざい /環孔材/
かんこうしき /感光式/
かんこうしきいがい /感光式以外/
かんこうしげん /観光資源/
かんこうしょ /官公署/
かんこうじぎょう /観光事業/
かんこうじゅ /官公需/
かんこうじょうほう /観光情報/
かんこうせい /感光性/
かんこうせん /緩行線/観光船/
かんこうせんつうか /緩行線通過/
かんこうせんでんしゃ /緩行線電車/
かんこうたい /感光体/
かんこうち /観光地/
かんこうちか /観光地化/
かんこうちず /観光地図/
かんこうちゃ /缶紅茶/
かんこうちゅう /敢行中/
かんこうちょう /官公庁/
かんこうちりょうきん /観光地料金/
かんこうてき /観光的/
かんこうてつどう /観光鉄道/
かんこうとっきゅう /観光特急/
かんこうばい /寒紅梅/
かんこうばしょ /観光場所/
かんこうぶ /観光部/
かんこうぶつ /刊行物/
かんこうへん /肝硬変/
かんこうまえ /刊行前/
かんこうむき /観光向き/
かんこうめいしょ /観光名所/
かんこうもくてき /観光目的/
かんこうよう /観光用/
かんこうりつびょういん /官公立病院/
かんこうりょこう /観光旅行/
かんこうりよう /緩行利用/
かんこうれい /箝口令/
かんこうろせん /観光路線/
かんこうろせんとっきゅう /観光路線特急/
かんこく /韓国/勧告/
かんこくいがい /韓国以外/
かんこくえいが /韓国映画/
かんこくえんせい /韓国遠征/
かんこくがわ /韓国側/
かんこくけい /韓国系/
かんこくけいゆ /韓国経由/
かんこくご /韓国語/
かんこくごかんきょう /韓国語環境/
かんこくごほうそう /韓国語放送/
かんこくさん /韓国産/
かんこくしき /韓国式/
かんこくしぜんじん /韓国自然人/
かんこくしゅっしん /韓国出身/
かんこくしょくざい /韓国食材/
かんこくじん /韓国人/
かんこくせい /韓国製/
かんこくせいしょくひん /韓国製食品/
かんこくせいふ /韓国政府/
かんこくせき /韓国籍/
かんこくそうざいてん /韓国惣菜店/
かんこくだいとうりょう /韓国大統領/
かんこくちょくゆにゅう /韓国直輸入/
かんこくない /韓国内/
かんこくばん /韓国版/
かんこくぶんか /韓国文化/
かんこくほうじん /韓国法人/
かんこくりょうり /韓国料理/
かんこくりょうりてん /韓国料理店/
かんこくりょうりや /韓国料理屋/
かんこつだったい /換骨奪胎/
かんこどり /閑古鳥/
かんこぴ /完コピ/
かんこぴふ /完コピ譜/
かんこん /冠婚/
かんこんそうさい /冠婚葬祭/
かんご /看護/漢語/
かんごう /巻号/嵌合/冠号/
かんごがっこう /看護学校/
かんごく /監獄/
かんごくゆき /監獄行/
かんごけい /漢語系/
かんごし /看護師;保健婦助産婦看護婦法一部改正による呼称変更/
かんごにん /看護人/
かんごふ /看護婦/看護夫/
かんごふめんきょ /看護婦免許/
かんごりん /漢語林/
かんさ /監査/鑑査/感作/間差/
かんさい /関西/寛斎/簡裁/完済/艦載/
かんさいいがい /関西以外/
かんさいいだいまえ /関西医大前/
かんさいいんかい /監査委員会/
かんさいえんせい /関西遠征/
かんさいおおくらこう /関西大倉高/
かんさいかんとう /関西関東/
かんさいがい /関西外/
かんさいがくせい /関西学生/
かんさいがわ /関西側/
かんさいき /艦載機/
かんさいきせん /関西汽船/
かんさいきょうかい /関西協会/
かんさいきんこう /関西近郊/
かんさいくうこう /関西空港/
かんさいくうこうえき /関西空港駅/
かんさいくうこうせん /関西空港線/
かんさいくうこうちゃく /関西空港着/
かんさいぐち /関西口/
かんさいけい /関西系/
かんさいけん /関西圏/関西圈/
かんさいこうえん /関西公演/
かんさいご /関西語/
かんさいざいじゅう /関西在住/
かんさいざいじゅうしゃ /関西在住者/
かんさいししゃ /関西支社/
かんさいししょ /関西支所/
かんさいしてつ /関西私鉄/
かんさいしてん /関西支店/
かんさいしぶ /関西支部/
かんさいしゃかいじん /関西社会人/
かんさいしゅっしん /関西出身/
かんさいしょうぎかいかん /関西将棋会館/
かんさいしんくうこう /関西新空港/
かんさいしんじだい /関西新時代/
かんさいじょうほう /関西情報/
かんさいじん /関西人/
かんさいじんたち /関西人達/
かんさいせん /関西線/
かんさいせんおうじ /関西線王寺/
かんさいせんしゅけん /関西選手権/
かんさいたいかい /関西大会/
かんさいだい /関西大/
かんさいだいがく /関西大学/
かんさいだいがくまえ /関西大学前/
かんさいだいひょう /関西代表/
かんさいちく /関西地区/
かんさいちほう /関西地方/
かんさいちほうしゅっしん /関西地方出身/
かんさいちゅうしん /関西中心/
かんさいつうしん /関西通信/
かんさいていれいかい /関西定例会/
かんさいてき /関西的/
かんさいてつどう /関西鉄道/
かんさいで /関西出/
かんさいでんりょく /関西電力/
かんさいば /関西馬/
かんさいばん /関西版/
かんさいふう /関西風/
かんさいふうみ /関西風味/
かんさいべん /関西弁/
かんさいべんけん /関西弁圏/
かんさいぺいんと /関西ペイント/
かんさいほうげん /関西方言/
かんさいほうげんけん /関西方言圏/
かんさいほうげんてき /関西方言的/
かんさいほうめん /関西方面/
かんさいほんせん /関西本線/
かんさいぼう /幹細胞/
かんさいりゅう /関西流/
かんさいん /鑑査員/監査員/
かんさく /間作/奸策/
かんさくめい /関作命/
かんさしつ /監査室/
かんさしどうかい /監査指導会/
かんさつ /観察/監察/鑑札/
かんさついん /監察員/監察院/
かんさつかい /観察会/
かんさつがくしゅう /観察学習/
かんさつぐん /監察軍/
かんさつけっか /観察結果/
かんさつしゃ /観察者/
かんさつしゃがわ /観察者側/
かんさつりょく /観察力/
かんさにん /監査人/
かんさぶ /監査部/
かんさやく /監査役/
かんさん /閑散/換算/
かんさんき /閑散期/
かんさんけいすう /換算係数/
かんさんしき /換算式/
かんさんじ /閑散時/
かんさんひょう /換算表/
かんざい /管財/
かんざいにん /管財人/
かんざき /神崎/神埼/
かんざきがわ /神崎川/
かんざし /簪/
かんざぶろう /勘三郎/
かんざん /換算/
かんざんかのう /換算可能/
かんざんしき /換算式/
かんざんじ /舘山寺/
かんざんひょう /換算表/
かんざんび /換算日/
かんし /監視/冠詞/干支/管子/鉗子/
かんしいん /監視員/
かんしかつどう /監視活動/
かんしき /鑑識/乾式/
かんしきき /監視機器/
かんしきこう /漢詩紀行/
かんししゃ /監視車/
かんしち /環七/
かんしつ /乾湿/間質/
かんしゃ /感謝/官舎/患者/
かんしゃかんげき /感謝感激/
かんしゃきん /感謝金/
かんしゃく /疳積/癇癪/
かんしゃさい /感謝祭/
かんしゃじょう /感謝状/
かんしゃめん /緩斜面/
かんしゅ /看守/看取/艦種/関手/艦首/函手/肝腫/凾手/緩手/
かんしゅう /慣習/監修/観衆/
かんしゅうか /慣習化/
かんしゅうこくさいほう /慣習国際法/
かんしゅうこじんこじん /観衆個人個人/
かんしゅうしゃ /監修者/
かんしゅうてき /慣習的/
かんしゅうばん /監修版/
かんしゅうほう /慣習法/
かんしょ /甘蔗/
かんしょう /観賞/鑑賞/干渉/感傷/緩衝/環礁/冠賞/完勝/管掌/勧奨/
かんしょうえき /緩衝液/
かんしょうかい /鑑賞会/観賞会/
かんしょうぎょ /観賞魚/
かんしょうけい /干渉計/緩衝系/
かんしょうけいさん /干渉計算/
かんしょうご /鑑賞後/
かんしょうさよう /緩衝作用/
かんしょうざい /緩衝材/
かんしょうしゃ /観賞者/鑑賞者/
かんしょうせい /干渉性/
かんしょうたい /干渉帯/
かんしょうだんたい /鑑賞団体/
かんしょうちゅう /観賞中/
かんしょうてき /感傷的/
かんしょうは /干渉波/
かんしょうひん /観賞品/
かんしょうほうほう /観賞方法/
かんしょうやく /緩衝役/
かんしょうよう /観賞用/鑑賞用/
かんしょうようえき /緩衝溶液/
かんしょく /感触/官職/間食/閑職/寒色/
かんしょくけい /寒色系/
かんしょくめい /官職名/
かんしん /感心/関心/寒心/歓心/奸臣/
かんしんじ /関心事/
かんしんじこう /関心事項/
かんしんど /関心度/
かんじ /漢字/幹事/感じ/完治/監事/寛治/完爾/完児/換字/莞爾/
かんじいがい /漢字以外/
かんじいちもじ /漢字一文字/
かんじいちもじぶん /漢字一文字分/
かんじおん /漢字音/
かんじか /漢字化/
かんじかい /幹事会/
かんじかた /感じ方/
かんじかなまじり /漢字仮名交じり/
かんじかなまじりぶん /漢字かな混じり文/
かんじかんけい /漢字関係/
かんじがく /漢字学/
かんじがっかい /幹事学会/
かんじがわ /幹事側/
かんじきんし /漢字禁止/
かんじけってい /幹事決定/
かんじけんさくほう /漢字検索法/
かんじこーど /漢字コード/
かんじこう /幹事校/
かんじこうほ /漢字候補/
かんじご /漢字語/
かんじさま /幹事様/
かんじしょり /漢字処理/
かんじじしょ /漢字辞書/
かんじじてん /漢字辞典/
かんじじゅくご /漢字熟語/
かんじせんたく /漢字選択/
かんじたいおう /漢字対応/
かんじたいおうばん /漢字対応版/
かんじたんまつ /漢字端末/
かんじだいひょう /幹事代表/
かんじだん /幹事団/
かんじちょう /幹事長/
かんじとうろく /漢字登録/
かんじにじ /漢字二字/
かんじにもじ /漢字二文字/
かんじにゅうしゅつりょく /漢字入出力/
かんじにゅうりょく /漢字入力/
かんじにゅうりょくきのう /漢字入力機能/
かんじにゅうりょくしゅだん /漢字入力手段/
かんじはつおん /漢字発音/
かんじばん /漢字版/
かんじひっとう /幹事筆頭/
かんじひともじぶん /漢字一文字分/
かんじひょう /漢字表/
かんじひょうき /漢字表記/
かんじひょうきぶぶん /漢字表記部分/
かんじひょうじ /漢字表示/
かんじひょうじかのう /漢字表示可能/
かんじふごう /漢字符号/
かんじふごうけい /漢字符号系/
かんじぶぶん /漢字部分/
かんじぶん /漢字分/
かんじぶんか /漢字文化/
かんじぶんかけん /漢字文化圏/
かんじへいき /漢字併記/
かんじへんかん /漢字変換/
かんじへんかんきりかえ /漢字変換切替/
かんじへんかんじしょ /漢字変換辞書/
かんじへんかんほうしき /漢字変換方式/
かんじへんかんよう /漢字変換用/
かんじほうこく /幹事報告/
かんじめい /漢字名/
かんじもじれつ /漢字文字列/
かんじゃ /患者/冠者/
かんじゃぎゃくたい /患者虐待/
かんじゃく /閑寂/
かんじゃすう /患者数/
かんじゃふたんわりあい /患者負担割合/
かんじやく /幹事役/
かんじゅ /甘受/感受/官需/
かんじゅく /完熟/慣熟/
かんじゅくそうこう /慣熟走行/
かんじゅくど /完熟度/慣熟度/
かんじゅくほこう /慣熟歩行/
かんじゅせい /感受性/
かんじゅん /間順/
かんじゅんそうさ /間順走査/
かんじょ /緩徐/
かんじょう /感情/勘定/冠状/環状/感状/艦上/完乗/管状/
かんじょういにゅう /感情移入/
かんじょうか /管状花/
かんじょうかもく /勘定科目;簿記の計算単位の各勘定の名称/管状花目/Tubiflorae/
かんじょうがい /勘定外/
かんじょうき /艦上機/
かんじょうけんきゅう /感情研究/
かんじょうしょ /勘定書/
かんじょうせん /環状線/
かんじょうせんてんまえき /環状線天満駅/
かんじょうちゅうしんちゅう /管状中心柱/
かんじょうてき /感情的/
かんじょうてきしゅちょう /感情的主張/
かんじょうてきたいりつ /感情的対立/
かんじょうてきはんぱつ /感情的反発/
かんじょうでんたつ /感情伝達/
かんじょうなど /感情等/
かんじょうはんのう /感情反応/
かんじょうひょうげん /感情表現/
かんじょうみゃく /冠静脈/
かんじょうようそ /管状要素/
かんじょうろん /感情論/
かんじょきん /緩徐筋/
かんじよう /漢字用/
かんじよこいんじ /漢字横印字/
かんじりよう /漢字利用/
かんじれつ /漢字列/
かんじれつちゅう /漢字列中/
かんじん /肝心/肝腎/閑人/勧進/
かんじんかなめ /肝心要/
かんじんちょう /勧進帳/
かんすい /完遂/冠水/潅水/灌水/
かんすいきんぞく /関水金属/
かんすいぎょ /寒水魚/
かんすう /関数/函数/巻数/函數/
かんすうかいせき /函数解析/関数解析/
かんすうかいせきがく /関数解析学/
かんすうかん /関数環/
かんすうかんやく /関数簡約/
かんすうがい /関数外/
かんすうがた /関数型/函数型/
かんすうがたげんご /関数型言語/
かんすうきごう /関数記号/
かんすうくうかん /関数空間/
かんすうぐん /関数群/
かんすうけい /関数系/関数形/関数型/
かんすうけいさん /関数計算/
かんすうごうせい /関数合成/
かんすうじ /漢数字/
かんすうじへんかん /漢数字変換/
かんすうせんげん /関数宣言/
かんすうぜんたい /関数全体/
かんすうぞく /関数族/
かんすうち /関数値/
かんすうちゅうしょう /関数抽象/
かんすうていぎ /関数定義/
かんすうていすう /関数定数/
かんすうてき /関数的/
かんすうてきじゅうぞく /関数的従属/
かんすうてきよう /関数適用/
かんすうでんたく /関数電卓/
かんすうない /関数内/
かんすうひきすう /関数引数/
かんすうひょうげん /関数表現/
かんすうほうていしき /関数方程式/
かんすうめい /関数名/
かんすうよびだし /関数呼び出し/
かんすうろん /関数論/函数論/
かんする /関する/
かんせい /完成/感性/歓声/慣性/管制/官製/乾性/喚声/閑静/監製/官制/陥穽/喊声/
かんせいうんどう /慣性運動/
かんせいかん /管制官/
かんせいがくいん /関西学院/
かんせいがくいんだい /関西学院大/
かんせいがくいんだいがく /関西学院大学/
かんせいがくいんだいり /関西学院大理/
かんせいくどうけい /慣性駆動系/
かんせいけい /慣性系/
かんせいこうほう /慣性航法/
かんせいご /完成後/
かんせいししゃかい /完成試写会/
かんせいしつ /管制室/
かんせいしつりょう /慣性質量/
かんせいしゃ /完成車/
かんせいじ /完成時/
かんせいじょうほう /感性情報/
かんせいじょうほうしょり /感性情報処理/
かんせいせいぶん /慣性成分/
かんせいていこう /慣性抵抗/
かんせいてき /感性的/
かんせいてんそる /慣性テンソル/
かんせいとじょう /完成途上/
かんせいど /完成度/
かんせいないぶじゅうりょくは /慣性内部重力波/
かんせいのうりつ /慣性能率/
かんせいはがき /官製葉書/
かんせいば /慣性場/
かんせいばん /完成版/
かんせいひん /完成品/
かんせいめい /官姓名/
かんせいよてい /完成予定/
かんせいりょく /慣性力/
かんせいりょくとうか /慣性力等価/
かんせかいどうてい /貫世界同定/
かんせき /寛晰/
かんせつ /間接/関節/冠雪/
かんせつえき /関節液/
かんせつえんばん /関節円盤/
かんせつおん /間接音/
かんせつかく /関節角/
かんせつかくざひょう /関節角座標/
かんせつきつえん /間接喫煙/
かんせつきょう /関節鏡/
かんせつきょうしか /関節鏡視下/
かんせつさぎょう /間接作業/
かんせつさんしょう /間接参照/
かんせつざひょう /関節座標/
かんせつしょうめい /間接照明/
かんせつすいしゅ /関節水腫/
かんせつぜい /間接税/
かんせつてき /間接的/
かんせつてん /関節点/
かんせつひ /間接費/
かんせつぶ /間接部/
かんせつほう /関節包/間接法/
かんせつみんしゅせい /間接民主制/
かんせつわざ /関節技/
かんせつわほう /間接話法/
かんせん /感染/幹線/観戦/艦船/艦戦/汗腺/
かんせんか /感染価/
かんせんかい /観戦会/
かんせんき /観戦記/
かんせんきぼう /観戦希望/
かんせんきゃく /観戦客/
かんせんけいろ /感染経路/
かんせんけん /観戦券/
かんせんげん /感染源/
かんせんご /感染後/
かんせんしゃ /感染者/観戦者/
かんせんしゃすう /感染者数/
かんせんしょう /感染症/
かんせんじ /観戦時/
かんせんじょう /観戦上/
かんせんせい /感染性/
かんせんせつ /感染説/
かんせんちゅう /感染中/
かんせんどうろ /幹線道路/
かんせんようしき /感染様式/
かんせんよてい /観戦予定/
かんせんりつ /感染率/
かんせんりょく /感染力/
かんぜい /関税/
かんぜいほう /関税法/
かんぜいりつ /関税率/
かんぜおん /観世音/
かんぜりゅう /観世流/
かんぜん /完全/勧善/敢然/
かんぜんあっせつ /完全圧雪/
かんぜんいしょく /完全移植/
かんぜんうちぜいほうしき /完全内税方式/
かんぜんえん /完全円/
かんぜんか /完全化/完全花/
かんぜんかい /完全解/
かんぜんかいとう /完全解答/
かんぜんかほうせい /完全加法性/
かんぜんきせいがた /完全寄生型/
かんぜんきんえん /完全禁煙/
かんぜんきんし /完全禁止/
かんぜんけっちゃく /完全決着/
かんぜんげんてい /完全限定/
かんぜんげんていばん /完全限定版/
かんぜんげんてんばん /完全原典版/
かんぜんこしつ /完全個室/
かんぜんごかん /完全互換/
かんぜんさつじんじけん /完全殺人事件/
かんぜんしてい /完全指定/
かんぜんしていじゅんじょきかい /完全指定順序機械/
かんぜんしゅうろく /完全収録/
かんぜんしゅうろくばん /完全収録版/
かんぜんしゅぎ /完全主義/
かんぜんしゅぎしゃ /完全主義者/
かんぜんしょうとう /完全消灯/
かんぜんじあい /完全試合/
かんぜんじどう /完全自動/
かんぜんじどううんてん /完全自動運転/
かんぜんじゅくすい /完全熟睡/
かんぜんじゅんきょ /完全準拠/
かんぜんすう /完全数/
かんぜんせい /完全性/
かんぜんせいき /完全正規/
かんぜんせいきちょっこうけい /完全正規直交系/
かんぜんせいていり /完全性定理/
かんぜんせいは /完全制覇/
かんぜんせいりつ /完全成立/
かんぜんせんが /完全線画/
かんぜんたい /完全体/
かんぜんたいおう /完全対応/
かんぜんちゅうけい /完全中継/
かんぜんちょうあく /勧善懲悪/
かんぜんちょっこう /完全直交/
かんぜんとういつ /完全統一/
かんぜんとうけつろ /完全凍結路/
かんぜんどうさ /完全動作/
かんぜんに /完全に/
かんぜんねんしょう /完全燃焼/
かんぜんはんざい /完全犯罪/
かんぜんはんしゃ /完全反射/
かんぜんばん /完全版/
かんぜんひせっしょく /完全非接触/
かんぜんひてい /完全否定/
かんぜんひどうき /完全非同期/
かんぜんふっかつ /完全復活/
かんぜんふっき /完全復帰/
かんぜんふっきゅう /完全復旧/
かんぜんふっこくばん /完全復刻版/
かんぜんぶあい /完全歩合/
かんぜんぶあいせい /完全歩合制/
かんぜんぶそう /完全武装/
かんぜんぶんえん /完全分煙/
かんぜんぶんかつあん /完全分割案/
かんぜんぶんさんかんりほうしき /完全分散管理方式/
かんぜんぶんり /完全分離/
かんぜんへんけい /完全変形/
かんぜんへんたい /完全変態/
かんぜんほうえい /完全放映/
かんぜんほうかい /完全崩壊/
かんぜんほうそう /完全放送/
かんぜんほうでん /完全放電/
かんぜんほしょう /完全保証/
かんぜんほせい /完全補正/
かんぜんほせいがた /完全補正型/
かんぜんほそう /完全舗装/
かんぜんぼうび /完全防備/
かんぜんみっぷう /完全密封/
かんぜんみっぺいがた /完全密閉型/
かんぜんむけつ /完全無欠/
かんぜんむし /完全無視/
かんぜんむせいげん /完全無制限/
かんぜんむてきわざ /完全無敵技/
かんぜんゆうしょう /完全優勝/
かんぜんよやくげんてい /完全予約限定/
かんぜんよやくせい /完全予約制/
かんぜんよやくはんばい /完全予約販売/
かんぜんりゅうたい /完全流体/
かんぜんわやく /完全和訳/
かんそ /簡素/
かんそう /感想/乾燥/完走/間奏/歓送/間想/完奏/換装/観相/乾草/
かんそうかい /歓送会/
かんそうき /乾燥機/乾燥器/
かんそうきかん /乾燥期間/
かんそうきょく /間想曲/間奏曲/
かんそうくうき /乾燥空気/
かんそうげい /歓送迎/
かんそうげいかい /歓送迎会/
かんそうこ /乾倉庫/
かんそうご /乾燥後/
かんそうざい /乾燥剤/
かんそうしつ /乾燥室/
かんそうしゃ /完走者/
かんそうじゅうりょう /乾燥重量/
かんそうせいざい /乾燥製剤/
かんそうせん /感想戦/
かんそうちたい /乾燥地帯/
かんそうど /乾燥度/
かんそうなど /感想等/
かんそうぶ /間奏部/
かんそうぶん /感想文/
かんそうよう /乾燥用/
かんそうらん /乾燥卵/
かんそうりつ /完走率/
かんそうろめん /乾燥路面/
かんそか /簡素化/
かんそく /観測/緩速/患側/
かんそくかい /観測会/
かんそくかのう /観測可能/
かんそくかのうりょう /観測可能量/
かんそくがぞう /観測画像/
かんそくき /観測器/観測機/
かんそくけい /観測系/
かんそくけいけん /観測経験/
かんそくけっか /観測結果/
かんそくこんなん /観測困難/
かんそくしゃ /観測者/
かんそくしょ /観測所/
かんそくじじつ /観測事実/
かんそくじょ /観測所/
かんそくすじ /観測筋/
かんそくたいしょう /観測対象/
かんそくち /観測地/観測値/
かんそくちてん /観測地点/
かんそくてん /観測点/
かんそくてんすう /観測点数/
かんそくばしょ /観測場所/
かんそくふかのう /観測不可能/
かんそくふのう /観測不能/
かんそくほうていしき /観測方程式/
かんそくもう /観測網/
かんそくりょう /観測量/
かんそくれき /観測歴/
かんそん /寒村/
かんぞう /肝臓/鑑三/
かんぞうがん /肝臓癌/
かんぞうきのう /肝臓機能/
かんぞく /漢族/奸賊/
かんた /幹太/
かんたい /艦隊/歓待/寒帯/鑑隊/艦体/桿体/冠体/
かんたいか /簡体化/
かんたいきかん /艦隊旗艦/
かんたいきどう /艦隊機動/
かんたいこうどう /艦隊行動/
かんたいじ /簡体字/
かんたいせん /艦隊戦/
かんたいは /艦隊派/
かんたいへいよう /環太平洋/
かんたく /干拓/
かんたろう /勘太郎/間太郎/
かんたん /簡単/感嘆/邯鄲/簡單/
かんたんか /簡単化/
かんたんじ /簡単字/
かんたんふ /感嘆符/
かんたんめいりょう /簡単明瞭/
かんだ /神田/関田/苅田/
かんだい /寛大/関大/漢代/
かんだいせん /関大戦/
かんだいまえ /関大前/
かんだいまええき /関大前駅/
かんだえき /神田駅/
かんだかん /神田間/
かんだがわ /神田川/神田側/
かんだがわより /神田川寄り/
かんだけいさつしょ /神田警察署/
かんだこしょ /神田古書/
かんだじょがくえん /神田女学園/
かんだじんぼうちょう /神田神保町/
かんだち /神立/
かんだちこうげん /神立高原/
かんだつ /神立/
かんだふるほんがい /神田古本街/
かんだほんてん /神田本店/
かんだん /歓談/寒暖/間断/
かんだんけい /寒暖計/
かんだんさ /寒暖差/
かんち /関知/完治/感知/寒地/姦智/奸知/奸智/
かんちがい /勘違い/
かんちき /感知器/
かんちく /患畜/
かんちそうち /感知装置/
かんちばん /感知板/
かんちゅう /寒中/管中/
かんちょう /艦長/館長/官庁/完調/浣腸/管長/干潮/間諜/
かんちょうじ /干潮時/
かんつう /貫通/姦通/
かんつうがわ /貫通側/
かんつうざい /姦通罪/
かんつうしき /貫通式/
かんつうじゅうそう /貫通銃創/
かんつうとびら /貫通扉/
かんつうりょく /貫通力/
かんつうろ /貫通路/
かんづめ /缶詰/罐詰/
かんてい /鑑定/官邸/艦艇/
かんていしょ /鑑定書/
かんていしょく /艦底色/
かんていない /艦艇内/
かんていにん /鑑定人/
かんていりゅう /勘亭流/
かんてき /観的/
かんてつ /完徹/貫徹/関鉄/官鉄/
かんてん /観点/寒天/干天/旱天/
かんでん /感電/関電/
かんでんこう /関電工/
かんでんさよう /感電作用/
かんでんし /感電死/
かんでんち /乾電池/
かんでんちしき /乾電池式/
かんとう /関東/巻頭/完答/竿灯/冠頭/敢闘/完投/竿頭/
かんとういがい /関東以外/
かんとういち /関東一/
かんとういちえん /関東一円/
かんとうおおてしてつ /関東大手私鉄/
かんとうかんじちょう /関東幹事長/
かんとうかんやく /冠頭簡約/
かんとうかんれい /関東管令/
かんとうがくいん /関東学院/
かんとうがくいんせん /関東学院戦/
かんとうがくいんだい /関東学院大/
かんとうがくいんだいがく /関東学院大学/
かんとうがくいんむつうら /関東学院六浦/
かんとうがくせい /関東学生/
かんとうがた /完投型/
かんとうきじ /巻頭記事/
かんとうきんけん /関東近県/
かんとうきんこう /関東近郊/
かんとうきんぺん /関東近辺/
かんとうぐん /関東軍/關東軍/
かんとうけい /関東系/
かんとうけん /関東圏/
かんとうげん /巻頭言/
かんとうこうしんえつ /関東甲信越/
かんとうこくさい /関東国際/
かんとうざいじゅう /関東在住/
かんとうし /間投詞/
かんとうしぶ /関東支部/
かんとうしゅうへん /関東周辺/
かんとうしゅっしん /関東出身/
かんとうしゅっしんしゃ /関東出身者/
かんとうしょう /敢闘賞/
かんとうしょうり /完投勝利/
かんとうじょしがくせい /関東女子学生/
かんとうじん /関東人/
かんとうせん /関東戦/
かんとうせんしゅしょう /敢闘選手賞/
かんとうぜい /関東勢/
かんとうぜんぱん /関東全般/
かんとうたいかい /関東大会/
かんとうだいがく /関東大学/
かんとうだいしんさい /関東大震災/
かんとうちいき /関東地域/
かんとうちく /関東地区/
かんとうちくいがい /関東地区以外/
かんとうちほう /関東地方/
かんとうてきかんかく /関東的感覚/
かんとうてつどう /関東鉄道/
かんとうでんし /関東電子/
かんとうとくしゅう /巻頭特集/
かんとうに /関東煮/
かんとうば /関東馬/
かんとうばん /関東版/
かんとうひょうじゅんけい /冠頭標準形/
かんとうふう /関東風/
かんとうふきん /関東付近/
かんとうへいや /関東平野/
かんとうへいやない /関東平野内/
かんとうべん /関東弁/
かんとうゆうい /関東優位/
かんとうよう /関東用/
かんとうりゅう /関東流/
かんとうれんめい /関東連盟/
かんとうろうさいびょういん /関東労災病院/
かんとく /監督/
かんとくいん /監督員/
かんとくえん /関特演/
かんとくか /監督下/
かんとくきかん /監督機関/
かんとくけん /監督権/
かんとくさく /監督作/
かんとくさくひん /監督作品/
かんとくしゃ /監督者/
かんとくじん /監督陣/
かんとくすいせん /監督推薦/
かんとくすいせんはっぴょう /監督推薦発表/
かんとくせきにん /監督責任/
かんとくだいこう /監督代行/
かんとくちょう /監督庁/
かんとん /広東/嵌頓/
かんとんご /広東語/廣東語/
かんとんふう /広東風/
かんとんめん /広東麺/
かんとんりょうり /広東料理/
かんど /感度/神戸/
かんどいじょう /感度以上/
かんどう /感動/完動/勘当/間道/
かんどうさく /感動作/
かんどうてき /感動的/
かんどうひん /完動品/
かんどうみゃく /冠動脈/肝動脈/
かんどころ /勘所/
かんどせってい /感度設定/
かんどちょうせい /感度調整/
かんどてん /感度点/
かんどぶんぷ /感度分布/
かんどり /神取/
かんな /鉋/寛和/
かんない /関内/管内/艦内/館内/幹内/
かんないえき /関内駅/
かんなぎ /巫/覡/
かんなづき /神無月/
かんなな /環七/
かんなべ /神辺/
かんなみ /函南/
かんなり /金成/
かんなん /艱難/
かんなんしんく /艱難辛苦/
かんにち /韓日/
かんにゅう /嵌入/
かんにん /堪忍/
かんにんぶくろ /堪忍袋/
かんぬき /閂/貫木/
かんぬし /神主/
かんねい /姦佞/奸佞/
かんねつ /感熱/乾熱/
かんねつし /感熱紙/
かんねつしき /感熱式/
かんねん /観念/
かんねんてき /観念的/
かんねんろん /観念論/
かんねんろんしゃ /観念論者/
かんの /神野/冠野/菅野/管野/
かんのう /官能/間脳/完納/感応/感能/
かんのうがた /感応型/
かんのうしゃしんしゅう /官能写真集/
かんのうせかい /官能世界/
かんのうてき /官能的/
かんのん /観音/
かんのんきょう /観音教/
かんのんざき /観音崎/
かんのんぞう /観音像/
かんのんとうげ /観音峠/
かんはつ /間髪/
かんば /悍馬/
かんばい /完売/寒梅/観梅/
かんばいこ /寒梅粉/
かんばく /艦爆/
かんばつ /簡抜/間伐/干魃/旱魃/
かんばつざい /間伐材/
かんばめい /冠馬名/
かんばやし /神林/上林/
かんばら /蒲原/神原/
かんばん /看板/乾板/燗番/
かんばんじょゆう /看板女優/
かんばんせんしゅ /看板選手/
かんばんまえ /看板前/
かんばんむすめ /看板娘/
かんばんや /看板屋/
かんばんれっしゃ /看板列車/
かんぱ /カンパ/寒波/看破/
かんぱい /乾杯/完敗/
かんぱく /関白/
かんぱち /環八/
かんぱつ /間髪/
かんぱん /甲板/干犯/乾板/
かんぱんいん /甲板員/
かんび /完備/甘美/艦尾/
かんびーる /缶ビール/
かんびいる /缶ビール/
かんびか /完備化/
かんびかてつづき /完備化手続/完備化手続き/
かんびせい /完備性/
かんびそく /完備束/
かんびょう /看病/
かんびん /簡便/
かんぴ /官費/韓非;始皇帝の時代の韓の公子/
かんぴし /韓非子;始皇帝の時代の韓の公子/
かんぴょう /鑑評/
かんぴょうかい /鑑評会/
かんぴょうき /間氷期/
かんふー /功夫/
かんぶ /幹部/患部/
かんぶしゃいん /幹部社員/
かんぶつ /乾物/干物/換物/奸物/
かんぶつえ /潅仏会/
かんぶつや /乾物屋/
かんぶり /寒ブリ/
かんぶん /漢文/
かんぶんくんどくたい /漢文訓読体/
かんぶんてき /漢文的/
かんぷ /乾布/還付/完膚/関釜/
かんぷう /寒風/完封/
かんぷうざん /寒風山/
かんぷうしあいすう /完封試合数/
かんぷうしょうり /完封勝利/
かんぷく /感服/
かんぷしんこく /還付申告/
かんぷせいきゅう /還付請求/
かんぷまさつ /乾布摩擦/
かんぷれんらくせん /関釜連絡船/
かんへんちょう /可変長/
かんべ /神戸/
かんべえ /勘兵衛/
かんべつ /鑑別/
かんべん /勘弁/簡便/
かんべんか /簡便化/
かんべんせい /簡便性/
かんべんほう /簡便法/
かんぺき /完璧/完ぺき/癇癖/
かんぺきしゅぎ /完璧主義/
かんぺきばん /完璧版/
かんぼう /官房/感冒/監房/奸謀/観望/姦謀/
かんぼうち /観望地/
かんぼうやく /感冒薬/
かんぼうよう /観望用/
かんぼく /潅木/灌木/
かんぼじあ /柬蒲寨/
かんぼつ /陥没/
かんぽう /官報/漢方/艦砲/館報/咸豐/
かんぽうい /漢方医/
かんぽういがく /漢方医学/
かんぽういりょう /漢方医療/
かんぽうやく /漢方薬/
かんぽうやくや /漢方薬屋/
かんま /カンマ/
かんまき /上牧/
かんまく /間膜/
かんまつ /巻末/
かんまつちゅう /巻末注/
かんまつふろく /巻末付録/
かんまん /緩慢/干満/
かんみ /甘味/寛美/
かんみゃく /間脈/
かんみりょう /甘味料/
かんみん /官民/
かんみんいったい /官民一体/
かんみんぞく /韓民族/漢民族/
かんみんぞくぶんか /漢民族文化/
かんむ /桓武/
かんむへいし /桓武平氏/
かんむり /冠/
かんむりょう /感無量/
かんめ /貫目/
かんめい /感銘/官名/簡明/艦名/
かんめいか /簡明化/
かんめん /乾麺/管面/
かんもん /関門/喚問/環紋/
かんもんかいきょう /関門海峡/
かんもんきょう /関門橋/
かんもんてつどう /関門鉄道/
かんやく /簡約/監訳/完訳/漢訳/
かんやくか /簡約化/
かんやくきそく /簡約規則/
かんやくけい /簡約形/
かんやくしゃ /監訳者/
かんやくにほんご /簡約日本語/
かんやくばん /完訳版/
かんやくほうていしき /簡約方程式/
かんやくりつ /簡約律/
かんゆ /換喩/肝油/
かんゆう /勧誘/奸雄/
かんゆういん /勧誘員/
かんゆうでんわ /勧誘電話/
かんゆうほうほう /勧誘方法/
かんよ /関与/
かんよう /肝要/慣用/寛容/観葉/涵養/観洋/
かんようか /慣用化/
かんようく /慣用句/
かんようしょくぶつ /観葉植物/
かんようてき /寛容的/慣用的/
かんようめい /慣用名/
かんようよみ /慣用読/
かんようりょく /寛容力/
かんよど /関与度/
かんら /甘楽/
かんらく /陥落/歓楽/乾酪/
かんらん /観覧/甘藍/橄欖/觀覽/
かんらんしゃ /観覧車/
かんらんせき /観覧席/
かんらんよう /観覧用/
かんらんりょう /観覧料/
かんり /管理/官吏/監理/
かんりいいん /管理委員/
かんりいいんかい /管理委員会/
かんりうんえい /管理運営/
かんりうんよう /管理運用/
かんりか /管理下/管理課/管理化/
かんりかちょう /管理課長/
かんりかんけい /管理関係/
かんりがえ /管理換/
かんりがかり /管理掛/
かんりがく /管理学/
かんりき /管理機/
かんりきこう /管理機構/
かんりきてい /管理規定/
かんりきのう /管理機能/
かんりきょういく /管理教育/
かんりきょく /監理局/
かんりぎじゅつ /管理技術/
かんりぎょうむ /管理業務/
かんりぎょうむしゃ /管理業務者/
かんりくいき /管理区域/
かんりくみあい /管理組合/
かんりけいたい /管理形態/
かんりけんげん /管理権限/
かんりけんげんがい /管理権限外/
かんりけんしゅう /管理研修/
かんりこうい /管理行為/
かんりこうがく /管理工学/
かんりこうがっか /管理工学科/
かんりこうざ /管理講座/
かんりさいと /管理サイト/
かんりさぎょう /管理作業/
かんりし /管理士/
かんりしえんかんきょう /管理支援環境/
かんりしつ /管理室/
かんりしゃ /管理者/
かんりしゃいがい /管理者以外/
かんりしゃかい /管理社会/
かんりしゃさま /管理者様/
かんりしゃどうし /管理者同士/
かんりしゃめいぼ /管理者名簿/
かんりしゃよう /管理者用/
かんりしゅぎ /管理主義/
かんりしゅぎきょういく /管理主義教育/
かんりしゅぎてき /管理主義的/
かんりしゅたい /管理主体/
かんりしょく /管理職/
かんりじむしょ /管理事務所/
かんりじゅんびいいん /管理準備委員/
かんりじょう /管理上/
かんりじょうたい /管理状態/
かんりじょうほう /管理情報/
かんりせい /管理性/
かんりせいど /管理制度/
かんりせきにん /管理責任/
かんりせきにんしゃ /管理責任者/
かんりそしき /管理組織/
かんりたいけい /管理体系/
かんりたいしょう /管理対象/
かんりたいせい /管理体制/
かんりたんとうしゃ /管理担当者/
かんりてき /管理的/
かんりてききょういく /管理的教育/
かんりてきそくめん /管理的側面/
かんりてじゅん /管理手順/
かんりとう /管理棟/
かんりにん /管理人/
かんりにんいがい /管理人以外/
かんりにんけんげん /管理人権限/
かんりにんこうたい /管理人交替/
かんりにんこじん /管理人個人/
かんりにんじしん /管理人自身/
かんりにんせい /管理人制/
かんりにんせいど /管理人制度/
かんりにんたいせい /管理人体制/
かんりにんだいり /管理人代理/
かんりにんほうしき /管理人方式/
かんりにんほさ /管理人補佐/
かんりのーど /管理ノード/
かんりのうりょく /管理能力/
かんりひ /管理費/
かんりひょう /管理表/管理票/
かんりぶ /管理部/
かんりぶちょう /管理部長/
かんりぶんや /管理分野/
かんりほう /管理法/
かんりほうしき /管理方式/
かんりほうしん /管理方針/
かんりほうほう /管理方法/
かんりほしゅ /管理保守/
かんりほんぶ /管理本部/
かんりぼ /管理簿/
かんりめん /管理面/
かんりゃく /簡略/
かんりゃくか /簡略化/
かんりゃくきおく /簡略記憶/
かんりゃくけい /簡略形/
かんりゅう /寒流/環流/還流/貫流/乾溜/潅流/
かんりゅうけい /寒流系/
かんりゅうほうしき /環流方式/
かんりょう /完了/官僚/
かんりょうきこう /官僚機構/
かんりょうご /完了後/
かんりょうしだい /完了次第/
かんりょうしゅぎ /官僚主義/
かんりょうせい /官僚制/
かんりょうてき /官僚的/
かんりょうてきてつづき /官僚的手続/官僚的手続き/
かんりよう /管理用/
かんりりょう /管理料/
かんりりょういき /管理領域/
かんるい /感涙/
かんれい /慣例/寒冷/管領/
かんれいか /慣例化/
かんれいじょう /慣例上/
かんれいち /寒冷地/
かんれいちしよう /寒冷地仕様/
かんれいちよう /寒冷地用/
かんれいてき /慣例的/
かんれき /還暦/
かんれん /関連/關聯/
かんれんかいぎしつ /関連会議室/
かんれんがいしゃ /関連会社/
かんれんきかん /関連機関/
かんれんきき /関連機器/
かんれんきじ /関連記事/
かんれんぎじゅつ /関連技術/
かんれんけんきゅう /関連研究/
かんれんけんきゅうしゃ /関連研究者/
かんれんこうもく /関連項目/
かんれんこく /関連国/
かんれんご /関連語/
かんれんざっし /関連雑誌/
かんれんしつもん /関連質問/
かんれんしゅっぱんぶつ /関連出版物/
かんれんしょ /関連書/
かんれんしょうちょう /関連省庁/
かんれんしょうひん /関連商品/
かんれんしょせき /関連書籍/
かんれんしりょう /関連資料/
かんれんしりょうかん /関連資料館/
かんれんじこう /関連事項/
かんれんじょう /関連上/
かんれんじょうきょう /関連状況/
かんれんじょうほう /関連情報/
かんれんず /関連図/
かんれんせい /関連性/
かんれんせいひん /関連製品/
かんれんだんたい /関連団体/
かんれんちしき /関連知識/
かんれんづけ /関連付/
かんれんとうこう /関連投稿/
かんれんとしょ /関連図書/
かんれんぶぶん /関連部分/
かんれんぶんけん /関連文献/
かんれんぶんや /関連分野/
かんれんほうき /関連法規/
かんれんようご /関連用語/
かんれんりょういき /関連領域/
かんれんわだい /関連話題/
かんろ /管路/寒露/甘露/
かんろく /貫禄/環六/
かんろくじゅうぶん /貫禄十分/
かんわ /緩和/漢和/閑話/
かんわきこう /緩和機構/
かんわきゅうだい /閑話休題/
かんわじてん /漢和辞典/
かんわそち /緩和措置/
かんわほう /緩和法/
かんんけつへん /完結編/
が /我/賀/雅/駕/画/餓/蛾/芽/臥/河/峨/俄/牙/ヶ/果/ケ/呀/哦/娥/峩/畫/莪/衙/訛/訝/鵝/鵞/瓦/伽/ヵ/
がーたー /ガーター/
がーど /ガード/
がーりっく /ガーリック/
がい /外/街/害/概/該/骸/涯/鎧/崖/慨/既/蓋/碍/凱/咳/劾/甲斐/買い/階/我意/乂/剴/啀/垓/孩/崕/漑/皚/盖/睚/磑/礙/艾/葢/駭/愾/
がいあく /害悪/
がいあつ /外圧/
がいい /害意/外衣/
がいいん /外因/
がいいんぶ /外陰部/
がいえん /外延/外苑/外薗/
がいえんせい /外延性/
がいえんせいこうり /外延性公理/
がいえんてき /外延的/
がいえんどおり /外苑通り/
がいえんひがしどおり /外苑東通り/
がいえんまえ /外苑前/
がいか /外化/凱歌/外貨/蓋果/
がいかい /外界/外海/
がいかいじょうほう /外界情報/
がいかく /外郭/外角/外殻/
がいかくきゅう /外角球/
がいかくだんたい /外郭団体/
がいかげんきん /外貨現金/
がいかさい /外貨債/
がいかだかんけん /外貨兌換券/
がいかつ /概括/
がいかつてき /概括的/
がいかりょうがえ /外貨両替/
がいかん /概観/外観/外環/
がいかんじょう /外観上/
がいかんてき /概観的/
がいかんどうろ /外環道路/
がいかんび /外観美/
がいき /外気/
がいきおん /外気温/
がいきょう /概況/外匡/
がいきょく /外局/
がいきれいぼう /外気冷房/
がいきん /外勤/
がいきんこん /外菌根/
がいぎょ /害魚/
がいくうかん /外空間/
がいくせいか /学生課/
がいけい /概形/外形/外径/外傾/
がいけいたい /外形態/
がいけいてき /外形的/
がいけん /外見/外圏/
がいけんじょう /外見上/
がいけんじょうたいとう /外見上対等/
がいけんてき /外見的/
がいげんけい /外原型/
がいこう /外交/外向/外光/
がいこういん /外交員/
がいこうかん /外交官/
がいこうかんけい /外交関係/
がいこうけいしせい /外向傾姿勢/
がいこうこうしょう /外交交渉/
がいこうじょう /外交上/
がいこうせい /外向性/
がいこうせん /外航船/
がいこうてき /外交的/
がいこうどりょく /外交努力/
がいこうぶんしょ /外交文書/
がいこく /外国/
がいこくえいが /外国映画/
がいこくか /外国課/
がいこくかぶ /外国株/
がいこくかわせ /外国為替/
がいこくかわせてがた /外国為替手形/
がいこくがた /外国型/
がいこくきぎょう /外国企業/
がいこくきゅうだん /外国球団/
がいこくけい /外国系/
がいこくこくせき /外国国籍/
がいこくご /外国語/
がいこくごがくぶ /外国語学部/
がいこくごきょういく /外国語教育/
がいこくごやく /外国語訳/
がいこくごろんぶん /外国語論文/
がいこくさい /外国債/
がいこくさん /外国産/
がいこくさんば /外国産馬/
がいこくさんまい /外国産米/
がいこくざい /外国材/
がいこくしほん /外国資本/
がいこくしゅっちょう /外国出張/
がいこくしょうたいば /外国招待馬/
がいこくじどうしゃ /外国自動車/
がいこくじん /外国人/
がいこくじんか /外国人課/
がいこくじんかしゅ /外国人歌手/
がいこくじんかんけいしゃ /外国人関係者/
がいこくじんかんとく /外国人監督/
がいこくじんさっか /外国人作家/
がいこくじんせんしゅ /外国人選手/
がいこくじんせんしゅわく /外国人選手枠/
がいこくじんせんよう /外国人専用/
がいこくじんだんせい /外国人男性/
がいこくじんとうろく /外国人登録/
がいこくじんとうろくしょ /外国人登録証/
がいこくじんりゅうがくせい /外国人留学生/
がいこくじんりょこうしゃ /外国人旅行者/
がいこくじんろうどうしゃ /外国人労働者/
がいこくじんろてんしょう /外国人露店商/
がいこくじんわく /外国人枠/
がいこくせい /外国製/
がいこくせいひん /外国製品/
がいこくせき /外国籍/
がいこくせん /外国船/
がいこくせんしゅ /外国選手/
がいこくせんりょうぐん /外国占領軍/
がいこくぜい /外国勢/
がいこくそうきん /外国送金/
がいこくだいひょうば /外国代表馬/
がいこくば /外国馬/
がいこくばしゅっそう /外国馬出走/
がいこくばしょうたい /外国馬招待/
がいこくばわく /外国馬枠/
がいこくぶつ /外国物/
がいこくぶんがく /外国文学/
がいこくぼん /外国本/
がいこくめんきょ /外国免許/
がいこくもの /外国物/
がいこくゆうびんかわせ /外国郵便為替/
がいこくりょこう /外国旅行/
がいこつ /骸骨/蓋骨/
がいこつか /骸骨化/
がいご /外語/
がいさい /外債/
がいさん /概算/
がいさんち /概算値/
がいさんようきゅう /概算要求/
がいざい /外材/外在/
がいざいてき /外在的/
がいし /外史/外資/外紙/碍子/
がいしけい /外資系/
がいしほういいかんそく /外篩包囲維管束/
がいしゃ /会社/外車/
がいしゃや /外車屋/
がいしゅう /外周/
がいしゅうき /概周期/
がいしゅうちょう /外周長/
がいしゅうぶ /外周部/
がいしゅつ /外出/
がいしゅつきょか /外出許可/
がいしゅつきんし /外出禁止/
がいしゅつさき /外出先/
がいしゅつじ /外出時/
がいしゅつちゅう /外出中/
がいしゅつまえ /外出前/
がいしょ /外書/
がいしょう /外傷/外相/外商/外渉/街娼/
がいしょうぶ /外商部/
がいしょく /外食/
がいしょくさんぎょう /外食産業/
がいしょくや /外食屋/
がいしょこうどく /外書講読/
がいしん /外信/外申/
がいじ /外字/外耳/
がいじつせい /概日性/
がいじとうろく /外字登録/
がいじとうろくきのう /外字登録機能/
がいじどう /外耳道/
がいじどういりぐち /外耳道入口/
がいじにゅうりょく /外字入力/
がいじゅ /外需/
がいじよう /外字用/
がいじん /外人/
がいじんあいて /外人相手/
がいじんおんな /外人女/
がいじんかしゅ /外人歌手/
がいじんぐみ /外人組/
がいじんけんきゅうしゃ /外人研究者/
がいじんしょうたいせんしゅ /外人招待選手/
がいじんせんしゅ /外人選手/
がいじんぜい /外人勢/
がいじんぶたい /外人部隊/
がいじんぼち /外人墓地/
がいじんりょうきん /外人料金/
がいじんわく /外人枠/
がいすう /概数/
がいず /概図/
がいせい /外征/外生/
がいせいき /外性器/
がいせいせいちょう /外生生長/
がいせいぶんし /外生分枝/
がいせき /外積/外戚/
がいせつ /概説/外接/
がいせつしょ /概説書/
がいせつちょうほうけい /外接長方形/
がいせつほう /外接法/
がいせん /外線/凱旋/街宣/
がいせんきこく /凱旋帰国/
がいせんしゃ /街宣車/
がいせんしょう /凱旋賞/
がいせんちょくつう /外線直通/
がいせんもん /凱旋門/
がいせんもんしょう /凱旋門賞/
がいせんよう /外線用/
がいぜん /蓋然/
がいぜんせい /蓋然性/
がいそう /外挿/外層/外装/
がいそうち /外挿値/
がいそうぶひん /外装部品/
がいそく /外足/外側/
がいそくど /外測度/
がいたい /外帯/
がいため /外為/
がいためほう /外為法/
がいたん /慨嘆/慨歎/外端/
がいだい /外大/
がいち /外地/
がいちゅう /外注/害虫/
がいちゅうくじょ /害虫駆除/
がいちゅうさき /外注先/
がいちょう /害鳥/
がいてき /外的/外敵/
がいてきよういん /外的要因/
がいてん /外点/
がいでん /外電/外伝/
がいでんてき /外伝的/
がいとう /該当/街頭/外灯/街灯/外套/街燈/
がいとうえんぜつ /街頭演説/
がいとうかしょ /該当個所/
がいとうきかん /該当機関/
がいとうきしゅ /該当機種/
がいとうきじ /該当記事/
がいとうくかん /該当区間/
がいとうこうしゅうでんわ /街頭公衆電話/
がいとうこうもく /該当項目/
がいとうしゃ /該当者/該当車/
がいとうしゃしゅ /該当車種/
がいとうすう /該当数/
がいとうはんばい /街頭販売/
がいとうぶぶん /該当部分/
がいとうぼきん /街頭募金/
がいど /ガイド/
がいどう /外道/
がいどく /害毒/
がいねん /概念/外燃/
がいねんか /概念化/
がいねんがくしゅう /概念学習/
がいねんきかん /外燃機関/
がいねんきてい /概念規定/
がいねんくうかん /概念空間/
がいねんけいせい /概念形成/
がいねんこうぞう /概念構造/
がいねんじたい /概念自体/
がいねんず /概念図/
がいねんせかい /概念世界/
がいねんてき /概念的/
がいねんてきちしき /概念的知識/
がいねんりかい /概念理解/
がいはいよう /外胚葉/
がいはく /外泊/該博/
がいはくりょこう /外泊旅行/
がいはん /外販/
がいはんぼし /外反母趾/外反拇趾/外反拇指/
がいはんぼしよう /外反母趾用/
がいばん /外盤/
がいひ /外皮/外被/
がいひがわ /外皮側/
がいひょう /概評/
がいびぶん /外微分/
がいふうしゃかん /凱風社刊/
がいぶ /外部/
がいぶいぶくろ /外部胃袋/
がいぶかんきょう /外部環境/
がいぶかんすう /外部関数/
がいぶきおく /外部記憶/
がいぶきおくばいたい /外部記憶媒体/
がいぶきかん /外部機関/
がいぶきき /外部機器/
がいぶけいしき /外部形式/
がいぶこんごうしき /外部混合式/
がいぶさんしょう /外部参照/
がいぶしゅつりょく /外部出力/
がいぶしよう /外部仕様/
がいぶせい /外部生/
がいぶせかい /外部世界/
がいぶそしき /外部組織/
がいぶぞうせつ /外部増設/
がいぶたんし /外部端子/
がいぶだんたい /外部団体/
がいぶちょうこう /外部調光/
がいぶちょうこうしき /外部調光式/
がいぶてき /外部的/
がいぶでんげん /外部電源/
がいぶどうき /外部同期/
がいぶどうきがた /外部同期型/
がいぶにゅうりょく /外部入力/
がいぶにゅうりょくたんし /外部入力端子/
がいぶぶんぴつこうぞう /外部分泌構造/
がいぶへんすう /外部変数/
がいぶもう /外部網/
がいぶん /外聞/外分/
がいへき /外壁/
がいへきあつ /外壁厚/
がいへきじょう /外壁上/
がいほう /概包/
がいぼう /外貌/
がいまい /外米/
がいむ /外務/
がいむしょう /外務省/
がいむしょうじかん /外務省次官/
がいむだいじん /外務大臣/
がいめん /外面/
がいめんせい /外面性/
がいめんてき /外面的/
がいもう /外毛/
がいもくほういいかんそく /外木包囲維管束/
がいもん /外門/
がいや /外野/
がいやしゅ /外野手/
がいやじゆうせき /外野自由席/
がいやじゆうせきけん /外野自由席券/
がいやじん /外野陣/
がいやせき /外野席/
がいやほうめん /外野方面/
がいゆう /外遊/
がいよう /概要/外用/外洋/
がいようがわ /外洋側/
がいようしょ /概要書/
がいようしょうかい /概要紹介/
がいようず /概要図/
がいようせつめい /概要説明/
がいようせつめいしょ /概要説明書/
がいようづ /概要図/
がいようやく /外用薬/
がいらい /外来/
がいらいご /外来語/
がいらいざつおん /外来雑音/
がいらいしゅ /外来種/
がいらいてき /外来的/
がいらいよう /外来用/
がいらん /外乱/
がいりゃく /概略/
がいりゃくず /概略図/
がいりゃくてき /概略的/
がいりょく /外力/
がいりょくせいぶん /外力成分/
がいりん /外輪/
がいりんざん /外輪山/
がいろ /街路/
がいろじゅ /街路樹/
がいろとう /街路灯/
がいろん /概論/
がいわくせい /外惑星/
がう /號/
がえ /換/
がえし /返し/
がお /顔/顏/
がおう /画王/
がおか /ヶ丘/
がおんしつ /画音質/
がか /画家/画架/
がかい /瓦解/瓦壊/
がかく /画角/畫角/
がかり /係/掛/
がが /峨々/峨峨/
ががく /雅楽/
がき /垣/餓鬼/
がきだいしょう /餓鬼大将/
がぎじょうぶ /鉤状部/
がぎょ /駕御/
がぎょう /ガ行/
がく /額/学/楽/岳/顎/學/愕/咢/斈/嶽/樂/諤/鄂/齶/壑/萼/鍔/鰐/
がくい /学位/
がくいき /学位記/
がくいきじゅよしき /学位記授与式/
がくいしんさ /学位審査/
がくいじゅよきこう /学位授与機構/
がくいじゅよしき /学位授与式/
がくいめい /学位名/
がくいり /額入り/
がくいろんぶん /学位論文/
がくいん /学院/
がくいんだい /学院大/
がくいんない /学院内/
がくえん /学園/
がくえんがわ /学園際/
がくえんさい /学園祭/
がくえんさいご /学園祭後/
がくえんとし /学園都市/
がくえんとしせん /学園都市線/
がくえんふんそう /学園紛争/
がくえんまえ /学園前/
がくえんまええきげしゃ /学園前駅下車/
がくえんもの /学園物/
がくおん /楽音/
がくおんごうせい /楽音合成/
がくがい /学外/
がくがいしゃ /学外者/
がくきょうかい /学協会/
がくぎょう /学業/
がくぎょうじょう /学業上/
がくぎょうせいせき /学業成績/
がくぐん /学群/
がくげい /学芸/
がくげいいん /学芸員/
がくげいかい /学芸会/
がくげいだい /学芸大/
がくげいだいがく /学芸大学/
がくげいだいがくえき /学芸大学駅/
がくげいだいふぞく /学芸大付属/
がくげいぶんこ /学芸文庫/
がくげき /楽劇/
がくさい /学祭/学際/学才/
がくさいか /学際化/
がくさいこうりゅう /学際交流/
がくさいてき /学際的/
がくさいぶんや /学際分野/
がくさいもんだい /学際問題/
がくさいりょういき /学際領域/
がくし /学士/学資/
がくしいじょう /学士以上/
がくしいん /学士院/
がくしかい /学士会/
がくしかいかん /学士会館/
がくしかいかんぶんかん /学士会館分館/
がくしかいめいぼ /学士会名簿/
がくしき /学識/学指揮/
がくしにゅうがく /学士入学/
がくしにゅうがくせいど /学士入学制度/
がくしゃ /学者/学舎/
がくしゃけい /学者系/
がくしゃたち /学者達/
がくしゃない /学者内/
がくしゃはだ /学者肌/
がくしゅう /学習/学修/
がくしゅうあるごりずむ /学習アルゴリズム/
がくしゅういん /学習院/
がくしゅういんしょとうか /学習院初等科/
がくしゅういんだい /学習院大/
がくしゅういんだいがく /学習院大学/
がくしゅういんめじろ /学習院目白/
がくしゅうかい /学習会/
がくしゅうかいすう /学習回数/
がくしゅうかがく /学習科学/
がくしゅうかてい /学習過程/
がくしゅうかのう /学習可能/
がくしゅうかのうせい /学習可能性/
がくしゅうかん /学習観/
がくしゅうかんきょう /学習環境/
がくしゅうがた /学習型/
がくしゅうきかい /学習機械/
がくしゅうきかん /学習期間/
がくしゅうきこう /学習機構/
がくしゅうきそく /学習規則/
がくしゅうきのう /学習機能/
がくしゅうけい /学習系/
がくしゅうけいすう /学習係数/
がくしゅうけいとう /学習系統/
がくしゅうけっか /学習結果/
がくしゅうけんきゅう /学習研究/
がくしゅうけんきゅうしゃ /学習研究社/
がくしゅうこうか /学習効果/
がくしゅうご /学習後/
がくしゅうさいくる /学習サイクル/
がくしゅうさんぷる /学習サンプル/
がくしゅうしどう /学習指導/
がくしゅうしどうようりょう /学習指導要領/
がくしゅうしゃ /学習者/
がくしゅうしゃじしん /学習者自身/
がくしゅうしゅうごう /学習集合/
がくしゅうしゅうりょうご /学習終了後/
がくしゅうしょうがい /学習障害/
がくしゅうしんごう /学習信号/
がくしゅうしんりがく /学習心理学/
がくしゅうじ /学習時/
がくしゅうじかん /学習時間/
がくしゅうじてん /学習辞典/
がくしゅうじゅく /学習塾/
がくしゅうじょう /学習上/
がくしゅうじょうきょう /学習状況/
がくしゅうじょうけん /学習条件/
がくしゅうじょうほう /学習情報/
がくしゅうずかん /学習図鑑/
がくしゅうずみ /学習済み/
がくしゅうせいぎょ /学習制御/
がくしゅうせっと /学習セット/
がくしゅうせつ /学習説/
がくしゅうそうだん /学習相談/
がくしゅうそく /学習則/
がくしゅうそくど /学習速度/
がくしゅうちゅう /学習中/
がくしゅうづくえ /学習机/
がくしゅうでえた /学習データ/
がくしゅうないよう /学習内容/
がくしゅうないようしだい /学習内容次第/
がくしゅうのうりょく /学習能力/
がくしゅうはん /学習班/
がくしゅうばいあす /学習バイアス/
がくしゅうひょうげん /学習表現/
がくしゅうふのう /学習不能/
がくしゅうぶぶん /学習部分/
がくしゅうほう /学習法/
がくしゅうほうしき /学習方式/
がくしゅうほうほう /学習方法/
がくしゅうもんだい /学習問題/
がくしゅうよう /学習用/
がくしゅうようりょう /学習容量/
がくしゅうりつ /学習率/
がくしゅうりょういき /学習領域/
がくしゅうりょく /学習力/
がくしゅうりろん /学習理論/
がくしゅうれい /学習例/
がくしょう /楽章/
がくしょく /学食/
がくしん /学振/学術審議会/学術振興会/
がくしんけんきゅういん /学振研究員/
がくじ /学事/
がくじぶ /学事部/
がくじゅつ /学術/
がくじゅつかいぎ /学術会議/
がくじゅつかつどう /学術活動/
がくじゅつけい /学術系/
がくじゅつけんきゅう /学術研究/
がくじゅつけんきゅうとし /学術研究都市/
がくじゅつこうえんかい /学術講演会/
がくじゅつざっし /学術雑誌/
がくじゅつし /学術誌/
がくじゅつしょ /学術書/
がくじゅつしんぎかい /学術審議会/
がくじゅつしんこう /学術振興/
がくじゅつじょう /学術上/
がくじゅつじょうほう /学術情報/
がくじゅつだんたい /学術団体/
がくじゅつてき /学術的/
がくじゅつてきかち /学術的価値/
がくじゅつてきわだい /学術的話題/
がくじゅつどうこう /学術動向/
がくじゅつはかせ /学術博士/
がくじゅつもくてき /学術目的/
がくじゅつよう /学術用/
がくじゅつようご /学術用語/
がくじゅつようごしゅう /学術用語集/
がくじゅつりよう /学術利用/
がくじゅつろんぶん /学術論文/
がくじょう /学情/学術情報センター/
がくじょうもう /学情網/学術情報センター網/
がくせい /学生/学制/
がくせいいん /学生員/
がくせいうんどう /学生運動/
がくせいえいがれんめい /学生映画連盟/
がくせいえんごかい /学生援護会/
がくせいか /学生課/学生掛/
がくせいかい /学生会/
がくせいかいいん /学生会員/
がくせいかいかくいご /学制改革以後/
がくせいかいかん /学生会舘/学生会館/
がくせいかばん /学生鞄/
がくせいかん /学生間/
がくせいがかり /学生係/
がくせいがわ /学生側/
がくせいきかい /学生棋界/
がくせいきしゅくしゃ /学生寄宿舎/
がくせいきょういく /学生教育/
がくせいけっこん /学生結婚/
がくせいけん /学生券/
がくせいげきだん /学生劇団/
がくせいさいご /学生最後/
がくせいさんか /学生参加/
がくせいしき /学生指揮/
がくせいしゅくしゃ /学生宿舎/
がくせいしょう /学生証/
がくせいしょうばんごう /学生証番号/
がくせいしょくん /学生諸君/
がくせいしんぶん /学生新聞/
がくせいじしん /学生自身/
がくせいじだい /学生時代/
がくせいじだいいらい /学生時代以来/
がくせいじちかい /学生自治会/
がくせいじっけん /学生実験/
がくせいじっしゅう /学生実習/
がくせいすう /学生数/
がくせいずもう /学生相撲/
がくせいせいかつ /学生生活/
がくせいせんしゅけん /学生選手権/
がくせいせんばつ /学生選抜/
がくせいたいしょう /学生対象/
がくせいたち /学生達/
がくせいちゅう /学生中/
がくせいなかま /学生仲間/
がくせいばんごう /学生番号/
がくせいひかえしつ /学生控室/
がくせいひとり /学生一人/
がくせいびんらん /学生便覧/
がくせいふう /学生風/
がくせいふく /学生服/
がくせいぶ /学生部/
がくせいぶかい /学生部会/
がくせいぶちょう /学生部長/
がくせいぼしゅう /学生募集/
がくせいむき /学生向/
がくせいやきゅう /学生野球/
がくせいやきゅうきょうかい /学生野球協会/
がくせいよう /学生用/
がくせいようあんない /学生用案内/
がくせいりょう /学生寮/
がくせいりょうきん /学生料金/
がくせいわりびき /学生割引/
がくせき /学籍/
がくせきばんごう /学籍番号/
がくせきぼ /学籍簿/
がくせつ /学説/楽節/
がくせつじょう /学説上/
がくぜん /愕然/
がくそう /学窓/楽想/学僧/学聡/
がくそく /学則/
がくそつ /学卒/
がくたい /楽隊/
がくたいようご /楽隊用語/
がくたんきょうかん /学担教官/
がくだん /楽団/楽壇/
がくちょう /学長/楽長/
がくちょうしつ /学長室/
がくていち /確定地/
がくてき /学的/
がくてん /楽典/
がくとう /咢筒/
がくとどういん /学徒動員/
がくどう /学童/
がくどうほいく /学童保育/
がくどうほいくしょ /学童保育所/
がくない /学内/
がくないえきでんたいかい /学内駅伝大会/
がくないかいかく /学内改革/
がくないがい /学内外/
がくないじゅんい /学内順位/
がくないせん /学内線/
がくないはいふよう /学内配布用/
がくないびん /学内便/
がくないぼうしょ /学内某所/
がくねん /学年/
がくねんてき /学年的/
がくねんまつ /学年末/
がくの /嶽野/
がくは /学派/
がくばす /学バス/
がくばつ /学閥/
がくひ /学費/岳飛;南宋の武将/
がくひめんじょ /学費免除/
がくふ /楽譜/
がくふう /学風/
がくふうりば /楽譜売場/
がくふか /楽譜化/
がくふがた /楽譜型/
がくふきごう /楽譜記号/
がくふきじゅつよう /楽譜記述用/
がくふしゅう /楽譜集/
がくふしゅっぱんしゃ /楽譜出版社/
がくふじょう /楽譜上/
がくふにゅうりょく /楽譜入力/
がくふにんしき /楽譜認識/
がくふひょうき /楽譜表記/
がくふや /楽譜屋/
がくふよう /楽譜用/
がくぶ /学部/
がくぶがくせい /学部学生/
がくぶがくせいじだい /学部学生時代/
がくぶきょういく /学部教育/
がくぶじだい /学部時代/
がくぶじむしつ /学部事務室/
がくぶせい /学部生/
がくぶそつ /学部卒/
がくぶたいかい /学部大会/
がくぶだんかい /学部段階/
がくぶち /額縁/
がくぶちょう /学部長/
がくぶない /学部内/
がくへん /がく片/咢片/萼片/
がくほう /学報/
がくむ /学務/
がくめい /学名/
がくめん /額面/
がくめんじょう /額面上/
がくめんてき /額面的/
がくもん /学問/
がくもんかん /学問観/
がくもんこうしょう /学問考証/
がくもんしゅほう /学問手法/
がくもんじょ /学問所/
がくもんじょう /学問上/
がくもんぜんぱん /学問全般/
がくもんたいけい /学問体系/
がくもんたいど /学問態度/
がくもんたんきゅう /学問探求/
がくもんてき /学問的/
がくもんてきぎょうせき /学問的業績/
がくもんてきこうりゅう /学問的交流/
がくもんてきしんり /学問的真理/
がくもんてきたいど /学問的態度/
がくもんぶんや /学問分野/
がくもんめん /学問面/
がくもんりょういき /学問領域/
がくや /楽屋/嶽野/
がくやうら /楽屋裏/
がくゆう /学友/
がくゆうかい /学友会/
がくゆうかいひ /学友会費/
がくゆうきょうかい /楽友協会/
がくようひん /学用品/
がくり /楽理/学理/
がくりょう /学寮/
がくりょうい /学寮委/
がくりょうせん /学寮専/
がくりょうせんもんいいんちょう /学寮専門委員長/
がくりょく /学力/
がくりょくいじょう /学力以上/
がくりょくぶそく /学力不足/
がくるい /学類/
がくれい /学齢/
がくれき /学歴/
がくれきじまん /学歴自慢/
がくれきじゅうし /学歴重視/
がくれん /学連/
がくわり /学割/
がくわりうんちん /学割運賃/
がくわりしんせい /学割申請/
がくわりせんよう /学割専用/
がけ /崖/垳/
がけい /芽型/
がけした /崖下/
がこう /画稿/
がご /雅語/
がごう /雅号/
がさ /傘/
がさい /画才/
がさくちゅう /画策中/
がざい /画材/
がざいてん /画材店/
がざいや /画材屋/
がし /樫/餓死/
がししゃ /餓死者/
がしつ /画質/
がしつこうじょう /画質向上/
がしつちょうせい /画質調整/
がしつてき /画質的/
がしつひかく /画質比較/
がしつれっか /画質劣化/
がしゅう /画集/我執/
がしゅん /賀春/
がしょう /賀正/画商/臥床/
がしんしょうたん /臥薪嘗胆/
がじょう /牙城/賀状/芽条/
がじょえんかんこう /雅叙園観光/
がじんかって /我侭勝手/
がす /ガス/瓦斯/
がせつ /我説/
がぜん /俄然/瓦全/
がそ /画素/
がそう /芽層/画層/
がそかん /画素間/
がそけいれつ /画素系列/
がそごと /画素毎/
がそすう /画素数/
がそち /画素値/
がそない /画素内/
がそみつど /画素密度/
がそりん /ガソリン/
がぞう /画像/
がぞうあっしゅく /画像圧縮/
がぞういがい /画像以外/
がぞうおうよう /画像応用/
がぞうかん /画像間/
がぞうぎじゅつかいはつ /画像技術開発/
がぞうけいしき /画像形式/
がぞうけんきゅうしつ /画像研究室/
がぞうけんきゅうじょ /画像研究所/
がぞうけんきゅうぶ /画像研究部/
がぞうけんさく /画像検索/
がぞうこうがく /画像工学/
がぞうこうがっか /画像工学科/
がぞうしゅうふく /画像修復/
がぞうしょり /画像処理/画像処/
がぞうしょりしつ /画像処理室/
がぞうしょりそうち /画像処理装置/
がぞうじょう /画像上/
がぞうじょうほう /画像情報/
がぞうせいせい /画像生成/
がぞうせいせいけんきゅう /画像生成研究/
がぞうせいせいそうち /画像生成装置/
がぞうてき /画像的/
がぞうでんしがっかい /画像電子学会/
がぞうでんそう /画像伝送/
がぞうとくちょうちゅうしゅつ /画像特徴抽出/
がぞうにゅうりょく /画像入力/
がぞうにゅうりょくよう /画像入力用/
がぞうにんしき /画像認識/
がぞうひょうじ /画像表示/
がぞうぶ /画像部/
がぞうめん /画像面/
がぞうりかい /画像理解/
がた /型/潟/方/形/難/
がたさ /難さ/
がだい /画題/
がちょう /画調/画帖/鵝鳥/鵞鳥/
がっ /合/
がっか /学科/学課/
がっかい /学会/学界/
がっかいいん /学会員/
がっかいかいいん /学会会員/
がっかいかいひ /学会会費/
がっかいかつどう /学会活動/
がっかいかんけい /学会関係/
がっかいきかんちゅう /学会期間中/
がっかいきょうさい /学会共催/
がっかいけいしき /学会形式/
がっかいし /学会誌/
がっかいしかく /学会資格/
がっかいしけいさい /学会誌掲載/
がっかいしゅっせき /学会出席/
がっかいしょう /学会賞/
がっかいじき /学会時期/
がっかいじむきょく /学会事務局/
がっかいじょう /学会上/
がっかいなど /学会等/
がっかいはっこう /学会発行/
がっかいはっぴょう /学会発表/
がっかいはっぴょうろんぶん /学会発表論文/
がっかいまえ /学会前/
がっかいめい /学会名/
がっかいろんぶん /学会論文/
がっかがい /学科外/
がっかごと /学科毎/
がっかしけん /学科試験/
がっかしゅっしん /学科出身/
がっかしょゆう /学科所有/
がっかぜんきょういん /学科全教員/
がっかそつぎょうしゃ /学科卒業者/
がっかちょう /学科長/
がっかどくじ /学科独自/
がっかない /学科内/
がっかめんじょ /学科免除/
がっかもく /学科目/
がっかん /学館/
がっき /楽器/学期/
がっきいがい /楽器以外/
がっきえんそう /楽器演奏/
がっきえんそうか /楽器演奏家/
がっきおん /楽器音/
がっきかん /楽器間/
がっきこゆう /楽器固有/
がっきずき /楽器好き/
がっきそうしゃ /楽器奏者/
がっきてん /楽器店/
がっきてんしゅさい /楽器店主催/
がっきはくぶつかん /楽器博物館/
がっきへんせい /楽器編成/
がっきほう /楽器法/
がっきほんらい /楽器本来/
がっきまつ /学期末/
がっきめい /楽器名/
がっきや /楽器屋/
がっきゅう /学級/学究/
がっきゅういいん /学級委員/
がっきゅういいんちょう /学級委員長/
がっきゅうかい /学級会/
がっきゅうき /学休期/
がっきゅうへいさ /学級閉鎖/
がっきょく /楽曲/
がっきょくこうせい /楽曲構成/
がっく /学区/
がっくがい /学区外/
がっくこう /学区校/
がっくない /学区内/
がっくり /(concat "(--\073)")/(concat "(-_-\073)")/
がっけい /学系/
がっけん /学研/
がっけんとし /学研都市/
がっけんとしせん /学研都市線/
がっこう /学校/學校/
がっこういがい /学校以外/
がっこううんえい /学校運営/
がっこうかんけいしゃ /学校関係者/
がっこうかんり /学校管理/
がっこうがい /学校外/
がっこうがわ /学校側/
がっこうきゅうぎょうきかん /学校休業期間/
がっこうきゅうしょく /学校給食/
がっこうきょういく /学校教育/
がっこうきょういくばんぐみ /学校教育番組/
がっこうきょういくほう /学校教育法/
がっこうきょうし /学校教師/
がっこうぐん /学校群/
がっこうけんしん /学校検診/
がっこうさい /学校祭/
がっこうしき /学校式/
がっこうしきちない /学校敷地内/
がっこうしてい /学校指定/
がっこうしゅうへん /学校周辺/
がっこうしんぶん /学校新聞/
がっこうじむ /学校事務/
がっこうすいせん /学校推薦/
がっこうせいかつ /学校生活/
がっこうせいど /学校制度/
がっこうせっちぎむ /学校設置義務/
がっこうたんい /学校単位/
がっこうちゅうしゃじょう /学校駐車場/
がっこうちょう /学校長/
がっこうない /学校内/
がっこうほうじん /学校法人/
がっこうめい /学校名/
がっさい /合切/合財/
がっさく /合作/
がっさん /合算/月山/
がっしゅう /合衆/
がっしゅうこく /合衆国/
がっしゅうこくけいゆ /合衆国経由/
がっしゅうこくけんぽう /合衆国憲法/
がっしゅうこくせいふ /合衆国政府/
がっしゅうこくどくとく /合衆国独特/
がっしゅうこくはつ /合衆国発/
がっしゅうこくほうれい /合衆国法令/
がっしゅく /合宿/
がっしゅくけいしき /合宿形式/
がっしゅくさき /合宿先/
がっしゅくじょ /合宿所/
がっしゅくちゅう /合宿中/
がっしょう /合唱/合掌/合従/合焦/
がっしょうきょく /合唱曲/
がっしょうきょくしゅう /合唱曲集/
がっしょうしどう /合唱指導/
がっしょうたいかい /合唱大会/
がっしょうだん /合唱団/
がっしょうだんいん /合唱団員/
がっしょうひねり /合掌捻り/
がっしょうれんこう /合従連衡/
がっしょうれんしゅう /合唱練習/
がっせい /合生/
がっせん /合戦/
がっそう /合奏/
がっそうきょうそうきょく /合奏協奏曲/
がっそうだん /合奏団/
がったい /合体/合體/
がったいご /合体後/
がったいほうほう /合体方法/
がったいまえ /合体前/
がったいよう /合体用/
がったいわざ /合体技/
がっち /合致/
がっちゃく /合着/
がって /勝手/
がってん /合点/合點/
がっと /ガット/
がっぴ /月日/
がっぴつ /合筆/
がっぺい /合併/
がっぺいご /合併後/
がっぺいごう /合併号/
がっぺいしゅうごう /合併集合/
がっぺいしょう /合併症/
がっぺいしょり /合併処理/
がっぺいじ /合併時/
がっぺいぞうだいごう /合併増大号/
がっぽん /合本/
がつ /月/歹/
がつ#にち /月#日/
がつころ /月頃/
がつごう /月号/
がつすえ /月末/
がつちゅう /月中/
がつど /月度/
がつばん /月版/
がつぶん /月分/
がつまつ /月末/
がてん /合点/
がでんいんすい /我田引水/
がと /賀戸/
がとう /餓島/
がな /仮名/
がにゅうどう /我入道/
がね /金/鐘/
がはく /画伯/
がばん /画板/
がひつ /画筆/
がひん /訝賓/
がびょう /画鋲/
がふう /画風/
がへい /画餅/
がべい /画餅/
がほう /画法/芽胞/
がま /蝦蟇/蒲/釜/蝦蟆/蟇/
がまごうり /蒲郡/
がまごおり /蒲郡/
がまもく /ガマ目/Typales/
がまん /我慢/
がみ /上/髪/髮/
がむ /ガム/
がめん /画面/
がめんいちばんうえ /画面一番上/
がめんいちまいぶん /画面一枚分/
がめんいっぱい /画面一杯/
がめんかいぞうど /画面解像度/
がめんかだん /画面下段/
がめんかん /画面間/
がめんがい /画面外/
がめんけいしき /画面形式/
がめんこうしん /画面更新/
がめんこうせい /画面構成/
がめんさつえい /画面撮影/
がめんした /画面下/
がめんしゃしん /画面写真/
がめんしゅつりょく /画面出力/
がめんしゅつりょくけい /画面出力系/
がめんしょうきょ /画面消去/
がめんじょう /画面上/
がめんじょうぶ /画面上部/
がめんせいぎょ /画面制御/
がめんせっけい /画面設計/
がめんぜんたい /画面全体/
がめんたてほうこう /画面縦方向/
がめんちゅう /画面中/
がめんちゅうおう /画面中央/
がめんちゅうおううえ /画面中央上/
がめんちゅうおうぶ /画面中央部/
がめんてき /画面的/
がめんてまえ /画面手前/
がめんない /画面内/
がめんにゅうりょく /画面入力/
がめんはし /画面端/
がめんはば /画面幅/
がめんひょうじ /画面表示/
がめんひょうじいき /画面表示域/
がめんひょうじよう /画面表示用/
がめんびょうが /画面描画/
がめんぶんかつ /画面分割/
がめんみぎ /画面右/
がも /賀茂/
がもう /蒲生/
がようし /画用紙/
がよく /我欲/
がら /柄/
がらく /雅楽/
がらす /硝子/ガラス/
がらすたい /硝子体/
がらっと /ガラっと/
がらん /伽藍/
がりべん /ガリ勉/
がりゅう /我流/
がりょう /雅量/
がりょうてんせい /画竜点睛/
がりょく /画力/
がりょくへんちょうしゅぎ /画力偏重主義/
がりん /芽鱗/
がれーじ /ガレージ/
がれき /瓦礫/
がろ /ガロ/
がろう /画廊/餓狼/
がろうきっさ /画廊喫茶/
がろうでんせつ /餓狼伝説/
がわ /側/川/河/巛/
がん /元/含/丸/願/頑/顔/岩/眼/岸/癌/雁/贋/翫/巌/玩/龕/厳/ガン/偐/嚴/嵒/巖/阮/頷/顏/鴈/鳫/
がんあつ /眼圧/
がんい /含意/⊃/
がんいりょう /癌医療/
がんえん /岩塩/
がんか /眼科/癌化/眼下/眼窩/
がんかい /眼界/岩塊/眼科医/
がんかよう /眼科用/
がんきゅう /眼球/
がんきゅううんどう /眼球運動/
がんきゅうたん /眼球譚/
がんきゅうない /眼球内/
がんきょう /眼鏡/頑強/元凶/
がんきょうせい /頑強性/
がんきん /眼筋/元金/
がんぎ /雁木/
がんぐ /玩具/
がんぐうりば /玩具売場/
がんぐせんもんてん /玩具専門店/
がんぐばこ /玩具箱/
がんぐや /玩具屋/
がんけい /眼形/
がんけん /頑健/癌研/眼瞼/
がんけんしん /癌検診/
がんけんせい /頑健性/
がんこ /頑固/
がんこう /眼光/雁行/
がんこくもじ /岩刻文字/
がんこもの /巌固者/頑固者/
がんさ /眼差/
がんさいぼう /癌細胞/
がんさく /贋作/
がんし /眼視/
がんしき /眼識/
がんしぼう /癌死亡/
がんしぼうゆ /含脂肪油/
がんしゅう /含羞/
がんしょ /願書/
がんしょう /岩礁/岩漿/
がんしょきぼう /願書希望/
がんしょく /顔色/
がんしん /眼振/
がんじ /元治/
がんじつ /元日/
がんじつよう /元日用/
がんじょう /頑丈/
がんじょうせい /頑丈性/
がんじょうにんげん /頑丈人間/
がんじろう /鴈治郎/
がんせいひろう /眼精疲労/
がんせき /岩石/
がんせきがく /岩石学/
がんぜん /眼前/
がんそ /元祖/
がんそう /含嗽/
がんそてんさい /元祖天才/
がんたい /眼帯/
がんたろう /巌太郎/
がんたん /元旦/
がんたんれいはい /元旦礼拝/
がんだい /岩大/
がんだれ /厂/
がんちく /含蓄/
がんちゅう /眼中/
がんちりょう /癌治療/
がんつう /眼痛/
がんてい /眼底/
がんていしゃしん /眼底写真/
がんていしゅっけつ /眼底出血/
がんとくせん /岩徳線/
がんねん /元年/
がんねんしき /元年式/
がんねんど /元年度/
がんのすけ /雁之助/
がんばり /頑張り/
がんばん /岩盤/
がんぱく /雁帛/
がんびょう /眼病/
がんぺい /贋幣/
がんぺき /岩壁/岸壁/
がんぼう /願望/眼房/
がんぽん /元本/
がんま /γ/Γ/
がんません /γ線/
がんめい /頑迷/
がんめいころう /頑迷固陋/
がんめん /顔面/
がんめんそうはく /顔面蒼白/
がんもう /願望/
がんもく /眼目/
がんもん /雁門/
がんやく /丸薬/
がんゆう /含有/
がんゆうりつ /含有率/
がんゆうりょう /含有量/
がんゆごうきん /含油合金/
がんよくせい /癌抑制/
がんよくせいいんし /癌抑制因子/
がんよぼう /癌予防/
がんらい /元来/
がんり /元利/
がんりき /眼力/
がんりゅうじま /厳流島/巌流島/
がんりゅうじまけっせん /厳流島決戦/
がんりょう /顔料/含量/
がんろう /玩弄/
き /気/木/機/記/基/器/貴/紀/期/寄/既/起/机/危/鬼/季/旗/騎/輝/亀/規/祈/帰/軌/汽/己/奇/樹/黄/棋/飢/稀/忌/幾/揮/棄/徽/喜/岐/饋/希/綺/畿/毅/企/氣/僖/来/嬉/伎/愧/着/悸/棊/聞/妓/城/生/麒/倚/熈/窺/來/冀/几/剞/匱/卉/唏/喟/噐/圻/毀/竒/屓/幃/弃/徠/愾/憙/掎/揆/旡/晞/暉/曁/朞/杞/榿/欷/欹/歸/麾/气/淇/煕/熹/燬/猗/畸/癸/皈/瞶/祺/禧/稘/羈/羇/耆/虧/覊/覬/詭/諱/譏/跂/跪/逵/餽/饑/馗/騏/驥/龜/熙/箕/枳/嵜/祁/碁/碕/其/槻/肌/姫/鰭/
き> /貴/
きー /キー/
きーせん /妓生/
きーたっち /キータッチ/
きーぼーど /キーボード/
きーわーど /キーワード/
きあ /騎亜/
きあい /気合い/気合/
きあつ /気圧/
きあつけい /気圧計/
きあつはいち /気圧配置/
きあん /起案/
きい /紀伊/奇異/貴意/忌諱/聞い/聴い/
きいかつうら /紀伊勝浦/
きいけ /紀伊家/
きいたなべ /紀伊田辺/
きいち /喜一/輝一/喜市/
きいちろう /喜一郎/
きいと /生糸/
きいとん /喜頓/
きいはんとう /紀伊半島/
きいはんとうおき /紀伊半島沖/
きいはんとうなんぶ /紀伊半島南部/
きいれ /喜入/
きいろ /黄色/
きいろせん /黄色線/
きいろぼん /黄色本/
きいん /起因/
きいんげん /起因源/
きう /気宇/
きうえ /木植/
きうえはら /木上原/
きうち /木内/
きうら /木浦/
きうん /気運/機運/
きえ /消え/帰依/気恵/
きえい /気鋭/機影/
きえこ /喜恵子/
きえつ /喜悦/
きえん /気炎/奇縁/機縁/気焔/
きえんさん /希塩酸/
きおい /気負い/紀尾井/
きおう /既往/棋王/
きおうしょう /既往症/
きおうじんじゃ /鬼王神社/
きおうせん /棋王戦/
きおうれき /既往歴/
きおく /記憶/
きおくあいまい /記憶曖昧/
きおくいき /記憶域/
きおくいち /記憶位置/
きおくかのう /記憶可能/
きおくかんり /記憶管理/
きおくかんりきこう /記憶管理機構/
きおくくうかん /記憶空間/
きおくくらす /記憶クラス/
きおくけいしき /記憶形式/
きおくけつらく /記憶欠落/
きおくこうぞう /記憶構造/
きおくしゅだん /記憶手段/
きおくしょく /記憶色/
きおくじゅつ /記憶術/
きおくじょう /記憶上/
きおくせんめい /記憶鮮明/
きおくそうしつ /記憶喪失/
きおくそうち /記憶装置/
きおくそし /記憶素子/
きおくそしき /記憶組織/
きおくないよう /記憶内容/
きおくのうりょく /記憶能力/
きおくばいたい /記憶媒体/
きおくばしょ /記憶場所/
きおくぶ /記憶部/
きおくぶつ /記憶物/
きおくほじ /記憶保持/
きおくほじどうさ /記憶保持動作/
きおくぼ /記憶薄/
きおくようりょう /記憶容量/
きおくようりょうさいだい /記憶容量最大/
きおくりょう /記憶量/
きおくりょういき /記憶領域/
きおくりょく /記憶力/
きおち /気落ち/気落/
きおん /気温/気音/基音/
きおんさ /気温差/
きおんじたい /気温自体/
きおんじょうしょう /気温上昇/
きか /幾何/帰化/気化/貴下/奇禍/奇貨/貴家/貴課/麾下/
きかい /機械/機会/奇怪/器械/貴会/気塊/喜界/
きかいあぶら /機械油/
きかいいん /既会員/
きかいうちゅうがっか /機械宇宙学科/
きかいおん /機械音/
きかいか /機械科/機械化/
きかいかこうか /機械加工科/
きかいかどく /機械可読/
きかいかどくけいしき /機械可読形式/
きかいかんそう /機械乾燥/
きかいがく /機械学/
きかいがくしゅう /機械学習/
きかいがっかい /機械学会/
きかいきんとう /機会均等/
きかいぎけん /機械技研/
きかいぎじゅつけん /機械技術研/
きかいぎじゅつけんきゅうしょ /機械技術研究所/
きかいぎじゅつしゃ /機械技術者/
きかいけい /機械系/
きかいけいけいさんき /機械系計算機/
きかいけいさん /機械計算/
きかいけん /機械研/機械研究所/
きかいけんきゅうしょ /機械研究所/
きかいけんきゅうじょ /機械研究所/
きかいこう /機械工/
きかいこうがく /機械工学/
きかいこうがくか /機械工学科/
きかいこうがくせんこう /機械工学専攻/
きかいこうがっか /機械工学科/
きかいこうがっかけい /機械工学科系/
きかいこうさく /機械工作/
きかいご /機械語/
きかいさよう /機械作用/
きかいざいりょうがく /機械材料学/
きかいしき /機械式/
きかいしきじゅぞうき /機械式受像機/
きかいしきとけい /機械式時計/
きかいしつ /機械室/
きかいしょり /機械処理/
きかいしんこうかいかん /機械振興会館/
きかいしんどう /機械振動/
きかいじょうほう /機械情報/
きかいせいぎょ /機械制御/
きかいせいめいたい /機械生命体/
きかいそうおん /機械騒音/
きかいそしき /機械組織/
きかいたいそう /器械体操/
きかいだいにこうがくか /機械第二工学科/
きかいちのう /機械知能/
きかいちのうこうがくか /機械知能工学科/
きかいつうくかん /既開通区間/
きかいてき /機械的/
きかいてきいんが /機械的因果/
きかいてききょうど /機械的強度/
きかいてきたいわ /機械的対話/
きかいない /機械内/
きかいにんしき /機械認識/
きかいはっけん /機械発券/
きかいはんてい /機械判定/
きかいぶひん /機械部品/
きかいほんやく /機械翻訳/
きかいめいれい /機械命令/
きかいや /機械屋/
きかいよう /機械用/
きかいりょう /機械量/
きかいろん /機械論/
きかおんきょうりろん /幾何音響理論/
きかおんせんほう /幾何音線法/
きかがく /幾何学/
きかがくてき /幾何学的/
きかがくてきこうそく /幾何学的拘束/
きかがくてきていぎ /幾何学的定義/
きかがくてきぶったいにんしき /幾何学的物体認識/
きかき /気化器/
きかきゅうすうてき /幾何級数的/
きかく /企画/規格/企劃/
きかくあん /企画案/
きかくうんえいけいえい /企画運営経営/
きかくか /規格化/企画課/
きかくかいはつ /企画開発/
きかくかいはつぶ /企画開発部/
きかくかいはつほんぶ /企画開発本部/
きかくかさぎょう /規格化作業/
きかくがい /規格外/
きかくがいひん /規格外品/
きかくきっぷ /企画切符/
きかくしつ /企画室/
きかくしゃ /企画者/
きかくしゅうだん /企画集団/
きかくしゅし /企画主旨/
きかくしょ /企画書/規格書/
きかくしょう /企画賞/
きかくしんこう /企画進行/
きかくじたい /企画自体/規格自体/
きかくじゅんきょ /規格準拠/
きかくじょう /規格上/
きかくじょうしゃけんるい /企画乗車券類/
きかくせい /企画性/
きかくせきにんしゃ /企画責任者/
きかくたんとうしゃ /企画担当者/
きかくだおれ /企画倒れ/
きかくだんかい /企画段階/
きかくちゅう /企画中/
きかくちょうさしつ /企画調査室/
きかくてん /企画展/
きかくとう /規格等/
きかくとういつ /規格統一/
きかくとうしょ /企画当初/
きかくないよう /規格内容/
きかくなど /規格等/
きかくばん /企画版/企画盤/規格判/
きかくひょう /規格票/規格表/
きかくひん /規格品/
きかくぶ /企画部/
きかくぶちょう /企画部長/
きかくぶつ /企画物/
きかくぶつき /企画部付/
きかくぶづけ /企画部付/
きかくほうしき /企画方式/
きかくりょく /企画力/
きかけいじょう /幾何形状/
きかげき /喜歌劇/
きかこうがく /幾何光学/
きかしょくぶつ /帰化植物/
きかじょうほう /幾何情報/
きかじん /帰化人/
きかてき /幾何的/
きかてきこうがく /幾何的光学/
きかでーた /幾何データ/
きかねつ /気化熱/
きかほせい /幾何補正/
きかん /期間/機関/基幹/饋還/貴艦/季刊/器官/帰還/気管/既刊/貴簡/旗艦/軌間/器管/汽罐/
きかんえんちょう /期間延長/
きかんかい /饋還会/
きかんがいしけん /期間外試験/
きかんく /機関区/
きかんくうぼ /帰還空母/
きかんけいとう /機関系統/
きかんげんてい /期間限定/
きかんこうざ /基幹講座/
きかんこうつうきかん /基幹交通機関/
きかんご /帰還後/
きかんごと /機関毎/
きかんし /機関紙/機関士/機関誌/季刊誌/気管支/
きかんしえん /気管支炎/
きかんしつ /機関室/
きかんしゃ /機関車/
きかんしゃいがい /機関車以外/
きかんしゃこうかん /機関車交換/
きかんしゃぜんたい /機関車全体/
きかんしゃぜんぶ /機関車全部/
きかんしゃだいよう /機関車代用/
きかんしゃどうし /機関車同士/
きかんしゃぶぶん /機関車部分/
きかんしゅ /機関手/
きかんじゅう /機関銃/
きかんぜんすう /奇完全数/
きかんちゅう /期間中/
きかんちゅうりよう /期間中利用/
きかんちょう /機関長/
きかんていし /期間停止/
きかんとうしか /機関投資家/
きかんない /期間内/
きかんぶ /機関部/
きかんぶん /既刊分/
きかんへんこう /軌間変更/
きかんへんこうだいしゃ /軌間変更台車/
きかんほう /機関砲/
きかんほうほう /帰還方法/
きかんまえ /期間前/
きかんめい /機関名/
きかんもう /基幹網/
きが /気賀/飢餓/
きがい /危害/気概/気愾/
きがえ /着替え/着替/着換え/
きがく /貴学/器楽/
きがくきょく /器楽曲/
きがじょうたい /飢餓状態/
きがじんこう /飢餓人口/
きがた /木方/木型/
きがね /気兼ね/気兼/
きがまえ /気構え/
きがる /気軽/
きがわ /木川/
きがん /祈願/奇岩/
きがんじょうじゅ /祈願成就/
きき /機器/危機/鬼気/飢鬼/記紀/諱忌/器機/騏驥/忌諱/汽機/奇気/奇奇/奇鰭/記旗/起期/帰期/喜気/毀棄/嬉嬉/輝輝/暉暉/窺基/嬉々/喜々/
ききあし /利き足/
ききいしき /危機意識/
ききいっぱつ /危機一髪/
ききうで /利腕/利き腕/
ききおう /騏鬼翁/
ききおぼえ /聞き覚え/
ききかいかい /奇々怪々/
ききかいひのうりょく /危機回避能力/
ききかん /危機感/
ききかんり /危機管理/
ききがわ /機器側/
ききけん /機器研/
ききけんきゅうじょ /機器研究所/
ききこうせい /機器構成/
ききこうにゅう /機器購入/
ききこみ /聞き込み/
ききごごち /聞き心地/
ききざけ /利酒/
ききしょしんしゃ /機器初心者/
ききしようりょう /機器使用料/
ききしんわ /記紀神話/
ききじぎょうぶ /機器事業部/
ききじぎょうほんぶ /機器事業本部/
ききじょうたい /危機状態/
ききすう /機器数/
ききすて /聞き捨て/
ききずて /聞き捨て/
ききだっしゅつ /危機脱出/
ききて /聴き手/聞き手/利き手/
ききてき /危機的/
ききてきじょうきょう /危機的状況/
ききてきじょうきょうか /危機的状況下/
ききてんじかい /機器展示会/
ききぶ /機器部/
ききみみ /聞き耳/利き耳/
ききめ /効き目/效/利き目/
ききもの /聴きもの/
ききゃく /棄却/
ききゃくすう /棄却数/
ききゃくほう /棄却法/
ききゃくりつ /棄却率/
ききやく /聞き役/
ききゅう /気球/希求/危急/
ききゅうほう /希求法/
ききょ /起居/
ききょう /帰郷/桔梗/帰京/帰敬/気胸/奇矯/
ききょうせんげん /帰郷宣言/
ききょうもく /キキョウ目/Campanulales/
ききるい /機器類/
ききん /基金/寄金/飢饉/
ききんぞく /貴金属/
きぎ /木々/樹々/
きぎけん /機技研/
きぎしつ /基技室/
きぎょう /企業/起業/
きぎょうあんない /企業案内/
きぎょうか /起業家/企業家/
きぎょうかいけい /企業会計/
きぎょうかつどう /企業活動/
きぎょうかん /企業間/
きぎょうがわ /企業側/
きぎょうけいえい /企業経営/
きぎょうけいえいしゃ /企業経営者/
きぎょうけんがく /企業見学/
きぎょうけんきゅうしゃ /企業研究者/
きぎょうけんきん /企業献金/
きぎょうごと /企業毎/
きぎょうしせい /企業姿勢/
きぎょうしゃかい /企業社会/
きぎょうじょうほう /企業情報/
きぎょうじん /企業人/
きぎょうせつめい /企業説明/
きぎょうぞう /企業像/
きぎょうたい /企業体/
きぎょうどりょく /企業努力/
きぎょうない /企業内/
きぎょうないきょういく /企業内教育/
きぎょうないしつぎょう /企業内失業/
きぎょうひみつ /企業秘密/
きぎょうべつ /企業別/
きぎょうめい /企業名/
きぎょうめいはいじょ /企業名排除/
きぎょうゆうち /企業誘致/
きぎょうりねん /企業理念/
きぎょうろんり /企業論理/
きく /菊/鞠/掬/聴く/椈/鞫/
きくい /喜久井/
きくいずみ /喜久泉/
きくいちょう /喜久井町/
きくえい /菊栄/
きくお /喜久男/喜久雄/菊男/菊雄/紀久男/
きくか /キク科/菊鹿/
きくかわ /菊川/掬川/
きくがわ /菊川/
きくこ /貴久子/菊子/喜久子/起久子/
きくごろう /菊五郎/
きくさと /喜久里/
きくざけ /菊酒/
きくじ /喜久治/
きくすい /菊水/
きくすいまる /菊水丸/
きくぞう /木久蔵/
きくた /菊田/
きくち /菊地/菊池/
きくちよ /菊千代/
きくな /菊名/
きくなえき /菊名駅/
きくなかん /菊名間/
きくに /喜国/
きくにんぎょう /菊人形/
きくね /菊音/
きくの /菊野/
きくのすけ /菊之助/
きくはら /菊原/
きくばり /気配り/気くばり/
きくばん /菊判/
きくひめ /菊姫/
きくひめあいこうかい /菊姫愛好会/
きくひめしゅぞう /菊姫酒造/
きくびし /菊菱/
きくま /菊間/
きくまさ /菊政/
きくまさむね /菊政宗/
きくもく /キク目/Asterales/
きくもくぐん /キク目群/
きくや /菊屋/
きくゆうかい /菊友会/
きくよう /菊陽/
きくん /貴君/
きぐ /危惧/器具/危ぐ/機具/
きぐう /奇遇/寄寓;寄迹、寓居/
きぐち /木口/
きぐつ /木靴/
きぐみ /木組み/
きぐらい /気位/
きぐるみ /着ぐるみ/
きぐろう /気苦労/
きけい /貴兄/奇形/畸型/畸形/畸計/詭計/
きけいぎょ /奇形魚/
きけいしき /木形式/
きけいじ /奇形児/
きけつ /帰結/既決/
きけつえんざん /帰結演算/
きけん /危険/棄権/気圏/貴顕/
きけんかいひ /危険回避/
きけんかいひじ /危険回避時/
きけんかいひのうりょく /危険回避能力/
きけんきゅう /危険球/
きけんきゅうしつ /貴研究室/
きけんこうい /危険行為/
きけんし /危険視/
きけんしそう /危険思想/
きけんしゃ /棄権者/
きけんしんし /貴顕紳士/
きけんじんぶつ /危険人物/
きけんすいいき /危険水域/
きけんせい /危険性/
きけんせいだい /危険性大/
きけんちたい /危険地帯/
きけんど /危険度/
きけんび /危険日/
きけんぶつ /危険物/
きけんぼうし /危険防止/
きけんりつ /危険率/
きけんりょういき /危険領域/
きげき /喜劇/
きげきえいが /喜劇映画/
きげきじん /喜劇人/
きげきつい /機撃墜/
きげつ /亀月/
きげん /期限/機嫌/起源/紀元/
きげんがい /期限外/
きげんぎれ /期限切/
きげんご /紀元後/
きげんせつ /起源説/紀元節/
きげんぜん /紀元前/
きげんぜんご /紀元前後/
きげんそう /起源層/
きこ /紀子/
きこう /機構/気候/寄稿/寄港/気功/気孔/紀行/季候/騎甲/奇行/帰港/貴校/起工/騎行/機甲/寄航/希覯/機工/帰航/稀覯/
きこうおんだん /気候温暖/
きこうかい /機甲界/
きこうがく /機構学/
きこうがたきんぞく /亀甲型金属/
きこうぐんだん /機甲軍団/
きこうけんきゅうぶ /機構研究部/
きこうし /貴公士/貴公子/
きこうしき /起工式/
きこうしすてむ /気候システム/
きこうしすてむけんきゅうせんたー /気候システム研究センター/
きこうしすてむせんたー /気候システムセンター/
きこうしだん /機甲師団/
きこうしゃ /寄稿者/
きこうじょう /機構上/
きこうせんたー /気候センター/
きこうぞう /木構造/
きこうち /寄港地/寄航地/
きこうてき /機構的/気候的/
きこうぶたい /機甲部隊/
きこうぶん /紀行文/
きこうぼん /稀覯本/
きこうもの /紀行物/
きこうりょうへい /機甲猟兵/
きこく /帰国/鬼哭/枳穀/
きこくきねん /帰国記念/
きこくご /帰国後/
きこくしじょ /帰国子女/
きこくしゅうしゅう /鬼哭啾啾/
きこくじ /帰国時/
きこくとどけ /帰国届/
きこくび /帰国日/
きこくびん /帰国便/
きこくほうこく /帰国報告/
きこくよう /帰国用/
きこし /木越/
きこつ /気骨/
きこない /木古内/
きこり /樵/
きこん /既婚/気根/
きこんしゃ /既婚者/
きこんじょし /既婚女子/
きこんじょせい /既婚女性/
きこんだんせい /既婚男性/
きこんれき /既婚歴/
きご /季語/木子/
きごう /記号/↓/※/→/■/←/↑/〒/＠/◎/◇/〓/▼/●/◆/▽/○/△/★/☆/□/§/▲/＞/×/＃/￣/％/【/℃/】/＆/￥/≠/＊/〜/＄/≧/』/∴/『/♀/＝/£/∞/≦/＜/♪/−/±/¢/″/》/―/′/＋/°/“/♂/々/《/／/〃/…/＼/÷/・/？/〕/」/！/｜/「/〉/〈/゛/‖/｝/］/｛/［/〔/；/）/（/”/¨/‥/ヽ/’/．/、/‘/＿/，/〆/‐/ー/〇/：/仝/≡/♭/ゞ/ゝ/ヾ/＾/｀/´/゜/-/。/Ц/⌒/¶/‡/∵/ヶ/≫/∧/∨/¬/∠/≪/∝/∫/Å/‰/†/揮毫/∪/
きごうか /記号化/
きごうがく /記号学/
きごうけい /記号系/
きごうこうぞう /記号構造/
きごうした /記号下/
きごうしょり /記号処理/
きごうしょりけい /記号処理系/
きごうせつめいらん /記号説明欄/
きごうそうさ /記号操作/
きごうそうさいっぱん /記号操作一般/
きごうたんご /記号単語/
きごうていすう /記号定数/
きごうてき /記号的/
きごうにゅうりょく /記号入力/
きごうひょう /記号表/
きごうひょうげん /記号表現/
きごうびぶん /記号微分/
きごうほう /記号法/
きごうもーど /記号モード/
きごうもうど /記号モード/
きごうるい /記号類/
きごうれつ /記号列/
きごうろん /記号論/
きごうろんり /記号論理/
きごうろんりか /記号論理化/
きごうろんりがく /記号論理学/
きごこち /着心地/
きごころ /気心/
きごし /木越/
きさ /蚶/吉舎/
きさい /記載/奇才/既済/起債/鬼才/騎西/
きさいあてさき /記載宛先/
きさいくかん /記載区間/
きさいじこう /記載事項/
きさいじこうへんこう /記載事項変更/
きさいないよう /記載内容/
きさいへんこう /記載変更/
きさいらん /記載欄/
きさかた /象潟/
きさかぶんきてん /木坂分岐点/
きさき /妃/后/
きさく /喜作/既作/
きさぬき /木佐貫/
きさぶろう /喜三郎/
きさま /貴様/
きさらぎ /如月/
きさらづ /木更津/
きさらづこうせん /木更津高専/
きさわ /木沢/
きさん /帰参/起算/
きざ /気障/起坐/
きざい /機材/器材/器財/
きざいじょうほう /機材情報/
きざいだん /貴財団/
きざいはんばい /器材販売/
きざき /木崎/稀崎/
きざくらしゅぞう /黄桜酒造/
きざけ /生酒/
きざさ /季笹/
きざし /兆/
きざはし /階/
きざみ /刻み/刻/
きざんかん /機山館/
きし /岸/来住/騎士/棋士/貴志/貴紙/貴誌/旗幟;日中の戦国武将が陣地に掲げる旗/
きしかいせい /起死回生/
きしかわ /貴志川/
きしかわせん /貴志川線/
きしかん /既弛緩/
きしがみ /岸上/
きしがわ /貴志川/
きしけいこ /岸恵子/
きしじま /岸島/
きしせんめい /旗幟鮮明;自分の立場をはっきりさせること/
きしだ /岸田/
きしだぎきょくしょう /岸田戯曲賞/
きしだん /騎士団/
きしつ /気質/基質/器質/
きしつてき /気質的/
きしの /岸野/
きしば /岸場/
きしべ /岸辺/
きしま /杵島/
きしみ /軋み/
きしもじん /鬼子母神/
きしもと /岸本/
きしゃ /記者/貴社/帰社/汽車/喜捨;寄付/騎射;馬上で弓を射ること. 武芸の一/
きしゃえき /汽車駅/
きしゃかいけん /記者会見/
きしゃかいけんしりょう /記者会見資料/
きしゃかいけんじょう /記者会見場/
きしゃがいしゃ /汽車会社/
きしゃく /希釈/稀釈/
きしゃくえき /希釈液/
きしゃくちゅう /希釈中/
きしゃせき /記者席/
きしゃたびそうだんしつ /汽車旅相談室/
きしゃだん /記者団/
きしゃちん /汽車賃/
きしゃのひろば /汽車の広場/
きしゃはっぴょう /記者発表/
きしやじま /岸屋島/
きしゅ /機種/騎手/旗手/期首/機首/期種/
きしゅいぞん /機種依存/
きしゅいぞんせい /機種依存性/
きしゅいぞんぶぶん /機種依存部分/
きしゅう /紀州/奇習/奇襲/
きしゅううめ /紀州梅/
きしゅうこうか /奇襲効果/
きしゅうこうげき /奇襲攻撃/
きしゅうじ /紀州路/
きしゅうてつどう /紀州鉄道/
きしゅうてん /起終点/
きしゅうわざ /奇襲技/
きしゅかん /機種間/
きしゅがっこう /騎手学校/
きしゅく /寄宿/耆宿/岐宿/
きしゅくしゃ /寄宿舎/
きしゅくりょう /寄宿料/
きしゅこうしん /機種更新/
きしゅこゆうもじ /機種固有文字/
きしゅごと /機種毎/
きしゅせんたく /機種選択/
きしゅせんてい /機種選定/
きしゅつ /既出/
きしゅとくてい /機種特定/
きしゅどくりつぶぶん /機種独立部分/
きしゅはんべつ /機種判別/
きしゅへんこう /機種変更/
きしゅべつ /機種別/
きしゅべつぶんかつ /機種別分割/
きしゅめい /機種名/騎手名/
きしゅめいふめい /機種名不明/
きしゅよう /機種用/
きしょ /寄書/貴所/貴書/奇書/
きしょう /起床/気象/気性/記章/希少/徽章/起請/毀傷/氣象/稀少/
きしょうえいせい /気象衛星/
きしょうかち /希少価値/稀少価値/
きしょうがく /気象学/
きしょうがくがいろん /気象学概論/
きしょうがくしゃ /気象学者/
きしょうがっかい /気象学会/
きしょうきょうかい /気象協会/
きしょうけん /気象研/
きしょうけんきゅうじょ /気象研究所/
きしょうしゃ /希少車/
きしょうじょうけん /気象条件/
きしょうじょうほう /気象情報/
きしょうだい /気象台/
きしょうだいがっこう /気象大学校/
きしょうちょう /気象庁/
きしょうてんけつ /起承転結/
きしょうなん /気性難/
きしょうぼり /起請彫り/
きしょうぼん /希少本/
きしょうもん /起請文/
きしょうりきがく /気象力学/
きしょく /気色/喜色/
きしょじまん /稀書自慢/
きしり /軋り/
きしろ /木城/
きしわだ /岸和田/
きしわだいずみ /岸和田和泉/
きしわだし /岸和田市/
きしわだしみん /岸和田市民/
きしん /紀信/貴信/寄進/帰心/鬼神/
きしんせん /姫神線/
きしんへいだん /機神兵団/
きじ /記事/生地/木地/雉/
きじいじょう /記事以上/
きじいぜん /記事以前/
きじきさい /記事記載/
きじく /機軸/基軸/
きじぐん /記事群/
きじごと /記事毎/
きじさんしょう /記事参照/
きじじたい /記事自体/
きじすう /記事数/
きじせんたく /記事選択/
きじせんたくがめん /記事選択画面/
きじぜんたい /記事全体/
きじぜんぱん /記事全般/
きじぜんぶ /記事全部/
きじちゅう /記事中/
きじつ /期日/
きじつない /期日内/
きじとうこう /記事投稿/
きじとうこうしゃ /記事投稿者/
きじないよう /記事内容/
きじなど /記事等/
きじばんごう /記事番号/
きじぶぶん /記事部分/
きじほんたい /記事本体/
きじま /木島/木嶋/貴島/
きじまだいら /木島平/
きじまつびさんしょう /記事末尾参照/
きじめい /記事名/
きじもと /雉本/
きじゅ /喜寿/
きじゅう /機銃/
きじゅうき /起重機/
きじゅうぐん /機銃群/
きじゅうそうしゃ /機銃掃射/
きじゅつ /記述/奇術/既述/
きじゅつかのう /記述可能/
きじゅつぐん /記述群/
きじゅつけいしき /記述形式/
きじゅつげんご /記述言語/
きじゅつこうもく /記述項目/
きじゅつご /記述後/
きじゅつし /記述子/奇術子/奇術師/
きじゅつしき /記述式/
きじゅつしきしけん /記述式試験/
きじゅつしきもんだい /記述式問題/
きじゅつしゃ /記述者/
きじゅつじょう /記述上/
きじゅつせい /記述性/
きじゅつてき /記述的/
きじゅつないよう /記述内容/
きじゅつのうりょく /記述能力/
きじゅつぶ /奇術部/記述部/
きじゅつぶぶん /記述部分/
きじゅつほう /記述法/
きじゅつほうほう /記述方法/
きじゅつもんだい /記述問題/
きじゅつよう /記述用/
きじゅつようげん /記述用言/
きじゅつようしき /記述様式/
きじゅつらん /記述欄/
きじゅつりょう /記述量/
きじゅつりょく /記述力/
きじゅつりろん /記述理論/
きじゅつれい /記述例/
きじゅん /基準/規準/帰順/
きじゅんいち /基準位置/
きじゅんおん /基準音/
きじゅんか /規準化/基準化/
きじゅんき /規準器/
きじゅんこう /基準項/
きじゅんしゃ /基準車/
きじゅんしゅうはすう /基準周波数/
きじゅんしんごう /基準信号/
きじゅんち /基準値/
きじゅんちょう /基準長/
きじゅんてき /規準的/
きじゅんてん /基準点/
きじゅんふく /基準服/
きじゅんへんこう /基準変更/
きじゅんほう /基準法/
きじゅんめん /基準面/
きじょ /機序/貴女/鬼女/
きじょう /机上/機上/騎乗/軌条/騎上/木城/
きじょういらい /騎乗依頼/
きじょうきかい /騎乗機会/
きじょうぎじゅつ /騎乗技術/
きじょうていし /騎乗停止/騎上停止/
きじょうていししょぶん /騎乗停止処分/
きじょうば /騎乗馬/
きじょうほうほう /騎乗方法/
きじらん /記事欄/
きじらんぱつ /記事乱発/
きじりゅうつうりょう /記事流通量/
きじりょう /記事量/
きじん /奇人/鬼神/貴人/畸人/
きじんぶ /基人部/
きじんへんじん /奇人変人/畸人變人/
きじんへんじんたち /奇人変人達/
きす /キス/木須/鱚/
きすい /既遂/気水/
きすいいき /気水域/
きすう /奇数/基数/寄数/機数/帰趨/
きすういすう /奇数位数/
きすうかい /奇数回/
きすうじ /奇数時/
きすうじほうていしき /奇数次方程式/
きすうばん /奇数番/
きすうぶ /基数部/
きすうぺーじ /奇数頁/
きすうほう /記数法/
きすが /貴家/
きすき /木次/
きすきせん /木次線/
きすぎ /来生/
きすみ /木栖/
きず /傷/瑕/疵/痍/岐津/生酢/
きずあと /傷跡/傷痕/
きずかい /気遣い/
きずくり /木造/
きずぐち /傷口/
きずな /絆/
きずもの /傷物/疵物/
きせ /吉瀬/木瀬/黄瀬/
きせい /規制/帰省/既成/寄生/奇声/既製/期生/気勢/規正/棋聖/紀勢/
きせいいがい /規制以外/
きせいかいじょ /規制解除/
きせいかんわ /規制緩和/
きせいがいねん /既成概念/
きせいきょうか /規制強化/
きせいくいき /規制区域/
きせいぐみ /帰省組/
きせいこん /寄生根/
きせいご /規制後/
きせいさき /帰省先/
きせいさきじゅうしょ /帰省先住所/
きせいしゃ /規制車/
きせいじ /帰省時/
きせいじじつ /既成事実/
きせいじゅう /寄生獣/
きせいせいぶつ /寄生生物/
きせいせん /棋聖戦/
きせいせんちょくつう /紀勢線直通/
きせいそくど /規制速度/
きせいたいしょう /規制対象/
きせいたいしょうがい /規制対象外/
きせいたいしょうしゃ /規制対象車/
きせいち /規制値/
きせいちいき /規制地域/
きせいちいきがい /規制地域外/
きせいちいきない /規制地域内/
きせいちく /紀勢地区/
きせいちゅう /寄生虫/帰省中/
きせいちょくぜん /規制直前/
きせいてきごう /規制適合/
きせいてっぱい /規制撤廃/
きせいどうにゅう /規制導入/
きせいないよう /規制内容/
きせいはんたい /規制反対/
きせいひょうしき /規制標識/
きせいひん /既製品/既成品/
きせいふく /既製服/
きせいふてきごうしゃ /規制不適合車/
きせいほう /規制法/
きせいほうこう /帰省方向/
きせいほんせん /紀勢本線/
きせいほんせんほうめん /紀勢本線方面/
きせいまえ /規制前/
きせいようりょう /寄生容量/
きせき /奇跡/軌跡/奇蹟;奇跡/鬼籍/帰責/帰籍/基石/奇石/棋石;碁石/碁石;棋石/貴戚;貴族、その親戚/貴石/輝石/寄迹;身を寄せる、寄寓する/
きせききろくじ /軌跡記録時/
きせきじゆう /帰責事由/
きせきてき /奇跡的/
きせきりょうほう /奇跡療法/
きせせん /紀勢線/
きせつ /季節/既設/
きせつうんてん /季節運転/
きせつかん /季節感/
きせつがい /季節外/
きせつがら /季節柄/
きせつげんてい /季節限定/
きせつごと /季節毎/
きせつしゃ /季節車/
きせつぞう /季節増/
きせつてき /季節的/
きせつふう /季節風/
きせつへんどう /季節変動/
きせつよう /季節用/
きせつれっしゃ /季節列車/
きせのん /キセノン/
きせる /煙管/
きせん /帰線/帰仙/基線/機先/汽船/棋戦/機船/帰船/貴賤/黄線/
きせんくかん /帰線区間/
きせんちょう /基線長/
きぜつ /気絶/
きぜつじ /気絶時/
きぜつち /気絶値/
きぜん /毅然/
きそ /基礎/起訴/木曾/木曽/木祖/
きそう /奇想/気相/起草/帰巣/竸/寄贈/吉左右/
きそうきょく /奇想曲/
きそうてんがい /奇想天外/
きそうてんがいしゃ /奇想天外社/
きそうほんのう /帰巣本能/
きそえいご /基礎英語/
きそえんしゅう /基礎演習/
きそおんきょう /基礎音響/
きそかいせき /基礎解析/
きそかがく /基礎科学/
きそかがっか /基礎科学科/
きそかもく /基礎科目/
きそがいねん /基礎概念/
きそがくりょく /基礎学力/
きそがわ /木曽川/
きそきかいぶ /基礎機械部/
きそきょういく /基礎教育/
きそきょうかいりょういき /基礎境界領域/
きそぎじゅつ /基礎技術/
きそぎじゅつけんきゅう /基礎技術研究/
きそぎじゅつへん /基礎技術編/
きそぎほう /基礎技法/
きそく /規則/気息/
きそくいはん /規則違反/
きそくえんえん /気息奄奄/気息奄々/
きそくか /規則化/
きそくかいせい /規則改正/
きそくがた /規則型/
きそくきごう /気息記号/
きそくごうせい /規則合成/
きそくしゅう /規則集/
きそくしょ /規則書/
きそくじょう /規則上/
きそくせい /規則性/
きそくちゅうしゅつ /規則抽出/
きそくてき /規則的/
きそくてきたいおう /規則的対応/
きそくへんこう /規則変更/
きそくめい /規則名/
きそくもんだい /規則問題/
きそくんれん /基礎訓練/
きそけい /基礎系/
きそけしょう /基礎化粧/
きそけしょうひん /基礎化粧品/
きそけん /基礎研/
きそけんきゅう /基礎研究/
きそけんきゅうしつ /基礎研究室/
きそけんきゅうしょ /基礎研究所/
きそけんきゅうじょ /基礎研究所/
きそけんきゅうぶ /基礎研究部/
きそげんじ /木曾源氏/
きそこう /基礎工/基礎項/
きそこうがく /基礎工学/
きそこうがくぶ /基礎工学部/
きそこうがくるい /基礎工学類/
きそこうざ /基礎講座/
きそこうじ /基礎工事/
きそこうじょ /基礎控除/
きそこまこうげん /木曽駒高原/
きそさぎょう /基礎作業/
きそざき /木曾岬/
きそしけん /基礎試験/
きそしりょう /基礎資料/
きそじ /木曽路/
きそじじつ /基礎事実/
きそじっけん /基礎実験/
きそじょう /起訴状/
きそじょうほうがく /基礎情報学/
きそじょうほうすうがく /基礎情報数学/
きそすう /奇素数/
きそすうがく /基礎数学/
きそすうがくせんしょ /基礎数学選書/
きそすうりがく /基礎数理学/
きそせつ /基礎節/
きそそうさ /基礎操作/
きそたい /基礎体/
きそたいしゃりょう /基礎代謝量/
きそたいりょく /基礎体力/
きそたに、きそだに /木曽谷/
きそちしき /基礎知識/
きそちゅう /基礎中/
きそづけ /基礎付け/
きそていいん /基礎定員/
きそてき /基礎的/
きそてきがいねん /基礎的概念/
きそてきけんきゅう /基礎的研究/
きそてきこうさつ /基礎的考察/
きそてきちしき /基礎的知識/
きそてん /基礎点/
きそとう /基礎棟/
きそにんげんこうがくぶ /基礎人間工学部/
きそひょう /基礎票/
きそふくしま /木曽福島/木曾福島/
きそふくしまえき /木曽福島駅/
きそぶぶん /基礎部分/
きそぶんけん /基礎文献/
きそへん /基礎編/
きそほうていしき /基礎方程式/
きそほうていしきけい /基礎方程式系/
きそや /基礎屋/
きそゆうよ /起訴猶予/
きそらせん /基礎螺旋/
きそりょく /基礎力/
きそりろん /基礎理論/
きそれんしゅう /基礎練習/
きそろん /基礎論/
きそろんけんきゅうかい /基礎論研究会/
きそろんこうざ /基礎論講座/
きそろんてき /基礎論的/
きそん /既存/毀損/
きぞう /寄贈/
きぞうひん /寄贈品/
きぞく /帰属/貴族/
きぞくいしき /帰属意識/
きぞくかんけい /帰属関係/
きぞくしゃかい /貴族社会/
きぞん /既存/
きぞんしゃりょう /既存車両/
きぞんせつび /既存設備/
きぞんせん /既存線/
きぞんばん /既存盤/
きた /北/喜多/来た/木田/
きたあいき /北相木/
きたあいづ /北会津/
きたあきた /北秋田/
きたあげお /北上尾/
きたあずみ /北安曇/
きたあだち /北足立/
きたあまべ /北海部/
きたあやせ /北綾瀬/
きたありま /北有馬/
きたい /期待/気体/危殆/機体/稀代/奇胎/北井/
きたいいじょう /期待以上/
きたいかん /期待感/
きたいかんり /機体管理/
きたいがい /期待外/
きたいきょうど /機体強度/
きたいけいじょう /機体形状/
きたいさく /期待作/
きたいさんそ /気体酸素/
きたいじゅうりょう /機体重量/
きたいずみ /北泉/
きたいたみ /北伊丹/
きたいだい /期待大/
きたいち /期待値/
きたいちがらす /北一硝子/
きたいちじたい /期待値自体/
きたいちほうしき /期待値方式/
きたいっき /北一輝/
きたいてん /期待点/
きたいど /期待度/
きたいはんぶん /期待半分/
きたいば /期待馬/
きたいばらき /北茨城/
きたいばらぎし /北茨城市/
きたいぼ /期待薄/
きたうおぬま /北魚沼/
きたうち /北内/
きたうら /北浦/
きたうらわ /北浦和/
きたうわ /北宇和/
きたえかた /鍛え方/
きたえき /北駅/
きたえだ /北枝/
きたお /北尾/
きたおおさか /北大阪/
きたおおさかきゅうこう /北大阪急行/
きたおおさかきゅうこうせん /北大阪急行線/
きたおおさかきんぺん /北大阪近辺/
きたおおじ /北大路/
きたおおじえき /北大路駅/
きたおおつか /北大塚/
きたおか /北岡/
きたおかざき /北岡崎/
きたおく /北奥/
きたおね /北尾根/
きたおり /北折/
きたかしま /北鹿島/
きたかしまえき /北鹿島駅/
きたかすかべ /北春日部/
きたかぜ /北風/
きたかぜこぞう /北風小僧/
きたかた /喜多方/北方/
きたかたかん /喜多方間/
きたかちどき /北勝閧/
きたかつしか /北葛飾/
きたかつらぎ /北葛城/
きたかべ /北壁/
きたかまくら /北鎌倉/
きたかみ /北上/
きたかみがわ /北上川/
きたかみせん /北上線/
きたかるいざわ /北軽井沢/
きたかわ /北川/
きたかわち /北河内/
きたかわべ /北川辺/
きたかんとう /北関東/
きたかんとうちく /北関東地区/
きたかんとうばん /北関東版/
きたかんばら /北蒲原/
きたがき /北垣/
きたがた /北方/
きたがわ /北川/北側/喜多川/北河/
きたがわちょう /北川町/
きたきつね /キタキツネ/北狐/
きたきゅうしゅう /北九州/
きたきゅうしゅうきねん /北九州記念/
きたきゅうしゅうくうこう /北九州空港/
きたきゅうしゅうこうじょう /北九州工場/
きたきゅうしゅうし /北九州市/
きたきゅうしゅうしえい /北九州市営/
きたきゅうしゅうしない /北九州市内/
きたきゅうしゅうせん /北九州線/
きたきんき /北近畿/
きたきんきおおさか /北近畿大阪/
きたく /帰宅/北区/寄託/
きたくかん /北区間/
きたくご /帰宅後/
きたくじ /帰宅時/
きたくじかん /帰宅時間/
きたくとちゅう /帰宅途中/
きたくまえ /帰宅前/
きたくみん /北区民/
きたくりはま /北久里浜/
きたくわだ /北桑田/
きたぐち /北口/
きたぐちふきん /北口付近/
きたぐに /北国/
きたぐんま /北群馬/
きたけ /着丈/
きたこう /北港/
きたこうじ /北小路/
きたこま /北巨摩/
きたこまぐん /北巨摩郡/
きたこまつ /北小松/
きたごう /北郷/
きたさいたま /北埼玉/
きたさく /北佐久/
きたさわとうげ /北沢峠/
きたざと /北里/
きたざとだいがく /北里大学/
きたざわ /北澤/北沢/
きたざわしょ /北沢署/
きたざわびじゅつかん /北澤美術館/
きたしおばら /北塩原/
きたしが /北志賀/
きたしたら /北設楽/
きたしながわえき /北品川駅/
きたしなの /北信濃/
きたしょく /北食/
きたしらかわ /北白川/
きたしんち /北新地/
きたじま /喜多嶋/北島/北嶋/
きたじまさぶろう /北島三郎/
きたじょう /喜多條/
きたすぎ /北杉/
きたすな /北砂/
きたせん /北線/
きたせんじゅ /北千住/
きたせんじゅいえん /北千住以遠/
きたせんじゅえき /北千住駅/
きたせんじゅきんぺん /北千住近辺/
きたせんじゅぐち /北千住口/
きたせんじゅはつ /北千住発/
きたせんじゅふきん /北千住付近/
きたせんぞく /北千束/
きたせんだい /北仙台/
きたせんり /北千里/
きたそうま /北相馬/
きたぞの /北園/
きたたいせいよう /北大西洋/
きたたいへいよう /北太平洋/
きたたかき /北高来/
きたたかぎ /北高来/
きたたちばな /北橘/
きたたに /北谷/
きたたま /北多摩/
きただ /北田/
きただい /北代/
きただいとう /北大東/
きただけ /北岳/
きたちく /北地区/
きたちしま /北千島/
きたちょうせん /北朝鮮/
きたちょうせんかんこう /北朝鮮観光/
きたつがる /北津軽/
きたつる /北都留/
きたとしま /北豊島/
きたとしまこうこう /北豊島高校/
きたとだ /北戸田/
きたど /北戸/
きたなか /北中/
きたなかぐすく /北中城/
きたならしの /北習志野/
きたならしのえき /北習志野駅/
きたに /木谷/
きたにほん /北日本/
きたにほんがくせい /北日本学生/
きたにほんたいかい /北日本大会/
きたね /北根/
きたの /北野/
きたのうみ /北の湖/
きたのせん /北野線/
きたのたけし /北野武/
きたのまる /北の丸/
きたはし /北橋/
きたはた /北波多/
きたはちおうじ /北八王子/
きたはっこうだ /北八甲田/
きたはま /北浜/
きたはまみつこしまえ /北浜三越前/
きたはら /北原/
きたはらはくしゅう /北原白秋/
きたはんきゅう /北半球/
きたはんぶん /北半分/
きたばたけ /北畠/北畑/
きたばやし /北林/
きたひろしま /北広島/
きたひろしまし /北広島市/
きたふちゅうほうめん /北府中方面/
きたべっぷ /北別府/
きたほ /北穂/
きたほだか /北穂高/
きたほっかいどう /北北海道/
きたまち /北町/
きたまちぶぎょう /北町奉行/
きたまつ /北松/
きたまつど /北松戸/
きたまわり /北回り/
きたみ /北見/喜多見/
きたみざわ /北見沢/
きたみち /北道/
きたみまき /北御牧/
きたむき /北向き/
きたむたやま /北村山/
きたむら /北村/喜多村/
きたむらやま /北村山/
きたむろ /北牟婁/
きため /北目/
きためまち /北目町/
きたもうこ /北蒙古/
きたもと /北本/
きたもとし /北本市/
きたもり /北森/
きたもりお /北杜夫/
きたもろかた /北諸県/
きたもん /北門/
きたや /北谷/
きたやま /北山/
きたやまさ /北山佐/
きたやまさちょう /北山佐町/
きたゆき /北行/
きたより /北寄り/
きたら /喜多羅/
きたりゅう /喜多流/
きたろう /喜多郎/鬼太郎/喜太郎/
きたわき /北脇/
きたん /忌憚/奇譚/綺譚/
きたんかいきょう /紀淡海峡/
きたんさく /木探索/
きだ /木田/貴田/
きだい /貴台/基台/機台/稀代/気大/
きだいがく /貴大学/
きだて /気だて/気立/
きだまり /木田余/
きだん /奇談/気団/綺譚/
きち /吉/基地/既知/機知/貴地/機智/危地/
きちあと /基地跡/
きちえもん /吉右衛門/
きちがい /気違い/
きちきょく /基地局/
きちく /鬼畜/
きちくべいえい /鬼畜米英/
きちじ /吉事/
きちじつ /吉日/
きちじま /吉島/
きちじょう /吉祥/
きちじょうじ /吉祥寺/
きちじょうじえき /吉祥寺駅/
きちじょうじがわ /吉祥寺側/
きちじょうじきんぺん /吉祥寺近辺/
きちじょうじてん /吉祥寺店/
きちじょうじとうきゅう /吉祥寺東急/
きちじょうじほうこう /吉祥寺方向/
きちじょうじょし /吉祥女子/
きちすう /吉数/
きちせい /既知性/
きちてん /既知点/
きちない /基地内/
きちのすけ /吉之助/
きちほうかい /基地崩壊/
きちぼうくう /基地防空/
きちゃく /帰着/
きちゅう /忌中/機中/
きちゅうはく /機中泊/
きちょう /貴重/基調/記帳/機長/几帳/綺帳/貴族/
きちょうこうえん /基調講演/
きちょうひん /貴重品/
きちょうめん /几帳面/
きちれい /吉例/
きちろう /吉郎/
きっか /菊花/菊華/橘花/
きっかけ /切っ掛け/
きっかこうこう /菊華高校/
きっかしょう /菊花賞/
きっかしょうば /菊花賞馬/
きっかわ /吉川/菊川/
きっきょう /吉凶/吃驚/
きっきん /喫緊/
きっく /キック/
きっこう /亀甲/拮抗/
きっこうきんぞく /亀甲金属/
きっこうけい /亀甲型/
きっこうまん /亀甲萬/
きっさ /喫茶/
きっさき /切先/切尖/
きっさしつ /喫茶室/
きっさてん /喫茶店/
きっしょう /吉祥/
きっしょういん /吉祥院/
きっしょうてんにょ /吉祥天女/
きっしょく /喫食/
きっす /キッス/
きっすい /生粋/喫水/吃水/
きっすいせん /喫水線/
きっせき /詰責/
きっせん /吉仙/
きっそう /吉左右/
きっそうさん /吉草酸/
きったか /橘高/
きっちょう /吉兆/
きっちん /キッチン/
きって /切手/
きってだい /切手代/
きってどうふう /切手同封/
きっと /キット/吉都/吃度/急度/屹度/
きっぷ /切符/キップ/気風/気っ風/
きっぷうりば /切符売場/
きっぷだい /切符代/
きっぷはいけん /切符拝見/
きっぽう /吉報/
きつ /詰/桔/喫/吉/橘/吃/乞/拮/佶/屹/訖/迄/
きつえん /喫煙/
きつえんいがい /喫煙以外/
きつえんいぞんしょう /喫煙依存症/
きつえんか /喫煙可/喫煙家/
きつえんかのう /喫煙可能/
きつえんき /喫煙期/
きつえんきせい /喫煙規制/
きつえんけん /喫煙権/
きつえんこうい /喫煙行為/
きつえんこうしんこく /喫煙後進国/
きつえんしつ /喫煙室/
きつえんしゃ /喫煙者/喫煙車/
きつえんしゃいっぱん /喫煙者一般/
きつえんしゃがわ /喫煙者側/
きつえんしゃぜんたい /喫煙者全体/
きつえんしゃはいせき /喫煙者排斥/
きつえんしゃりつ /喫煙者率/
きつえんしゃりょう /喫煙車両/
きつえんしゅうかん /喫煙習慣/
きつえんしょ /喫煙所/
きつえんじ /喫煙時/
きつえんじょ /喫煙所/
きつえんじょいがい /喫煙所以外/
きつえんせいげん /喫煙制限/
きつえんせき /喫煙席/
きつえんちゅう /喫煙中/
きつえんは /喫煙派/
きつえんばしょ /喫煙場所/
きつえんふか /喫煙不可/
きつえんほうほう /喫煙方法/
きつえんめんきょ /喫煙免許/
きつえんもんだい /喫煙問題/
きつえんりつ /喫煙率/
きつえんりょう /喫煙量/
きつえんれき /喫煙歴/
きつおん /吃音/
きつかわ /橘川/
きつき /杵築/
きつけ /気付/気附/着付け/
きつぜん /屹然/
きつつき /啄木鳥/
きつと /吉都/
きつとせん /吉都線/
きつね /狐/
きつねいろ /狐色/
きつねつき /狐憑き/
きつねのまごか /キツネノマゴ科/Acanthaceae/
きつもん /詰問/
きつりつ /屹立/吃立/
きつれがわ /喜連川/
きづ /木津/岐津/
きづかい /氣遣い/
きづかれ /気疲れ/
きづがわ /木津川/
きづき /木築/木月/
きづく /気附/
きづけ /気付/気附/
きづち /木鎚/
きて /来て/
きてい /規定/基底/既定/規程/
きていいがい /既定以外/
きていいじょう /規定以上/
きていえんぎ /規程演技/
きていか /規定化/
きていかいすう /規定回数/
きていかんすう /基底関数/
きていがい /規定外/
きていぎ /既定義/
きていぎてつづき /既定義手続/既定義手続き/
きていくいきない /規定区域内/
きていこう /基底項/
きていさんかかいすう /規定参加回数/
きていじかん /規定時間/
きていじょう /規定上/
きていじょうたい /基底状態/
きていすういじょう /規定数以上/
きていだせき /規定打席/
きていだせきとうたつ /規定打席到達/
きていち /既定値/規定値/
きていとうきゅうかいすう /規定投球回数/
きていないよう /規定内容/
きていはんい /規定範囲/
きていぶん /基底文/
きていぶんぽう /基底文法/
きていまく /基底膜/
きていまくじょう /基底膜上/
きていりょう /規定量/
きていれい /基底例/
きていろせん /規定路線/
きてき /汽笛/
きてん /基点/起点/機転/貴店/
きてんいち /基点位置/
きでら /紀寺/
きでりょく /起電力/
きでん /貴殿/機電/
きでんりょく /起電力/
きと /帰途/企図/
きとう /気筒/祈祷/亀頭/木藤/祈梼/紀藤/鬼頭/木頭/
きとうすう /気筒数/
きとく /危篤/奇特/既得/
きとくけん /既得権/
きとくけんげん /既得権限/
きど /城戸/木戸/輝度/希土/鬼怒/
きどあいらく /喜怒哀楽/
きどう /起動/軌道/機動/棋道/鬼道/気道/
きどうおん /起動音/
きどうかんきょう /起動環境/
きどうかんたい /機動艦隊/
きどうかんりょうじ /起動完了時/
きどうがめん /起動画面/
きどうきょうか /軌道強化/
きどうけいさつ /機動警察/
きどうけいじょう /軌道形状/
きどうご /起動後/
きどうしき /軌道敷/
きどうしきいがい /軌道敷以外/
きどうしきちない /軌道敷地内/
きどうしゃ /気動車/
きどうしゃかいそく /気動車快速/
きどうしゅうせい /軌道修正/
きどうしゅうりょう /起動終了/
きどうじ /起動時/
きどうじかん /起動時間/
きどうじき /軌道敷/
きどうじじっこう /起動時実行/
きどうじたい /軌道自体/
きどうじどうしゃ /軌道自動車/
きどうじゅんい /起動順位/
きどうじょう /軌道上/
きどうじょうけん /起動条件/
きどうせい /機動性/
きどうせいぎょ /軌道制御/
きどうせいびじょう /軌道整備上/
きどうせんし /機動戦士/
きどうせんよう /機動戦用/
きどうたい /機動隊/
きどうたいいん /機動隊員/
きどうちゅう /起動中/
きどうちょくご /起動直後/
きどうちょっけい /軌道直径/
きどうてん /軌道点/
きどうでんりゅう /起動電流/
きどうとちゅう /起動途中/
きどうはんけい /軌道半径/
きどうふかていこう /起動負荷抵抗/
きどうぶたい /機動部隊/
きどうへいき /機動兵器/
きどうほう /起動法/軌道法/
きどうほうほう /起動方法/
きどうまえ /起動前/
きどうよう /起動用/
きどうようそ /軌道要素/
きどうよてい /起動予定/
きどうりょく /機動力/
きどかいぞうど /輝度解像度/
きどく /既読/
きどくきじ /既読記事/
きどけいさん /輝度計算/
きどこうばい /輝度勾配/
きどしんごう /輝度信号/
きどせん /木戸錢/
きどちょうせい /輝度調整/
きどって /気取って/
きどで /木戸出/
きどるい /希土類/
きどわき /木戸脇/
きない /機内/畿内/
きないご /畿内語/
きないし /機内誌/
きないしょく /機内食/
きないはく /機内泊/
きないはんばい /機内販売/
きなが /気長/
きなさ /鬼無里/
きなし /木梨/
きなべ /汽鍋/
きなん /危難/紀南/貴男/
きにち /忌日/
きにゅう /記入/
きにゅうしゃ /記入者/
きにゅうじょう /記入上/
きにゅうばしょ /記入場所/
きにゅうほう /記入法/
きにゅうほうほう /記入方法/
きにゅうらん /記入欄/
きにゅうれい /記入例/
きにゅうれいさんしょう /記入例参照/
きにん /帰任/貴人/
きにんご /帰任後/
きにんだて /貴人点/
きぬ /絹/衣/帛/
きぬいと /絹糸/
きぬえ /絹枝/
きぬおりもの /絹織物/
きぬかわ /衣川/
きぬがさ /衣笠/
きぬがわ /鬼怒川/
きぬがわおんせん /鬼怒川温泉/
きぬがわおんせんいき /鬼怒川温泉行/
きぬがわおんせんゆき /鬼怒川温泉行/
きぬけ /気抜け/
きぬた /砧/
きね /杵/
きねしま /杵嶋/
きねま /キネマ/
きねん /記念/祈念/
きねんかい /記念会/
きねんかいかん /記念会館/
きねんかん /記念館/
きねんきって /記念切手/
きねんきっぷ /記念切符/
きねんきょうぎじょう /記念競技場/
きねんきょく /記念局/
きねんぎょうじ /記念行事/
きねんけん /記念券/
きねんこうえん /記念公園/
きねんこうどう /記念講堂/
きねんさい /記念祭/
きねんさつえい /記念撮影/
きねんさつえいよう /記念撮影用/
きねんし /記念誌/
きねんしきてん /記念式典/
きねんしゃしん /記念写真/
きねんしゅっぱん /記念出版/
きねんじぎょう /記念事業/
きねんじゅ /記念樹/
きねんじょうしゃけん /記念乗車券/
きねんたいかい /記念大会/
きねんひ /記念碑/
きねんひてきけっさく /記念碑的傑作/
きねんひん /記念品/
きねんひんだい /記念品代/
きねんび /記念日/
きねんぶつ /記念物/
きねんろんぶんしゅう /記念論文集/
きの /木野/
きのう /昨日/機能/帰納/
きのういがい /機能以外/
きのうかいぜん /機能改善/
きのうかがくせんこう /機能科学専攻/
きのうかくちょう /機能拡張/
きのうかくちょうげんご /機能拡張言語/
きのうかくちょうばん /機能拡張版/
きのうかてい /帰納仮定/
きのうかん /機能間/
きのうがいよう /機能概要/
きのうがくしゅう /帰納学習/
きのうきょう /昨日今日/
きのうきょうか /機能強化/
きのうぐん /機能群/
きのうげんざい /昨日現在/
きのうげんてい /機能限定/
きのうこうじょう /機能向上/
きのうごと /機能毎/
きのうしゅぎ /機能主義/
きのうしょうがい /機能障害/
きのうしよう /機能仕様/
きのうしようしょ /機能仕様書/
きのうじゅうぞくせい /機能従属性/
きのうじょう /機能上/
きのうすいろん /帰納推論/
きのうせい /機能性/
きのうせいげん /機能制限/
きのうせっけい /機能設計/
きのうせってい /機能設定/
きのうせつめい /機能説明/
きのうたんい /機能単位/
きのうち /木之内/木内/城内/
きのうついか /機能追加/
きのうつき /機能付/
きのうていし /機能停止/
きのうていり /帰納定理/
きのうてき /帰納的/機能的/
きのうてきかさん /帰納的可算/
きのうてきかさんしゅうごう /帰納的可算集合/
きのうてきかんすう /帰納的関数/帰納的函数/
きのうてきけつろん /帰納的結論/
きのうてきしゅうごう /帰納的集合/
きのうてきじゅつご /帰納的述語/
きのうてきすいろん /帰納的推論/
きのうてきせいしつ /機能的性質/
きのうてきていぎ /帰納的定義/
きのうてん /機能点/
きのうとし /機能都市/
きのうひょうげん /機能表現/
きのうび /機能美/
きのうふか /機能付加/
きのうぶい /機能部位/
きのうぶそく /機能不足/
きのうぶんか /機能分化/
きのうぶんさん /機能分散/
きのうへんすう /帰納変数/
きのうべつ /機能別/
きのうほう /帰納法/
きのうほうのかてい /帰納法の仮定/
きのうほうふ /機能豊富/
きのうほかん /機能補完/
きのうまんさい /機能満載/
きのうめん /機能面/
きのうゆにっと /機能ユニット/
きのうようきゅう /機能要求/
きのうよそく /機能予測/
きのうよびだ /機能呼出/
きのうろんり /帰納論理/
きのうわせい /機能和声/
きのうわせいてき /機能和声的/
きのえ /甲/木江/
きのえいぬ /甲戌/
きのえうま /甲午/
きのえき /木野駅/
きのえさる /甲申/
きのえたつ /甲辰/
きのえとら /甲寅/
きのえね /甲子/
きのかわ /紀ノ川/
きのくに /紀伊國/
きのくにや /紀伊国屋/紀伊國屋/紀之國屋/
きのくにやしょてん /紀伊国屋書店/紀伊國屋書店/
きのこ /キノコ/蕈/茸/
きのさき /城ノ崎/城崎/
きのした /木下/樹下/木の下/木ノ下/
きのしたけいすけ /木下恵介/
きのつらゆき /紀貫之/
きのと /乙/
きのとい /乙亥/
きのとう /乙卯/
きのとうし /乙丑/
きのととり /乙酉/
きのとひつじ /乙未/
きのとみ /乙巳/
きのどく /気の毒/
きのね /木の根/
きのはら /木之原/
きのぼり /木登り/
きのみ /木の実/
きのみきのまま /着の身着の侭/
きのみや /来宮/
きのめ /木の芽/
きのもと /木之元/木ノ本/
きのり /気乗り/
きは /際/
きはい /跪拝/
きはいち /既配置/
きはく /希薄/気迫/気魄/稀薄/
きはた /木幡/
きはだ /木肌/檗/蘗/
きはち /喜八/
きはちろう /喜八郎/
きはっぴょう /既発表/
きはつ /揮発/輝発/既発/
きはつせい /揮発性/
きはつせいぶん /揮発成分/
きはつばい /既発売/
きはつゆ /揮発油/揮發油/
きはつゆぜい /揮発油税/
きはら /木原/樹原/
きはらせん /木原線/
きはらみちこ /木原美智子/
きはん /規範/機搬/帰阪/
きはんけいざいがく /規範経済学/
きはんせん /機帆船/
きはんてき /規範的/
きはんりろん /規範理論/
きば /牙/木場/騎馬/
きばえき /木場駅/
きばく /起爆/
きばくざい /起爆剤/
きばくしょく /起爆色/
きばくてん /起爆点/
きばこ /木箱/
きばせん /騎馬戦/
きばたい /騎馬隊/
きばたらき /気ばたらき/
きばつ /奇抜/
きばほうめん /木場方面/
きばみんぞく /騎馬民族/
きばらい /既払い/
きばらし /気晴らし/
きばん /基盤/基板/機番/
きばんかいはつしつ /基盤開発室/
きばんがい /基板外/
きばんこうかん /基盤交換/
きばんじょう /基板上/基盤上/碁盤状/
きばんつき /基盤付き/
きばんてきぎじゅつ /基盤的技術/
きばんめい /基板名/
きばんや /基盤屋/基板屋/
きばんよう /基盤用/
きひ /忌避/
きひざい /忌避剤/
きひつ /起筆/
きひょう /起票/
きひろ /帰広/
きひん /気品/貴賓/
きひんしつ /貴賓室/
きひんせき /貴賓席/
きび /黍/吉備/機微/綺靡/驥尾/
きびき /忌引/
きびす /踵/
きびだんご /黍団子/
きびょう /奇病/
きびょうし /黄表紙/
きびん /機敏/
きびんせい /機敏性/
きふ /寄付/棋譜/寄附/
きふう /気風/棋風/
きふきん /寄付金/
きふく /起伏/帰服/
きふこうい /寄付行為/
きふこうざきょういん /寄付講座教員/
きふじん /貴夫人/貴婦人/
きふね /貴船/
きふねぐち /貴船口/
きぶ /基部/
きぶかわ /貴生川/
きぶくれ /着膨れ/
きぶし /木歩士/
きぶつ /器物/
きぶつそんかい /器物損壊/
きぶつそんかいざい /器物損壊罪/
きぶつはそん /器物破損/
きぶね /貴船/
きぶもん /貴部門/
きぶん /気分/紀文/
きぶんいっしん /気分一新/
きぶんしだい /気分次第/
きぶんそうかい /気分爽快/
きぶんてき /気分的/
きぶんてんかん /気分転換/
きぶんよし /気分良/
きへい /騎兵/機兵/喜平/
きへん /木偏/桾/杞/櫻/
きべん /詭弁/
きほう /記法/貴方/木方/既報/気泡/紀宝/季報/
きほうさま /貴方様/
きほく /輝北/
きほん /基本/
きほんえんざんし /基本演算子/
きほんおんけい /基本音型/
きほんかい /基本解/
きほんかいろ /基本回路/
きほんかかく /基本価格/
きほんかんすう /基本関数/
きほんがいねん /基本概念/
きほんがく /基本額/
きほんがた /基本型/
きほんきごうれつ /基本記号列/
きほんきのう /基本機能/
きほんきゅう /基本給/
きほんきゅうじゅうし /基本給重視/
きほんきょうぎ /基本教義/
きほんきょうよう /基本教養/
きほんぎじゅつ /基本技術/
きほんくかく /基本区画/
きほんけい /基本形/
きほんけん /基本権/
きほんげんそく /基本原則/
きほんげんり /基本原理/
きほんこうしき /基本公式/
きほんこうせい /基本構成/
きほんこうせいぎじゅつ /基本構成技術/
きほんこうぞう /基本構造/
きほんこうどうげんそく /基本行動原則/
きほんこころえ /基本心得/
きほんこころえへん /基本心得篇/
きほんご /基本語/
きほんさようそ /基本作用素/
きほんさんぽう /基本算法/
きほんしき /基本式/
きほんしこう /基本指向/
きほんしせい /基本姿勢/
きほんしそう /基本思想/
きほんしゅうき /基本周期/
きほんしゅうはすう /基本周波数/
きほんしょく /基本色/
きほんしよう /基本仕様/
きほんしようばん /基本仕様版/
きほんじこう /基本事項/
きほんすんぽう /基本寸法/
きほんせいしつ /基本性質/
きほんせいしん /基本精神/
きほんせいのう /基本性能/
きほんせっけい /基本設計/
きほんせってい /基本設定/
きほんせん /基本線/
きほんせんとうのうりょく /基本戦闘能力/
きほんせんぽう /基本戦法/
きほんせんりゃく /基本戦略/
きほんそうさ /基本操作/
きほんそしきけい /基本組織系/
きほんたんい /基本単位/
きほんたんご /基本単語/
きほんち /基本値/
きほんちしき /基本知識/
きほんちゅう /基本中/
きほんていすう /基本定数/
きほんていり /基本定理/
きほんてき /基本的/
きほんてきぎもん /基本的疑問/
きほんてきけんり /基本的権利/
きほんてきしせい /基本的姿勢/
きほんてきじょうけん /基本的条件/
きほんてきじんけん /基本的人権/
きほんてきちしき /基本的知識/
きほんてきどうぐ /基本的道具/
きほんてきもんだい /基本的問題/
きほんてきろせん /基本的路線/
きほんてきわくぐみ /基本的枠組/
きほんてん /基本点/
きほんてんすう /基本点数/
きほんとくせい /基本特性/
きほんとくちょうりょう /基本特徴量/
きほんとっきょ /基本特許/
きほんどうさ /基本動作/
きほんにんしき /基本認識/
きほんは /基本波/
きほんば /基本場/
きほんぱたあん /基本パターン/
きほんぶ /基本部/
きほんぶぶん /基本部分/
きほんぶんれつそしき /基本分裂組織/
きほんへんかん /基本変換/
きほんへんせい /基本編成/
きほんほう /基本法/
きほんほうしん /基本方針/
きほんほうそく /基本法則/
きほんぼいん /基本母音/
きほんようご /基本用語/
きほんようごしゅう /基本用語集/
きほんようそ /基本要素/
きほんよそう /基本予想/
きほんりねん /基本理念/
きほんりゅうし /基本粒子/
きほんりょう /基本料/
きほんりょういき /基本領域/
きほんりょうきん /基本料金/
きほんりょうきんぶん /基本料金分/
きほんわざ /基本技/
きぼ /規模/
きぼう /希望/
きぼうか /希望価/
きぼうかいとりかかく /希望買取価格/
きぼうかかく /希望価格/
きぼうがおか /希望ヶ丘/
きぼうきんがく /希望金額/
きぼうこうりかかく /希望小売価格/
きぼうこすう /希望個数/
きぼうさっすう /希望冊数/
きぼうしていせき /希望指定席/
きぼうしゃ /希望者/
きぼうしゃぜんいん /希望者全員/
きぼうしゃたすう /希望者多数/
きぼうしゃふくすう /希望者複数/
きぼうしゃぼしゅう /希望者募集/
きぼうじゅん /希望順/
きぼうじょうげんかかく /希望上限価格/
きぼうたすう /希望多数/
きぼうちょうさ /希望調査/
きぼうてき /希望的/
きぼうてきかんそく /希望的観測/
きぼうてきよそう /希望的予想/
きぼうとしょ /希望図書/
きぼうにんずう /希望人数/
きぼうねだん /希望値段/
きぼうばいか /希望売価/
きぼうび /希望日/
きぼうほう /喜望峰/
きぼうまいすう /希望枚数/
きぼく /亀卜/
きぼし /木星/
きぼじたい /規模自体/
きぼつ /鬼没/
きぼてきようせい /規模適用性/
きぼとうかせい /規模透過性/
きぼり /木彫り/
きまえ /気前/
きまぐれ /気まぐれ/
きまじめ /生真面目/
きまた /木俣/
きまち /木町/
きまちどおり /木町通/
きまつ /期末/
きまつしけん /期末試験/
きまま /気まま/
きまめ /黄豆/
きまり /決り/
きみ /君/気味/黄身/希美/生美/公/キミ/黄み/喜美/辟/貴美/
きみあき /公明/
きみいがい /君以外/
きみえ /君江/君枝/希己枝/貴美江/
きみお /喜三男/公男/公雄/
きみか /公佳/
きみがよ /君が代/
きみこ /公子/喜美子/君子/季実子/季美子/紀美子/貴美子/きみ子/
きみしま /君島/君嶋/
きみじま /君島/君嶋/
きみた /君田/
きみたか /君孝/公尚/
きみたち /君達/
きみち /季道/
きみつ /機密/君津/気密/
きみつぐん /君津郡/
きみつじこう /機密事項/
きみつじょうほう /機密情報/
きみつせい /気密性/機密性/
きみつひ /機密費/
きみとし /公稔/
きみどり /黄緑/木緑/
きみなお /公尚/
きみのり /公紀/公典/
きみひこ /公彦/仁彦/
きみひと /公人/
きみひろ /公裕/公博/公宏/公広/
きみゃく /気脈/
きみやす /公保/
きみやま /君山/
きみょう /奇妙/帰命/
きみよ /君代/
きみわる /気味悪/
きむ /帰無/金/
きむいるそん /金日成/
きむすめ /生娘/
きむち /キムチ/沈菜/
きむら /木村/木邑/
きむらけん /木村研/
きむらしょうのすけ /木村庄之助/
きむらや /木村屋/
きめ /肌理/木目/
きめい /記明/記名/貴名/記銘/
きめいしき /記名式/
きめいとうひょう /記名投票/
きめうち /決め打ち/
きめかた /決め方/
きめたおし /極め倒し/
きめだし /極め出し/
きめて /決め手/
きめら /キメラ/
きも /肝/胆/
きもいり /肝いり/肝煎り/
きもち /気持/気持ち/
きもったま /肝っ玉/
きもつき /肝付/
きもと /木本/木元/樹本/
きもの /着物/
きものや /着物屋/
きもべつ /喜茂別/
きもぽん /肝ポン/
きもん /奇問/鬼門/奇門/
きもんすう /旗門数/
きもんとんこう /奇門遁甲/
きゃ /伽/迦/
きゃく /客/脚/却/卻/攫/
きゃくあし /客足/
きゃくいん /客員/脚韻/
きゃくいんけんきゅういん /客員研究員/
きゃくおうたい /客応対/
きゃくかしゃく /客貨車区/
きゃくがわ /客側/
きゃくさき /客先/脚先/
きゃくさま /客様/
きゃくさまかくい /客様各位/
きゃくし /客死/
きゃくしき /脚式/
きゃくしつ /客室/脚質/
きゃくしつがわ /客室側/
きゃくしつじょうむいん /客室乗務員/
きゃくしつない /客室内/
きゃくしつりょうむりょう /客室料無料/
きゃくしゃ /客車/
きゃくしゃか /客車化/
きゃくしゃけんいんじ /客車牽引時/
きゃくしゃけんいんよう /客車牽引用/
きゃくしゃどうし /客車同士/
きゃくしゃりょこう /客車旅行/
きゃくしゃれっしゃ /客車列車/
きゃくしゃれっしゃどうし /客車列車同士/
きゃくしょうばい /客商売/
きゃくしょく /脚色/
きゃくじん /客人/
きゃくすじ /客筋/
きゃくせき /客席/
きゃくせん /客船/
きゃくぜんいん /客全員/
きゃくそう /客層/
きゃくたい /客体/
きゃくちゅう /脚注/脚註/
きゃくでん /客電/
きゃくどうし /客同士/
きゃくひき /客引き/
きゃくぶ /脚部/
きゃくぶふあん /脚部不安/
きゃくほん /脚本/
きゃくほんか /脚本家/
きゃくま /客間/
きゃくゆそう /客輸送/
きゃくよう /客用/
きゃくよせ /客寄/客寄せ/
きゃくりょく /脚力/
きゃしゃ /華奢/花車/
きゃたつ /脚立/
きゃっか /却下/脚下/
きゃっかん /客観/
きゃっかんか /客観化/
きゃっかんきじゅつ /客観記述/
きゃっかんし /客観視/
きゃっかんしゅぎ /客観主義/
きゃっかんじかん /客観時間/
きゃっかんせい /客観性/
きゃっかんてき /客観的/
きゃっかんてききじゅん /客観的基準/
きゃっかんてきじじつ /客観的事実/
きゃっかんてきじぶつ /客観的事物/
きゃっかんてきじょうきょう /客観的状況/
きゃっかんてきじれい /客観的事例/
きゃっかんてきすうじ /客観的数字/
きゃっかんてきせいか /客観的成果/
きゃっかんてきたいしょう /客観的対象/
きゃっかんてきたちば /客観的立場/
きゃっかんてきとうけい /客観的統計/
きゃっかんてきにんしきど /客観的認識度/
きゃっかんてきはんだん /客観的判断/
きゃっかんてきひょうか /客観的評価/
きゃっかんてきひょうかほう /客観的評価法/
きゃっかんてきようそ /客観的要素/
きゃっかんひょうか /客観評価/
きゃっかんろん /客観論/
きゃっこう /脚光/
きゃっしゅ /キャッシュ/
きゃっしゅふろーけいさんしょ /キャシュフロー計算書;財務諸表の1つ/
きゃっち /キャッチ/
きゃっちふれーず /キャッチフレーズ/
きゃのん /キヤノン/キャノン/
きゃのんはんばい /キヤノン販売/
きゃはん /脚絆/
きゃばれー /キャバレー/
きゃびねっと /キャビネット/
きゃぷてん /キャプテン/
きゃべつ /キャベツ/
きゃら /伽羅/
きゃらくたー /キャラクター/
きゃらたん /キャラ端/
きゃりあ /キャリア/
きゃりあー /キャリアー/
きゃんせる /キャンセル/
きゃんでぃ /キャンディ/
きゃんでぃー /キャンディー/
きゃんでぃーず /キャンディーズ/
きゃんぱす /キャンパス/
きゃんぺーん /キャンペーン/
きや /紀谷/
きやく /規約/既約/
きやくいはん /規約違反/
きやくけい /既約形/
きやくじゅんきょ /規約準拠/
きやくじょう /規約上/
きやくじょうよるい /既約剰余類/
きやくたこうしき /既約多項式/
きやくぶんすう /既約分数/
きやくへんこう /規約変更/
きやす /喜安/
きやすさ /気安さ/
きやすめ /気休め/
きやせ /着痩せ/
きやま /木山/基山/
きやまち /木屋町/
きやむ /喜屋武/
きやん /喜屋武/
きゅーば /玖瑪/
きゅーぴっと /キューピット/
きゅーぶ /キューブ/
きゅう /旧/急/久/休/級/球/求/究/吸/及/救/泣/九/給/糾/宮/弓/汲/灸/笈/窮/朽/仇/丘/躬/嗅/９/扱/岌/恷/摎/柩/樛/歙/烋/疚/皀/穹/糺/翕/舊/蚯/裘/貅/赳/逑/邱/鬮/鳩/臼/
きゅう> /旧/
きゅうあい /求愛/
きゅうあいき /旧愛機/
きゅうあいこうどう /求愛行動/
きゅうあく /旧悪/
きゅうい /球威/級位/
きゅういん /吸引/
きゅういんかいぞう /吸引改造/
きゅういんしき /吸引式/
きゅういんそうち /吸引装置/
きゅういんてき /吸引的/
きゅういんりょく /吸引力/
きゅうえき /旧駅/
きゅうえきめい /旧駅名/
きゅうえん /休演/救援/休煙/
きゅうえんかつどう /救援活動/
きゅうえんき /救援機/
きゅうえんきかんしゃ /救援機関車/
きゅうえんきがいけんこう /吸煙危害健康/
きゅうえんしゅつじょう /球宴出場/
きゅうえんとうしゅ /救援投手/
きゅうえんぶっし /救援物資/
きゅうえんよう /救援用/
きゅうおうじょうけん /旧応情研/
きゅうおおくらやま /旧大倉山/
きゅうおん /吸音/旧恩/
きゅうおんざい /吸音材/
きゅうおんせい /吸音性/
きゅうおんとくせい /吸音特性/
きゅうおんめん /吸音面/
きゅうおんりつ /吸音率/
きゅうおんりょく /吸音力/
きゅうか /休暇/急下/旧家/求家/球果/
きゅうかーぶ /急カーブ/
きゅうかい /休会/求解/球界/
きゅうかいうら /九回裏/
きゅうかいぐん /旧海軍/
きゅうかいぜんたい /球界全体/
きゅうかいそく /旧快速/
きゅうかいついほう /球会追放/球界追放/
きゅうかいていぐんかん /旧海底軍艦/
きゅうかいどう /旧街道/
きゅうかいひ /旧会費/
きゅうかいふっき /球界復帰/
きゅうかく /嗅覚/球殻/
きゅうかくだい /急拡大/
きゅうかくど /急角度/
きゅうかこう /急下降/
きゅうかしょくぶつ /球果植物/
きゅうかしょくぶつこう /球果植物綱/
きゅうかじょうきょう /休暇状況/
きゅうかせいど /休暇制度/
きゅうかそく /急加速/
きゅうかそくじ /急加速時/
きゅうかちゅう /休暇中/
きゅうかな /旧仮名/
きゅうかむら /休暇村/
きゅうかもつせん /旧貨物線/
きゅうかん /休刊/休館/休閑/急患/旧館/
きゅうかんごう /休刊号/
きゅうかんじ /旧漢字/
きゅうかんちゅう /休館中/
きゅうかんちょう /九官鳥/
きゅうかんび /休館日/休肝日/
きゅうかんりにん /旧管理人/
きゅうが /休芽/
きゅうがく /休学/
きゅうがた /旧型/
きゅうがたきゃくしゃ /旧型客車/旧形客車/
きゅうがたけんばいき /旧型券売機/
きゅうがたこくでん /旧型国電/
きゅうがたしゃ /旧型車/
きゅうがたしゃりょう /旧型車両/
きゅうがたでんしゃ /旧形電車/旧型電車/
きゅうがたとっきゅうしゃ /旧型特急車/
きゅうがたひん /旧型品/
きゅうがたよう /旧型用/
きゅうき /吸気/給気/
きゅうきおん /吸気音/
きゅうきがわ /吸気側/
きゅうきけい /吸気系/
きゅうきしゅ /旧機種/
きゅうきていこう /吸気抵抗/
きゅうきてき /求基的/
きゅうきてきぶんか /求基的分化/
きゅうきみゃくどう /吸気脈動/
きゅうきゃく /旧客/
きゅうきゅう /救急/急求/汲々/
きゅうきゅういりょう /救急医療/
きゅうきゅういりょうたいせい /救急医療体制/
きゅうきゅうしてい /救急指定/
きゅうきゅうしていしゃ /救急指定車/
きゅうきゅうしていびょういん /救急指定病院/
きゅうきゅうしゃ /救急車/
きゅうきゅうそせいほう /救急蘇生法/
きゅうきゅうたい /救急隊/
きゅうきゅうばこ /救急箱/
きゅうきゅうばんそうこう /救急絆創膏/
きゅうきょ /急遽/急きょ/
きゅうきょう /窮境/
きゅうきょうさんけんしょこく /旧共産圏諸国/
きゅうきょうしょくいん /旧教職員/
きゅうきょうようぶ /旧教養部/
きゅうきょく /究極/窮極/
きゅうきょくせん /急曲線/
きゅうきょくちょうじん /究極超人/
きゅうきょくてき /究極的/
きゅうきょくりろん /究極理論/
きゅうきょひつよう /急遽必要/
きゅうきん /球菌/給金/
きゅうぎ /球技/
きゅうぎかいとう /旧議会棟/
きゅうぎじゅつ /旧技術/
きゅうぎじょう /球技場/
きゅうぎょう /休業/
きゅうぎょうちゅう /休業中/
きゅうぎょうほしょうひ /休業保証費/
きゅうくつ /窮屈/
きゅうぐ /弓具/
きゅうぐんき /旧軍機/
きゅうぐんぐんじん /旧軍軍人/
きゅうぐんじん /旧軍人/
きゅうけい /休憩/急啓/求刑/球形/球茎/
きゅうけいご /休憩後/
きゅうけいしつ /休憩室/
きゅうけいしゃ /急傾斜/
きゅうけいしゃち /急傾斜地/
きゅうけいじ /休憩時/
きゅうけいじかん /休憩時間/
きゅうけいじょ /休憩所/
きゅうけいちゅう /休憩中/
きゅうけいどうぎ /休憩動議/
きゅうけいばしょ /休憩場所/
きゅうけいりょう /休憩料/
きゅうけつ /吸血/
きゅうけつき /吸血鬼/救血鬼/
きゅうけつこんちゅう /吸血昆虫/
きゅうけつせいぶつ /吸血生物/
きゅうけんぽう /旧憲法/
きゅうけんぽういはん /旧憲法違反/
きゅうけんぽうか /旧憲法下/
きゅうげき /急激/急劇/
きゅうげん /急減/
きゅうげんあん /旧原案/
きゅうげんそく /急減速/
きゅうげんそくのうりょく /急減速能力/
きゅうこう /急行/休講/旧交/休校/休耕/吸光/
きゅうこういじょう /急行以上/
きゅうこううんてん /急行運転/
きゅうこううんてんくかん /急行運転区間/
きゅうこうおだわらいき /急行小田原行/
きゅうこうおだわらゆき /急行小田原行/
きゅうこうか /急降下/
きゅうこうかばくげき /急降下爆撃/
きゅうこうがた /急行型/
きゅうこうくかん /急行区間/
きゅうこうけい /急行系/
きゅうこうけん /急行券/
きゅうこうさつじんじけん /急行殺人事件/
きゅうこうざ /旧講座/
きゅうこうざせきしゃ /急行座席車/
きゅうこうしゃりょう /急行車両/
きゅうこうしゅうかいどう /旧甲州街道/
きゅうこうしょく /急行色/
きゅうこうしんじゅくいき /急行新宿行/
きゅうこうしんじゅくゆき /急行新宿行/
きゅうこうじゆうせき /急行自由席/
きゅうこうせん /急行線/
きゅうこうそう /旧構想/
きゅうこうたいひ /急行退避/
きゅうこうだい /九工大/九州工業大学/久工大/
きゅうこうだいがわ /九工大側/
きゅうこうだいじょうほう /九工大情報/
きゅうこうだいじょうほうこう /九工大情報工/
きゅうこうだいちのう /九工大知能/
きゅうこうちゅう /休耕中/
きゅうこうつうかえき /急行通過駅/
きゅうこうつがる /急行津軽/
きゅうこうていしゃえき /急行停車駅/
きゅうこうでんしゃ /急行電車/
きゅうこうとうかい /急行東海/
きゅうこうど /吸光度/
きゅうこうどうし /急行同士/
きゅうこうばい /急勾配/
きゅうこうび /休稿日/
きゅうこうびん /急行便/
きゅうこうほんあつぎいき /急行本厚木行/
きゅうこうほんあつぎゆき /急行本厚木行/
きゅうこうよう /急行用/
きゅうこうようしゃ /急行用車/
きゅうこうようしゃりょう /急行用車両/
きゅうこうらくえんきゅうじょう /旧後楽園球場/
きゅうこうりつ /休講率/
きゅうこうりょうきん /急行料金/
きゅうこうれっしゃ /急行列車/
きゅうこく /急告/救国/
きゅうこくてつ /旧国鉄/
きゅうこくてつせん /旧国鉄線/
きゅうこくてつでんしゃ /旧国鉄電車/
きゅうこくてつろせん /旧国鉄路線/
きゅうこくどう /旧国道/
きゅうこくめい /旧国名/
きゅうこくらしやくしょ /旧小倉市役所/
きゅうこはまてつどう /旧小浜鉄道/
きゅうこん /求婚/球根/
きゅうご /救護/
きゅうごく /旧国/
きゅうさい /救済/休載/
きゅうさいかん /救済観/
きゅうさいさく /救済策/
きゅうさいじょうたい /休載状態/
きゅうさいせいど /救済制度/
きゅうさいそち /救済措置/
きゅうさいちゅう /休載中/
きゅうさいぶん /休載分/
きゅうさいろせん /救済路線/
きゅうさか /急坂/
きゅうさく /旧作/窮策/久作/
きゅうさつ /旧札/
きゅうさんだい /九産大/
きゅうさんわ /旧三和/
きゅうざか /急坂/
きゅうざひょう /球座標/
きゅうざぶろう /究三郎/
きゅうし /休止/給紙/臼歯/急死/九死/球史/
きゅうしあげ /急仕上げ/
きゅうしがい /旧市街/
きゅうしき /旧式/
きゅうしきかん /休止期間/
きゅうしききかき /旧式気化器/
きゅうしじょうたい /休止状態/
きゅうしせん /休止線/
きゅうしそう /休止相/
きゅうしちゅう /休止中/
きゅうしつ /吸湿/
きゅうしつざい /吸湿剤/
きゅうしつせい /吸湿性/
きゅうしない /旧市内/
きゅうしひん /休止品/
きゅうしふ /休止符/
きゅうしほうほう /給紙方法/
きゅうしゃ /厩舎/急斜/旧車/廐舎/
きゅうしゃめい /旧社名/
きゅうしゃめん /急斜面/
きゅうしゅ /級酒/九首/
きゅうしゅう /吸収/九州/急襲/旧習/
きゅうしゅうあさひほうそう /九州朝日放送/
きゅうしゅうおうだん /九州横断/
きゅうしゅうかくち /九州各地/
きゅうしゅうかのう /吸収可能/
きゅうしゅうかん /九州間/
きゅうしゅうがっぺい /吸収合併/
きゅうしゅうきた /九州北/
きゅうしゅうけいすう /吸収係数/
きゅうしゅうげいこうだい /九州芸工大/
きゅうしゅうげいじゅつこうかだいがく /九州芸術工科大学/
きゅうしゅうこう /九州工/
きゅうしゅうこうぎょうだい /九州工業大/
きゅうしゅうこうぎょうだいがく /九州工業大学/
きゅうしゅうこうぞう /吸収構造/
きゅうしゅうこうだい /九州工大/
きゅうしゅうこうだいいいづか /九州工大飯塚/
きゅうしゅうこうだいちのう /九州工大知能/
きゅうしゅうこくさいだいふ /九州国際大附/
きゅうしゅうさん /九州産/
きゅうしゅうさんぎょうだいがく /九州産業大学/
きゅうしゅうさんしんば /九州産新馬/
きゅうしゅうさんち /九州山地/
きゅうしゅうさんば /九州産馬/
きゅうしゅうざい /吸収剤/
きゅうしゅうしぶ /九州支部/
きゅうしゅうしま /九州志摩/
きゅうしゅうしゅっしん /九州出身/
きゅうしゅうしゅっしんしゃ /九州出身者/
きゅうしゅうしんかんせん /九州新幹線/
きゅうしゅうじゅうかんどう /九州縦貫道/
きゅうしゅうじん /九州人/
きゅうしゅうせい /吸収性/
きゅうしゅうせん /吸収線/
きゅうしゅうせんいかくりつ /吸収遷移確率/
きゅうしゅうせんりょう /吸収線量/
きゅうしゅうぜんいき /九州全域/
きゅうしゅうぜんど /九州全土/
きゅうしゅうそうち /吸収装置/
きゅうしゅうそしき /吸収組織/
きゅうしゅうたい /吸収帯/
きゅうしゅうだい /九州大/
きゅうしゅうだいがく /九州大学/
きゅうしゅうだいひょう /九州代表/
きゅうしゅうちく /九州地区/
きゅうしゅうちほう /九州地方/
きゅうしゅうちゅう /吸収中/
きゅうしゅうちゅうぶ /九州中部/
きゅうしゅうでんりょく /九州電力/
きゅうしゅうとっきゅう /九州特急/
きゅうしゅうない /九州内/
きゅうしゅうながさきちく /九州長崎地区/
きゅうしゅうなんぶちほう /九州南部地方/
きゅうしゅうにゅうぎょう /九州乳業/
きゅうしゅうねつ /吸収熱/
きゅうしゅうばしょ /九州場所/
きゅうしゅうばん /九州版/
きゅうしゅうふうとんこつ /九州風豚骨/
きゅうしゅうぶんこうけい /吸収分光計/
きゅうしゅうほうほう /吸収方法/
きゅうしゅうほうめん /九州方面/
きゅうしゅうほうめんやこう /九州方面夜行/
きゅうしゅうほくぶ /九州北部/
きゅうしゅうまつした /九州松下/
きゅうしゅうまつしたでんき /九州松下電器/
きゅうしゅうもう /吸収毛/
きゅうしゅうやまぐち /九州山口/
きゅうしゅうよう /吸収用/
きゅうしゅうりつ /吸収率/
きゅうしゅうりょく /吸収力/
きゅうしゅうりょこう /九州旅行/
きゅうしゅつ /休出/救出/
きゅうしゅつさくせん /救出作戦/
きゅうしゅん /急峻/
きゅうしょ /急所/究所/
きゅうしょう /旧称/
きゅうしょく /休職/給食/求職/
きゅうしょくいん /旧職員/
きゅうしょくしゃ /求職者/
きゅうしょくみんち /旧植民地/
きゅうしょくや /給食屋/
きゅうしろう /久四郎/
きゅうしん /休診/急進/求心/球心/
きゅうしんぐうてつどう /旧新宮鉄道/
きゅうしんじん /旧新人/
きゅうしんせい /求心性/
きゅうしんは /急進派/
きゅうしんび /休診日/
きゅうしんりょく /求心力/
きゅうじ /給仕/旧字/九字/
きゅうじたい /旧字体/
きゅうじつ /休日/
きゅうじつうんきゅう /休日運休/
きゅうじつしゅっきん /休日出勤/
きゅうじつしんりょう /休日診療/
きゅうじつつうか /休日通過/
きゅうじつつうでん /休日通電/
きゅうじつまえ /休日前/
きゅうじゅう /九十/
きゅうじゅうしょ /旧住所/
きゅうじゅつ /弓術/救恤/
きゅうじょ /救助/
きゅうじょう /球場/球上/休場/球状/窮状/弓場/宮場/九条/
きゅうじょうがわ /球場側/
きゅうじょうしょう /急上昇/
きゅうじょうしょうちゅう /急上昇中/
きゅうじょうしようりょう /球場使用料/
きゅうじょうじゅう /球場中/
きゅうじょうせいもんまえ /球場正門前/
きゅうじょうない /球場内/
きゅうじょうほう /旧情報/
きゅうじょうまえ /球場前/
きゅうじょしゃ /救助者/
きゅうじょたい /救助隊/
きゅうじょほう /救助法/
きゅうじょよう /救助用/
きゅうじょようせい /救助要請/
きゅうじん /求人/旧人/窮盡/
きゅうじんかつどう /求人活動/
きゅうじんこうこく /求人広告/
きゅうじんじょうほう /求人情報/
きゅうじんじょうほうし /求人情報誌/
きゅうじんひょう /求人票/
きゅうじんぼしゅう /求人募集/
きゅうじんるい /旧人類/
きゅうす /急須/
きゅうすい /吸水/給水/
きゅうすいがかり /給水係/
きゅうすいしゃ /給水車/
きゅうすいじょ /給水所/
きゅうすいせい /吸水性/
きゅうすいせいげん /給水制限/
きゅうすいせいげんかいし /給水制限開始/
きゅうすいとう /給水塔/
きゅうすいりょう /給水量/
きゅうすう /級数/
きゅうすうてんかい /級数展開/
きゅうすうわ /級数和/
きゅうず /旧図/
きゅうせい /旧姓/急性/急逝/旧制/球聖/救世/
きゅうせいかんえん /急性肝炎/
きゅうせいき /急性期/九世紀/
きゅうせいきょう /救世教/
きゅうせいぐん /救世軍/
きゅうせいこうこうせい /旧制高校生/
きゅうせいしゅ /救世主/
きゅうせいちょう /急成長/
きゅうせいど /旧制度/
きゅうせいどう /急制動/
きゅうせいどくせい /急性毒性/
きゅうせいひん /旧製品/
きゅうせいびょう /急性病/
きゅうせいふ /旧政府/
きゅうせいりょく /旧勢力/
きゅうせき /旧跡/求積/
きゅうせだい /旧世代/
きゅうせっきじだい /旧石器時代/
きゅうせってい /旧設定/
きゅうせつ /旧説/
きゅうせん /休戦/旧線/急戦/
きゅうせんかい /急旋回/
きゅうせんかいじ /急旋回時/
きゅうせんどう /球泉洞/
きゅうぜんじつ /休前日/
きゅうそ /窮鼠/
きゅうそう /九索/急送/給送/穹蒼/
きゅうそうしゅこく /旧宗主国/
きゅうそく /急速/休息/
きゅうそくじゅうでん /急速充電/
きゅうそくじょ /休息所/
きゅうぞう /急増/九蔵/急造/久蔵/
きゅうたい /球体/旧態/
きゅうたいいぜん /旧態依然/
きゅうたいけい /球体系/
きゅうたいせい /旧体制/
きゅうたいせいか /旧体制化/
きゅうたま /九玉/
きゅうたろう /久太郎/
きゅうだい /九大/及第/旧題/久大/九州大学/
きゅうだいがわ /九大側/
きゅうだいきょうよう /九大教養/
きゅうだいじょうほう /九大情報/
きゅうだいせん /久大線/
きゅうだいてん /及第点/
きゅうだいにっぽんていこく /旧大日本帝国/
きゅうだいほんせん /久大本線/
きゅうだいまえ /九大前/
きゅうだん /球団/糾弾/糾彈/糺弾/糺彈/
きゅうだんか /球団歌/
きゅうだんかくちょう /球団拡張/
きゅうだんかしらもじ /球団頭文字/
きゅうだんかんけいしゃ /球団関係者/
きゅうだんがわ /球団側/
きゅうだんき /球団旗/
きゅうだんこうほう /球団広報/
きゅうだんしん /球団新/
きゅうだんしんきろく /球団新記録/
きゅうだんじむしょ /球団事務所/
きゅうだんべつ /球団別/
きゅうだんめい /球団名/
きゅうち /窮地/旧知/
きゅうちとせくうこうえき /旧千歳空港駅/
きゅうちゃき /給茶器/
きゅうちゃく /吸着/
きゅうちゅう /宮中/
きゅうちゅうりょうり /宮中料理/
きゅうちょ /旧著/
きゅうちょう /級長/
きゅうちょうそん /旧町村/
きゅうちょうてき /求頂的/
きゅうちょうてきぶんか /求頂的分化/
きゅうつい /胸椎/
きゅうつうしん /旧通信/
きゅうてい /宮廷/
きゅうていがか /宮廷画家/
きゅうていこくかいぐん /旧帝国海軍/
きゅうていこくだいがく /旧帝国大学/
きゅうていし /急停止/
きゅうていしゃ /急停車/
きゅうてき /仇敵/旧敵/
きゅうてん /急転/急轉/
きゅうてんかい /急展開/
きゅうてんちょっか /急転直下/
きゅうてんぽくせん /旧天北線/
きゅうでん /宮殿/給電/九電/給田/
きゅうとう /給湯/急騰/
きゅうとうおう /旧東欧/
きゅうとうかいどう /旧東海道/
きゅうとうかいどうせん /旧東海道線/
きゅうとうき /給湯器/
きゅうとうしつ /給湯室/
きゅうとうどく /旧東独/
きゅうとそう /旧塗装/
きゅうとちょう /旧都庁/
きゅうどう /弓道/旧道/球道/
きゅうどうかく /九同角/
きゅうどうしゃ /求道者/
きゅうどうしん /求道心/
きゅうどうぶ /弓道部/
きゅうない /球内/
きゅうないぞうがた /旧内蔵型/
きゅうなん /救難/
きゅうなんせいこうくう /旧南西航空/
きゅうにし /旧西/
きゅうにほんかいぐん /旧日本海軍/
きゅうにほんぐん /旧日本軍/
きゅうにほんぐんじん /旧日本軍人/
きゅうにゅう /吸入/
きゅうにゅうかんせい /吸入慣性/
きゅうにゅうき /吸入器/
きゅうにゅうきよう /吸入器用/
きゅうにゅうはいき /吸入排気/
きゅうにゅうりょう /吸入量/
きゅうねつ /吸熱/
きゅうねん /旧年/九年/
きゅうねんちゅう /旧年中/
きゅうは /急派/
きゅうはいき /給排気/
きゅうはいきけい /給排気系/吸排気系/
きゅうはく /休拍/急迫/窮迫/
きゅうはちこう /旧八高/
きゅうはっしん /急発進/
きゅうはん /旧版/急坂/
きゅうば /急場/九馬/
きゅうばい /急売/
きゅうばん /旧版/吸盤/旧盤/
きゅうばんごうたいけい /旧番号体系/
きゅうばんしき /吸盤式/
きゅうひ /給費/
きゅうひがしがわしょこく /旧東側諸国/
きゅうひき /九匹/
きゅうひつちゅう /休筆中/
きゅうび /九尾/鳩尾/
きゅうびのねこ /九尾の猫/
きゅうびょう /急病/
きゅうびん /急便/
きゅうふ /休符/休譜/給付/旧譜/宮阜/
きゅうふきん /給付金/
きゅうふくおかしないせん /旧福岡市内線/
きゅうふじょう /急浮上/
きゅうぶつりがっこう /旧物理学校/
きゅうぶれーき /急ブレーキ/
きゅうぶん /旧聞/
きゅうへん /急変/
きゅうべえ /久兵衛/
きゅうほう /急報/
きゅうほうしき /旧方式/
きゅうほうじ /久宝寺/
きゅうぼ /急募/
きゅうぼう /窮乏/
きゅうぼん /旧盆/
きゅうま /久馬/
きゅうまんしゅう /旧満州/
きゅうみん /休眠/窮民/
きゅうみんが /休眠芽/
きゅうみんちゅう /休眠中/
きゅうみんぽう /旧民法/
きゅうむ /急務/
きゅうむいん /厩務員/
きゅうめい /究明/救命/糾明/旧名/窮命/糺明/求明/及明/
きゅうめいかん /救命艇/
きゅうめいきゅうきゅうし /救命救急士/
きゅうめいしょう /旧名称/
きゅうめいちゅう /究明中/
きゅうめいぼーと /救命ボート/
きゅうめいりつ /救命率/
きゅうめかません /旧目蒲線/
きゅうめん /球面/
きゅうめんしゅうさ /球面収差/
きゅうめんじょう /球面状/球面上/
きゅうめんは /球面波/
きゅうや /久弥/
きゅうやく /旧訳/
きゅうやくせいしょ /旧約聖書/
きゅうやくせいしょがく /旧約聖書学/
きゅうゆ /給油/
きゅうゆう /級友/旧友/
きゅうゆきがいしゃ /給湯機会社/
きゅうゆぐち /給油口/
きゅうゆしゃ /給油車/
きゅうゆじ /給油時/
きゅうゆちゅう /給油中/
きゅうよ /給与/窮余/窮餘/
きゅうよう /休養/急用/休用/
きゅうようあけ /休養明/
きゅうようきかん /休養期間/
きゅうようせんげん /休養宣言/
きゅうようち /休養地/
きゅうようちゅう /休養中/
きゅうようび /休養日/
きゅうようまえ /休養前/
きゅうよか /給与課/
きゅうよけいさん /給与計算/
きゅうよさべつ /給与差別/
きゅうよしょとく /給与所得/
きゅうよしょとくこうじょ /給与所得控除/
きゅうよしょとくしゃ /給与所得者/
きゅうよたいけい /給与体系/
きゅうよたいけいじたい /給与体系自体/
きゅうらい /旧来/
きゅうらいほうしき /旧来方式/
きゅうらぎ /厳木/
きゅうらく /急落/
きゅうり /胡瓜/
きゅうりゅう /急流/九龍/穹窿/
きゅうりょう /給料/丘陵/
きゅうりょうち /丘陵地/
きゅうりょうび /給料日/
きゅうりょうびまえ /給料日前/
きゅうりょうまえ /給料前/
きゅうりょうめいさいしょ /給料明細書/
きゅうれい /急冷/
きゅうれき /旧暦/
きゅうろう /旧臘/
きゅうろせん /旧路線/
きゅうわ /九羽/
きゅうわり /九割/
きゅうわりいじょう /九割以上/
きゅりうむ /Cm/キュリウム/
きゆう /杞憂/既有/
きょ /虚/居/去/挙/拠/距/許/巨/渠/拒/嘘/鋸/倨/據/歔/炬/秬/筥/苣/踞/遽/醵/鉅/擧/舉/
きょう /今日/強/教/京/共/狂/狭/橋/叫/興/響/恭/胸/鏡/郷/協/驚/香/経/境/競/恐/挟/況/脅/凶/峡/喬/饗/亨/蕎/矯/享/匡/卿/彊/怯/供/僑/兇/侠/驕/梗/陜/杏/馨/叶/兄/劫/頃/姜/亰/僵/兢/竸/况/刧/匈/嚮/夾/嬌/峽/廾/徼/恟/恊/抂/拱/挾/洶/炯/烱/狹/疆/皀/矜/竅/筐/筺/筴/篋/經/繦/羌/莢/襁/誑/跫/轎/鍄/鞏/竟/棘/荊/
きょうあい /狭隘/
きょうあく /凶悪/兇悪/強悪/
きょうあくはん /凶悪犯/
きょうあくはんざい /凶悪犯罪/
きょうあす /今日明日/
きょうあすじゅう /今日明日中/
きょうあつ /強圧/
きょうい /脅威/胸囲/驚異/強意/
きょういく /教育/
きょういくいいんかい /教育委員会/
きょういくいいんかいがわ /教育委員会側/
きょういくいいんちょう /教育委員長/
きょういくいっぱん /教育一般/
きょういくか /教育課/
きょういくかい /教育界/
きょういくかいかく /教育改革/
きょういくかつどう /教育活動/
きょういくかてい /教育過程/教育課程/
きょういくかんきょう /教育環境/
きょういくかんけい /教育関係/
きょういくかんじ /教育漢字/
きょういくがかり /教育係/
きょういくがく /教育学/
きょういくがくかんけい /教育学関係/
きょういくがくかんけいしゃ /教育学関係者/
きょういくがくけんきゅうか /教育学研究科/
きょういくがくじしん /教育学自身/
きょういくがくせんもん /教育学専門/
きょういくがくぶ /教育学部/
きょういくがんぐ /教育玩具/
きょういくきかん /教育機関/
きょういくきかんぜんぱん /教育機関全般/
きょういくきき /教育機器/
きょういくきほんほう /教育基本法/
きょういくぎじゅつ /教育技術/
きょういくぎじゅつてき /教育技術的/
きょういくぎほう /教育技法/
きょういくぎむ /教育義務/
きょういくくんれん /教育訓練/
きょういくけい /教育系/
きょういくけいたい /教育形態/
きょういくけん /教育権/教育県/
きょういくけんきゅう /教育研究/
きょういくけんきゅうきかん /教育研究機関/
きょういくけんきゅうじょせい /教育研究助成/
きょういくげんご /教育言語/
きょういくげんば /教育現場/
きょういくこうか /教育効果/
きょういくこうがく /教育工学/
きょういくこうがくかいはつ /教育工学開発/
きょういくし /教育史/
きょういくしえん /教育支援/
きょういくしえんかんきょう /教育支援環境/
きょういくしじょう /教育市場/
きょういくしせつ /教育施設/
きょういくしどうようりょう /教育指導要領/
きょういくしゃ /教育者/
きょういくしゃしんしょ /教育社新書/
きょういくしゅっぱん /教育出版/
きょういくしょう /教育省/
きょういくしょく /教育職/
きょういくしんり /教育心理/
きょういくじしん /教育自身/
きょういくじたい /教育自体/
きょういくじっしゅう /教育実習/
きょういくじょう /教育上/
きょういくじょうきょう /教育状況/
きょういくじょうほう /教育情報/
きょういくじょうもんだい /教育上問題/
きょういくせいさく /教育政策/
きょういくせいど /教育制度/
きょういくぜんぱん /教育全般/
きょういくそうだん /教育相談/
きょういくたいせい /教育体制/
きょういくだい /教育大/
きょういくだいがくまえ /教育大学前/
きょういくちょう /教育長/
きょういくてき /教育的/
きょういくてきいぎ /教育的意義/
きょういくてきけんち /教育的見地/
きょういくてきこうか /教育的効果/
きょういくてきしどう /教育的指導/
きょういくてきはいりょ /教育的配慮/
きょういくない /教育内/
きょういくないよう /教育内容/
きょういくにゅうもん /教育入門/
きょういくひ /教育費/
きょういくひょうか /教育評価/
きょういくぶ /教育部/
きょういくぶんせき /教育分析/
きょういくぶんや /教育分野/
きょういくほう /教育法/
きょういくほうしき /教育方式/
きょういくほうしん /教育方針/
きょういくほうそう /教育放送/
きょういくほうほう /教育方法/
きょういくほうほうじょう /教育方法上/
きょういくほうほうろん /教育方法論/
きょういくもくてき /教育目的/
きょういくもんだい /教育問題/
きょういくよう /教育用/
きょういくようけいさんき /教育用計算機/
きょういくようけいさんきせんたー /教育用計算機センター/
きょういくろん /教育論/
きょういち /恭一/京一/
きょういちにち /今日一日/
きょういちろう /恭一郎/
きょういてき /驚異的/脅威的/
きょういてきじじつ /驚異的事実/
きょういん /教員/
きょういんこうぼ /教員公募/
きょういんさいようしけん /教員採用試験/
きょういんめんきょ /教員免許/
きょういんようせい /教員養成/
きょううん /凶運/強運/
きょうえい /競泳/共栄/鏡映/
きょうえいがくえん /共栄学園/
きょうえいたんかー /共栄タンカー/
きょうえいどう /共栄堂/
きょうえき /共益/共役/
きょうえきこうばいほう /共役勾配法/
きょうえきひ /共益費/
きょうえん /共演/協演/競演/狂宴/饗宴/
きょうえんき /強塩基/
きょうえんさく /共演作/
きょうえんしゃ /共演者/
きょうおう /供応/響應/
きょうおん /跫音/
きょうおんな /京女/
きょうか /強化/教科/教化/狂歌/莢果/鏡花/
きょうかい /協会/境界/教会/協會/疆界/
きょうかいいん /協会員/教会員/強化委員/
きょうかいいんかい /強化委員会/
きょうかいいんちょう /強化委員長/
きょうかいおんがく /教会音楽/
きょうかいかいちょう /協会会長/
きょうかいかんぶ /協会幹部/
きょうかいがわ /協会側/
きょうかいきょくせん /境界曲線/
きょうかいけん /境界研/
きょうかいしき /教会式/
きょうかいしゅうへん /教会周辺/
きょうかいしゅさい /協会主催/
きょうかいしょくいん /協会職員/
きょうかいじょう /境界上/
きょうかいじょうけん /境界条件/
きょうかいせきぶん /境界積分/
きょうかいせん /境界線/
きょうかいせんふきん /境界線付近/
きょうかいせんぽう /教会旋法/
きょうかいそう /境界層/
きょうかいち /境界値/
きょうかいちょう /教会長/
きょうかいない /境界内/教会内/
きょうかいひょうご /協会標語/
きょうかいふきん /境界付近/
きょうかいぶんや /境界分野/
きょうかいへん /境界辺/協会編/
きょうかいめん /境界面/
きょうかいもんだい /境界問題/
きょうかいようそ /境界要素/
きょうかいようそほう /境界要素法/
きょうかいりゅう /境界流/
きょうかいりょう /境界量/
きょうかいりょういき /境界領域/
きょうかがくしゅう /強化学習/
きょうかがっしゅく /強化合宿/
きょうかく /胸郭/侠客/狭角/
きょうかさく /強化策/
きょうかざい /強化剤/
きょうかしゅうかん /強化週間/
きょうかしょ /教科書/
きょうかしょきじゅつ /教科書記述/
きょうかしょくひん /強化食品/
きょうかしょけんてい /教科書検定/
きょうかしょじけん /教科書事件/
きょうかしょそうどう /教科書騒動/
きょうかしょちょうさかん /教科書調査官/
きょうかしょてき /教科書的/
きょうかしょてきじょうしき /教科書的常識/
きょうかしょひっしゃ /教科書筆者/
きょうかしょもんだい /教科書問題/
きょうかしょや /教科書屋/
きょうかつ /恐喝/
きょうかでんげん /強化電源/
きょうかね /京兼/
きょうかばん /強化版/
きょうかふく /強化服/
きょうかりょく /強火力/
きょうかん /教官/共感/叫喚/驕悍/
きょうかんかいぎ /教官会議/
きょうかんかくてきひゆ /共感覚的比喩/
きょうかんしつ /教官室/
きょうかんめい /教官名/
きょうが /恭賀/
きょうがい /境涯/
きょうがく /共学/驚愕/教学/
きょうがくこう /共学校/
きょうがせ /京ヶ瀬/
きょうがね /京兼/
きょうがんい /強含意/
きょうき /狂気/凶器/共起/狂喜/驚喜/狭軌/強記/兇器/侠気/
きょうきか /狭軌化/
きょうきぎょうれつ /共起行列/
きょうきくかん /狭軌区間/
きょうきしゃりょう /狭軌車両/
きょうきしんかんせん /狭軌新幹線/
きょうきせん /狭軌線/
きょうきゃく /橋脚/
きょうきゅう /供給/
きょうきゅうかじょう /供給過剰/
きょうきゅうかた /供給過多/
きょうきゅうがわ /供給側/
きょうきゅうがわかくしゃ /供給側各社/
きょうきゅうけいたい /供給形態/
きょうきゅうげん /供給源/
きょうきゅうさき /供給先/
きょうきゅうばいたい /供給媒体/
きょうきゅうもと /供給元/
きょうきゅうりょく /供給力/
きょうきょ /僑居;寓居、僑寓/
きょうきょう /恐々/兢々/
きょうきらんぶ /狂喜乱舞/
きょうきれっしゃ /狭軌列車/
きょうきん /胸襟/胸筋/
きょうぎ /協議/競技/狭義/供犠/教義/
きょうぎいいん /協議委員/
きょうぎいいんちょう /競技委員長/
きょうぎいっぱん /教義一般/
きょうぎかい /協議会/競技会/
きょうぎかいし /競技開始/
きょうぎかいじょう /競技会場/
きょうぎきそく /競技規則/
きょうぎさんか /競技参加/
きょうぎしっかく /競技失格/
きょうぎしゃ /競技者/競技車/
きょうぎしゅうりょう /競技終了/
きょうぎしゅうりょうご /競技終了後/
きょうぎしゅっしん /競技出身/
きょうぎしょしんしゃ /競技初心者/
きょうぎじこう /協議事項/
きょうぎじょう /競技場/
きょうぎじょうない /競技場内/
きょうぎじんこう /競技人口/
きょうぎせつめい /競技説明/
きょうぎぜんじつ /競技前日/
きょうぎそうこう /競技走行/
きょうぎたいかい /競技大会/
きょうぎたんとう /競技担当/
きょうぎちゅう /協議中/競技中/
きょうぎちょくぜん /競技直前/
きょうぎないよう /競技内容/
きょうぎにってい /競技日程/
きょうぎほうほう /競技方法/
きょうぎまあじゃん /競技麻雀/
きょうぎめい /競技名/
きょうぎゅうびょう /狂牛病/
きょうぎょう /協業/
きょうぎょうしんしょう /教行信証/
きょうぎよう /競技用/
きょうぎようぐるま /競技用車/
きょうぎようしゃりょう /競技用車両/
きょうく /教区/恐懼/狂句/
きょうくう /胸腔/
きょうくん /教訓/
きょうぐう /境遇/僑寓;僑居、寓居/
きょうけい /教計/共形/
きょうけいせい /共形性/
きょうけいば /共形場/
きょうけいばりろん /共形場理論/
きょうけつ /供血/
きょうけん /強健/強権/狂犬/強肩/鏡検/
きょうけんびょう /狂犬病/
きょうげき /京劇/挟撃/挾撃/
きょうげん /狂言/
きょうげんざい /今日現在/
きょうこ /強固/鞏固/響子/恭子/京子/今日子/杏子/享子/協子/教子/香子/
きょうこう /恐慌/強行/強硬/凶行/教皇/胸腔/興行/
きょうこうきんげん /恐惶謹言/
きょうこうぐん /強行軍/
きょうこうさいけつ /強行採決/
きょうこうさく /強攻策/強硬策/
きょうこうしゅだん /強行手段/
きょうこうじょうたい /恐慌状態/
きょうこうせん /京工繊/
きょうこうせんだい /京工繊大/
きょうこうは /強行派/
きょうこうはんたいは /強硬反対派/
きょうこうほうき /強行法規/
きょうこく /峡谷/強国/狭谷/教国/
きょうこつ /胸骨/
きょうこのごろ /今日此頃/今日この頃/
きょうこは /狂虎派/
きょうご /教護/
きょうごう /競合/強豪/
きょうごうかいろ /競合回路/
きょうごうがくしゅう /競合学習/
きょうごうたしゃ /競合他社/
きょうごうてき /競合的/
きょうごうどうし /強豪同士/
きょうごうりょく /競合力/
きょうごうろせん /競合路線/
きょうごく /京極/
きょうさ /教唆/
きょうさい /共済/共催/恐妻/
きょうさいか /恐妻家/
きょうさいがっかいいん /共催学会員/
きょうさいけんきゅうかい /共催研究会/
きょうさく /競作/凶作/共作/狭窄/
きょうさくきょく /共作曲/
きょうさくだいぜんしゅう /競作大全集/
きょうさはん /教唆犯/
きょうさん /協賛/共産/京産/
きょうさんかいいん /協賛会員/
きょうさんがっかい /協賛学会/
きょうさんがっかいいん /協賛学会員/
きょうさんがわ /共産側/
きょうさんきぎょう /協賛企業/
きょうさんけん /共産圏/
きょうさんしゅぎ /共産主義/
きょうさんしゅぎしゃ /共産主義者/
きょうさんしゅぎたいせい /共産主義体制/
きょうさんしゅぎてき /共産主義的/
きょうさんせい /強酸性/
きょうさんせん /京産戦/
きょうさんだい /京産大/京都産業大学/
きょうさんだいせん /京産大戦/
きょうさんちゅうごく /共産中国/
きょうさんとう /共産党/
きょうさんとういん /共産党員/
きょうさんとうかんけいしゃ /共産党関係者/
きょうさんとうこうにん /共産党公認/
きょうさんとうせんげん /共産党宣言/
きょうざい /教材/
きょうざいけんきゅう /教材研究/
きょうざつ /夾雑/
きょうざつぶつ /夾雑物/
きょうざぶろう /恭三郎/
きょうざめ /興覚め/興醒め/
きょうし /教師/教使/供試/享祀/
きょうしありがくしゅう /教師あり学習/
きょうしいっぱん /教師一般/
きょうしがわ /教師側/
きょうしきょく /狂詩曲/
きょうししんごう /教師信号/
きょうしつ /教室/
きょうしつがい /教室外/
きょうしつすう /教室数/
きょうしなし /教師なし/
きょうしなしがくしゅう /教師なし学習/
きょうしゃ /強者/香車/
きょうしやく /教師役/
きょうしゅ /興趣/教主/強手/
きょうしゅう /教習/郷愁/強襲/共終/
きょうしゅうかん /郷愁感/
きょうしゅうしゃ /教習車/
きょうしゅうしょ /教習所/
きょうしゅうじかん /教習時間/
きょうしゅうじょ /教習所/
きょうしゅうせい /教習生/教習制/
きょうしゅうちゅう /教習中/
きょうしゅうないよう /教習内容/
きょうしゅく /恐縮/強縮/
きょうしゅつ /供出/
きょうしょ /教書/
きょうしょう /京商/
きょうしょうてん /共焦点/
きょうしょきゅうしゃ /境勝厩舎/
きょうしょく /教職/強食/
きょうしょくいん /教職員/
きょうしよう /教師用/
きょうしろう /狂四郎/
きょうしん /共振/強震/狂信/狭心/驕心/
きょうしんかいろ /共振回路/
きょうしんき /共振器/
きょうしんけい /共振系/
きょうしんざい /強心剤/
きょうしんしゃしゅうだん /狂信者集団/
きょうしんしゅうはすう /共振周波数/
きょうしんしょう /狭心症/
きょうしんしんどう /共振振動/
きょうしんてき /狂信的/
きょうじ /恭司/教示/恭二/享治/恭治/狂児/矜持/矜恃/挾持/衿持/鏡次/共時/
きょうじく /橋軸/
きょうじせい /強磁性/
きょうじてき /共時的/
きょうじば /強磁場/
きょうじま /京嶋/
きょうじゃく /強弱/
きょうじゃくほう /強弱法/
きょうじゅ /教授/亨受/享受/
きょうじゅう /今日中/凶獣/
きょうじゅかい /教授会/
きょうじゅかた /教授方/
きょうじゅけん /享受権/
きょうじゅしつ /教授室/
きょうじゅしゃ /教授者/
きょうじゅじん /教授陣/
きょうじゅせんせい /教授先生/
きょうじゅたち /教授達/
きょうじゅつ /供述/
きょうじゅつしょ /供述書/
きょうじゅつちょうしょ /供述調書/
きょうじゅどの /教授殿/
きょうじゅん /恭順/
きょうじょう /教条/兇状/橋上/
きょうじょうえきしゃ /橋上駅舎/
きょうじょうしゅぎ /教条主義/
きょうじょうしゅぎしゃ /教条主義者/
きょうじょうしゅぎてき /教条主義的/
きょうじょうてき /教条的/
きょうじん /強靭/狂人/兇刃/凶刃/強靱/
きょうじんたち /狂人達/
きょうす /香車/
きょうすい /胸水/
きょうすけ /京介/京助/恭介/恭助/恭輔/
きょうず /京津/
きょうせい /強制/矯正/教生/共棲/共生/強請/強勢/嬌声/嬌聲/狭正/
きょうせいかいしゅう /強制改宗/
きょうせいきか /強正規化/
きょうせいきぐ /矯正器具/
きょうせいげんしょう /共生現象/
きょうせいこうい /強制行為/
きょうせいしか /矯正歯科/
きょうせいしっこう /強制執行/
きょうせいしゅうよう /強制収容/
きょうせいしゅうりょう /強制終了/
きょうせいしりょく /矯正視力/
きょうせいしんどう /強制振動/
きょうせいせいかつ /共生生活/
きょうせいせいぶつ /共生生物/
きょうせいせんたく /強制選択/
きょうせいそうかん /強制送還/
きょうせいそち /強制措置/
きょうせいたいきょ /強制退去/
きょうせいだいしっこう /強制代執行/
きょうせいちょうよう /強制徴用/
きょうせいていし /強制停止/
きょうせいてき /強制的/
きょうせいてんか /強制添加/
きょうせいはいき /強制排気/
きょうせいはっこう /強制発光/
きょうせいほう /強制法/
きょうせいほうねつ /強制放熱/
きょうせいほけん /強制保険/
きょうせいほけんりょう /強制保険料/
きょうせいりょうがえ /強制両替/
きょうせいりょく /強制力/
きょうせいれんこう /強制連行/
きょうせいろうどう /強制労働/
きょうせき /共石/
きょうせら /京セラ/
きょうせん /共線/胸腺/
きょうそ /教祖/
きょうそう /競争/競走/強壮/競漕/強壯/狂躁/狂想/
きょうそうあいて /競争相手/
きょうそうきょく /協奏曲/狂想曲/
きょうそうきょくばん /協奏曲版/
きょうそうきょくふう /協奏曲風/
きょうそうげきか /競争激化/
きょうそうげんり /競争原理/
きょうそうこうきょうきょく /協奏交響曲/
きょうそうご /競走後/
きょうそうしゃ /競争者/
きょうそうしゃかい /競争社会/
きょうそうしん /競争心/
きょうそうせいせき /競走成績/競争成績/
きょうそうたいけい /競走体系/
きょうそうちゅう /競走中/
きょうそうちゅうし /競争中止/競走中止/
きょうそうにゅうさつ /競争入札/
きょうそうば /競争馬/競走馬/
きょうそうめい /競走名/
きょうそうよう /競争用/
きょうそうりつ /競争率/
きょうそうりょく /競争力/
きょうそく /教則/
きょうそくぼん /教則本/
きょうそさま /教祖様/
きょうそん /共存/
きょうぞう /鏡像/胸像/享三/
きょうぞうおんげん /鏡像音源/
きょうぞうてん /鏡像点/
きょうぞうもじ /鏡像文字/
きょうぞめ /京染/
きょうぞん /共存/
きょうぞんかのう /共存可能/
きょうぞんきょうえい /共存共栄/
きょうぞんほう /共存法/
きょうぞんほうほう /共存方法/
きょうたい /筐体/狂態/嬌態/
きょうたいいき /狭帯域/ナローバンド/
きょうたく /供託/教卓/
きょうたくきん /供託金/
きょうたくしょ /供託所/
きょうたくじょ /供託所/
きょうたる /京樽/
きょうたん /驚嘆/
きょうだ /強打/怯懦/
きょうだい /京大/兄弟/兄妹/姉妹/強大/姉弟/橋台/鏡台/兄姉/京都大学/
きょうだいあい /兄弟愛/
きょうだいうちゅうぶつり /京大宇宙物理/
きょうだいうぶつ /京大宇物/
きょうだいえいせい /京大衛生/
きょうだいかいかん /京大会館/
きょうだいかけん /京大化研/
きょうだいかん /兄弟間/
きょうだいかんきょうちきゅう /京大環境地球/
きょうだいがた /京大型/
きょうだいがわ /京大側/
きょうだいき /兄弟機/
きょうだいきけん /京大基研/
きょうだいけいざい /京大経済/
きょうだいけいざいがくぶ /京大経済学部/
きょうだいげんか /兄妹喧嘩/兄弟喧嘩/
きょうだいこう /京大工/
きょうだいこうごうせい /京大工合成/
きょうだいしまい /兄弟姉妹/
きょうだいしゅっしん /京大出身/
きょうだいじょうほう /京大情報/
きょうだいじん /京大陣/
きょうだいじんぶんけん /京大人文研/
きょうだいすいどうけん /京大水道研/
きょうだいすうかいけん /京大数解研/
きょうだいすうり /京大数理/
きょうだいすうりけん /京大数理研/
きょうだいせい /京大生/
きょうだいせいきょう /京大生協/
きょうだいせきとり /兄弟関取/
きょうだいたいけつ /兄弟対決/
きょうだいだいけい /京大大型/
きょうだいちきゅう /京大地球/
きょうだいちょうこうそう /京大超高層/
きょうだいてん /兄弟店/
きょうだいで /京大出/
きょうだいでんき /京大電気/
きょうだいでんきだいに /京大電気第２/
きょうだいでんさんき /京大電算機/
きょうだいでんし /京大電子/
きょうだいでんしこうがく /京大電子工学/
きょうだいどうし /兄弟同士/
きょうだいどぼく /京大土木/
きょうだいない /京大内/
きょうだいにんげんかんきょう /京大人間環境/
きょうだいのうがくぶ /京大農学部/
きょうだいびょういん /京大病院/
きょうだいぶんし /京大分子/
きょうだいほんぶちく /京大本部地区/
きょうだいぼうさいけん /京大防災研/
きょうだいまいこんくらぶ /京大マイコンクラブ/
きょうだいよしだ /京大吉田/
きょうだいり /京大理/
きょうだいりがくぶ /京大理学部/
きょうだいりがくぶそつ /京大理学部卒/
きょうだいりきし /兄弟力士/
きょうだいろ /京大炉/
きょうだしゃ /強打者/
きょうだる /京樽/
きょうだん /凶弾/教団/教壇/兇弾/兇彈/
きょうだんいん /教団員/
きょうだんかん /教団間/
きょうだんきょうそ /教団教祖/
きょうだんほんぶ /教団本部/
きょうち /境地/
きょうちくこうつう /京築交通/
きょうちくとう /夾竹桃/
きょうちゅう /胸中/
きょうちゅうじゃく /強中弱/
きょうちょ /共著/
きょうちょう /協調/強調/共聴/凶兆/
きょうちょううんてん /協調運転/
きょうちょうけいさん /協調計算/
きょうちょうけいさんきこう /協調計算機構/
きょうちょうげんしょう /協調現象/
きょうちょうこうどう /協調行動/
きょうちょうさぎょう /協調作業/
きょうちょうさぎょうじっけん /協調作業実験/
きょうちょうしょり /協調処理/
きょうちょうせい /協調性/
きょうちょうたんさくしゅほう /協調探索手法/
きょうちょうてき /協調的/
きょうちょうてきそしき /協調的組織/
きょうちょうどうさ /協調動作/
きょうちょうぶんさん /協調分散/
きょうちょうほう /強調法/
きょうちょうほうしき /協調方式/
きょうちょうもんだいかいけつ /協調問題解決/
きょうちょしゃ /共著者/
きょうちょしゃめい /共著者名/
きょうちょしょ /共著書/
きょうぢゅう /今日中/
きょうつい /胸椎/
きょうつう /共通/
きょうつういき /共通域/
きょうつういちじ /共通一次/
きょうつういちじしけん /共通一次試験/
きょうつううんよう /共通運用/
きょうつうか /共通化/共通課/
きょうつうかいすうけん /共通回数券/
きょうつうかんかく /共通感覚/
きょうつうがいねん /共通概念/
きょうつうきかく /共通規格/
きょうつうきやく /共通規約/
きょうつうぎょうれつ /共通行列/
きょうつうけいしき /共通形式/
きょうつうけん /共通券/
きょうつうけんかい /共通見解/
きょうつうげんご /共通言語/
きょうつうこう /共通項/
きょうつうこうぞう /共通構造/
きょうつうこうもく /共通項目/
きょうつうご /共通語/
きょうつうごおんせい /共通語音声/
きょうつうごか /共通語化/
きょうつうごひょうき /共通語表記/
きょうつうしゅうごう /共通集合/
きょうつうしよう /共通仕様/
きょうつうせい /共通性/
きょうつうせいさく /共通政策/
きょうつうせっけい /共通設計/
きょうつうせん /共通線/
きょうつうたいせんこう /共通対戦校/
きょうつうちしき /共通知識/
きょうつうてき /共通的/
きょうつうてん /共通点/
きょうつうにんしき /共通認識/
きょうつうぶ /共通部/
きょうつうぶひん /共通部品/
きょうつうぶぶん /共通部分/
きょうつうぶぶんしき /共通部分式/
きょうつうぶん /共通分/
きょうつうへんせい /共通編成/
きょうつうようそ /共通要素/
きょうづか /京塚/
きょうづせん /京津線/
きょうてい /競艇/協提/協定/教程/
きょうていがっこう /競艇学校/
きょうていぎょうむ /協定業務/
きょうていしせい /強停止性/
きょうていしょ /協定書/
きょうていじょう /競艇場/強定常/
きょうていむし /協定無視/
きょうてき /強敵/狂的/
きょうてん /経典/教典/
きょうでん /強電/
きょうでんけい /強電系/
きょうでんしゃ /共電社/
きょうと /京都/教徒/
きょうとあさひかいかん /京都朝日会舘/
きょうといがい /京都以外/
きょうといちりつげいだい /京都市立芸大/
きょうとう /教頭/共闘/鏡筒/京濤/
きょうとうぶ /鏡筒部/
きょうとうほ /橋頭堡/
きょうとえいぎょうしてん /京都営業支店/
きょうとえき /京都駅/
きょうとえきざいらいせん /京都駅在来線/
きょうとえきちか /京都駅地下/
きょうとえきふきん /京都駅付近/
きょうとえきほうめん /京都駅方面/
きょうとえきまえ /京都駅前/
きょうとおうしょう /京都王将/
きょうとおおさかほんせん /京都大阪本線/
きょうとかいかん /京都会館/
きょうとかいさい /京都開催/
きょうとかた /京都方/
きょうとかん /京都間/
きょうとがくえん /京都学園/
きょうとがくえんだいがく /京都学園大学/
きょうとがわ /京都側/
きょうときねん /京都記念/
きょうときゅうしない /京都旧市内/
きょうときょういくだいがく /京都教育大学/
きょうときんぺん /京都近辺/
きょうとぎおん /京都祇園/
きょうとく /京徳/
きょうとぐち /京都口/
きょうとぐん /京都郡/
きょうとけい /京都系/
きょうとけいばじょう /京都競馬場/
きょうとけいばじょうまえ /京都競馬場前/
きょうとけいゆ /京都経由/
きょうとけんきゅうじょ /京都研究所/
きょうとこうせんだい /京都工繊大/
きょうとこうつう /京都交通/
きょうとごしょ /京都御所/
きょうとさんぎょうだい /京都産業大/
きょうとさんぎょうだいがく /京都産業大学/
きょうとし /京都市/
きょうとしいき /京都市域/
きょうとしえい /京都市営/
きょうとしがい /京都市街/
きょうとしこうつうきょく /京都市交通局/
きょうとしさきょうく /京都市左京区/
きょうとししもぎょうく /京都市下京区/
きょうとしちょう /京都市長/
きょうとしでん /京都市電/
きょうとしない /京都市内/
きょうとしないおうふく /京都市内往復/
きょうとしゅうへん /京都周辺/
きょうとしょう /京都賞/
きょうとしんぶん /京都新聞/
きょうとしんぶんはい /京都新聞杯/
きょうとじゅう /京都中/
きょうとじょしだいがく /京都女子大学/
きょうとじん /京都人/
きょうとせらみっく /京都セラミック/
きょうとせん /京都線/
きょうとたいしょうてん /京都大賞典/
きょうとたきぎのう /京都薪能/
きょうとだい /京都大/
きょうとだいがく /京都大学/
きょうとだいしょうがい /京都大障害/
きょうとちゃく /京都着/
きょうとてん /京都店/
きょうとふ /京都府/
きょうとふうじし /京都府宇治市/
きょうとふきん /京都付近/
きょうとふけい /京都府警/
きょうとふだいひょう /京都府代表/
きょうとふない /京都府内/
きょうとふほくぶ /京都府北部/
きょうとふみん /京都府民/
きょうとふりつ /京都府立/
きょうとふりついかだいがく /京都府立医科大学/
きょうとふりつだいがく /京都府立大学/
きょうとべん /京都弁/
きょうとほうめん /京都方面/
きょうとまるぜん /京都丸善/
きょうとみなみ /京都南/
きょうとむき /京都向き/
きょうど /強度/郷土/匈奴/
きょうどう /共同/協同/経堂/鏡胴/教導/嚮導/共働/協働/
きょうどううんこう /共同運航/共同運行/
きょうどうえき /共同駅/
きょうどうえきこうない /経堂駅構内/
きょうどうかいはつ /共同開発/
きょうどうかんり /共同管理/
きょうどうききん /共同基金/
きょうどうくみあい /共同組合/協同組合/
きょうどうけんきゅう /共同研究/
きょうどうけんきゅうしゃ /共同研究者/
きょうどうげんそう /共同幻想/
きょうどうこうい /共同行為/
きょうどうこうげき /共同攻撃/
きょうどうこうにゅう /共同購入/
きょうどうさぎょう /共同作業/協同作業/
きょうどうさぎょうしゃ /協同作業者/
きょうどうしっぴつしゃ /共同執筆者/
きょうどうしゃこ /経堂車庫/
きょうどうしゅうはいそう /共同集配送/
きょうどうしゅっし /共同出資/
きょうどうしりょう /共同飼料/
きょうどうじっけんしゃ /共同実験者/
きょうどうじゅしょう /共同受賞/
きょうどうせいかつ /共同生活/
きょうどうせいかつじょう /共同生活上/
きょうどうせいさく /共同製作/
きょうどうせいさくしゃ /共同制作者/
きょうどうせきゆ /共同石油/
きょうどうせっけいしゃ /共同設計者/
きょうどうせんげん /共同宣言/
きょうどうせんせん /共同戦線/
きょうどうたい /共同体/協同体/
きょうどうちょさくぶつ /共同著作物/
きょうどうつうしん /共同通信/
きょうどうつうしんはい /共同通信杯/
きょうどうばぬし /共同馬主/
きょうどうほいくしょ /共同保育所/
きょうどうやく /共同訳/
きょうどうよくじょう /共同浴場/
きょうどうりよう /共同利用/
きょうどうりよういいんかい /共同利用委員会/
きょうどうりようか /共同利用化/
きょうどうりようかのう /共同利用可能/
きょうどうりようがかり /共同利用掛/
きょうどうりようがた /共同利用型/
きょうどうりようしせつ /共同利用施設/
きょうどきごう /強度記号/
きょうどけいさん /強度計算/
きょうどさ /強度差/
きょうどし /郷土史/
きょうどしょく /郷土色/
きょうどていか /強度低下/
きょうどぶんぷ /強度分布/
きょうどまり /今日泊/
きょうどりょうり /郷土料理/
きょうなんちょう /境南町/
きょうにんぎょう /京人形/
きょうねん /享年/亨年/凶年/
きょうの /京野/
きょうは /教派/
きょうはく /脅迫/強迫/
きょうはくかんねん /強迫観念/
きょうはくしゃ /脅迫者/
きょうはくじょう /脅迫状/
きょうはくてき /脅迫的/
きょうはくぶん /脅迫文/
きょうはつ /今日初/
きょうはつばい /今日発売/
きょうはん /共犯/
きょうはんかんけい /共犯関係/
きょうはんしゃ /共犯者/
きょうばい /競売/
きょうばいじょ /競売所/
きょうばいせい /競売制/
きょうばいせん /強焙煎/
きょうばし /京橋/
きょうばしえき /京橋駅/
きょうばしきんぺん /京橋近辺/
きょうばしけいはん /京橋京阪/
きょうばん /響板/
きょうばんちゃ /京番茶/
きょうび /今日日/
きょうふ /恐怖/京麩/教父/
きょうふう /強風/京風/
きょうふうじ /強風時/
きょうふえいが /恐怖映画/
きょうふかん /恐怖感/
きょうふくぶ /胸腹部/
きょうふしょう /恐怖症/
きょうふしょうてき /恐怖症的/
きょうふしん /恐怖心/
きょうふもの /恐怖物/
きょうぶ /胸部/
きょうぶんさん /共分散/
きょうぶんさんぎょうれつ /共分散行列/
きょうへい /京平/恭兵/恭平/
きょうへき /胸壁/
きょうへん /共編/共変/
きょうへんせい /共変性/
きょうへんちょう /共変調/
きょうへんてんそる /共変テンソル/
きょうへんどう /共変動/
きょうへんびぶん /共変微分/
きょうべん /強弁/教鞭/
きょうほ /競歩/享保/
きょうほう /凶報/
きょうほん /教本/狂奔/
きょうぼう /凶暴/兇暴/共謀/狂暴/
きょうぼうさ /狂暴さ/
きょうぼうせい /凶暴性/
きょうぼく /経木/
きょうまい /供米/
きょうまく /莢膜/胸膜/
きょうまる /京丸/
きょうまん /驕慢/
きょうみ /興味/
きょうみいじょう /興味以上/
きょうみしんしん /興味津々/興味津津/
きょうみたいしょう /興味対象/
きょうみとうげ /京見峠/
きょうみはんぶん /興味半分/
きょうみぶかい /興味深い/
きょうみほんい /興味本意/興味本位/
きょうむ /教務/
きょうむか /教務課/
きょうむかかり /教務係/
きょうむがかり /教務係/
きょうむしょくいん /教務職員/
きょうむら /京村/
きょうめい /共鳴/
きょうめいおん /共鳴音/
きょうめいきゅうしゅう /共鳴吸収/
きょうめいしつ /共鳴室/
きょうめいじょうけん /共鳴条件/
きょうめいせきぶん /共鳴積分/
きょうめいたい /共鳴体/
きょうめいばん /共鳴板/
きょうめん /鏡面/共面/
きょうめんはんしゃ /鏡面反射/
きょうめんようそ /鏡面要素/
きょうもと /京本/
きょうもとまさき /京本政樹/
きょうもん /経文/
きょうや /京哉/
きょうやく /協約/共訳/共役/供役/
きょうやくいがい /協約以外/
きょうやくかんすう /共役関数/
きょうやくきてい /共役基底/
きょうやくきょく /共役極/
きょうやくこうばいほう /共役勾配法/
きょうやくこうぶんし /共役高分子/
きょうやくさようそ /共役作用素/
きょうやくしゃ /共訳者/
きょうやくじこう /協約事項/
きょうやさい /京野菜/
きょうゆ /教諭/
きょうゆう /共有/享有/亨有/
きょうゆうか /共有化/
きょうゆうかそうきおく /共有仮想記憶/
きょうゆうかのう /共有可能/
きょうゆうきこう /共有機構/
きょうゆうけつごう /共有結合/
きょうゆうしげん /共有資源/
きょうゆうじしょ /共有辞書/
きょうゆうせい /共優性/共有性/
きょうゆうたい /共有体/
きょうゆうちょさくけん /共有著作権/
きょうゆうてん /共有点/
きょうゆうでんたい /強誘電体/
きょうゆうば /共有場/
きょうゆうぶつ /共有物/
きょうゆうぶんさん /共有分散/
きょうゆうへんすう /共有変数/
きょうゆうりょういき /共有領域/
きょうゆうれい /共有例/
きょうよ /供与/
きょうよう /共用/教養/強要/供用/
きょうようか /共用化/
きょうようかてい /教養課程/
きょうようがくぶ /教養学部/
きょうようき /共用機/
きょうようきき /共用機器/
きょうようくかん /共用区間/
きょうようざい /強要罪/
きょうようしつ /共用室/
きょうようしょうせつ /教養小説/
きょうようじ /共用時/
きょうようじかん /供用時間/
きょうようじしょ /共用辞書/
きょうようじだい /教養時代/
きょうようたい /共用体/
きょうようとう /教養棟/
きょうようひ /共用費/
きょうようぶ /教養部/
きょうようぶしょぞく /教養部所属/
きょうようぶつ /共用物/
きょうようぶん /共用分/
きょうらく /享楽/
きょうらん /狂乱/供覧/供卵/
きょうり /郷里/
きょうりき /強力/
きょうりきこ /強力粉/
きょうりきこむぎこ /強力小麦粉/
きょうりつ /共立/
きょうりつしゅっぱん /共立出版/
きょうりつしゅっぱんしゃ /共立出版社/
きょうりつじょし /共立女子/
きょうりつじょしこうこう /共立女子高校/
きょうりつじょしたんきだいがく /共立女子短期大学/
きょうりつせん /京立戦/
きょうりつだいに /共立第二/
きょうりつでんし /共立電子/
きょうりつでんしさんぎょう /共立電子産業/
きょうりゅう /恐竜/恐龍/
きょうりゅうえいが /恐竜映画/
きょうりゅうじだい /恐竜時代/
きょうりゅうせんしゃ /恐竜戦車/
きょうりゅうせんたい /恐竜戦隊/
きょうりゅうだいきこう /恐竜大紀行/
きょうりゅうてん /恐竜展/
きょうりゅうものがたり /恐竜物語/
きょうりょう /橋梁/狭量/
きょうりょく /協力/強力/
きょうりょくかいいん /協力会員/
きょうりょくかんけい /協力関係/
きょうりょくきどうしゃ /強力気動車/
きょうりょくこ /強力粉/
きょうりょくこうざ /協力講座/
きょうりょくこうどう /協力行動/
きょうりょくしゃ /協力者/
きょうりょくしゃぼしゅうちゅう /協力者募集中/
きょうりょくじば /強力磁場/
きょうりょくたいせい /協力体制/
きょうりょくてき /協力的/
きょうりょくてん /協力店/
きょうりょくむひ /強力無比/
きょうりょくゆまく /強力油膜/
きょうれい /強冷/
きょうれき /教歴/
きょうれつ /強烈/
きょうれん /教練/教錬/
きょうれんけつ /強連結/
きょうろ /狭路/
きょうわ /協和/共和/興和/
きょうわおんてい /協和音程/
きょうわかん /協和感/
きょうわぎんこう /協和銀行/
きょうわこく /共和国/
きょうわこくはい /共和国杯/
きょうわさいたま /協和埼玉/
きょうわしゅぎ /共和主義/
きょうわせい /協和性/共和制/
きょうわせいいっぱん /共和制一般/
きょうわせいたい /共和政体/
きょうわてき /協和的/
きょうわとう /共和党/
きょうわはっこう /協和発酵/
きょえい /虚栄/巨影/
きょえいしん /虚栄心/
きょえんばん /共演盤/
きょおんげん /虚音源/
きょか /許可/炬火/
きょかき /許可機/
きょかこくち /許可告知/
きょかしゃりょういがい /許可車両以外/
きょかしょ /許可書/
きょかしょう /許可証/
きょかしんせい /許可申請/
きょかせい /許可制/
きょかせいきょうか /許可制強化/
きょかせいど /許可制度/
きょかん /巨漢/巨艦/居館/
きょかんけつ /許冠傑/
きょかんりきし /巨漢力士/
きょがく /巨額/
きょがん /巨岩/炬眼/
きょきょじつじつ /虚々実々/
きょきん /拠金/
きょぎ /虚偽/
きょぎょう /虚業/
きょく /曲/局/極/旭/棘/亟/勗/洫/蕀/跼/巨躯/
きょくあて /局宛/
きょくい /極意/
きょくいがい /曲以外/
きょくいん /局員/
きょくう /極右/虚空/
きょくうた /曲歌/
きょくかい /曲解/
きょくかく /極角/
きょくかん /曲管/
きょくかんちしよう /極寒地使用/
きょくがい /局外/
きょくがいしゃ /局外者/
きょくがわ /局側/
きょくきぼ /局規模/
きょくぎ /曲技/
きょくぎめ /曲決め/
きょくけいしき /極形式/
きょくげい /曲芸/
きょくげん /極言/極限/局限/
きょくげんぎじゅつか /極限技術課/
きょくげんじょうたい /極限状態/
きょくげんち /極限値/
きょくげんどうてい /極限同定/
きょくげんどうていかのう /極限同定可能/
きょくげんぶとう /極限舞踊/
きょくげんほう /極限法/
きょくげんりゅう /極限流/
きょくこうしんくう /極高真空/
きょくこうせい /曲構成/
きょくさ /極左/
きょくさく /曲作/
きょくざい /局在/
きょくざいか /局在化/極在化/
きょくざいせい /局在性/
きょくざいろん /局在論/
きょくざひょう /極座標/
きょくし /旭志/極至/
きょくしゅう /曲集/
きょくしゅうろく /曲収録/
きょくしょ /局所/局所座標系/
きょくしょう /極小/
きょくしょうか /極小化/
きょくしょうかい /極小解/
きょくしょうせい /極小性/
きょくしょうち /極小値/
きょくしょか /局所化/
きょくしょかい /局所解/
きょくしょかん /局所環/
きょくしょかんきょう /局所環境/
きょくしょかんすう /局所関数/
きょくしょかんせいけい /局所慣性系/
きょくしょきんじ /局所近似/
きょくしょけつごう /局所結合/
きょくしょさいてき /局所最適/
きょくしょさよう /局所作用/
きょくしょし /局所視/
きょくしょしつてん /局所質点/
きょくしょせい /局所性/
きょくしょせんけいか /局所線形化/
きょくしょせんげんめい /局所宣言名/
きょくしょそくど /局所速度/
きょくしょたい /局所体/
きょくしょちょっこうくうかん /局所直交空間/
きょくしょちょっこうざひょう /局所直交座標/
きょくしょてき /局所的/
きょくしょてきけんち /局所的見地/
きょくしょひょうげん /局所表現/
きょくしょへいきんば /局所平均場/
きょくしょへんすう /局所変数/
きょくしょへんすうめい /局所変数名/
きょくしょほうしき /局所方式/
きょくしょますいやく /局所麻酔薬/
きょくしん /極真/
きょくしんかいかん /極真会館/
きょくしんからて /極真空手/
きょくじく /極軸/
きょくじたい /曲自体/
きょくじつ /旭日/
きょくじゅん /曲順/
きょくすい /曲水/
きょくすう /曲数/極数/局数/
きょくせい /極性/
きょくせいとういつ /極性統一/
きょくせいとういつけい /極性統一形/
きょくせいぶんし /極性分子/
きょくせつ /曲折/
きょくせん /曲線/局線/
きょくせんきんじ /曲線近似/
きょくせんこう /曲先行/
きょくせんざひょう /曲線座標/
きょくせんざひょうけい /曲線座標系/
きょくせんじょう /曲線上/
きょくせんぜんたい /曲線全体/
きょくせんたく /曲選択/
きょくせんつうかそくど /曲線通過速度/
きょくせんひょう /曲線標/
きょくせんぶぶん /曲線部分/
きょくせんへん /曲線片/
きょくせんれつ /曲線列/
きょくぜんしゅう /曲全集/
きょくぜんたい /曲全体/
きょくそう /曲想/
きょくたい /極体/
きょくたん /極端/
きょくたんい /曲単位/
きょくたんか /極端化/
きょくたんじょう /曲誕生/
きょくだい /極大/
きょくだいか /極大化/
きょくだいげん /極大元/
きょくだいせい /極大性/
きょくだいち /極大値/
きょくだいてん /極大点/
きょくだん /曲弾/
きょくち /極値/極致/局地/極地/
きょくちせいふく /極地征服/
きょくちてき /局地的/
きょくちぶんぷ /極値分布/
きょくちゅう /曲中/局中/
きょくちゅういちょう /曲中移調/
きょくちょう /局長/曲調/
きょくちょうだいり /局長代理/
きょくつき /曲付/
きょくてき /極的/
きょくてん /極点/
きょくとう /極東/曲頭/
きょくとうちいき /極東地域/
きょくとうほうそう /極東放送/
きょくど /極度/
きょくどうざん /旭道山/
きょくどめ /局止め/局留/
きょくない /局内/
きょくは /棘波/
きょくはつ /局発/
きょくはつかいろ /局発回路/
きょくば /曲馬/
きょくばだん /曲馬団/
きょくばん /局番/曲番/
きょくばんごう /曲番号/
きょくひ /棘皮/
きょくふう /曲風/
きょくぶ /局部/
きょくぶますい /局部麻酔/
きょくへいめん /曲平面/
きょくほく /極北/
きょくむき /極向き/
きょくめ /曲目/
きょくめい /曲名/局名/
きょくめん /局面/曲面/局免/
きょくめんきょ /局免許/
きょくめんこうせん /曲面交線/
きょくめんしんせい /局免申請/
きょくめんしんせいちゅう /局免申請中/
きょくめんじょう /曲面上/
きょくめんない /曲面内/
きょくめんへん /曲面片/
きょくもく /曲目/
きょくもくひょう /曲目表/
きょくやく /曲約/
きょくよう /極洋/
きょくりつ /曲率/
きょくりつきょくだいてん /曲率極大点/
きょくりつはんけい /曲率半径/
きょくりょく /極力/
きょくりょくこうへい /極力公平/
きょくりょくちゅうい /極力注意/
きょくりょくはいじょ /極力排除/
きょくろん /極論/
きょけつ /虚血/虚血心筋/
きょけつせいしんしっかん /虚血性心疾患/
きょけん /巨犬/
きょげい /巨鯨/
きょげん /虚言/
きょこう /虚構/挙行/
きょこうせんだん /虚航船団/
きょこく /挙国/
きょこん /許婚/巨根/
きょごう /倨傲/
きょさいぼう /巨細胞/
きょざい /巨財/
きょし /巨視/挙止/鋸歯/
きょしき /挙式/
きょしきび /挙式日/
きょしつ /居室/
きょしつめんせき /居室面積/
きょしてき /巨視的/
きょしゅ /挙手/
きょしゅう /去就/
きょしゅつ /拠出/
きょしゅつきん /拠出金/
きょしょ /居所/
きょしょう /巨匠/挙証/
きょしょうせきにん /挙証責任/
きょしょく /虚飾/巨食/拒食/
きょしょくしょう /拒食症/
きょしん /巨神/虚心/許慎/
きょしんけい /共振系/
きょしんたんかい /虚心坦懐/
きょしんへい /巨神兵/
きょじつ /虚実/
きょじゃく /虚弱/
きょじゃくたいしつ /虚弱体質/
きょじゅ /巨樹/
きょじゅう /居住/
きょじゅうく /居住区/
きょじゅうくうかん /居住空間/
きょじゅうしゃ /居住者/
きょじゅうしゃぜんいんぶん /居住者全員分/
きょじゅうしょうめいしょ /居住証明書/
きょじゅうじょうけん /居住条件/
きょじゅうせい /居住性/
きょじゅうち /居住地/
きょじゅうちいき /居住地域/
きょじゅうちさべつ /居住地差別/
きょじゅうぶ /居住部/
きょじょう /許状/居城/
きょじん /巨人/巨神/虚人/
きょじんぐん /巨人軍/
きょじんすうはい /巨人崇拝/
きょじんせん /巨人戦/
きょじんだせん /巨人打線/
きょじんのほし /巨人の星/
きょじんはんしんせん /巨人阪神戦/
きょすう /虚数/
きょすうかい /虚数解/
きょすうたんい /虚数単位/
きょすうぶ /虚数部/
きょすうぶぶん /虚数部分/
きょせい /虚勢/去勢/巨星/
きょせき /巨石/
きょせん /巨泉/
きょぜつ /拒絶/
きょぜつはんのう /拒絶反応/
きょぜつりつ /拒絶率/
きょそ /挙惜/
きょぞう /巨象/虚像/巨像/虚象/
きょぞうほう /虚像法/
きょたい /巨体/
きょたく /居宅/
きょだい /巨大/
きょだいあり /巨大蟻/
きょだいか /巨大化/
きょだいかがく /巨大科学/
きょだいきかい /巨大機械/
きょだいくうちゅうせんかん /巨大空中戦艦/
きょだいけんちく /巨大建築/
きょだいこうがく /巨大工学/
きょだいこうちくぶつ /巨大構築物/
きょだいこくてん /巨大黒点/
きょだいさんぎょう /巨大産業/
きょだいしじょう /巨大市場/
きょだいじしん /巨大地震/
きょだいじんめん /巨大人面/
きょだいじんめんいわ /巨大人面岩/
きょだいせんかん /巨大戦艦/
きょだいれんさ /巨大連鎖/
きょだいわくせい /巨大惑星/
きょだく /許諾/
きょだくしょ /許諾書/
きょだくはんい /許諾範囲/
きょだつ /虚脱/
きょだつかん /虚脱感/
きょだつじょうたい /虚脱状態/
きょだん /鋸断/
きょっかい /曲解/
きょっけい /極刑/
きょてん /拠点/
きょてんかん /拠点間/
きょとう /巨頭/挙党/巨塔/
きょどう /挙動/
きょどうげんそく /挙動原則/
きょどうふしん /挙動不審/
きょどうへんか /挙動変化/
きょなん /鋸南/
きょにゅう /巨乳/
きょにんか /許認可/
きょにんかけん /許認可権/
きょにんかじぎょう /許認可事業/
きょねん /去年/
きょねんいじょう /去年以上/
きょねんくれ /去年暮/
きょねんすえ /去年末/
きょねんぜんはん /去年前半/
きょねんどうよう /去年同様/
きょねんどじっせき /去年度実績/
きょねんまつ /去年末/
きょねんゆうしょう /去年優勝/
きょひ /拒否/巨費/
きょひうんどう /拒否運動/
きょひかん /拒否感/
きょひけん /拒否権/
きょひはんのう /拒否反応/
きょふ /巨富/
きょぶ /虚部/
きょへい /挙兵/
きょほう /虚報/巨峰/巨砲/
きょぼく /巨木/
きょまん /巨万/
きょむ /虚無/
きょむかん /虚無感/
きょむそう /虚無僧/
きょもう /虚妄/
きょよう /許容/
きょようかのう /許容可能/
きょようげんど /許容限度/
きょようごさ /許容誤差/
きょようじゅふうめんせき /許容受風面積/
きょようせい /許容性/
きょようそくど /許容速度/
きょようど /許容度/
きょようにゅうりょく /許容入力/
きょようはんい /許容範囲/
きょようはんいない /許容範囲内/
きょようりょう /許容量/
きょらい /去来/
きょり /距離/巨利/
きょりえんちょう /距離延長/
きょりかん /距離感/
きょりかんかく /距離感覚/
きょりかんすう /距離関数/
きょりがいねん /距離概念/
きょりがぞう /距離画像/
きょりくうかん /距離空間/
きょりけい /距離計/
きょりけいそく /距離計測/
きょりけいれんどうしき /距離計連動式/距離系連動式/
きょりさ /距離差/
きょりしゃくど /距離尺度/
きょりすう /距離数/
きょりそう /距離走/
きょりち /距離値/
きょりちかく /距離知覚/
きょりていい /距離定位/
きょりてき /距離的/
きょりてきせい /距離適性/
きょりひょうじ /距離表示/
きょりふあん /距離不安/
きょりへんかん /距離変換/
きょりめん /距離面/
きょりゅう /居留/
きょりゅうち /居留地/
きょりゅうみん /居留民/
きょれい /虚礼/
きょれいはいし /虚礼廃止/
きょんきょん /キョンキョン/
きょんじゅ /慶州/
きよ /清/寄与/季代/喜代/奇与/毀誉/喜世/寄予/キヨ/
きよあき /清明/清朗/清昭/
きよい /清井/
きよう /器用/起用/紀要/機用/記要/紀陽/
きようぎんこう /紀陽銀行/
きようけん /崎陽軒/
きようど /器用度/
きようびんぼう /器用貧乏/
きようほう /起用法/
きよえ /清栄/
きよおか /清岡/
きよか /清佳/
きよかず /清一/清和/
きよかわ /清川/
きよき /清木/
きよくに /清久仁/
きよくら /清倉/
きよこ /貴代子/聖子/希世子/清子/喜代子/紀代子/希代子/
きよさと /清里/
きよさとか /清里化/
きよさとこうげん /清里高原/
きよし /清/喜代志/潔/清司/清志/清茂/清史/僖良/淳/潔司/喜好/澄/
きよしげ /清重/清滋/
きよしろう /清志郎/清志朗/
きよじ /喜代治/
きよす /清洲/
きよすみ /清住/
きよせ /清瀬/
きよたか /清貴/清隆/清孝/清高/清天/
きよたき /清竜/清滝/
きよたけ /清武/
きよたに /清谷/
きよだ /清田/
きよつか /清塚/
きよつぐ /清次/
きよと /清人/
きよとし /清利/
きよぬま /浄沼/
きよね /清音/
きよの /清野/
きよのぶ /清信/
きよのり /清典/
きよはら /清原/
きよはる /清晴/清治/
きよひこ /清彦/
きよひと /清人/
きよひら /清衡/
きよひろ /恭弘/清宏/清博/
きよぶん /寄与分/
きよほうへん /毀誉褒貶/
きよまつ /清松/
きよみ /清美/聖美/紀代美/貴予美/清見/喜代美/
きよみず /清水/
きよみずきんぺん /清水近辺/
きよみずでら /清水寺/
きよもと /清元/
きよゆき /清之/聖之/
きよりつ /寄与率/
きよわ /気弱/
きら /綺羅/吉良/
きらい /嫌い/帰来/機雷/記頼/
きらいほう /鬼雷砲/
きらく /気楽/喜楽/
きらくてい /喜良久亭/
きらぼし /綺羅星/
きらら /雲母/
きり /霧/桐/切/錐/雰/
きりあげ /切上げ/切り上げ/
きりいちよう /桐一葉/
きりうり /切り売り/
きりえ /切り絵/切絵/
きりか /霧化/
きりかえ /切替/切換え/切り替え/切換/切替え/切り換え/
きりかえき /切替器/
きりかえくかん /切替区間/
きりかえし /切り返し/
きりかえじ /切替時/
きりかき /切り欠き/
きりかけ /切掛/
きりかた /切り方/
きりかぶ /切株/切り株/檮/
きりが /霧賀/
きりがみ /切り紙/
きりきず /切傷/切り傷/斬傷/
きりきり /吉里吉里/
きりきりじん /吉里吉里人/
きりきりまい /きりきり舞い/
きりぎりす /キリギリス/蛬/蟋蟀/
きりくず /切りくず/
きりくち /切口/切り口/
きりぐち /切り口/
きりこ /桐子/切子/
きりこうじょう /切り口上/
きりこみ /切込み/
きりさげ /切下げ/
きりさめ /霧雨/
きりざい /桐材/
きりしたん /切支丹/
きりしま /桐島/桐嶋/霧島/
きりじょう /霧状/
きりすて /切捨て/切り捨て/
きりすときょう /基督教/
きりた /桐田/
きりたっぷ /霧多布/
きりたに /桐谷/
きりだ /切り出/
きりだし /切り出し/切出し/
きりだしかた /切り出し方/
きりつ /規律/起立/
きりつじゅうし /規律重視/
きりつぼ /桐壷/桐壺/
きりづま /切妻/
きりづみ /霧積/
きりと /桐戸/
きりとり /切り取り/切取り/切取/
きりとりせん /切取り線/------------------------------ ここから ------------------------------/
きりどおし /切通し/切通/
きりどおしざか /切通坂/
きりなみ /霧浪/
きりにしき /起利錦/
きりぬき /切り抜き/切抜き/
きりの /桐野/
きりはら /桐原/
きりはり /切り貼り/
きりばな /切り花/
きりばり /切り張り/
きりひとは /桐一葉/
きりび /鑽り火/
きりふき /霧吹き/
きりふだ /切札/切り札/
きりふだてき /切札的/
きりぶち /桐渕/
きりみ /切り身/切身/
きりもと /桐本/
きりもみ /錐揉み/
きりもり /切盛り/切り盛り/
きりゃく /機略/
きりや /桐谷/
きりやま /桐山/
きりゅう /桐生/気流/霧生/
きりゅういん /鬼龍院/
きりゅうえき /桐生駅/
きりゅうだいいち /桐生第一/
きりょう /帰寮/器量/
きりょく /気力/棋力/氣力/
きりわけ /切り分け/
きりん /麒麟/キリン/
きりんかん /麒麟館/
きりんてい /麒麟亭/
きりんびーる /麒麟麦酒/
きるい /帰塁/
きるかえあすてるか /キルカエアステル科/Circaeasteraceae/
きれ /喜連/
きれあじ /切れ味/
きれい /綺麗/奇麗/
きれいごと /綺麗事/
きれいずき /綺麗好き/
きれいどころ /綺麗所/
きれじ /切れ地/
きれつ /亀裂/
きれはし /切れ端/
きれま /切れ間/
きれまけ /切れ負け/
きれめ /切れ目/
きれん /喜連/
きろ /岐路/帰路/
きろく /記録/
きろくえいが /記録映画/
きろくかい /記録会/
きろくがかり /記録係/
きろくがた /記録型/
きろくき /記録機/
きろくぎじゅつ /記録技術/
きろくけいしき /記録形式/
きろくこうがく /記録工学/
きろくし /記録紙/
きろくしゃ /記録者/
きろくしんごう /記録信号/
きろくじかん /記録時間/
きろくじゅりつ /記録樹立/
きろくじょうほう /記録情報/
きろくせい /記録性/
きろくぜんしゅう /記録全集/
きろくたっせい /記録達成/
きろくたっせいご /記録達成後/
きろくてき /記録的/
きろくないよう /記録内容/
きろくばいたい /記録媒体/
きろくひょう /記録表/
きろくぶ /季肋部/
きろくぶぶん /記録部分/
きろくほうこく /記録報告/
きろくほうしき /記録方式/
きろくほかんじょ /記録保管所/
きろくまどぐち /記録窓口/
きろくみつど /記録密度/
きろくやぶり /記録破り/
きろくよう /記録用/
きろぐらむ /瓩/
きろめーとる /粁/
きろりっとる /竏/
きわ /際/紀和/
きわく /木枠/
きわこ /貴和子/
きわた /木棉/
きわまりづき /極月/
きわみ /極み/
きわむ /究/
きわめつけ /極めつけ/
きわめて /極めて/
きわもの /際物/
きん /金/近/筋/菌/今/緊/禁/謹/襟/衿/琴/欽/芹/禽/勤/錦/均/欣/斤/巾/僅/瑾/檎/听/噤/忻/懃/掀/擒/窘/箘/箟/覲/釁/鈞/釿/饉/
きんあ /金鴉/
きんあつ /禁圧/
きんい /近位/近医/
きんいち /金一/錦一/欽一/
きんいっぷう /金一封/
きんいつ /均一/
きんいつうんちん /均一運賃/
きんいつうんちんろせん /均一運賃路線/
きんいつか /均一化/
きんいつくかん /均一区間/
きんいつくかんがい /均一区間外/
きんいつせい /均一性/
きんいつちいき /均一地域/
きんいつりょうきん /均一料金/
きんいろ /金色/
きんいん /近因/金印/
きんうんどう /筋運動/
きんえい /近影/
きんえき /菌液/
きんえん /禁煙/近縁/
きんえんうんどう /禁煙運動/
きんえんか /禁煙化/
きんえんかんけい /近縁関係/
きんえんくいき /禁煙区域/
きんえんくかん /禁煙区間/
きんえんしつ /禁煙室/
きんえんしてい /禁煙指定/
きんえんしていせき /禁煙指定席/
きんえんしゃ /禁煙車/禁煙者/
きんえんしゃしていせき /禁煙車指定席/
きんえんしゃりょう /禁煙車両/
きんえんしゅ /近縁種/
きんえんじゆうせき /禁煙自由席/
きんえんじょ /禁煙所/
きんえんせき /禁煙席/
きんえんせきいがい /禁煙席以外/
きんえんせきそうび /禁煙席装備/
きんえんせんげん /禁煙宣言/
きんえんばしょ /禁煙場所/
きんえんひょうじ /禁煙表示/
きんえんれい /禁煙令/
きんか /金貨/近火/槿花/
きんかい /金塊/近海/勤快/琴海/
きんかぎょくじょう /金科玉条/
きんかく /金閣/
きんかくじ /金閣寺/
きんかさん /金華山/
きんかざん /金華山/
きんかん /金管/近刊/金柑/
きんかんがっき /金管楽器/
きんかんごじゅうそう /金管五重奏/
きんかんしょく /金環蝕/金環食/
きんかんそうしゃ /金管奏者/
きんが /謹賀/
きんがく /金額/
きんがくかんさん /金額換算/
きんがくけいさん /金額計算/
きんがくしじねびき /金額指示値引き/
きんがくしてい /金額指定/
きんがくていど /金額程度/
きんがくてき /金額的/
きんがくへんかん /金額返還/
きんがしんねん /謹賀新年/
きんがん /近眼/
きんき /近畿/近幾/禁忌/錦旗/欣喜/
きんきいがい /近畿以外/
きんきがくせい /近畿学生/
きんきけん /近畿圏/
きんきご /近畿語/
きんきしゃりょう /近畿車輛/近畿車両/
きんきしゃりょうせい /近畿車両製/
きんきじどうしゃどう /近畿自動車道/
きんきせいけん /近畿政権/
きんきだい /近畿大/
きんきだいがく /近畿大学/
きんきちほう /近畿地方/
きんきてつどう /近畿鉄道/
きんきどう /近畿道/
きんきにほん /近畿日本/
きんきにほんてつどう /近畿日本鉄道/
きんきばん /近畿版/
きんきゅう /緊急/
きんきゅういりょう /緊急医療/
きんきゅういりょうほう /緊急医療法/
きんきゅうえんじょ /緊急援助/
きんきゅうかいひ /緊急回避/
きんきゅうこうどう /緊急行動/
きんきゅうこくち /緊急告知/
きんきゅうさどう /緊急作動/
きんきゅうしゃりょう /緊急車両/
きんきゅうじ /緊急時/
きんきゅうじたい /緊急事態/
きんきゅうじどうしゃ /緊急自動車/
きんきゅうじょうこう /緊急条項/
きんきゅうじれんらく /緊急時連絡/
きんきゅうせい /緊急性/
きんきゅうそうこう /緊急走行/
きんきゅうそうこうじ /緊急走行時/
きんきゅうそせいほう /緊急蘇生法/
きんきゅうそち /緊急措置/
きんきゅうたいさく /緊急対策/
きんきゅうたいさくほんぶ /緊急対策本部/
きんきゅうたいさくほんぶちょう /緊急対策本部長/
きんきゅうだっしゅつ /緊急脱出/
きんきゅうつうほう /緊急通報/
きんきゅうていし /緊急停止/
きんきゅうてはい /緊急手配/
きんきゅうど /緊急度/
きんきゅうにゅういん /緊急入院/
きんきゅうはっしん /緊急発進/
きんきゅうはっしんじ /緊急発進時/
きんきゅうひなん /緊急避難/緊急非難/
きんきゅうひなんてき /緊急避難的/
きんきゅうふじょう /緊急浮上/
きんきゅうほうそう /緊急放送/
きんきゅうよう /緊急用/
きんきゅうれんらく /緊急連絡/
きんきょう /近況/
きんきょうほうこく /近況報告/
きんきょり /近距離/
きんきょりがわ /近距離側/
きんきょりきゃく /近距離客/
きんきょりゆそう /近距離輸送/
きんきょりろせん /近距離路線/
きんきょりわざ /近距離技/
きんきん /僅々/近々/
きんぎょ /金魚/
きんぎょばち /金魚鉢/
きんぎょや /金魚屋/
きんぎょよう /金魚用/
きんぎん /金銀/
きんく /禁句/
きんぐ /キング/
きんけい /謹啓/近景/
きんけつ /金欠/
きんけつびょう /金欠病/
きんけん /金券/金権/金研/近県/金属材料研究所/勤倹/
きんけんたいしつ /金権体質/
きんけんや /金券屋/
きんげん /金言/謹厳/
きんげんだいきょく /近現代曲/
きんげんてい /金原亭/
きんこ /金庫/禁固/禁錮/
きんこう /均衡/近郊/金鉱/金鉤/
きんこうか /均衡化/近郊化/
きんこうがた /近郊型/
きんこうがたしゃりょう /近郊型車両/
きんこうくかん /近郊区間/
きんこうけい /近交系/
きんこうざいせい /均衡財政/
きんこうせんよう /近郊専用/
きんこうだい /金工大/
きんこうだいじょうほう /金工大情報/
きんこうでんしゃ /近郊電車/
きんこうとし /近郊都市/
きんこうどう /金港堂/
きんこうよう /近郊用/
きんこうろん /均衡論/
きんこく /謹告/近国/
きんこけい /禁固刑/
きんこつ /筋骨/
きんこん /菌根/
きんこんしき /金婚式/
きんご /金吾/
きんごう /金剛/
きんごろう /金語楼/
きんさ /僅差/
きんさがち /僅差勝ち/
きんさく /金作/近作/金策/
きんざ /金座/
きんざい /近在/
きんざいけん /金材研/
きんざん /金山/
きんし /禁止/近視/錦糸/菌糸/金鵄/
きんしがん /近視眼/
きんしがんてき /近視眼的/
きんしきかん /禁止期間/
きんしきそく /禁止規則/
きんしくいき /禁止区域/
きんしくかん /禁止区間/
きんしくんしょう /金鵄勲章/
きんしこうもく /禁止項目/
きんししょぶん /禁止処分/
きんししんごう /禁止信号/
きんしじこう /禁止事項/
きんしじょう /金市場/
きんしだい /禁止台/
きんしちいき /禁止地域/
きんしちょう /錦糸町/
きんしちょうかん /錦糸町間/
きんしちょうふきん /錦糸町付近/
きんしつ /均質/
きんしつか /均質化/
きんしてんかぶつ /禁止添加物/
きんしないよう /禁止内容/
きんしまえ /禁止前/
きんしゃち /金鯱/
きんしゃちしょう /金鯱賞/
きんしゅ /禁酒/金種/
きんしゅう /錦繍/金繍/
きんしゅうしゅく /筋収縮/
きんしゅきんえん /禁酒禁煙/
きんしゅく /緊縮/
きんしゅほう /禁酒法/
きんしゅれい /禁酒令/
きんしょう /金賞/僅少/近称/金将/金章/筋少/金消/
きんしょうけん /金証券/
きんしょうしょ /金証書/
きんしょうまたいち /金商又一/
きんしょく /金食/
きんしようご /禁止用語/
きんしれい /禁止令/
きんしろう /金四郎/
きんしん /近親/謹慎/
きんしんこん /近親婚/
きんしんしゃ /近親者/
きんしんそうかん /近親相姦/
きんしんぞうお /近親憎悪/
きんじ /近似/禁児/金次/金治/欽司/
きんじかい /近似解/
きんじかいほう /近似解法/
きんじがくしゅう /近似学習/
きんじきょくせん /近似曲線/
きんじく /近軸/
きんじくきんじ /近軸近似/
きんじくこうせん /近軸光線/
きんじさ /近時差/
きんじしき /近似式/
きんじじょうけん /近似条件/
きんじせいど /近似精度/
きんじち /近似値/
きんじつ /近日/
きんじつちゅう /近日中/
きんじつてんいどう /近日点移動/
きんじつはつばい /近日発売/
きんじつはつばいかいし /近日発売開始/
きんじて /禁じ手/
きんじてき /近似的/
きんじてきしゅだん /近似的手段/
きんじてきじつげん /近似的実現/
きんじとう /金字塔/
きんじど /近似度/
きんじほう /近似法/
きんじほうていしき /近似方程式/
きんじゅう /禽獣/
きんじょ /近所/
きんじょう /近状/金城/今上/
きんじょめいわく /近所迷惑/
きんじりょう /近似量/
きんじりろん /近似理論/
きんじれつ /近似列/
きんじろう /金次郎/
きんす /金子/
きんせい /金星/禁制/均整/謹製/近世/均斉/Venus/
きんせいしょく /金星食/
きんせいたい /禁制帯/
きんせいだいみょう /近世大名/
きんせいひん /禁制品/
きんせきがい /近赤外/
きんせきもじ /金石文字/
きんせつ /近接/
きんせつかく /近接覚/
きんせつきょり /近接距離/
きんせつさつえいじ /近接撮影時/
きんせつさよう /近接作用/
きんせつせん /近接線/
きんせつてん /近接点/
きんせつば /近接場/
きんせつぶ /近接部/
きんせん /金銭/琴線/金線/
きんせんかんかく /金銭感覚/
きんせんてき /金銭的/
きんせんてきひょうか /金銭的評価/
きんせんてきよゆう /金銭的余裕/
きんせんてきりえき /金銭的利益/
きんせんてきりゆう /金銭的理由/
きんせんとばく /金銭賭博/
きんせんふたん /金銭負担/
きんせんめん /金銭面/
きんせんもんだい /金銭問題/
きんぜい /禁制/
きんぜん /欣然/
きんそく /禁則/禁足/
きんそくしょり /禁則処理/
きんそくじこう /禁則事項/
きんぞう /金蔵/金造/
きんぞく /金属/勤続/勤属/
きんぞくおん /金属音/
きんぞくかこう /金属加工/
きんぞくかこうぎょう /金属加工業/
きんぞくかん /金属缶/
きんぞくくず /金属屑/
きんぞくけい /金属系/
きんぞくげんし /金属原子/
きんぞくこうがく /金属工学/
きんぞくこうさく /金属工作/
きんぞくこうたく /金属光沢/
きんぞくざいしつ /金属材質/
きんぞくざいりょう /金属材料/
きんぞくざいりょうけんきゅうじょ /金属材料研究所/
きんぞくしゃ /勤続者/
きんぞくせい /金属製/金属性/
きんぞくせっけん /金属石鹸/
きんぞくせってん /金属接点/
きんぞくせん /金属線/
きんぞくたんちき /金属探知機/
きんぞくてき /金属的/
きんぞくでんきょく /金属電極/
きんぞくないほう /金属内包/
きんぞくばん /金属板/
きんぞくひまく /金属皮膜/
きんぞくひろう /金属疲労/
きんぞくびりゅうし /金属微粒子/
きんぞくふん /金属粉/
きんぞくぶ /金属部/
きんぞくぶぶん /金属部分/
きんぞくへん /金属片/
きんぞくぼう /金属棒/
きんた /金太/
きんたい /勤怠/
きんたいひょう /勤怠表/
きんたろう /金太郎/
きんたろうあめ /金太郎飴/
きんだい /近代/近大/金大/
きんだいいぜん /近代以前/
きんだいえいが /近代映画/
きんだいか /近代化/
きんだいかがく /近代科学/
きんだいかがくしゃ /近代科学社/
きんだいかこうじ /近代化工事/
きんだいき /近代機/
きんだいきゅうしゅう /近大九州/
きんだいけいざいがく /近代経済学/
きんだいこっか /近代国家/
きんだいごうりしゅぎ /近代合理主義/
きんだいさんぎょうきぎょう /近代産業企業/
きんだいし /近代史/
きんだいしゅっしん /近大出身/
きんだいしょうぎ /近代将棋/
きんだいじん /近代人/
きんだいせいぶつがく /近代生物学/
きんだいせいりがく /近代生理学/
きんだいせん /近大戦/
きんだいたいせい /近代体制/
きんだいち /金田一/
きんだいちこうすけ /金田一耕介/
きんだいちはるひこ /金田一春彦/
きんだいてき /近代的/
きんだいにほん /近代日本/
きんだいのうほう /近代農法/
きんだいばじゅつ /近代馬術/
きんだいびじゅつ /近代美術/
きんだいぶんめい /近代文明/
きんだいまあじゃん /近代麻雀/
きんだいみんしゅしゅぎ /近代民主主義/
きんだか /金高/
きんだち /公達/
きんだん /禁断/禁男/
きんだんしょうじょう /禁断症状/
きんだんのかじつ /禁断の果実/
きんち /近地/
きんちさんしゃ /禁治産者/
きんちてん /近地点/
きんちゃく /近着/巾着/
きんちょ /近著/
きんちょう /緊張/金鳥/謹聴/謹聽/金長/
きんちょうかん /緊張感/
きんちょうかんけい /緊張関係/
きんちょうぎみ /緊張気味/
きんつば /金鍔/
きんつま /金妻/
きんてい /謹呈/欽定/
きんてき /金的/
きんてつ /近鉄/
きんてついがせん /近鉄伊賀線/
きんてつえんせん /近鉄沿線/
きんてつおおさかせん /近鉄大阪線/
きんてつきゅうだん /近鉄球団/
きんてつきょうとせん /近鉄京都線/
きんてつげきじょう /近鉄劇場/
きんてつしらこえき /近鉄白子駅/
きんてつせん /近鉄線/
きんてつたんばばしえき /近鉄丹波橋駅/
きんてつとっきゅう /近鉄特急/
きんてつなごや /近鉄名古屋/
きんてつなごやせん /近鉄名古屋線/
きんてつなら /近鉄奈良/
きんてつならせん /近鉄奈良線/
きんてつなんばせん /近鉄難波線/
きんてつひがしおおさかせん /近鉄東大阪線/
きんてつふう /近鉄風/
きんてつほんせん /近鉄本線/
きんてつめいはんせん /近鉄名阪線/
きんてつようろうせん /近鉄養老線/
きんてつよっかいち /近鉄四日市/
きんてつよっかいちえき /近鉄四日市駅/
きんてん /近点/
きんてんさい /禁転載/
きんでん /筋電/
きんでんず /筋電図/
きんとう /均等/近東/
きんとうか /均等化/
きんとうぶんかつ /均等分割/
きんとうわり /均等割/均等割り/
きんとうわりつけ /均等割付/
きんとき /金時/
きんど /金土/
きんどう /金藤/金道/
きんどけい /金時計/
きんどにち /金土日/
きんなみ /金並/
きんなら /緊那羅/
きんにく /筋肉/
きんにくしつ /筋肉質/
きんにくしょうじょたい /筋肉少女帯/筋肉少女隊/
きんにくそしき /筋肉組織/
きんにくつう /筋肉痛/
きんにっせいしゅせき /金日成主席/
きんねん /近年/
きんねんちゅう /近年中/
きんねんまれ /近年稀/
きんのう /勤皇/
きんのすけ /金之助/
きんば /金馬/金歯/
きんばく /緊縛/
きんばり /金張り/
きんぱい /金杯/
きんぱく /金箔/緊迫/金帛/
きんぱくかん /緊迫感/
きんぱち /金八/
きんぱつ /金髪/
きんぱら /金原/
きんびょうぶ /金屏風/
きんぴ /金皮/
きんぴん /金品/
きんふたん /筋負担/
きんぶち /金縁/
きんぶん /均分/金文/
きんぷん /金粉/
きんべん /勤勉/
きんべんせいじつ /謹勉誠実/
きんべんとう /禁弁当/
きんぺん /近辺/
きんぺんじゅうみん /近辺住民/
きんほんい /金本位/
きんぼう /近傍/
きんぼうがた /近傍型/
きんぼうけい /近傍系/
きんぼうこう /近傍項/
きんぼうすい /筋紡錘/
きんぼうば /近傍場/
きんぼうばせいぶん /近傍場成分/
きんぼし /金星/
きんぽ /金浦/
きんぽう /金峰/
きんぽうげあか /キンポウゲ亜科/Rununculoideae/
きんぽうげか /キンポウゲ科/Ranunculaceae/
きんぽうげしょくぶつ /キンポウゲ植物/
きんぽうげしょくぶつるい /キンポウゲ植物類/Ranales/
きんぽうげもく /キンポウゲ目/Ranunculales/
きんぽうげもくぐん /キンポウゲ目群/Ranunculales/
きんぽくうこう /金浦空港/
きんまく /筋膜/
きんみつ /緊密/
きんみゃく /金脈/
きんみらい /近未来/
きんみらいけんきゅうじょ /近未来研究所/
きんみらいてき /近未来的/
きんみらいは /近未来派/
きんむ /勤務/
きんむい /勤務医/
きんむきそく /勤務規則/
きんむけいたい /勤務形態/
きんむさき /勤務先/
きんむじかん /勤務時間/
きんむじかんちゅう /勤務時間中/
きんむじかんない /勤務時間内/
きんむたいけい /勤務体系/
きんむたいせい /勤務体制/
きんむち /勤務地/
きんむちゅう /勤務中/
きんむび /勤務日/
きんめい /金明/
きんめいちょう /金明町/
きんめっき /金メッキ/
きんもくせい /金木犀/
きんもじ /金文字/
きんもつ /禁物/
きんもん /金文/
きんや /金弥/欣也/欽也/謹也/欣哉/
きんやっかん /金約款/
きんゆ /禁輸/
きんゆう /金融/
きんゆうかい /金融界/
きんゆうきかん /金融機関/
きんゆうきかんめい /金融機関名/
きんゆうぎょう /金融業/
きんゆうこうこ /金融公庫/
きんゆうさい /金融債/
きんゆうさいせいほう /金融再生法/
きんゆうしさん /金融資産/
きんゆうしょうひん /金融商品/
きんゆうどう /金融道/
きんゆじょうやく /禁輸条約/
きんよう /金曜/
きんようしんや /金曜深夜/
きんようどよう /金曜土曜/
きんようび /金曜日/
きんようほうえいぶん /金曜放映分/
きんよく /禁欲/
きんよくしゅぎ /禁欲主義/
きんよくてきしゅうきょう /禁欲的宗教/
きんらい /近来/
きんらん /金襴/
きんらんせんり /金蘭千里/
きんらんそう /金蘭荘/
きんらんどんす /金襴緞子/
きんり /金利/
きんりゅう /金竜/
きんりょう /禁漁/禁猟/金陵/斤量/
きんりょうさ /斤量差/
きんりょく /筋力/金力/
きんりょくてき /筋力的/
きんりん /近隣/錦林/
きんりんえいぎょうしょ /錦林営業所/
きんりんしゃこ /錦林車庫/
きんりんしゃこまえ /錦林車庫前/
きんりんしょこく /近隣諸国/
きんりんじゅうみん /近隣住民/
きんりんちいき /近隣地域/
きんるい /菌類/
きんれい /禁令/
きんろう /勤労/金狼/
きんろういよく /勤労意欲/
きんろうか /勤労課/
きんろうかんしゃ /勤労感謝/
きんろうしゃ /勤労者/
きんろうしゃぜんたい /勤労者全体/
きんろうじょうけん /勤労条件/
きんろうてき /勤労的/
きんろうぶ /勤労部/
ぎ /偽/技/議/義/疑/犠/擬/戯/儀/誼/蟻/欺/城/木/宜/妓/祇/着/伎/僞/嶬/巍/戲/曦/沂/犧/礒/羲/艤/萓/魏/祁/
ぎあ /ギア/
ぎあく /偽悪/
ぎあん /議案/
ぎあんいちらん /議案一覧/
ぎあんしょ /議案書/
ぎいち /義一/
ぎいん /議員/議院/
ぎいんかんれん /議員関連/
ぎいんすう /議員数/
ぎいんていすう /議員定数/
ぎいんないかくせい /議院内閣制/議員内閣制/
ぎいんりっぽう /議員立法/
ぎえん /義援/義捐/
ぎえんきん /義援金/義捐金/
ぎおん /祇園/擬音/
ぎおんしょうじゃ /祇園精舎/
ぎおんちょう /祇園町/
ぎおんばやし /祇園囃子/
ぎおんひょうげん /擬音表現/
ぎおんまつり /祇園祭/
ぎか /技科/技家/偽果/
ぎかい /議会/
ぎかいかいさんけん /議会解散権/
ぎかいけん /技開研/
ぎかいほん /技開本/
ぎかだい /技科大/
ぎかん /技官/技管/
ぎが /戯画/偽画/儀我/
ぎがてき /戯画的/
ぎがん /義眼/
ぎきょうしん /義侠心/義狭心/
ぎきょうだい /義兄弟/
ぎきょく /戯曲/
ぎきょくか /戯曲化/
ぎぎ /疑義/魏魏/
ぎく /疑懼/
ぎけい /義兄/
ぎけつ /議決/
ぎけつきかん /議決機関/
ぎけつけん /議決権/
ぎけん /技研/
ぎけんかぶしきがいしゃ /技研株式会社/
ぎけんこうかい /技研公開/
ぎけんこうぎょう /技研工業/
ぎげい /技芸/
ぎげいてん /伎芸天/
ぎこう /技巧/技工/技功/
ぎこうしゃ /技工社/
ぎこうてき /技巧的/
ぎごく /疑獄/
ぎごしょく /魏呉蜀/
ぎさく /偽作/
ぎさん /蟻酸/
ぎし /技師/岸/技士/義肢/義姉/義歯/魏史/
ぎしき /儀式/
ぎしきてき /儀式的/
ぎしちょう /技師長/
ぎしぶちょう /技師部長/
ぎしほ /技師補/
ぎしゅ /義手/
ぎしょ /偽書/
ぎしょう /偽称/偽証/
ぎしょうざい /偽証罪/
ぎしょうだに /棋将谷/
ぎしわじんでん /魏志倭人伝/
ぎしん /疑心/
ぎしんあんき /疑心暗鬼/
ぎしんごう /偽信号/
ぎじ /擬似/議事/疑似/
ぎじいんよう /擬似引用/
ぎじえ /疑似餌/
ぎじえさ /擬似餌/
ぎじおやゆび /疑似親指/
ぎじかいせつ /疑似解説/
ぎじかがく /疑似科学/擬似科学/
ぎじかがくしゃ /疑似科学者/
ぎじかがくしょ /疑似科学書/
ぎじかがくしょせき /疑似科学書籍/
ぎじぎゃくぎょうれつ /擬似逆行列/
ぎじけいけん /疑似経験/
ぎじけつごうせい /疑似結合性/
ぎじご /疑似語/
ぎじしき /擬似式/
ぎじじんかく /疑似人格/
ぎじせいめい /疑似生命/
ぎじせかい /擬似世界/
ぎじたいけん /疑似体験/
ぎじちょっこうきてい /擬似直交基底/
ぎじちょっこうけい /擬似直交系/
ぎじていい /擬似定位/
ぎじてき /擬似的/疑似的/
ぎじとう /擬似頭/
ぎじどう /議事堂/
ぎじはん /疑似半/
ぎじばり /疑似針/
ぎじぶっしつ /疑似物質/
ぎじへんすう /擬似変数/疑似変数/
ぎじめいれい /疑似命令/
ぎじゅく /義塾/羲塾/
ぎじゅつ /技術/
ぎじゅついいん /技術委員/
ぎじゅついいんかい /技術委員会/
ぎじゅついじ /技術維持/
ぎじゅついてん /技術移転/
ぎじゅついん /技術院/
ぎじゅつえいぎょうか /技術営業課/
ぎじゅつか /技術課/技術科/
ぎじゅつかいせつ /技術解説/
ぎじゅつかいはつ /技術開発/
ぎじゅつかいはつきこう /技術開発機構/
ぎじゅつかいはつしつ /技術開発室/
ぎじゅつかいはつじょう /技術開発上/
ぎじゅつかいはつぶ /技術開発部/
ぎじゅつかいはつほんぶ /技術開発本部/
ぎじゅつかがくだいがく /技術科学大学/
ぎじゅつかくしん /技術革新/
ぎじゅつかてい /技術家庭/
ぎじゅつかん /技術館/
ぎじゅつかんりぶ /技術管理部/
ぎじゅつがかり /技術係/
ぎじゅつがく /技術学/
ぎじゅつがっこう /技術学校/
ぎじゅつきかくしつ /技術企画室/
ぎじゅつきじゅん /技術規準/技術基準/
ぎじゅつきばん /技術基盤/
ぎじゅつきょういくか /技術教育課/
ぎじゅつきょうしつ /技術教室/
ぎじゅつきょうりょくぶ /技術協力部/
ぎじゅつけい /技術系/
ぎじゅつけいぶんしょ /技術系文書/
ぎじゅつけんきゅう /技術研究/
ぎじゅつけんきゅうしつ /技術研究室/
ぎじゅつけんきゅうしょ /技術研究所/
ぎじゅつけんきゅうじょ /技術研究所/
ぎじゅつけんきゅうぶ /技術研究部/
ぎじゅつこうしゅうかい /技術講習会/
ぎじゅつこうじょう /技術向上/
ぎじゅつこうりゅう /技術交流/
ぎじゅつし /技術士/技術誌/技術史/
ぎじゅつしえん /技術支援/
ぎじゅつしつ /技術室/
ぎじゅつしゃ /技術者/技術社/
ぎじゅつしゃかい /技術社会/
ぎじゅつしゃきょうかい /技術者協会/
ぎじゅつしゃむけ /技術者向け/
ぎじゅつしゅたい /技術主体/
ぎじゅつしゅっぱん /技術出版/
ぎじゅつしょ /技術書/
ぎじゅつしょく /技術職/技術色/
ぎじゅつしりょう /技術資料/
ぎじゅつしんさいいん /技術審査委員/
ぎじゅつじっしょうき /技術実証機/
ぎじゅつじょう /技術上/
ぎじゅつじょうほう /技術情報/
ぎじゅつじん /技術陣/
ぎじゅつすいしんか /技術推進課/
ぎじゅつすいしんぶ /技術推進部/
ぎじゅつすいじゅん /技術水準/
ぎじゅつせっけいぶ /技術設計部/
ぎじゅつせん /技術戦/技術選/
ぎじゅつせんしゅけん /技術選手権/
ぎじゅつせんもん /技術専門/
ぎじゅつたいけい /技術体系/
ぎじゅつたいこく /技術大国/
ぎじゅつたんとう /技術担当/
ぎじゅつたんとうしゃ /技術担当者/
ぎじゅつだいにぶ /技術第二部/
ぎじゅつちしき /技術知識/
ぎじゅつちょう /技術庁/技術長/
ぎじゅつていけい /技術提携/
ぎじゅつていけいてん /技術提携店/
ぎじゅつてき /技術的/
ぎじゅつてきかいけつさく /技術的解決策/
ぎじゅつてきけっかん /技術的欠陥/
ぎじゅつてきけんきゅう /技術的研究/
ぎじゅつてきこうさつ /技術的考察/
ぎじゅつてきしゅだん /技術的手段/
ぎじゅつてきしんぽ /技術的進歩/
ぎじゅつてきすいじゅん /技術的水準/
ぎじゅつてきせいじゅくど /技術的成熟度/
ぎじゅつてきせってい /技術的設定/
ぎじゅつてきそくめん /技術的側面/
ぎじゅつてきちしき /技術的知識/
ぎじゅつてきないよう /技術的内容/
ぎじゅつてきもんだい /技術的問題/
ぎじゅつてきもんだいてん /技術的問題点/
ぎじゅつてきよういん /技術的要因/
ぎじゅつてきりゆう /技術的理由/
ぎじゅつてん /技術展/
ぎじゅつとうかつぶ /技術統括部/
ぎじゅつどうこう /技術動向/
ぎじゅつどうこうちょうさ /技術動向調査/
ぎじゅつにんてい /技術認定/
ぎじゅつのうりょく /技術能力/
ぎじゅつはってん /技術発展/
ぎじゅつはっぴょう /技術発表/
ぎじゅつばたけ /技術畑/
ぎじゅつひょうろん /技術評論/
ぎじゅつひょうろんしゃ /技術評論社/
ぎじゅつぶ /技術部/
ぎじゅつぶぎじゅつか /技術部技術課/
ぎじゅつぶそく /技術不足/
ぎじゅつぶでんき /技術部電気/
ぎじゅつぶでんきけい /技術部電気系/
ぎじゅつぶもん /技術部門/
ぎじゅつぶもんいがい /技術部門以外/
ぎじゅつぶんかかい /技術分科会/
ぎじゅつぶんけん /技術文献/
ぎじゅつぶんしょ /技術文書/
ぎじゅつぶんしょさくせい /技術文書作成/
ぎじゅつへんちょう /技術偏重/
ぎじゅつほうこく /技術報告/
ぎじゅつほうこくしょ /技術報告書/
ぎじゅつほさいん /技術補佐員/
ぎじゅつほぞん /技術保存/
ぎじゅつほんぶ /技術本部/
ぎじゅつほんぶちょう /技術本部長/
ぎじゅつむけ /技術向け/
ぎじゅつめん /技術面/
ぎじゅつや /技術屋/
ぎじゅつよう /技術用/
ぎじゅつようご /技術用語/
ぎじゅつようそ /技術要素/
ぎじゅつらん /技術欄/
ぎじゅつりっこく /技術立国/
ぎじゅつりょう /技術料/
ぎじゅつりょく /技術力/
ぎじゅつれきししょ /技術歴史書/
ぎじゅつれんらくかい /技術連絡会/
ぎじゅつろん /技術論/
ぎじゅつろんぶん /技術論文/
ぎじゅんじょ /擬順序/
ぎじょう /技情/議場/議定/儀杖/
ぎじょうへい /儀杖兵/
ぎじらんすう /疑似乱数/
ぎじらんすうはっせい /疑似乱数発生/
ぎじろく /議事録/
ぎじろくちゅう /議事録中/
ぎじん /擬人/
ぎじんか /擬人化/
ぎじんてき /擬人的/
ぎじんてきひょうげん /擬人的表現/
ぎじんほう /擬人法/
ぎせい /犠牲/擬声/擬制/
ぎせいご /擬声語/
ぎせいしゃ /犠牲者/
ぎせき /議席/
ぎせきすう /議席数/
ぎせきはいぶん /議席配分/
ぎせん /岐セン/義戦/義戰/
ぎぜん /偽善/
ぎぜんしゃ /偽善者/
ぎぜんてき /偽善的/
ぎぜんてきこうい /偽善的行為/
ぎそう /偽装/擬装/艤装/
ぎそうぎじゅつ /擬装技術/
ぎそうけいかく /偽装計画/
ぎそうけんきゅうぶ /艤装研究部/
ぎそうしんじゅう /偽装心中/
ぎそく /義足/
ぎぞう /偽造/
ぎぞうこうさく /偽造工作/
ぎぞく /義賊/
ぎたー /ギター/
ぎたい /擬態/
ぎたん /技短/義丹/
ぎだ /犠打/
ぎだい /議題/技大/
ぎだいていき /議題提起/
ぎだゆう /義太夫/
ぎちょう /議長/
ぎちょうこうほしゃ /議長候補者/
ぎちょうさいりょう /議長裁量/
ぎちょうしめい /議長指名/
ぎちょうせいど /議長制度/
ぎちょうてき /議長的/
ぎちょうやく /議長役/
ぎっしゃ /牛車/
ぎつう /技通/
ぎてい /議定/義弟/
ぎていしょ /議定書/
ぎてきしょうめい /技適証明/
ぎてきしょうめいせいど /技適証明制度/
ぎてん /儀典/
ぎとう /蟻塔/
ぎなん /岐南/
ぎにんしん /擬妊娠/
ぎねん /疑念/
ぎねんりん /偽年輪/
ぎのう /技能/
ぎのうきょういく /技能教育/
ぎのうしゃ /技能者/
ぎのうしょう /技能賞/
ぎのうしょく /技能職/
ぎのうてき /技能的/
ぎのざ /宜野座/
ぎのわん /宜野湾/
ぎひょう /技評/
ぎふ /岐阜/義父/
ぎふえき /岐阜駅/
ぎふおうかんしょう /岐阜王冠賞/
ぎふけん /岐阜県/
ぎふこうこう /岐阜高校/
ぎふこうせん /岐阜高専/
ぎふし /岐阜市/
ぎふだい /岐阜大/
ぎふだいがく /岐阜大学/
ぎふだいじょうほう /岐阜大情報/
ぎふと /ギフト/
ぎふながらがわ /岐阜長良川/
ぎふはしま /岐阜羽島/
ぎふはしまえき /岐阜羽島駅/
ぎふべん /岐阜弁/
ぎふほうそう /岐阜放送/
ぎふぼ /義父母/
ぎふん /義憤/
ぎほう /技法/技報/
ぎほうどう /技報堂/
ぎぼ /義母/
ぎまい /義妹/
ぎまん /欺瞞/欺慢/
ぎみ /気味/
ぎむ /義務/
ぎむか /義務化/
ぎむかん /義務感/
ぎむきょういく /義務教育/
ぎむきょういくいじょう /義務教育以上/
ぎむきょういくがっこう /義務教育学校/
ぎむきょういくきかん /義務教育期間/
ぎむづけ /義務付け/義務づけ/
ぎむてき /義務的/
ぎめい /偽名/
ぎもん /疑問/
ぎもんけい /疑問形/
ぎもんけいようし /疑問形容詞/
ぎもんし /疑問視/疑問詞/
ぎもんしゅ /疑問手/
ぎもんていき /疑問提起/
ぎもんてん /疑問点/
ぎもんひょうかい /疑問氷解/
ぎもんふ /疑問符/
ぎもんふんしゅつ /疑問噴出/
ぎもんぶん /疑問文/
ぎゃ /伽/
ぎゃく /逆/虐/謔/
ぎゃく> /逆/
ぎゃくいそう /逆位相/
ぎゃくいぞん /逆依存/
ぎゃくいっぽんぜおい /逆一本背負/
ぎゃくうんどうがく /逆運動学/
ぎゃくえん /逆縁/
ぎゃくえんざん /逆演算/
ぎゃくえんすい /逆円錐/
ぎゃくかいてん /逆回転/
ぎゃくかくさん /逆拡散/
ぎゃくかのう /逆可能/
ぎゃくかんじへんかん /逆漢字変換/
ぎゃくかんすう /逆関数/
ぎゃくがくしゅう /逆学習/
ぎゃくがわ /逆側/
ぎゃくがわせ /逆為替/
ぎゃくきでんあつ /逆起電圧/
ぎゃくきでんりょく /逆起電力/
ぎゃくぎょうれつ /逆行列/
ぎゃくけい /逆形/
ぎゃくげん /逆元/
ぎゃくげんしょう /逆現象/
ぎゃくこう /逆光/逆向/
ぎゃくこうか /逆効果/
ぎゃくこうりゃく /逆攻略/
ぎゃくごさ /逆誤差/
ぎゃくさいせい /逆再生/
ぎゃくさつ /虐殺/
ぎゃくさつげんば /虐殺現場/
ぎゃくさつこうい /虐殺行為/
ぎゃくさつじけん /虐殺事件/
ぎゃくさつすう /虐殺数/
ぎゃくさべつ /逆差別/
ぎゃくさよう /逆作用/
ぎゃくさん /逆算/
ぎゃくさんかく /逆三角/
ぎゃくさんかくけい /逆三角形/
ぎゃくさんかっけい /逆三角形/
ぎゃくさんしょう /逆参照/
ぎゃくざや /逆鞘/
ぎゃくしべん /逆止弁/
ぎゃくしめい /逆指名/
ぎゃくしゃせん /逆車線/
ぎゃくしゃぞう /逆写像/
ぎゃくしゅう /逆襲/
ぎゃくしん /逆進/逆心/逆臣/
ぎゃくしんとう /逆浸透/
ぎゃくじきょく /逆磁極/
ぎゃくじせい /逆磁性/
ぎゃくじゅうじ /逆十字/
ぎゃくじゅうでん /逆充電/
ぎゃくじゅん /逆順/
ぎゃくじょう /逆上/
ぎゃくすいへい /逆水平/
ぎゃくすう /逆数/
ぎゃくすうがく /逆数学/
ぎゃくせいせつ /逆正接/
ぎゃくせがわ /逆瀬川/
ぎゃくせつ /逆説/逆接/
ぎゃくせつすいみん /逆説睡眠/
ぎゃくせつてき /逆説的/
ぎゃくせんいかんすう /逆遷移関数/
ぎゃくせんでん /逆宣伝/
ぎゃくそう /逆走/逆相/
ぎゃくそうかん /逆相関/
ぎゃくそうだ /逆操舵/
ぎゃくそこ /逆底/
ぎゃくぞう /逆像/
ぎゃくぞく /逆賊/
ぎゃくたい /虐待/
ぎゃくたん /逆探/
ぎゃくたんち /逆探知/
ぎゃくちょうりゅう /逆潮流/
ぎゃくて /逆手/
ぎゃくてまえ /逆手前/
ぎゃくてん /逆転/
ぎゃくてんおう /逆転王/
ぎゃくてんかのう /逆転可能/
ぎゃくてんがち /逆転勝ち/
ぎゃくてんげき /逆転劇/
ぎゃくてんしょうり /逆転勝利/逆点勝利/
ぎゃくてんそう /逆転層/逆転送/
ぎゃくてんまけ /逆転負/
ぎゃくてんまんるい /逆転満塁/
ぎゃくてんゆうしょう /逆転優勝/
ぎゃくでんあつ /逆電圧/
ぎゃくでんぱ /逆伝播/
ぎゃくでんぱん /逆伝搬/
ぎゃくとくせい /逆特性/
ぎゃくはんのう /逆反応/
ぎゃくひれい /逆比例/
ぎゃくびき /逆引き/逆引/
ぎゃくふぃるた /逆フィルタ/
ぎゃくふう /逆風/
ぎゃくふんしゃ /逆噴射/
ぎゃくへいほう /逆平方/
ぎゃくへん /逆片/逆辺/
ぎゃくへんかん /逆変換/
ぎゃくへんかんしき /逆変換式/
ぎゃくほうこう /逆方向/
ぎゃくむき /逆向き/
ぎゃくもど /逆戻/
ぎゃくもどり /逆戻り/
ぎゃくもんだい /逆問題/
ぎゃくゆにゅう /逆輸入/
ぎゃくゆにゅうしゃ /逆輸入車/
ぎゃくゆにゅうばん /逆輸入版/
ぎゃくゆにゅうひん /逆輸入品/
ぎゃくよう /逆用/
ぎゃくり /逆理/
ぎゃくりゅう /逆流/
ぎゃくりよう /逆利用/
ぎゃぐ /ギャグ/
ぎゃっきょう /逆境/
ぎゃっこう /逆行/逆光/
ぎゃっこうじ /逆光時/
ぎゃっこうほせい /逆光補正/
ぎゃっぷ /ギャップ/
ぎゃんぶる /ギャンブル/
ぎゅう /牛/
ぎゅうかわ /牛革/
ぎゅうし /牛脂/
ぎゅうしゃ /牛舎/
ぎゅうしんてい /牛心亭/
ぎゅうじ /牛耳/
ぎゅうそうきんぺん /牛窓近辺/
ぎゅうたん /牛タン/
ぎゅうたんや /牛タン屋/
ぎゅうてつ /牛鉄/
ぎゅうとう /牛刀/
ぎゅうどん /牛丼/
ぎゅうどんや /牛丼屋/
ぎゅうどんやてんちょう /牛丼屋店長/
ぎゅうにく /牛肉/
ぎゅうにくせつ /牛肉説/
ぎゅうにゅう /牛乳/
ぎゅうにゅうせっけん /牛乳石鹸/
ぎゅうにゅうや /牛乳屋/
ぎゅうば /牛馬/
ぎゅうひれ /牛ヒレ/
ぎゅうほ /牛歩/
ぎゅうほせんじゅつ /牛歩戦術/
ぎゅうらく /牛楽/
ぎょ /魚/御/禦/漁/圄/圉/馭/
ぎょーざ /餃子/
ぎょい /御意/
ぎょう /行/業/仰/暁/尭/凝/形/僥/嶢/曉/澆/翹/蟯/驍/堯/痙/繞/
ぎょういこう /行以降/
ぎょういち /行位置/
ぎょうかい /業界/
ぎょうかいうら /業界裏/
ぎょうかいおおて /業界大手/
ぎょうかいがわ /業界側/
ぎょうかいがん /凝灰岩/
ぎょうかいし /業界誌/業界紙/
ぎょうかいじょうほう /業界情報/
ぎょうかいじん /業界人/
ぎょうかいじんそうほう /業界人双方/
ぎょうかいせいかつ /業界生活/
ぎょうかいぜんたい /業界全体/
ぎょうかいだんたい /業界団体/
ぎょうかいない /業界内/
ぎょうかいはつ /業界初/
ぎょうかいひょうじゅん /業界標準/
ぎょうかいひょうじゅんたいけい /業界標準体型/業界標準体形/
ぎょうかいびょう /業界病/
ぎょうかいようご /業界用語/
ぎょうかく /行革/仰角/
ぎょうかん /行間/
ぎょうかんかく /行間隔/
ぎょうかんちょうせい /行間調整/
ぎょうが /仰臥/
ぎょうがい /仰臥位/
ぎょうぎ /行儀/行義/
ぎょうぎょうしい /仰々しい/
ぎょうぎょうしく /仰々しく/
ぎょうくぎり /行区切り/
ぎょうけつ /凝結/凝血/
ぎょうけつすい /凝結水/
ぎょうこ /凝固/
ぎょうこう /行幸/僥倖/
ぎょうこてん /凝固点/
ぎょうさくじょ /行削除/
ぎょうざ /餃子/
ぎょうざや /餃子屋/
ぎょうし /凝視/
ぎょうした /行下/
ぎょうしてい /行指定/
ぎょうしてん /凝視点/
ぎょうしゃ /業者/業社/
ぎょうしゃかん /業者間/
ぎょうしゃはいそう /業者配送/
ぎょうしゃめい /業者名/
ぎょうしゅ /業種/
ぎょうしゅう /凝集/凝聚/
ぎょうしゅく /凝縮/
ぎょうしゅくど /凝縮度/
ぎょうしょ /行書/
ぎょうしょう /行商/
ぎょうしょうしゃりょう /行商車両/
ぎょうしょうせんよう /行商専用/
ぎょうしょうせんようしゃりょう /行商専用車両/
ぎょうしょうにん /行商人/
ぎょうしょたい /行書体/
ぎょうじ /行事/行司/
ぎょうじゃ /行者/
ぎょうじゅうざが /行住座臥/
ぎょうじょう /行状/行上/
ぎょうじよてい /行事予定/
ぎょうじよていらん /行事予定欄/
ぎょうじん /行人/
ぎょうすう /行数/
ぎょうすうせいげん /行数制限/
ぎょうすうちょうか /行数超過/
ぎょうずい /行水/
ぎょうせい /行政/暁星/
ぎょうせいいん /行政院/
ぎょうせいかいかく /行政改革/
ぎょうせいかん /行政官/
ぎょうせいかんりちょう /行政管理庁/
ぎょうせいがく /行政学/
ぎょうせいがわ /行政側/
ぎょうせいきかん /行政機関/
ぎょうせいく /行政区/
ぎょうせいくいきない /行政区域内/
ぎょうせいくかくない /行政区画内/
ぎょうせいくぶん /行政区分/
ぎょうせいけん /行政権/
ぎょうせいこくさい /暁星国際/
ぎょうせいざい /行政罰/
ぎょうせいしどう /行政指導/
ぎょうせいしょく /行政職/
ぎょうせいしょし /行政書士/
ぎょうせいしょぶん /行政処分/
ぎょうせいしょぶんせいど /行政処分制度/
ぎょうせいじむ /行政事務/
ぎょうせいじょう /行政上/
ぎょうせいじょうほう /行政情報/
ぎょうせいそしょう /行政訴訟/
ぎょうせいたんい /行政単位/
ぎょうせいちく /行政地区/
ぎょうせいちょう /行政庁/
ぎょうせいのうりょく /行政能力/
ぎょうせいふ /行政府/
ぎょうせいめん /行政面/
ぎょうせき /業績/
ぎょうせきあっか /業績悪化/
ぎょうせきしょ /業績書/
ぎょうせん /暁泉/
ぎょうせんとう /行先頭/
ぎょうぜんご /行前後/
ぎょうそう /形相/
ぎょうそうにゅう /行挿入/
ぎょうぞう /行三/
ぎょうたい /業態/
ぎょうたん /行端/
ぎょうたんい /行単位/
ぎょうだ /行田/
ぎょうだし /行田市/
ぎょうちゅう /蟯虫/行中/
ぎょうてん /仰天/
ぎょうとう /行頭/
ぎょうとく /行徳/
ぎょうとくえき /行徳駅/
ぎょうない /行内/
ぎょうにんべん /徨/彷/
ぎょうはんい /行範囲/
ぎょうばんごう /行番号/
ぎょうぶ /刑部/行歩/
ぎょうぶんかつ /行分割/
ぎょうへんしゅう /行編集/
ぎょうほうこう /行方向/
ぎょうまつ /行末/
ぎょうまつもじ /行末文字/
ぎょうむ /業務/
ぎょうむか /業務課/
ぎょうむき /業務機/
ぎょうむさべつ /業務差別/
ぎょうむしりょう /業務資料/
ぎょうむじかん /業務時間/
ぎょうむじょう /業務上/
ぎょうむじょうおうりょう /業務上横領/
ぎょうむじょうかしつ /業務上過失/
ぎょうむちゅう /業務中/
ぎょうむていけい /業務提携/
ぎょうむていし /業務停止/
ぎょうむないよう /業務内容/
ぎょうむはんい /業務範囲/
ぎょうむぶ /業務部/
ぎょうむほうこく /業務報告/
ぎょうむぼうがい /業務妨害/
ぎょうむぼうがいざい /業務妨害罪/
ぎょうむめいれい /業務命令/
ぎょうむもくてき /業務目的/
ぎょうむもくひょう /業務目標/
ぎょうむよう /業務用/
ぎょうむようきゅうとうき /業務用給湯機/
ぎょうむれんらく /業務連絡/
ぎょうめ /行目/
ぎょうれつ /行列/
ぎょうれつえんざん /行列演算/
ぎょうれつがた /行列型/
ぎょうれつけいさん /行列計算/
ぎょうれつしき /行列式/
ぎょうれつせき /行列積/
ぎょうれつち /行列値/
ぎょうれつちかんすう /行列値関数/
ぎょうれつひょうげん /行列表現/
ぎょうれつりろん /行列理論/
ぎょえい /魚影/
ぎょえん /御苑/
ぎょかい /魚介/魚貝/魚会/
ぎょかいるい /魚介類/
ぎょかく /漁獲/
ぎょかくりょう /漁獲量/
ぎょがん /魚眼/
ぎょきょう /漁協/漁況/魚協/
ぎょぎょう /漁業/
ぎょぎょうかんれん /漁業関連/
ぎょぎょうくみあい /漁業組合/
ぎょぎょうけん /漁業権/
ぎょぎょうそうぎょう /漁業操業/
ぎょぎょうほう /漁業法/
ぎょく /玉/漁区/嶷/閠/
ぎょくおん /玉音/
ぎょくさい /玉砕/
ぎょくざ /玉座/
ぎょくしょう /玉漿/
ぎょくせき /玉石/
ぎょくせきこんこう /玉石混淆/玉石混交/
ぎょくとう /玉東/玉頭/
ぎょくはく /玉帛/
ぎょくりんじ /玉林寺/
ぎょくろ /玉露/
ぎょぐ /漁具/
ぎょぐん /魚群/
ぎょぐんたんちき /魚群探知機/
ぎょけい /魚形/
ぎょこう /漁港/
ぎょこうない /漁港内/
ぎょしゃ /馭者/御者/
ぎょしゅ /魚種/
ぎょしょう /漁礁/
ぎょしん /魚信/
ぎょじ /御璽/
ぎょじょう /漁場/
ぎょせん /漁船/
ぎょそん /漁村/
ぎょたい /魚体/
ぎょたく /魚拓/
ぎょっこう /玉鉤/
ぎょにく /魚肉/
ぎょにくせいひん /魚肉製品/
ぎょふ /漁夫/
ぎょぶつ /御物/
ぎょほう /漁法/
ぎょみん /漁民/
ぎょめい /御名/
ぎょらい /魚雷/
ぎょらいてい /魚雷艇/
ぎょらいはっしゃかん /魚雷発射管/
ぎょりゅう /魚龍/
ぎょりん /魚鱗/
ぎょるい /魚類/
ぎょれん /魚連/
ぎよこぶんれつ /偽横分裂/
ぎり /義理/斬り/切/
ぎりしあ /希臘/
ぎりしゃ /ギリシャ/
ぎりちょこ /義理チョコ/
ぎりにんじょう /義理人情/
ぎりょう /技量/議了/技倆/
ぎりょうぶそく /技量不足/
ぎれい /儀礼/
ぎれいてき /儀礼的/
ぎれん /技連/
ぎろん /議論/
ぎろんいぜん /議論以前/
ぎろんがい /議論外/
ぎろんきかんえんちょう /議論期間延長/
ぎろんけっか /議論結果/
ぎろんさんかしゃ /議論参加者/
ぎろんしゅうそく /議論収束/
ぎろんしゅうりょう /議論終了/
ぎろんじ /議論時/
ぎろんじょうきょう /議論状況/
ぎろんぜんたい /議論全体/
ぎろんちゅう /議論中/
ぎろんてき /議論的/
ぎろんとうけつ /議論凍結/
ぎろんふじゅうぶん /議論不十分/
ぎろんぶそく /議論不足/
ぎろんほうき /議論放棄/
ぎろんりょういき /議論領域/
ぎわ /際/羲和/
ぎわく /疑惑/
ぎん /銀/吟/岑/垠/崟/憖/
ぎんいち /銀一/
ぎんいちろう /銀一郎/
ぎんいろ /銀色/
ぎんいろしゃ /銀色車/
ぎんいろゆうこうしょう /銀色有功賞/
ぎんうち /銀打/
ぎんえい /吟詠/
ぎんえいでん /銀英伝/
ぎんか /銀貨/銀花/銀貸/
ぎんかく /銀閣/
ぎんかくじ /銀閣寺/
ぎんかくじみち /銀閣寺道/
ぎんが /銀河/
ぎんがうちゅう /銀河宇宙/
ぎんがえいゆうでんせつ /銀河英雄伝説/
ぎんがえんばん /銀河円盤/
ぎんがけい /銀河系/
ぎんがけいない /銀河系内/
ぎんがざひょう /銀河座標/
ぎんがだん /銀河団/
ぎんがちず /銀河地図/
ぎんがちゅうしん /銀河中心/
ぎんがちゅうしんいき /銀河中心域/
ぎんがつうしん /銀河通信/
ぎんがていこく /銀河帝国/
ぎんがてつどう /銀河鉄道/
ぎんがぶんぷ /銀河分布/
ぎんがまる /銀河丸/
ぎんがみ /銀紙/
ぎんがめん /銀河面/
ぎんこう /銀行/銀鉤/
ぎんこういん /銀行員/銀行印/
ぎんこうかい /銀行界/
ぎんこうかん /銀行間/銀交換/
ぎんこうがわ /銀行側/
ぎんこうぎょうむ /銀行業務/
ぎんこうけい /銀行系/
ぎんこうこうざ /銀行口座/
ぎんこうごうとう /銀行強盗/
ぎんこうちょきん /銀行貯金/
ぎんこうふつうこうざ /銀行普通口座/
ぎんこうふりかえ /銀行振替/
ぎんこうふりこみ /銀行振込/
ぎんこうめい /銀行名/
ぎんこうよきん /銀行預金/
ぎんこんしき /銀婚式/
ぎんざ /銀座/
ぎんざいっちょうめ /銀座一丁目/
ぎんざえき /銀座駅/
ぎんざえきしゅうへん /銀座駅周辺/
ぎんざかん /銀座間/
ぎんざがい /銀座街/
ぎんざしゅうへん /銀座周辺/
ぎんざせん /銀座線/
ぎんざちか /銀座地下/
ぎんざどおり /銀座通/
ぎんざばし /銀座橋/
ぎんざほうめん /銀座方面/
ぎんざまつざかや /銀座松坂屋/
ぎんざまつや /銀座松屋/
ぎんざみつこし /銀座三越/
ぎんざん /銀山/
ぎんしょう /吟唱/銀賞/吟嘯/吟誦/銀章/銀将/
ぎんしょっき /銀食器/
ぎんじ /銀次/
ぎんじょう /吟醸/
ぎんじょういんりょう /吟醸飲料/
ぎんじょうしゅ /吟醸酒/
ぎんすいしょう /銀水晶/
ぎんずいしょう /銀水晶/
ぎんせい /銀製/銀星/
ぎんせかい /銀世界/
ぎんせん /銀泉/
ぎんぞう /銀蔵/
ぎんだまでっぽう /銀玉鉄砲/
ぎんなん /銀杏/
ぎんばん /銀盤/
ぎんぱい /銀杯/
ぎんぱく /銀箔/
ぎんぷんちょう /銀粉蝶/
ぎんべえ /銀兵衛/
ぎんほんい /銀本位/
ぎんまく /銀幕/
ぎんみ /吟味/
ぎんゆう /吟遊/
ぎんゆうしじん /吟遊詩人/
ぎんりん /銀鈴/
ぎんれい /銀嶺/
く /苦/口/区/駆/駒/句/九/工/駈/矩/久/躯/玖/狗/倶/９/劬/區/吁/吼/實/嶇/怐/惧/懼/枸/柧/桍/煦/瞿/窶/衢/驅/鉤/鳩/供/孔/貢/宮/庫/功/拘/紅/
くーにゃん /姑娘/
くーぽん /クーポン/
くーら /クーラ/
くーりー /苦力/
くい /杭/悔/久井/悔い/
くいーん /クイーン/
くいき /区域/
くいきない /区域内/
くいきわり /区域割/
くいけ /食い気/
くいず /クイズ/
くいたん /杭端/
くいちがい /食い違い/
くいとう /杭頭/
くいどうらく /喰い道楽/
くいにげ /食い逃げ/
くいほうだい /喰い放題/食い放題/
くいもの /喰い物/食い物/
くいものや /食い物屋/
くう /空/劫/腔/φ/刧/
くうあつ /空圧/
くうい /空位/空尉/
くういき /空域/
くうかい /空海/空回/
くうかん /空間/
くうかんおんきょう /空間音響/
くうかんかいぞうど /空間解像度/
くうかんかんかく /空間感覚/
くうかんきどう /空間軌道/
くうかんきょくりつ /空間曲率/
くうかんきょり /空間距離/
くうかんこうりつ /空間効率/
くうかんしゅうはすう /空間周波数/
くうかんじょう /空間上/
くうかんすいろん /空間推論/
くうかんぜんたい /空間全体/
くうかんそうごさよう /空間相互作用/
くうかんちゅう /空間中/
くうかんてき /空間的/
くうかんてきへいこう /空間的平衡/
くうかんでんぱん /空間伝播/
くうかんない /空間内/
くうかんにんしき /空間認識/
くうかんは /空間波/
くうかんひずみ /空間歪/
くうかんぶんかつ /空間分割/
くうかんぶんかつすう /空間分割数/
くうかんほう /空間法/
くうかんりょういき /空間領域/
くうかんりようこうりつ /空間利用効率/
くうかんろん /空間論/
くうが /空牙/
くうき /空気/
くうきあつ /空気圧/
くうきあな /空気穴/
くうきおせん /空気汚染/
くうきかいめん /空気界面/
くうきかんげき /空気間隙/
くうきげん /空気源/
くうきこうかん /空気交換/
くうきじゅう /空気銃/
くうきせいじょうき /空気清浄器/空気清浄機/
くうきせいどう /空気制動/
くうきそう /空気層/
くうきちゅう /空気中/
くうきちょうしつ /空気調湿/
くうきていこう /空気抵抗/
くうきにんぎょう /空気人形/
くうきふじょうしき /空気浮上式/
くうきみつど /空気密度/
くうきょ /空虚/
くうきょじかん /空虚時間/
くうきりゅう /空気流/
くうぎょう /空行/
くうぐん /空軍/
くうぐんきち /空軍基地/
くうぐんだいせんりゃく /空軍大戦略/
くうげき /空隙/
くうこう /空港/
くうこうえき /空港駅/
くうこうかかく /空港価格/
くうこうかかりかん /空港係官/
くうこうかん /空港間/
くうこうきゅうこう /空港急行/
くうこうけいゆ /空港経由/
くうこうけんせつ /空港建設/
くうこうけんせつけいかく /空港建設計画/
くうこうこうそくてつどう /空港高速鉄道/
くうこうこうだん /空港公団/
くうこうしょくいん /空港職員/
くうこうしようりょう /空港使用料/
くうこうせいびじょうえき /空港整備場駅/
くうこうせん /空港線/
くうこうぜい /空港税/
くうこうちゃく /空港着/
くうこうちょくつうれっしゃ /空港直通列車/
くうこうない /空港内/
くうこうはつ /空港発/
くうこうはんたいは /空港反対派/
くうこうよていち /空港予定地/
くうこうりようきゃく /空港利用客/
くうこうりようりょう /空港利用料/
くうこうりようりょうきん /空港利用料金/
くうこうれんらく /空港連絡/
くうこうれんらくれっしゃ /空港連絡列車/
くうさつ /空撮/
くうしきぜくう /空色是空/
くうしつじょうきょう /空室状況/
くうしゃ /空車/
くうしゅう /空襲/
くうしゅうけいほう /空襲警報/
くうしゅうごう /空集合/
くうしょ /空所/
くうじ /空自/
くうじきほんは /空耳基本波/
くうせい /空制/
くうせき /空席/
くうせきあんない /空席案内/
くうせきじょうきょう /空席状況/
くうせつ /空節/
くうせん /空戦/
くうぜん /空前/
くうぜんぜつご /空前絶後/
くうそ /空疎/
くうそう /空想/
くうそうきょり /空走距離/
くうそうじょう /空想上/
くうそうじょうたい /空走状態/
くうそうへき /空想癖/
くうそくぜしき /空即是色/
くうたいくう /空対空/
くうたいち /空対地/
くうちゅう /空中/
くうちゅうさつえい /空中撮影/
くうちゅうしゃしん /空中写真/
くうちゅうせん /空中戦/空中線/
くうちゅうせんかん /空中戦艦/
くうちゅうせんでんりょく /空中線電力/
くうちゅうていえん /空中庭園/
くうちゅうはどう /空中波動/
くうちゅうひっさつわざ /空中必殺技/
くうちゅうぶつ /空中物/
くうちゅうぶんかい /空中分解/
くうちゅうほうにょう /空中放尿/
くうちゅうほこう /空中歩行/
くうちゅうゆうえい /空中遊泳/
くうちゅうようさい /空中要塞/
くうちゅうろうかく /空中楼閣/
くうちょう /空調/空腸/
くうちょうおん /空調音/
くうちょうき /空調機/
くうちょうせつび /空調設備/
くうちょうそうおん /空調騒音/
くうちょうよう /空調用/
くうてい /空挺/
くうていだん /空挺団/
くうていぶたい /空挺部隊/
くうてん /空転/
くうてんがわ /空転側/
くうてんじ /空転時/
くうてんぼうし /空転防止/
くうどう /空洞/
くうどうか /空洞化/
くうにゅうりょく /空入力/
くうねんぴ /空燃費/
くうはく /空白/　/
くうはくぎょう /空白行/
くうはくち /空白地/
くうはくぶぶん /空白部分/
くうはくもじ /空白文字/
くうばく /空爆/
くうばくちゅう /空爆中/
くうひ /空飛/空費/
くうふく /空腹/
くうふくかん /空腹感/
くうふくじ /空腹時/
くうぶん /空文/
くうほう /空砲/空包/
くうぼ /空母/
くうぼうそう /空乏層/
くうぼせん /空母戦/
くうもじ /空文字/
くうもじれつ /空文字列/
くうや /空也/
くうゆ /空輸/
くうらん /空欄/
くうりき /空力/
くうりきせいのう /空力性能/
くうりすと /空リスト/
くうりょくてき /空力的/
くうりょくふかぶつ /空力付加物/
くうれい /空冷/
くうれいしき /空冷式/
くうれつ /空列/
くうろ /空路/
くうろん /空論/
くぇすちょん /クェスチョン/
くぇっしょん /クェッション/
くえい /区営/
くえき /苦役/
くえすと /クエスト/
くえん /枸櫞/
くえんさん /枸櫞酸/
くぉーと /クォート/
くおん /久遠/
くか /久賀/
くかい /句会/区会/苦界/
くかいぎいん /区会議員/
くかく /区画/
くかくせいり /区画整理/
くかくほうしき /区画方式/
くかた /久方/
くかん /区間/
くかんうんてん /区間運転/
くかんうんてんれっしゃ /区間運転列車/
くかんえんちょう /区間延長/
くかんかいそく /区間快速/
くかんかいそくきゅうこう /区間快速急行/
くかんがい /区間外/
くかんがいじょうしゃ /区間外乗車/
くかんがいりよう /区間外利用/
くかんきゅうこう /区間急行/
くかんきょり /区間距離/
くかんごと /区間毎/
くかんしき /区間式/
くかんたんしゅく /区間短縮/
くかんちょう /区間長/
くかんてき /区間的/
くかんとっきゅう /区間特急/
くかんない /区間内/
くかんぶんかつ /区間分割/
くかんぶんかつすう /区間分割数/
くかんへんこう /区間変更/
くかんゆうしょう /区間優勝/
くかんれっしゃ /区間列車/
くが /久我/玖珂/玖賀/
くがい /区外/苦界/
くがいそう /九蓋草/
くがく /苦学/
くがつ /九月/9月/９月/長月/
くがつひめ /九月姫/
くがやま /久我山/
くがよしこ /久我美子/
くき /久喜/茎/九鬼/莖/
くきざき /茎崎/
くきまきひげ /茎巻きひげ/茎巻鬚/
くきもと /久木元/
くきゅう /区急/
くきょう /苦境/
くぎ /釘/供犠/
くぎうち /釘打/
くぎし /釘師/
くぎちょうせい /釘調整/
くぎちょうせいふよう /釘調整不要/
くぎづけ /釘付け/
くぎの /久木野/
くぎみや /釘宮/
くぎもと /釘本/
くぎょう /苦行/公卿/
くぎり /区切/区切り/句切/
くぎりかた /区切り方/
くぎりし /区切り子/
くぎん /苦吟/
くく /区々/九九/区区/
くくりぞめ /纐/
くぐい /鵠/
くぐつ /傀儡/裹/
くぐの /久々野/
くけい /矩形/
くけいいき /矩形域/
くけいしつ /矩形室/
くけいじょうほう /矩形情報/
くけいは /矩形波/
くけいはんい /矩形範囲/
くけいばん /矩形板/
くけいまど /矩形窓/
くけいりょういき /矩形領域/
くげ /公家/公卿/久下/
くげがた /公家方/
くげぬま /鵠沼/
くげん /苦言/
くこ /枸杞/
くこうぞう /句構造/
くこうぞうきそく /句構造規則/
くこうぞうぶんぽう /句構造文法/
くごう /久郷/
くさ /草/日/艸/
くさい /クサい/
くさお /草尾/
くさか /久坂/日下/
くさかい /草開/草皆/
くさかべ /日下部/
くさかり /草刈/草刈り/草苅/
くさがみ /草上/
くさき /草木/
くさけいば /草競馬/
くさずもう /草相撲/
くさせんり /草千里/
くさたいかい /草大会/
くさち /草地/
くさつ /草津/
くさつおうふく /草津往復/
くさつおんせん /草津温泉/
くさつこうげん /草津高原/
くさつごう /草津号/
くさつし /草津市/
くさつしてん /草津支店/
くさつしらね /草津白根/
くさつせん /草津線/
くさつどうろ /草津道路/
くさつほうめん /草津方面/
くさなぎ /草薙/
くさなぎきゅうじょう /草薙球場/
くさなぎのたち /草薙の太刀/
くさなぎのつるぎ /草薙剣/
くさの /草野/
くさのね /草の根/
くさは /草葉/
くさはら /草原/
くさば /草場/
くさばな /草花/
くさび /楔/
くさま /日馬/草間/
くさむら /叢/
くさやきゅう /草野球/
くさやきゅういか /草野球以下/
くさやなぎ /草柳/
くさよもぎ /藾/
くさり /鎖/銷/
くされえん /腐れ縁/
くさわけ /草分け/草分/
くし /駆使/櫛/釧/串/梳/
くしあげ /串揚げ/
くしがた /櫛形/櫛型/
くしがはま /櫛ケ浜/
くしきの /串木野/
くしくも /奇しくも/
くしさし /串刺/
くしざし /串刺/くし刺し/
くしだ /串田/
くしてい /区指定/
くしはら /櫛原/串原/
くしびき /櫛引/
くしま /串間/久嶋/
くしまうみ /久島海/
くしもと /串本/
くしゃみ /嚔/
くしやき /串焼き/串焼/
くしやま /串山/
くしゅう /句集/
くしょ /区処/
くしょう /苦笑/
くしら /串良/
くしろ /釧路/釧/
くしろえき /釧路駅/
くしろこうせん /釧路高専/
くしろしつげん /釧路湿原/
くしろしつげんえき /釧路湿原駅/
くしん /苦心/
くじ /九時/久慈/籤/九字/
くじしょう /久慈商/
くじせん /久慈線/
くじびき /くじ引き/籤引き/
くじゃく /孔雀/
くじゅ /口授/
くじゅう /苦渋/苦汁/久住/
くじゅうくり /九十九里/
くじゅうくりはま /九十九里浜/
くじょ /駆除/
くじょう /苦情/九条/
くじょうしゃこ /九条車庫/
くじょうしゃこまえ /九条車庫前/
くじょうやま /九条山/
くじょうやまえき /九条山駅/
くじょほう /駆除法/
くじら /鯨/鯀/クジラ/
くじらい /鯨井/
くじらおか /鯨岡/
くす /楠/玖珠/樟/
くすおか /楠岡/
くすだ /楠田/
くすだま /薬玉/
くすね /藥煉/
くすのき /楠/樟/楠木/
くすのきあか /クスノキ亜科/Lauroideae/
くすのきか /クスノキ科/Lauraceae/
くすのきまさしげ /楠正成/楠木正成/
くすのせ /楠瀬/
くすのは /樟葉/
くすのはえき /樟葉駅/
くすはら /楠原/
くすみ /楠見/
くすもと /楠本/楠元/
くすやま /楠山/
くすり /薬/藥/
くすりうり /薬売り/
くすりし /薬師/
くすりや /薬屋/
くすりゆび /薬指/
くず /屑/葛/
くずう /葛生/
くずおか /葛岡/
くずかご /屑篭/
くずきじ /屑記事/
くずきり /葛切り/葛切/
くずこ /葛粉/
くずてつ /屑鉄/
くずてつや /屑鉄屋/
くずは /楠葉/葛葉/
くずはもーる /樟葉モール/
くずはら /葛原/
くずまき /葛巻/
くずみ /久住/
くずゆ /葛湯/
くずりゅう /九頭竜/
くずりゅうこ /九頭竜湖/
くずれ /崩れ/
くせ /癖/久世/
くせげ /癖毛/
くせつ /苦節/
くせもの /曲者/
くせん /苦戦/
くせんちゅう /苦戦中/
くせんてい /駆潜艇/
くせんひっし /苦戦必至/
くぜ /久世/久瀬/
くぜつ /口説/
くそ /糞/
くたい /躯体/
くたにやき /九谷焼/
くたんもん /狗蜑門/
くだ /管/菅/
ください /下さい/
くだされたく /被下度/
くだまつ /下松/
くだもの /果物/
くだら /百斉/百済/百濟/
くだらご /百済語/
くだり /下り/件/
くだりざか /下り坂/
くだりせん /下り線/
くだん /九段/件/
くだんきた /九段北/
くだんこうこう /九段高校/
くだんした /九段下/
くだんしたえき /九段下駅/
くだんしたかん /九段下間/
くち /口/
くちあたり /口当り/
くちいがい /口以外/
くちうつし /口移し/
くちうら /口裏/口占/
くちえ /口絵/
くちかず /口数/
くちがね /口金/
くちき /朽木/
くちきき /口利き/
くちきり /口切り/
くちく /駆逐/
くちくかん /駆逐艦/
くちくせんしゃ /駆逐戦車/
くちくたいしれい /駆逐隊司令/
くちぐせ /口ぐせ/口癖/
くちぐち /口々/
くちぐるま /口車/
くちげんか /口喧嘩/
くちこみ /口コミ/
くちさき /口先/吻/
くちじょうず /口上手/
くちすう /口数/
くちせん /口銭/
くちぞえ /口添え/
くちた /口田/
くちたっしゃ /口達者/
くちだし /口出し/
くちづけ /口づけ/
くちづて /口伝/
くちどめ /口止め/
くちなし /梔/
くちのつ /口之津/
くちのは /朽葉/
くちのまち /口ノ町/
くちは /朽葉/
くちば /朽葉/
くちばし /喙/嘴/
くちばや /口早/
くちぱく /口パク/
くちひげ /髭/
くちび /口火/
くちびる /唇/口唇/
くちふうじ /口封じ/
くちぶえ /口笛/
くちぶり /口ぶり/口振り/
くちべた /口下手/
くちべに /口紅/
くちべらし /口減らし/
くちまね /口真似/
くちもと /口元/口許/
くちゃ /苦茶/
くちやくそく /口約束/
くちゅう /駆虫/
くちょう /口調/区長/
くちよごし /口汚し/
くちわ /口和/
くちわき /口脇/
くっきょう /屈強/倔強/究竟/
くっきょく /屈曲/
くっきょくしき /屈曲式/
くっきょくは /屈曲波/
くっきょくぶ /屈曲部/
くっきん /屈筋/
くっさく /掘削/掘鑿/
くっし /屈指/
くっしゃろこ /屈斜路湖/
くっしょん /クッション/
くっしん /屈伸/
くっしんばつじゅう /屈伸抜重/
くっせい /屈性/
くっせつ /屈折/
くっせついじょう /屈折異常/
くっせつしき /屈折式/
くっせつりつ /屈折率/
くったく /屈託/
くっちゃん /倶知安/
くっぷく /屈伏/屈服/
くつ /靴/掘/窟/沓/屈/履/倔/崛/鞋/
くつあと /靴跡/
くつう /苦痛/
くつかけ /沓掛/
くつかけしんごうしょ /沓掛信号所/
くつかわ /沓川/
くつき /朽木/
くつさわ /沓沢/
くつざわ /沓澤/沓沢/
くつした /靴下/くつ下/
くつじゅう /屈従/
くつじょく /屈辱/
くつじょくせん /屈辱戦/
くつじょくてき /屈辱的/
くつじょくど /屈辱度/
くつずれ /靴擦れ/
くつぞこ /靴底/
くつばこ /靴箱/
くつひも /靴紐/
くつみ /九津見/
くつや /靴屋/
くつわ /轡/銜/
くつわだ /轡田/
くてん /句点/区点/
くでん /口伝/
くとう /苦闘/久東/
くとうてん /句読点/
くとうてんきごう /句読点記号/
くどう /工藤/駆動/区道/久道/
くどうおん /駆動音/
くどうかいろ /駆動回路/
くどうかん /駆動艦/
くどうがた /駆動型/
くどうがわ /駆動側/
くどうけい /駆動系/
くどうげん /駆動源/
くどうじかん /駆動時間/
くどうそうち /駆動装置/
くどうてん /駆動点/
くどうでんきけい /駆動電気系/
くどうぶ /駆動部/
くどうぶぶん /駆動部分/
くどうほうしき /駆動方式/
くどうめん /駆動面/
くどうりつ /駆動率/
くどうりょく /駆動力/
くどうりん /駆動輪/
くどうりんしゅつりょく /駆動輪出力/
くどお /久遠/
くどき /口説き/
くどきかた /口説き方/
くどく /口説く/功徳/
くどやま /九度山/
くない /宮内/区内/苦無/工内/
くないちょう /宮内庁/
くなこく /狗奴国/
くなしり /国後/
くなり /九那里/
くなん /苦難/
くに /国/邦/國/訓/圀/久邇/六合/
くにあき /国昭/邦昭/邦明/国明/
くにい /國井/国井/
くにえだ /国枝/國枝/
くにお /邦夫/邦男/國雄/国男/国夫/国雄/邦雄/邦央/久仁雄/邦生/
くにかず /邦和/
くにかた /國方/
くにがみ /国頭/
くにがら /国柄/
くにがわ /国側/
くにきょうかい /国協会/
くにく /苦肉;敵をだますために自身を傷つけること/
くにぐに /国々/
くにこ /邦子/久仁子/くに子/都子/
くにこう /国高/
くにこうしんぶん /国高新聞/
くにさか /国坂/
くにさき /国東/
くにさだ /國貞/
くにさわ /国沢/
くにざかい /国境/
くにざね /国実/
くにしげ /国重/
くにしま /国島/
くにしゅどう /国主導/
くにじ /邦次/
くにじま /国島/
くにじゅう /国中/
くにせん /国線/
くにぜんたい /国全体/
くにたいこう /国対抗/
くにたち /国立/
くにたちおんだい /国立音大/
くにたちかん /国立間/
くにたちこうこう /国立高校/
くにたちし /国立市/
くにたちしない /国立市内/
くにたちてん /国立店/
くにだ /国田/
くにつかみ /国津神/
くにとみ /国富/
くにとも /邦朋/國友/
くにとりものがたり /国盗物語/
くになまり /国訛り/
くになり /邦成/
くにのぶ /国信/
くにはま /国浜/
くにはる /邦治/邦明/
くにばんごう /国番号/
くにひこ /邦彦/國彦/国彦/
くにひさ /国久/邦久/
くにひと /邦仁/
くにひろ /邦宏/訓弘/国博/邦洋/
くにびと /国人/
くにふじ /國藤/
くにふみ /邦文/
くにべつ /国別/
くにべつたいこうせん /国別対抗戦/
くにまさ /邦匡/国政/
くにまつ /國松/
くにみ /国見/
くにみがおか /国見ヶ丘/
くにみだけ /国見岳/
くにみつ /國光/
くにむね /國宗/
くにもと /国本/
くにもとじょしこうこう /国本女子高校/
くにものがたり /国物語/
くにやしょてん /国屋書店/
くにやす /国安/国泰/國安/
くにゆき /邦之/
くによし /国吉/邦義/國義/國吉/
くぬぎ /椚/栩/椢/椪/椡/櫟/檪/功刀/功力/
くねん /九年/
くの /久野/
くのいち /くノ一/
くのう /苦悩/久能/
くのくら /玄倉/
くのへ /九戸/
くはい /苦杯/
くば /久場/玖場/
くび /首/馘/頚/馘首/頸/
くびかざり /首飾/首飾り/珞/
くびかせ /首枷/
くびき /頚城/軛/
くびきり /首切/首切り/
くびくくり /首縊り/
くびさ /首差/
くびしめ /首締/
くびす /跟/踵/
くびすじ /首筋/
くびつり /首吊/
くびなげ /首投げ/
くびひねり /首捻り/
くびわ /首輪/
くふう /工夫/
くふうしだい /工夫次第/
くぶ /九分/
くぶくりん /九分九厘/
くぶん /区分/
くぶんしつ /区分室/
くぶんせん /区分線/
くぶんてき /区分的/
くぶんほう /区分法/
くべつ /区別/
くべつなし /区別無し/
くほんぶつ /九品仏/
くぼ /久保/窪/玖保/
くぼう /公方/久宝/
くぼかわ /窪川/久保川/
くぼがみ /久保上/
くぼき /久保木/
くぼさわ /久保沢/
くぼしょてん /久保書店/
くぼた /久保田/窪田/クボタ/
くぼたとしのぶ /久保田利伸/
くぼち /窪地/くぼ地/
くぼでら /久保寺/窪寺/
くぼの /窪野/
くぼや /窪谷/
くぼやま /久保山/
くま /熊/隈/球磨/久万/
くまい /熊井/
くまいし /熊石/
くまがい /熊谷/
くまがいぐみ /熊谷組/
くまがね /熊ヶ根/
くまがや /熊谷/
くまがやこう /熊谷工/
くまくす /熊楠/
くまくら /熊倉/
くまぐす /熊楠/
くまげ /熊毛/
くまげら /熊啄木鳥/
くまこう /熊公/
くまこうせいもんまえ /熊高正門前/
くまさか /熊坂/
くまさき /熊崎/
くまさわ /熊沢/
くまざわ /熊沢/
くまそ /熊襲/
くまだ /熊田/隈田/
くまだい /熊大/
くまつづらか /クマツヅラ科/
くまで /熊手/
くまとり /熊取/
くまどり /隈取り/
くまの /熊野/
くまのがわ /熊野川/
くまのせん /熊野線/
くまはち /熊八/
くまもと /熊本/隈本/
くまもといなん /熊本以南/
くまもとえきまえ /熊本駅前/
くまもとかん /熊本間/
くまもとけん /熊本県/
くまもとけんあそ /熊本県阿蘇/
くまもとけんえんがんぶ /熊本県沿岸部/
くまもとけんしゅっしん /熊本県出身/
くまもとけんしょくいん /熊本県職員/
くまもとけんないりくぶ /熊本県内陸部/
くまもとご /熊本語/
くまもとし /熊本市/
くまもとしえい /熊本市営/
くまもとしない /熊本市内/
くまもとしりつ /熊本市立/
くまもとじょう /熊本城/
くまもとだい /熊本大/
くまもとだいがく /熊本大学/
くまもとでんてつ /熊本電鉄/
くまもとでんぱこうせん /熊本電波高専/
くまもとべん /熊本弁/
くまやま /熊山/
くみ /組/久美/与/公美/
くみあい /組合/
くみあいいいんしょう /組合員証/
くみあいいん /組合員/
くみあいいんいがい /組合員以外/
くみあいいんしょう /組合員証/
くみあいいんとうろくめいぼ /組合員登録名簿/
くみあいかつどう /組合活動/
くみあいかんけい /組合関係/
くみあいひ /組合費/
くみあいれんごうかい /組合連合会/
くみあげ /九美上/
くみあわせ /組み合わせ/組合せ/組み合せ/
くみあわせろん /組合せ論/
くみいれ /組入れ/
くみいん /組員/
くみえ /久美恵/
くみかえ /組み替え/組換え/
くみかた /組み方/
くみきょく /組曲/
くみきょくばん /組曲版/
くみこ /久美子/玖海子/クミ子/公美子/
くみこみ /組み込み/組込/
くみこみかた /組み込み方/
くみこみがた /組み込み型/
くみこみじ /組込時/
くみたい /組対/
くみたいそう /組体操/
くみたて /組み立て/組立/
くみたてこう /組立工/
くみたてしき /組立式/
くみたてせつめいしょ /組立説明書/
くみちがい /組み違い/
くみちょう /組長/
くみて /組み手/
くみはば /組幅/
くみはま /久美浜/
くみはん /組版/組み版/
くみはんじ /組版時/
くみばん /組版/
くみひも /組紐/
くみめい /組名/
くみやま /久御山/
くみん /区民/
くめ /粂/久米/
くめい /区名/苦鳴/
くめうち /粂内/
くめがわ /久米川/
くめしょぼう /久米書房/
くめた /久米田/
くめだ /久米田/
くめなん /久米南/
くめの /粂野/
くめのせんにん /久米の仙人/
くめひろし /久米宏/
くめん /工面/
くも /雲/蜘/蜘蛛/
くもあひ /雲合/
くもい /雲井/
くもおとこ /蜘蛛男/
くもがくれ /雲隠れ/雲隠/
くもがた /雲形/
くもがたじょうぎ /雲型定規/雲形定規/
くもつ /供物/貢物/
くもとりやま /雲取山/
くものい /雲乃井/
くものす /蜘蛛の巣/
くもま /雲間/
くもゆき /雲行/雲行き/
くもり /曇/曇り/
くもん /苦悶/公文/久門/
くもんしき /公文式/
くやくしょ /区役所/
くやくしょどおり /区役所通り/
くやくしょふきん /区役所付近/
くやしなき /悔し泣き/
くやしなみだ /悔し涙/
くやま /久山/
くゆう /区有/
くゆうち /区有地/
くよう /供養/
くようさい /供養祭/
くら /蔵/倉/鞍/庫/峅/藏/
くらあく /暗悪/
くらい /位/
くらいし /倉石/
くらいまっくす /クライマックス/
くらいり /蔵入/
くらいれ /倉入/
くらうち /蔵内/
くらうつし /倉移/
くらかけ /倉掛/
くらかげ /鞍掛/
くらかた /倉片/
くらがえ /鞍替/
くらがり /闇/
くらく /苦楽/
くらくえんぐち /苦楽園口/
くらくしょん /クラクション/
くらげ /クラゲ/鮓/海月/水母/
くらさ /暗さ/
くらさき /倉崎/
くらさわ /倉沢/
くらし /暮らし/
くらしき /倉敷/
くらしきし /倉敷市/
くらしげ /倉重/倉茂/
くらした /蔵下/
くらしっく /クラシック/
くらしな /倉品/
くらしま /倉島/
くらす /クラス/
くらすた /クラスタ/
くらた /倉田/鞍田/蔵田/
くらたけ /倉岳/
くらたや /蔵田家/
くらち /倉知/
くらっち /クラッチ/
くらて /鞍手/
くらてぐん /鞍手郡/
くらでこうつう /鞍手交通/
くらとみ /倉富/
くらに /倉荷/
くらの /蔵野/
くらのうち /蔵之内/
くらはし /倉橋/
くらはら /倉原/
くらふと /クラフト/
くらぶ /倶楽部/クラブ/
くらぶち /倉淵/
くらべ /倉部/
くらま /鞍馬/蔵間/
くらまえ /蔵前/藏前/
くらまえかん /蔵前間/
くらまえこくぎかん /蔵前国技館/
くらまえゆうしょうせん /蔵前優勝戦/
くらません /鞍馬線/
くらまた /倉又/
くらまてんぐ /鞍馬天狗/
くらまやま /鞍馬山/
くらめ /暗め/
くらもち /倉持/
くらもと /倉本/蔵本/蔵元/
くらもとまさひろ /倉本昌弘/
くらやみ /暗闇/
くらよし /倉吉/
くり /栗/繰/庫裡/涅/
くりーにんぐ /クリーニング/
くりーむ /クリーム/
くりあ /クリア/
くりあげ /繰り上げ/
くりいれ /繰入/
くりいろ /栗色/
くりお /栗生/
くりかえし /繰り返し/繰りかえし/繰返し/々/
くりから /倶利伽羅/倶利迦羅/
くりげ /栗毛/
くりここくさい /栗子国際/
くりこし /繰越/
くりこしきん /繰越金/
くりこま /栗駒/
くりごはん /栗御飯/
くりさわ /栗沢/
くりす /栗栖/
くりすたる /クリスタル/
くりすます /クリスマス/
くりすますろーずあか /クリスマスローズ亜科/Helleboroideae/
くりた /栗田/栗太/
くりっぷ /クリップ/
くりっぷぼーど /クリップボード/
くりつ /区立/栗津/
くりつとしょかん /区立図書館/
くりにっく /クリニック/
くりねずみ /栗鼠/
くりの /栗野/
くりのべしさん /繰延資産;創立費、試験研究費、新株発行費用など、一度に計上せずに数年間かけて費用として計上する費用/
くりはし /栗橋/
くりはま /久里浜/
くりはまおき /久里浜沖/
くりはら /栗原/久利原/
くりはらこまき /栗原小巻/
くりはらでんてつ /栗原電鉄/
くりばやし /栗林/
くりもと /栗本/栗源/
くりもとしんいちろう /栗本慎一郎/
くりや /廚/厨/
くりやがわ /栗谷川/
くりやま /栗山/
くりやまむら /栗山村/
くりゅう /九龍/
くりょ /苦慮/
くりん /九厘/
くる /久留/
くるー /クルー/
くるいざき /狂咲/
くるす /来須/
くるすの /栗栖野/
くるぶし /踝/
くるま /車/クルマ/俥/
くるまいがい /車以外/
くるまいす /車椅子/
くるまいぞんしゃかい /車依存社会/
くるまいちだいぶん /車一台分/
くるまいど /車井戸/
くるまかんけい /車関係/
くるまかんれん /車関連/
くるまがわ /車側/
くるまこうにゅうじ /車購入時/
くるまさんぎょう /車産業/
くるまざき /車折/
くるまざっし /車雑誌/
くるましゃかい /車社会/
くるまじたい /車自体/
くるまぜんたい /車全体/
くるまたに /車谷/
くるまだ /車田/
くるまだい /車代/
くるまつうがく /車通学/
くるまどうし /車同志/車同士/
くるまどおり /車通り/
くるまどめ /車止/
くるまぶんか /車文化/
くるまや /車屋/
くるまやま /車山/
くるまゆうせん /車優先/
くるまゆり /車百合/
くるまよい /車酔/車酔い/
くるまよう /車用/
くるまりよう /車利用/
くるみ /胡桃/久留味/
くるみざわ /胡桃沢/
くるみもく /クルミ目/Juglandales/
くるめ /久留米/
くるめこうぎょうだい /久留米工業大/
くるめこうぎょうだいがく /久留米工業大学/
くるめこうだい /久留米工大/
くるめし /久留米市/
くるわ /廓/
くれ /暮/呉/暮れ/
くれーしゃげき /クレー射撃/
くれーたー /クレーター/
くれーむ /クレーム/
くれぐれ /暮々/呉呉/
くれし /呉市/
くれじっと /クレジット/
くれせん /呉線/
くれたけ /呉竹/
くれない /紅/
くれないのぶた /紅の豚/
くれはかがく /呉羽化学/
くればやし /紅林/暮林/
くれよん /クレヨン/
くれよんしゃ /クレヨン社/
くろ /黒/
くろーず /クローズ/
くろあめ /黒飴/
くろあん /黒餡/
くろいし /黒石/
くろいそ /黒磯/
くろいそいほく /黒磯以北/
くろいそえき /黒磯駅/
くろいろ /黒色/黒色腫/
くろいわ /黒岩/
くろう /苦労/
くろうさま /苦労様/
くろうしょう /苦労性/
くろうじ /黒氏/
くろうだん /苦労談/
くろうと /玄人/
くろうにん /苦労人/
くろうばなし /苦労話/
くろうめもどきもく /クロウメモドキ目/Rhamnales/
くろえ /黒江/
くろおとこ /黒男/
くろかび /黒黴/
くろかみ /黒髪/
くろかみちょう /黒髪町/
くろかわ /黒川/黒河/
くろかわぐん /黒川郡/
くろがそ /黒画素/
くろがね /黒鉄/鉄/鐵/黒銀/
くろき /黒木/
くろぎ /黒木/
くろぐろ /黒々/
くろけい /黒系/
くろこ /黒子/
くろこげ /黒焦げ/
くろご /黒子/黒衣/
くろさか /黒坂/
くろさき /黒崎/
くろさわ /黒澤/黒沢/
くろさわあきら /黒沢明/黒澤明/
くろざとう /黒砂糖/
くろしお /黒潮/
くろしおおんせん /黒潮温泉/
くろしおふきん /黒潮付近/
くろしかく /■/
くろしかげ /黒鹿毛/
くろしろ /黒白/
くろしろもよう /黒白模様/
くろじ /黒字/黒地/
くろじとうさん /黒字倒産/
くろす /黒須;姓/クロス/
くろすいしょう /黒水晶/
くろすみ /黒住;姓/
くろずみ /黒住;姓/
くろせ /黒瀬;姓/
くろせん /黒線/
くろた /黒田;姓/
くろたき /黒滝/
くろたてじま /黒縦縞/
くろだ /黒田;姓/
くろだい /黒鯛/
くろだけ /黒岳/
くろだま /黒玉/
くろだんしゃく /黒男爵/
くろち /黒地/
くろぢ /黒地/
くろっく /クロック/
くろっくはば /クロック幅/
くろつち /黒土/
くろでんわ /黒電話/
くろとかげ /黒蜥蜴/
くろぬり /黒塗り/
くろねこ /黒猫/
くろば /黒羽/
くろばね /黒羽/
くろばん /黒番/
くろひめ /黒姫/
くろひめこうげん /黒姫高原/
くろひりつ /黒比率/
くろびかり /黒光り/
くろびし /黒菱/
くろふく /黒服/
くろふね /黒船/
くろぶた /黒豚/
くろべ /黒部/
くろべがわ /黒部川/
くろべきょうこくてつどう /黒部峡谷鉄道/
くろべこ /黒部湖/
くろほね /黒保根/
くろぼし /黒星/●/
くろまく /黒幕/
くろまじゅつ /黒魔術/
くろまつ /黒松/
くろまつない /黒松内/
くろまほう /黒魔法/
くろまめ /黒豆/
くろまる /黒丸/●/
くろみかずら /黒御鬘/
くろみや /黒宮/
くろむぎしゅ /黒麦酒/
くろめ /黒目/
くろもよう /黒模様/
くろもん /黒門/
くろや /黒屋/
くろやなぎ /黒柳/
くろやなぎてつこ /黒柳徹子/
くろやま /黒山/
くろゆり /黒百合/
くろわく /黒枠/
くろわし /黒鷲/
くわ /桑/鍬/久和/钁/
くわおり /桑折/
くわかど /桑門/
くわけ /区分け/
くわこ /桑子/
くわこう /桑港/
くわしく /詳しく/
くわずぎらい /食わず嫌い/
くわた /桑田/
くわだ /桑田/
くわだて /企/
くわづる /桑鶴/
くわな /桑名/
くわなえき /桑名駅/
くわの /桑野/
くわはた /桑畑/
くわはら /桑原/
くわばら /桑原/
くわむら /桑村/
くわもと /桑本/
くわやま /桑山/
くわり /区割り/桑理/
くん /君/訓/董/薫/勲/勳/桾/熏/燻/皸/皹/葷/裙/醺/
くんいく /訓育/
くんかい /訓戒/
くんこく /訓告/
くんし /君子/
くんしゅ /君主/葷酒/
くんしゅせい /君主制/
くんしゅせいいっぱん /君主制一般/
くんしょう /勲章/
くんしん /君臣/
くんじ /訓示/訓辞/
くんじょう /燻蒸/
くんせい /燻製/董製/
くんづけ /君付/
くんとう /薫陶/
くんどう /訓導/
くんどく /訓読/
くんねっぷ /訓子府/
くんねっぷちょう /訓子府町/
くんぷう /薫風/
くんぷうまんまん /薫風満々/
くんみんせいおん /訓民正音/
くんやん /崑央/
くんゆ /訓諭/
くんよみ /訓読み/
くんりん /君臨/
くんれい /訓令/
くんれいしき /訓令式/
くんれん /訓練/
くんれんうんてん /訓練運転/
くんれんか /訓練科/
くんれんし /訓練士/
くんれんしだい /訓練次第/
くんれんしょ /訓練所/
くんれんじょ /訓練所/
くんれんじょう /訓練場/
くんれんじょうむ /訓練乗務/
くんれんせい /訓練生/
くんれんちゅう /訓練中/
くんれんど /訓練度/
くんれんぶそく /訓練不足/
くんれんよう /訓練用/
くんわ /訓話/
ぐ /具/愚/虞/倶/狗/禺/颶/麌/壺/壷/惧/
ぐあい /具合/具合い/工合/
ぐあん /愚案/
ぐう /隅/遇/偶/寓/宮/嵎/藕/
ぐうい /寓意/
ぐうえん /宮宛/
ぐうかんすう /偶関数/
ぐうき /偶奇/
ぐうきせい /偶奇性/
ぐうきょ /寓居;僑居、僑寓/
ぐうじ /宮司/
ぐうすう /偶数/
ぐうすうかい /偶数回/
ぐうすうけた /偶数桁/
ぐうすうじ /偶数時/
ぐうすうづき /偶数月/
ぐうすうばんごう /偶数番号/
ぐうすうび /偶数日/
ぐうすうびょう /偶数秒/
ぐうすうぺーじ /偶数頁/
ぐうすうほん /偶数本/
ぐうぜん /偶然/
ぐうぜんせい /偶然性/
ぐうぜんてき /偶然的/
ぐうぜんはっけん /偶然発見/
ぐうぞう /偶像/
ぐうぞうし /偶像視/
ぐうぞうすうはい /偶像崇拝/
ぐうぞうすうはいしゅぎ /偶像崇拝主義/
ぐうぞうすうはいひはん /偶像崇拝批判/
ぐうていもく /偶蹄目/
ぐうはつ /偶発/
ぐうはつてき /偶発的/
ぐうもく /寓目/
ぐうりょく /偶力/
ぐうわ /寓話/
ぐきょ /愚挙/
ぐけい /愚兄/
ぐげん /具現/
ぐげんか /具現化/
ぐこう /愚行/愚考/
ぐさ /種/
ぐさい /愚妻/
ぐざい /ξ/Ξ/
ぐしかみ /具志頭/
ぐしかわ /具志川/
ぐしけん /具志堅/
ぐしゃ /愚者/
ぐしょう /具象/
ぐしょうか /具象化/
ぐしょうこう /具象項/
ぐしん /具申/
ぐじょう /郡上/
ぐじょうはちまん /郡上八幡/
ぐすくべ /城辺/
ぐず /愚図/
ぐせ /癖/
ぐせい /愚生/
ぐそく /具足/愚息/
ぐたい /具体/
ぐたいあん /具体案/
ぐたいか /具体化/具体化 /
ぐたいけい /具体形/
ぐたいこうどう /具体行動/
ぐたいさく /具体策/
ぐたいせい /具体性/
ぐたいてき /具体的/
ぐたいてきいけん /具体的意見/
ぐたいてきがいねん /具体的概念/
ぐたいてきぎろん /具体的議論/
ぐたいてきこうい /具体的行為/
ぐたいてきこうどう /具体的行動/
ぐたいてきさぎょう /具体的作業/
ぐたいてきしゅだん /具体的手段/
ぐたいてきしゅほう /具体的手法/
ぐたいてきしょうこ /具体的証拠/
ぐたいてきしょうめい /具体的証明/
ぐたいてきじじつ /具体的事実/
ぐたいてきじれい /具体的事例/
ぐたいてきすうち /具体的数値/
ぐたいてきたいけん /具体的体験/
ぐたいてきたいけんだん /具体的体験談/
ぐたいてきたいしょう /具体的対象/
ぐたいてきていあん /具体的提案/
ぐたいてきないよう /具体的内容/
ぐたいてきへいがい /具体的弊害/
ぐたいてきほうほう /具体的方法/
ぐたいてきもんだい /具体的問題/
ぐたいてきれい /具体的例/
ぐたいれい /具体例/
ぐたいろん /具体論/
ぐち /口/愚痴/
ぐちょく /愚直/
ぐどん /愚鈍/
ぐねつむこう /グネツム綱/
ぐのう /愚能/
ぐのこっちょう /愚の骨頂/
ぐはん /虞犯/
ぐはんしゃ /虞犯者/
ぐび /具備/
ぐびじん /虞美人/
ぐびじんそう /虞美人草/
ぐふう /颶風/
ぐほう /求法/
ぐまい /愚昧/
ぐみ /組/茱/萸/グミ/
ぐみん /愚民/
ぐもん /愚問/
ぐらい /位/
ぐらいだー /グライダー/
ぐらうんど /グラウンド/
ぐらす /グラス/
ぐらふ /グラフ/
ぐらふぃくす /グラフィクス/
ぐらふぃっく /グラフィック/
ぐらみーしょう /グラミー賞/
ぐらむ /グラム/
ぐらんで /グランデ/
ぐらんど /グランド/
ぐり /栗/
ぐりーん /グリーン/
ぐりーんぴあ /グリーンピア/
ぐりこーげん /グリコーゲン/
ぐりせりん /グリセリン/
ぐりる /グリル/
ぐるーぷ /グループ/
ぐるーぷめい /グループ名/
ぐるーべくとる /グルーベクトル/
ぐるめ /グルメ/
ぐるり /周/
ぐれ /昏/
ぐれー /グレー/
ぐれーとぶりてん /大不列顛/
ぐれーぷ /グレープ/
ぐれい /グレイ/
ぐれつ /愚劣/
ぐれん /紅蓮/
ぐれんたい /愚連隊/
ぐれんな /紅蓮奈/
ぐれんなだいしきょう /紅蓮奈大司教/
ぐろ /黒/
ぐろーばる /グローバル/
ぐろう /愚弄/
ぐろん /愚論/
ぐわい /具合/
ぐん /群/軍/郡/羣/麕/
ぐんい /軍医/
ぐんいち /軍一/
ぐんえい /群栄/軍営/
ぐんか /軍歌/群化/
ぐんかく /軍拡/
ぐんかくしゅぎしゃ /軍拡主義者/
ぐんかん /軍艦/軍鑑/
ぐんかんき /軍艦旗/
ぐんかんく /軍管区/
ぐんかんけい /軍関係/
ぐんかんぶ /軍艦部/
ぐんがくたい /軍楽隊/
ぐんき /軍旗/軍機/軍紀/軍規/
ぐんきしゅくせい /軍規粛正/
ぐんきょ /群居/
ぐんけ /郡家/
ぐんこう /軍港/
ぐんこく /軍国/
ぐんこくしゅぎ /軍国主義/
ぐんこくしゅぎしゃ /軍国主義者/
ぐんさい /軍才/
ぐんさんふくごうたい /軍産複合体/
ぐんし /軍士/軍師/軍史/
ぐんしきん /軍資金/
ぐんしけい /軍師型/
ぐんしゅう /群衆/群集/群聚/
ぐんしゅく /軍縮/
ぐんしん /軍神/
ぐんじ /郡司/軍事/軍二/群司/
ぐんじえんじょ /軍事援助/
ぐんじかいにゅう /軍事介入/
ぐんじかがく /軍事科学/
ぐんじかんけい /軍事関係/
ぐんじきみつ /軍事機密/
ぐんじきょういく /軍事教育/
ぐんじこうどう /軍事行動/
ぐんじさんぎょう /軍事産業/
ぐんじしょうとつ /軍事衝突/
ぐんじしんりゃく /軍事侵略/
ぐんじじょうしき /軍事常識/
ぐんじせんもんか /軍事専門家/
ぐんじそしき /軍事組織/
ぐんじそち /軍事措置/
ぐんじたいこく /軍事大国/
ぐんじてき /軍事的/
ぐんじてきやしん /軍事的野心/
ぐんじてきりゆう /軍事的理由/
ぐんじひ /軍事費/
ぐんじほうてい /軍事法廷/
ぐんじもくてき /軍事目的/
ぐんじゅ /軍需/
ぐんじゅこうじょう /軍需工場/
ぐんじゅさんぎょう /軍需産業/
ぐんじゅひん /軍需品/
ぐんじょう /群青/
ぐんじょうしょく /群青色/
ぐんじよう /軍事用/
ぐんじようびちく /軍事用備蓄/
ぐんじりょく /軍事力/
ぐんじん /軍人/
ぐんじんしゅくしゃ /軍人宿舎/
ぐんじんしょうぎ /軍人将棋/
ぐんすう /群数/
ぐんせい /群生/軍政/
ぐんぜい /軍勢/
ぐんぜさんぎょう /グンゼ産業/
ぐんぜんたい /群全体/
ぐんそう /軍曹/
ぐんそうどの /軍曹殿/
ぐんそくど /群速度/
ぐんそしき /軍組織/
ぐんぞう /群像/
ぐんぞく /軍属/
ぐんたい /軍隊/群体/
ぐんたいしき /軍隊式/
ぐんたいはけん /軍隊派遣/
ぐんたいむとうせい /軍隊無統制/
ぐんだい /群大/
ぐんだいじょうほう /群大情報/
ぐんだり /軍荼利/
ぐんだん /軍団/群団/
ぐんだんこうそう /軍団抗争/
ぐんだんちょう /軍団長/
ぐんだんらいしゅう /軍団来襲/
ぐんちえん /群遅延/
ぐんちゅうおう /軍中央/
ぐんちょう /軍長/
ぐんて /軍手/
ぐんてい /軍偵/
ぐんていすう /群定数/
ぐんとう /群島/
ぐんない /郡内/
ぐんば /軍馬/
ぐんばい /軍配/
ぐんばつ /軍閥/
ぐんぱつ /群発/
ぐんぱつじしん /群発地震/
ぐんび /軍備/
ぐんびかくだい /軍備拡大/
ぐんぶ /郡部/群舞/軍部/
ぐんぷく /軍服/
ぐんぽうかいぎ /軍法会議/
ぐんま /群馬/
ぐんまけん /群馬県/
ぐんまけんあづません /群馬県吾妻線/
ぐんまけんおおいずみちょう /群馬県大泉町/
ぐんまけんきりゅうし /群馬県桐生市/
ぐんまけんしゅっしん /群馬県出身/
ぐんまけんじん /群馬県人/
ぐんまだい /群馬大/
ぐんまだいがく /群馬大学/
ぐんまだいがくいん /群馬大学院/
ぐんまちょう /群馬町/
ぐんみん /軍民/
ぐんむきょくちょう /軍務局長/
ぐんめいれい /軍命令/
ぐんもう /群盲/
ぐんもん /軍門/
ぐんゆう /群雄/
ぐんゆうかっきょ /群雄割拠/
ぐんよう /軍用/
ぐんようき /軍用機/
ぐんようしゃ /軍用車/
ぐんようろうむしゃ /軍用労務者/
ぐんらく /群落/
ぐんりゅうせい /群流星/
ぐんれい /軍令/
ぐんれいぶ /軍令部/
ぐんれいぶそうちょう /軍令部総長/
ぐんれいぶちょう /軍令部長/
ぐんろん /群論/
ぐんろんにゅうもん /群論入門/
け /家/毛/化/卦/怪/祁/袈/気/ヶ/ケ/仮/花/假/恠/氣/乖/懸/迦/褻/華/掛/
けーき /ケーキ/
けーす /ケース/
けーぶる /ケーブル/
けあがり /蹴上がり/
けあげ /蹴上/
けあな /毛穴/
けい /系/形/計/型/軽/恵/継/兄/経/傾/景/警/敬/慶/蛍/携/圭/掲/桂/啓/繋/渓/鶏/頚/掛/詣/慧/係/茎/荊/罫/畦/痙/稽/憩/径/刑/契/珪/佳/ケイ/楔/脛/蹊/兮/冂/冏/剄/勁/勍/匸/夐/奎/奚/彑/徑/惠/憇/憬/挂/挈/攜/枅/檠/溪/炯/烱/煢/瓊/盻/硅/磬/笄/絅/經/綮/繼/莖/螢/謦/谿/輕/迥/逕/醯/頸/鷄/黥/馨/京/競/卿/境/鮭/頃/閨/
けい#まい /計#1枚/計#2枚/計#3枚/計#4枚/
けい> /計/
けいあい /敬愛/
けいあつ /傾圧/
けいあつたいき /傾圧大気/
けいあつふあんていじょうらん /傾圧不安定擾乱/
けいい /経緯/敬意/慶伊/軽易/慶弔/
けいいち /恵一/啓一/圭一/慶一/敬一/佳一/桂一/蛍一/螢一/
けいいちろう /敬一郎/啓一郎/圭一朗/圭一郎/
けいいど /経緯度/
けいいん /契印/
けいえい /経営/
けいえいあっか /経営悪化/
けいえいかんり /経営管理/
けいえいがく /経営学/
けいえいがくしょう /経済学賞/
けいえいがくぶ /経営学部/
けいえいがくるい /経営学類/
けいえいがっか /経営学科/
けいえいがわ /経営側/
けいえいきかくしつ /経営企画室/
けいえいきき /経営危機/
けいえいきぼ /経営規模/
けいえいけい /経営系/
けいえいけん /経営権/
けいえいこうがく /経営工学/
けいえいこうがくかいいん /経営工学会員/
けいえいこうがくこうざ /経営工学講座/
けいえいこうがっか /経営工学科/
けいえいしげん /経営資源/
けいえいしゃ /経営者/
けいえいしゃがわ /経営者側/
けいえいじょう /経営上/
けいえいじょうたい /経営状態/
けいえいじん /経営陣/
けいえいせんりゃく /経営戦略/
けいえいたい /経営体/
けいえいたいしつ /経営体質/
けいえいてき /経営的/
けいえいてきかんてん /経営的観点/
けいえいとうけいがく /経営統計学/
けいえいどりょく /経営努力/
けいえいなん /経営難/
けいえいぶんや /経営分野/
けいえいほうしん /経営方針/
けいえいぼたい /経営母体/
けいえん /敬遠/
けいえんさく /敬遠策/
けいおう /慶應/慶応/京王/
けいおういなだつつみ /京王稲田堤/
けいおうかく /京王閣/
けいおうかんきょうじょうほう /慶應環境情報/
けいおうぎじゅく /慶応義塾/慶應義塾/
けいおうぎじゅくじょし /慶應義塾女子/
けいおうぎじゅくだい /慶應義塾大/慶応義塾大/
けいおうぎじゅくだいがく /慶應義塾大学/慶応義塾大学/
けいおうぐち /京王口/
けいおうけいそく /慶應計測/慶応計測/
けいおうこうがくかい /慶應工学会/
けいおうしょうがくぶ /慶応商学部/
けいおうしょうなんふじさわ /慶應湘南藤沢/
けいおうしんじゅく /京王新宿/
けいおうしんじゅくえき /京王新宿駅/
けいおうしんせん /京王新線/
けいおうせい /慶應生/
けいおうせん /京王線/
けいおうせんえんせん /京王線沿線/
けいおうせんしんじゅく /京王線新宿/
けいおうそうごうせいさく /慶應総合政策/
けいおうたま /京王多摩/
けいおうだい /慶応大/慶應大/
けいおうだいがく /慶応大学/慶應大学/
けいおうだいふじさわ /慶應大藤沢/慶応大藤沢/
けいおうだいぶつりか /慶應大物理科/
けいおうていと /京王帝都/
けいおうていとでんてつ /京王帝都電鉄/
けいおうはい /京王杯/
けいおうはちおうじ /京王八王子/
けいおうひよし /慶應日吉/慶応日吉/
けいおうびん /京王便/
けいおうふじさわ /慶応藤沢/慶應藤沢/
けいおうみた /慶應三田/
けいおうやがみ /慶應矢上/
けいおうりこう /慶応理工/
けいおうりこうがくぶ /慶応理工学部/
けいおん /軽音/
けいおんがく /軽音楽/軽音楽部/
けいおんがくぶ /軽音楽部/
けいおんき /警音器/
けいか /経過/計科/軽過/桂花/京華/圭花/
けいかい /警戒/軽快/
けいかいかん /軽快感/
けいかいくいき /警戒区域/
けいかいしょく /警戒色/
けいかいしん /警戒心/
けいかいそうち /警戒装置/
けいかいたいせい /警戒態勢/
けいかいでんしゃ /軽快電車/
けいかおん /経過音/
けいかかんさつ /経過観察/
けいかきろく /経過記録/
けいかく /計画/形覚/経過句/計畫/
けいかくけいざいか /計画経済下/
けいかくけんきゅうじょ /計画研究所/
けいかくしつ /計画室/
けいかくしょ /計画書/
けいかくじ /計画時/
けいかくじつげんじてん /計画実現時点/
けいかくじょうきょう /計画状況/
けいかくせい /計画性/
けいかくせん /計画線/
けいかくだんかい /計画段階/
けいかくちゅう /計画中/
けいかくちゅうし /計画中止/
けいかくちょうしょ /計画調書/
けいかくてき /計画的/
けいかくとうさん /計画倒産/
けいかくにんしき /計画認識/
けいかくにんち /計画認知/
けいかくひょう /計画表/
けいかくぶ /計画部/
けいかくぶんべん /計画分娩/
けいかくほう /計画法/
けいかくろせんず /計画路線図/
けいかしゅだい /経過主題/
けいかしょうぎょう /京華商業/
けいかじかん /経過時間/
けいかじょし /京華女子/
けいかせつめい /経過説明/
けいかそち /経過措置/
けいかほうこく /経過報告/
けいかん /警官/景観/頚管/
けいかんたい /警官隊/
けいかんたち /警官達/
けいかんもの /警官物/
けいが /慶賀/
けいがい /形骸/謦咳/
けいがいぎんが /系外銀河/
けいがく /啓学/
けいがくしゅっぱん /啓学出版/
けいがん /慧眼/炯眼/
けいき /景気/契機/継起/刑期/計器/圭樹/掲記/恵輝/
けいきかいふく /景気回復/
けいきかいふくまえ /景気回復前/
けいきざい /軽機材/
けいきち /啓吉/
けいきづけ /景気付け/
けいきどう /経気道/
けいきひこう /計器飛行/
けいきゅう /京急/
けいきゅうかまたえき /京急蒲田駅/
けいきゅうかみおおおか /京急上大岡/
けいきゅうくうこうせん /京急空港線/
けいきゅうくりはまえき /京急久里浜駅/
けいきゅうせん /京急線/
けいきゅうせんない /京急線内/
けいきゅうちょうきょり /京急長距離/
けいきょ /軽挙/
けいきょう /景況/
けいきんぞく /軽金属/
けいく /警句/
けいくうぼ /軽空母/
けいぐ /敬具/
けいけつびょう /壊血病/
けいけん /経験/敬虔/經驗/
けいけんあり /経験有/
けいけんしき /経験式/
けいけんしゃ /経験者/
けいけんしゃだん /経験者談/
けいけんしゃゆうぐう /経験者優遇/
けいけんしゅぎてき /経験主義的/
けいけんじょう /経験上/
けいけんずみ /経験済/
けいけんそく /経験則/
けいけんだん /経験談/
けいけんち /経験値/
けいけんちぶそく /経験値不足/
けいけんてき /経験的/
けいけんてきじじつ /経験的事実/
けいけんてきにんしき /経験的認識/
けいけんてん /経験点/
けいけんねんすう /経験年数/
けいけんば /経験馬/
けいけんぶそく /経験不足/
けいけんほうふ /経験豊富/
けいげん /軽減/
けいげんか /軽減化/
けいこ /恵子/佳子/圭子/景子/稽古/桂子/啓子/慶子/蛍子/奎子/敬子/華子/
けいこう /傾向/携行/蛍光/螢光/経口/馨香/
けいこうかん /蛍光管/
けいこうがくえん /啓光学園/
けいこうぎょう /軽工業/
けいこうざい /蛍光剤/
けいこうしきそ /蛍光色素/
けいこうしょく /蛍光色/
けいこうせんしょく /蛍光染色/
けいこうぞうはくざい /蛍光増白剤/
けいこうたい /蛍光体/
けいこうたいなど /蛍光体等/
けいこうとう /蛍光灯/螢光灯/蛍光燈/
けいこうとうか /蛍光灯下/
けいこうとうよ /経口投与/
けいこうとりょう /蛍光塗料/
けいこうはちょう /蛍光波長/
けいこうひにんやく /経口避妊薬/
けいこうめん /蛍光面/
けいこく /警告/渓谷/溪谷/谿谷/
けいこくおん /警告音/
けいこくきじ /警告記事/
けいこくそうち /警告装置/
けいこくてつどう /渓谷鉄道/
けいこくとう /警告灯/警告燈/
けいこくぶん /警告文/
けいこごと /稽古事/
けいこしょにち /稽古初日/
けいこつ /頚骨/脛骨/
けいこつけっせつ /脛骨結節/
けいこねっしん /稽古熱心/
けいこば /稽古場/
けいこび /稽古日/
けいご /敬語/警護/圭悟/啓吾/
けいごう /契合/
けいごうきん /軽合金/
けいごしゃ /警護車/
けいごよう /警護用/
けいさい /掲載/
けいさいかろんぶん /掲載可論文/
けいさいきぼうしゃ /掲載希望者/
けいさいきょか /掲載許可/
けいさいこうもく /掲載項目/
けいさいごう /掲載号/
けいさいさくひん /掲載作品/
けいさいざっし /掲載雑誌/
けいさいざっしめい /掲載雑誌名/
けいさいし /掲載誌/
けいさいしめい /掲載誌名/
けいさいしゃ /掲載者/
けいさいじ /掲載時/
けいさいじゅん /掲載順/
けいさいちゅう /掲載中/
けいさいないようふめい /掲載内容不明/
けいさいねんがっぴ /掲載年月日/
けいさいはんい /掲載範囲/
けいさいぶん /掲載分/
けいさいほうほう /掲載方法/
けいさいよてい /掲載予定/
けいさぎょう /軽作業/
けいさく /啓作/
けいさつ /警察/
けいさついがい /警察以外/
けいさつかん /警察官/
けいさつかんけい /警察関係/
けいさつかんけいしゃ /警察関係者/
けいさつがっこう /警察学校/
けいさつがわ /警察側/
けいさつぎょう /警察業/
けいさつぎょうむ /警察業務/
けいさつしゃりょう /警察車両/
けいさつしょ /警察署/
けいさつしょちょう /警察署長/
けいさつだいがっこう /警察大学校/
けいさつちょう /警察庁/
けいさつてちょう /警察手帳/
けいさつび /警察曰/
けいさつほんぶ /警察本部/
けいさつむせん /警察無線/
けいさつや /警察屋/
けいさつようご /警察用語/
けいさつようじどうしゃ /警察用自動車/
けいさつりょく /警察力/
けいさん /計算/珪酸/経産/
けいさんかがく /計算科学/
けいさんかがくせんこう /計算科学専攻/
けいさんかてい /計算過程/
けいさんかのう /計算可能/
けいさんかのうせい /計算可能性/
けいさんがいねん /計算概念/
けいさんき /計算機/
けいさんきいがい /計算機以外/
けいさんきえんしゅう /計算機演習/
けいさんきおんがく /計算機音楽/
けいさんきかい /計算機械/
けいさんきかいはつ /計算機開発/
けいさんきかいろ /計算機回路工学/
けいさんきかいろこうがく /計算機回路工学/
けいさんきかがく /計算機科学/計算幾何学/
けいさんきかがくしゃ /計算機科学者/
けいさんきかがっか /計算機科学科/
けいさんきかんきょう /計算機環境/
けいさんきかんけい /計算機関係/
けいさんきかんけいしゃ /計算機関係者/
けいさんきかんり /計算機管理/
けいさんきかんりしゃ /計算機管理者/
けいさんきかんれん /計算機関連/
けいさんきがく /計算機学/
けいさんきがくしゅうりろん /計算機学習理論/
けいさんきがっか /計算機学科/
けいさんきがわ /計算機側/
けいさんききょういく /計算機教育/
けいさんきぎじゅつ /計算機技術/
けいさんきぎょうかい /計算機業界/
けいさんきけん /計算機研/
けいさんきけんきゅうしつ /計算機研究室/
けいさんきげんご /計算機言語/
けいさんきげんごがく /計算機言語学/
けいさんきこう /計算機構/
けいさんきこうがく /計算機工学/
けいさんきこうせい /計算機構成/
けいさんきしげん /計算機資源/
けいさんきしつ /計算機室/
けいさんきしょり /計算機処理/
けいさんきしようりょう /計算機使用料/
けいさんきじたい /計算機自体/
けいさんきじっしゅう /計算機実習/
けいさんきじっしゅうよう /計算機実習用/
けいさんきじょう /計算機上/
けいさんきせいぎょ /計算機制御/
けいさんきそうご /計算機相互/
けいさんきそく /計算規則/
けいさんきない /計算機内/
けいさんきないぶ /計算機内部/
けいさんきのう /計算機能/
けいさんきぼ /計算規模/
けいさんきや /計算機屋/
けいさんきよう /計算機用/
けいさんきりよう /計算機利用/
けいさんぎ /計算木/
けいさんぎじゅつ /計算技術/
けいさんけい /計算系/
けいさんけっか /計算結果/
けいさんけっかひょうじ /計算結果表示/
けいさんげんごがく /計算言語学/
けいさんこうい /計算行為/
けいさんこうがくせんこう /計算工学専攻/
けいさんこうりつ /計算効率/
けいさんこんきょ /計算根拠/
けいさんご /計算後/
けいさんしき /計算式/
けいさんしつ /計算室/
けいさんしゃ /計算者/
けいさんしょ /計算書/
けいさんしょり /計算処理/
けいさんじ /計算時/
けいさんじかん /計算時間/
けいさんじゃく /計算尺/
けいさんじょう /計算上/
けいさんじょうけん /計算条件/
けいさんすうがく /計算数学/
けいさんせい /計算性/
けいさんせいど /計算精度/
けいさんそくど /計算速度/
けいさんだい /京産大/
けいさんち /計算値/
けいさんちゅう /計算中/
けいさんてき /計算的/
けいさんてきしょがいねん /計算的諸概念/
けいさんてじゅん /計算手順/
けいさんのうりょく /計算能力/
けいさんぶつりがく /計算物理学/
けいさんぷ /経産婦/
けいさんほう /計算法/
けいさんほうしき /計算方式/
けいさんほうほう /計算方法/
けいさんもんだい /計算問題/
けいさんや /計算屋/
けいさんよう /計算用/
けいさんりきがく /計算力学/
けいさんりきがくけんきゅう /計算力学研究/
けいさんりょう /計算量/
けいさんりょうりろん /計算量理論/
けいさんりょく /計算力/
けいさんりろん /計算理論/
けいさんれい /計算例/
けいさんれつ /計算列/
けいさんれんしゅう /計算練習/
けいさんろん /計算論/
けいさんろんてきがくしゅう /計算論的学習/
けいさんろんりがく /計算論理学/
けいざい /経済/
けいざいいぞん /経済依存/
けいざいえんじょ /経済援助/
けいざいか /経済化/
けいざいかい /経済界/
けいざいかつどう /経済活動/
けいざいかんけい /経済関係/
けいざいがく /経済学/
けいざいがくかんれん /経済学関連/
けいざいがくしゃ /経済学者/
けいざいがくせんこう /経済学専攻/
けいざいがくてき /経済学的/
けいざいがくぶ /経済学部/
けいざいがくぶせい /経済学部生/
けいざいがっか /経済学科/
けいざいきかくちょう /経済企画庁;2001年1月の中央省庁再編で内閣府に再編された/
けいざいきぼ /経済規模/
けいざいけんきゅうしょ /経済研究所/
けいざいげんろん /経済原論/
けいざいこうか /経済効果/
けいざいこうぞう /経済構造/
けいざいこうりつ /経済効率/
けいざいさんぎょうしょう /経済産業省;通商産業省と科学技術庁が2001年1月の中央省庁再編で再編されたもの/
けいざいざっし /経済雑誌/
けいざいし /経済誌/
けいざいしんりゃく /経済侵略/
けいざいじょう /経済上/
けいざいじょうたい /経済状態/
けいざいじょうふり /経済上不利/
けいざいじん /経済人/
けいざいせい /経済性/
けいざいせいさい /経済制裁/
けいざいせいさく /経済政策/
けいざいせいちょう /経済成長/
けいざいせかい /経済世界/
けいざいそくていがく /経済測定学/
けいざいたいこく /経済大国/
けいざいたいこくにっぽん /経済大国日本/
けいざいちょう /経済庁/
けいざいてき /経済的/
けいざいてきあつりょく /経済的圧力/
けいざいてきいぞん /経済的依存/
けいざいてきえんじょ /経済的援助/
けいざいてきかち /経済的価値/
けいざいてきかんきょう /経済的環境/
けいざいてきかんてん /経済的観点/
けいざいてききばん /経済的基盤/
けいざいてきこうか /経済的効果/
けいざいてきしさん /経済的資産/
けいざいてきじじょう /経済的事情/
けいざいてきじりつ /経済的自立/
けいざいてきそんがい /経済的損害/
けいざいてきどくりつ /経済的独立/
けいざいてきはってん /経済的発展/
けいざいてきひつようせい /経済的必要性/
けいざいてきふたん /経済的負担/
けいざいてきほうほう /経済的方法/
けいざいてきよゆう /経済的余裕/
けいざいてきりえき /経済的利益/
けいざいてきりゆう /経済的理由/
けいざいとうけい /経済統計/
けいざいはってん /経済発展/
けいざいふうさ /経済封鎖/
けいざいふっこう /経済復興/
けいざいぶ /経済部/
けいざいめん /経済面/
けいざいもんだい /経済問題/
けいざいらん /経済欄/
けいざいりじゅん /経済利潤/
けいざいりょく /経済力/
けいざいりろんじょう /経済理論上/
けいざいれん /経済連/
けいざいろん /経済論/
けいざぶろう /啓三郎/
けいし /軽視/圭司/罫紙/警視/啓史/景士/圭史/啓示/
けいしき /形式/型式/
けいしきいがい /形式以外/
けいしきおんがくろん /形式音楽論/
けいしきか /形式化/
けいしきかん /形式感/
けいしききじゅつ /形式記述/
けいしきけい /形式系/
けいしきけんさ /型式検査/
けいしきげんご /形式言語/
けいしきげんごりろん /形式言語理論/
けいしきしてい /形式指定/
けいしきしゅぎ /形式主義/
けいしきしゅぎてき /形式主義的/
けいしきしゅほう /形式手法/
けいしきしよう /形式仕様/
けいしきじたい /形式自体/
けいしきじょう /形式上/
けいしきすう /形式数/
けいしきず /形式図/
けいしきせい /形式性/
けいしきたいけい /形式体系/
けいしきてき /形式的/
けいしきてきいみろん /形式的意味論/
けいしきてきかいはつほう /形式的開発法/
けいしきてきくんれん /形式的訓練/
けいしきてきげんご /形式的言語/
けいしきてきしゅほう /形式的手法/
けいしきてきしょうめいたいけい /形式的証明体系/
けいしきてきしよう /形式的仕様/
けいしきてきそうさ /形式的操作/
けいしきてきたいけい /形式的体系/
けいしきてきほうほう /形式的方法/
けいしきてきりろん /形式的理論/
けいしきにんてい /型式認定/形式認定/
けいしきばんごう /形式番号/型式番号/
けいしきび /形式美/
けいしきぶんぽう /形式文法/
けいしきへんかん /形式変換/
けいしきへんこう /形式変更/
けいしきべつ /形式別/
けいしきめい /形式名/
けいしきろん /形式論/
けいしきろんり /形式論理/
けいしきろんりてき /形式論理的/
けいしちょう /警視庁/
けいしつ /軽質/形質/
けいしついでん /形質遺伝/
けいしつゆ /軽質油/
けいしゃ /傾斜/
けいしゃかく /傾斜角/
けいしゃち /傾斜地/
けいしゃてき /傾斜的/
けいしゃほうこう /傾斜方向/
けいしゃめん /傾斜面/
けいしゃりょう /軽車両/
けいしゅう /閨秀/慶周/慶州/
けいしゅく /慶祝/痙縮/
けいしゅつ /掲出/
けいしょう /継承/敬称/形象/景勝/警鐘/軽傷/軽症/
けいしょうかいそう /継承階層/
けいしょうかんけい /継承関係/
けいしょうきのう /継承機能/
けいしょうけん /継承権/
けいしょうこうせい /継承構成/
けいしょうしゃ /継承者/
けいしょうじゅんい /継承順位/
けいしょうせい /継承性/
けいしょうぞくせい /継承属性/
けいしょうち /景勝地/
けいしょうりゃく /敬称略/敬省略/
けいしょく /軽食/
けいしょくや /軽食屋/
けいしん /軽震/京神/敬信/京津/恵信/茎針/
けいしんこくどう /京津国道/
けいしんせん /京津線/
けいしんでんききどう /京津電気軌道/
けいじ /掲示/刑事/計時/圭二/経時/敬司/啓司/啓二/慶治/敬二/啓示/形而/桂治/継時/恵司/啓治/圭司/慶事/敬治/圭児/啓次/景示/
けいじがわ /刑事側/
けいじきかん /掲示期間/
けいじこくそ /刑事告訴/
けいじしょぶん /刑事処分/
けいじじけん /刑事事件/
けいじじょう /形而上/刑事上/
けいじじょうがく /形而上学/
けいじじょうがくてき /形而上学的/
けいじすう /掲示数/
けいじそしょう /刑事訴訟/
けいじそしょうほう /刑事訴訟法/
けいじちゅう /掲示中/
けいじてき /経時的/継時的/刑事的/
けいじてつづき /刑事手続/
けいじどうしゃ /軽自動車/
けいじどうしゃきょうかい /軽自動車協会/
けいじどうしゃぜい /軽自動車税/
けいじどうしゃめんきょ /軽自動車免許/
けいじどうしゃわく /軽自動車枠/
けいじはん /刑事犯/
けいじばつ /刑事罰/
けいじばん /掲示板/掲示版/
けいじばんごう /掲示番号/
けいじへんか /経時変化/
けいじべんごにん /刑事弁護人/
けいじますきんぐ /継時マスキング/
けいじもの /刑事物/
けいじやく /刑事役/
けいじゅ /圭樹/
けいじゅん /軽巡/
けいじゅんようせんかん /軽巡洋戦艦/
けいじょう /形状/計上/経常/啓上/京城/
けいじょうけいそく /形状計測/
けいじょうけってい /形状決定/
けいじょうけんきゅう /経常研究/
けいじょうごさ /形状誤差/
けいじょうてき /形状的/
けいじょうにんしき /形状認識/
けいじょうひ /経常費/
けいじょうめい /形状名/
けいじょうようしゃ /軽乗用車/
けいじょうりえき /経常利益/
けいじょうりえきりつ /経常利益率/
けいじよう /掲示用/
けいじろう /圭次郎/圭二郎/慶次郎/啓二郎/恵二郎/啓次朗/
けいす /ケイス/磬子;お堂の中で置いて使う鐘/
けいすい /軽水/型推/
けいすいりんどう /軽水林道/
けいすいろ /軽水炉/
けいすう /係数/計数/計數/
けいすうかん /計数管/
けいすうかんかく /計数感覚;利益感覚/
けいすうき /計数器/
けいすうぎょうれつ /係数行列/
けいすうぎょうれつしき /係数行列式/
けいすうぐん /係数群/
けいすうこうがくか /計数工学科/
けいすうこうがくせんこう /計数工学専攻/
けいすうこうがっか /計数工学科/
けいすうたい /係数体/
けいすうち /係数値/
けいすうひょうじ /計数表示/
けいすうりつ /計数率/
けいすけ /敬介/佳祐/啓助/桂輔/圭介/啓介/慶裕/慶輔/啓典/啓輔/圭祐/佳佑/啓祐/惠介/景介/
けいず /系図/
けいずい /頸髄/
けいずかい /系図買/窩主買/
けいせい /形成/京成/形勢/傾城/形声/
けいせいうえの /京成上野/
けいせいえんせん /京成沿線/
けいせいおおくぼえき /京成大久保駅/
けいせいおしあげ /京成押上/
けいせいかてい /形成過程/
けいせいき /形成期/
けいせいげんりょう /形成原料/
けいせいしゃ /形成者/
けいせいしゅだん /形成手段/
けいせいせきや /京成関屋/
けいせいせん /京成線/
けいせいせんない /京成線内/
けいせいそう /形成層/
けいせいたかさご /京成高砂/
けいせいちば /京成千葉/
けいせいつだぬま /京成津田沼/
けいせいでんてつ /京成電鉄/
けいせいなりた /京成成田/
けいせいはい /京成杯/
けいせいはんだん /形勢判断/
けいせいふなばし /京成船橋/
けいせいほう /形成法/
けいせいほうしき /形成方式/
けいせいほうほう /形成方法/
けいせいほんしゃ /京成本社/
けいせいほんせん /京成本線/
けいせいもじ /形声文字/
けいせいりょく /形成力/
けいせき /形跡/
けいせきくっせつ /蛍石屈折/
けいせつ /蛍雪/螢雪/
けいせん /┴/罫線/┤/┘/┼/┬/└/├/┐/─/│/┌/━/┃/┏/┓/┛/┗/┣/┳/┫/┻/╋/┠/┯/┨/┷/┿/┝/┰/┥/┸/╂/経線/繋船/係船/恵泉/
けいせんきのう /罫線機能/
けいせんしゃ /軽戦車/
けいせんそへん /罫線素片/
けいせんそへんなど /罫線素片等/
けいせんたようぶんしょ /罫線多用文書/
けいせんへんしゅう /罫線編集/
けいせんもじ /罫線文字/
けいせんようそ /罫線要素/
けいせんわく /罫線枠/
けいそ /形素/硅素/ケイ素/珪素/
けいそう /軽装/係争/計装/珪藻/慶早/勁草/
けいそうしょぼう /勁草書房/
けいそうじこう /係争事項/
けいそうせん /慶早戦/
けいそうちゅう /係争中/
けいそく /計測/
けいそくかのう /計測可能/
けいそくき /計測器/計測機/
けいそくぎけん /計測技研/
けいそくこうがっか /計測工学科/
けいそくしゃ /計測者/
けいそくしゅほう /計測手法/
けいそくじ /計測時/
けいそくじどうせいぎょ /計測自動制御/
けいそくじどうせいぎょがっかい /計測自動制御学会/
けいそくち /計測値/
けいそくちてん /計測地点/
けいそくてん /計測点/
けいそくど /計速度/
けいそくふかのう /計測不可能/
けいそくほう /計測法/
けいそくほうほう /計測方法/
けいそくよう /計測用/
けいそくようぞうふくき /計測用増幅器/
けいそくりょう /計測量/
けいそくりろん /計測理論/
けいそつ /軽率/輕率/
けいぞう /敬三/佳三/啓三/恵三/恵贈/形像/経三/慶三/恵造/圭三/
けいぞく /継続/繼續/
けいぞくかのう /継続可能/
けいぞくきんむ /継続勤務/
けいぞくぎょう /継続行/
けいぞくけんさ /継続検査/
けいぞくご /継続後/
けいぞくしよう /継続使用/
けいぞくしんせい /継続申請/
けいぞくじかん /継続時間/
けいぞくじかんちょう /継続時間長/
けいぞくせい /継続性/
けいぞくちゅう /継続中/
けいぞくてき /継続的/
けいぞくとうこう /継続投稿/
けいぞくぶん /継続分/
けいぞくぶんれつざんぶ /継続分裂残部/
けいぞくりつ /継続率/
けいぞん /桂損/
けいた /慶太/圭太/
けいたい /形態/携帯/敬体/
けいたいか /携帯化/
けいたいがく /形態学/
けいたいがた /携帯型/
けいたいがたほちょうき /携帯型補聴器/
けいたいけいせい /形態形成/
けいたいじたい /形態自体/
けいたいせい /携帯性/
けいたいそ /形態素/
けいたいそかいせき /形態素解析/
けいたいそかいせきぶ /形態素解析部/
けいたいてき /形態的/
けいたいでんわ /携帯電話/
けいたいはいざら /携帯灰皿/
けいたいひん /携帯品/
けいたいぶんか /形態分化/
けいたいへんか /形態変化/
けいたいもしゃ /形態模写/
けいたいよう /携帯用/
けいたいようはいざら /携帯用灰皿/
けいたいろん /形態論/
けいたいろんてき /形態論的/
けいたく /恵沢/
けいだ /慶田/
けいだい /慶大/掲題/境内/継代/
けいだいかんきょうじょうほう /慶大環境情報/
けいだいきょうじゅ /慶大教授/
けいだいしょうなんふじさわ /慶大湘南藤沢/
けいだいじょう /慶大情/
けいだいそうごうせいさく /慶大総合政策/
けいだいふじさわ /慶大藤沢/
けいだんれん /経団連/
けいちつ /啓蟄/
けいちゅう /傾注/
けいちょう /慶弔/傾聴/慶長/軽重/敬重/軽佻/茎頂/
けいちょうきん /慶弔金/
けいちょうじょうほう /慶弔情報/
けいちょうふはく /軽佻浮薄/
けいちょうぶんれつそしき /茎頂分裂組織/
けいつい /頚椎/
けいてい /兄弟/逕庭/係蹄/
けいていしゃ /兄弟車/
けいてき /警笛/
けいでんき /継電器/
けいと /毛糸/慶人/
けいとう /系統/傾倒/継投/鷄頭/
けいとううんよう /系統運用/
けいとうか /系統化/
けいとうぐん /系統群/
けいとうしっぱい /継投失敗/
けいとうじゅ /系統樹/
けいとうず /系統図/
けいとうせい /系統性/
けいとうてき /系統的/
けいとうてきぶんか /系統的分化/
けいとうてきぶんるい /系統的分類/
けいとうはっせい /系統発生/
けいとうばんごう /系統番号/
けいとうばんごうごと /系統番号毎/
けいとうべつ /系統別/
けいとうめい /系統名/
けいとうもんだい /系統問題/
けいとうれんけい /系統連系/
けいとうろん /系統論/
けいとくくうこう /啓徳空港/
けいとざんぐつ /軽登山靴/
けいとだま /毛糸玉/
けいとら /軽トラ/
けいとらっく /軽トラック/
けいど /経度/軽度/傾度/
けいどうみゃく /頚動脈/
けいどほうこう /経度方向/
けいない /系内/
けいなわ /京奈和/
けいなん /慶南/
けいにりん /軽二輪/
けいにりんしゃ /軽二輪車/
けいねん /経年/
けいねんへんか /経年変化/
けいねんれっか /経年劣化/
けいのじょう /蛍之丞/
けいはく /軽薄/敬白/
けいはくたんしょう /軽薄短小/
けいはくやろう /軽薄野郎/
けいはつ /啓発/
けいはん /京阪/
けいはんえんせん /京阪沿線/
けいはんかいつうまえ /京阪開通前/
けいはんがわ /京阪側/
けいはんきゅうこう /京阪急行/
けいはんけいれつ /京阪系列/
けいはんごじょうえき /京阪五条駅/
けいはんさんじょう /京阪三条/
けいはんざい /軽犯罪/
けいはんざいほう /軽犯罪法/
けいはんざいほういはん /軽犯罪法違反/
けいはんしん /京阪神/
けいはんしんちく /京阪神地区/
けいはんしんほうめん /京阪神方面/
けいはんじこくひょう /京阪時刻表/
けいはんせん /京阪線/
けいはんたんばばし /京阪丹波橋/
けいはんたんばばしえき /京阪丹波橋駅/
けいはんつうきん /京阪通勤/
けいはんでんしゃ /京阪電車/
けいはんでんてつ /京阪電鉄/
けいはんとっきゅう /京阪特急/
けいはんな /京阪奈/
けいはんならせん /京阪奈良線/
けいはんはい /京阪杯/
けいはんひゃっかてんまえ /京阪百貨店前/
けいはんほんせん /京阪本線/
けいはんゆいいつ /京阪唯一/
けいはんりようしゃ /京阪利用者/
けいば /競馬/
けいばうんえい /競馬運営/
けいばおう /競馬王/
けいばかい /競馬会/
けいばかいせつしゃ /競馬解説者/
けいばかんけい /競馬関係/
けいばかんけいしゃ /競馬関係者/
けいばぎょうかい /競馬業界/
けいばけんきゅう /競馬研究/
けいばしきほう /競馬四季報/
けいばしゅぎ /競馬主義/
けいばしょしんしゃ /競馬初心者/
けいばしんぶん /競馬新聞/
けいばじっきょう /競馬実況/
けいばじょう /競馬場/
けいばじょうまえ /競馬場前/
けいばせんもんし /競馬専門誌/競馬専門紙/
けいばせんよう /競馬専用/
けいばちゅうけい /競馬中継/
けいばつ /刑罰/閨閥/
けいばにんき /競馬人気/
けいばはくぶつかん /競馬博物館/
けいばばんぐみ /競馬番組/
けいばばんぐみひょう /競馬番組表/
けいばほう /競馬報/競馬法/
けいばほうち /競馬報知/
けいばよそう /競馬予想/
けいばれき /競馬歴/
けいひ /経費/桂皮/荊扉/
けいひこうき /軽飛行機/
けいひせつげん /経費節減/
けいひせつやく /経費節約/
けいひよさん /経費予算/
けいひん /京浜/景品/
けいひんおおみやせん /京浜大宮線/
けいひんかがく /景品価額/
けいひんかんきん /景品換金/
けいひんきたいき /京浜北行/
けいひんきたゆき /京浜北行/
けいひんきゅうこう /京浜急行/
けいひんきゅうこうえんせん /京浜急行沿線/
けいひんきゅうこうせん /京浜急行線/
けいひんきゅうこうでんてつ /京浜急行電鉄/
けいひんこうかん /景品交換/
けいひんこうかんじょ /景品交換所/
けいひんこうかんばしょ /景品交換場所/
けいひんずしえきがわ /京浜逗子駅側/
けいひんせん /京浜線/
けいひんちく /京浜地区/
けいひんでぐち /京浜出口/
けいひんとうほく /京浜東北/
けいひんとうほくせん /京浜東北線/
けいひんみなみいき /京浜南行/
けいひんみなみゆき /京浜南行/
けいび /警備/軽微/
けいびいん /警備員/
けいびしゃりょう /警備車両/
けいびじょう /警備上/
けいびたい /警備隊/
けいびたいいん /警備隊員/
けいびてい /警備艇/
けいびへい /警備兵/
けいびん /軽便/
けいびんてつどう /軽便鉄道/
けいふ /系譜/
けいふうまる /啓風丸/
けいふか /軽負荷/
けいふく /敬服/京福/
けいふくけいれつ /京福系列/
けいふくさが /京福嵯峨/
けいふくでんてつ /京福電鉄/
けいふず /系譜図/
けいふん /鶏糞/
けいぶ /軽侮/警部/頸部/頚部/
けいぶほ /警部補/
けいぶん /慶文/
けいぶんしゃ /勁分社/勁文社/
けいべつ /軽蔑/
けいべつてき /軽蔑的/
けいほう /警報/刑法/
けいほういはん /刑法違反/
けいほうおん /警報音/
けいほうかいじょ /警報解除/
けいほうき /警報機/
けいほうきよう /警報機用/
けいほうこう /径方向/
けいほうじょう /刑法上/
けいほうそうち /警報装置/
けいほく /京北/
けいほくせん /京北線/
けいぼ /継母/敬慕/
けいぼう /警棒/圭膀/閨房/
けいま /桂馬/
けいまい /兄妹/
けいみょう /軽妙/
けいむ /警務/
けいむいん /警務員/
けいむしょ /刑務所/
けいめい /啓明/経明/
けいめいがくえん /啓明学園/
けいめん /軽免/
けいめんきょ /軽免許/
けいもう /啓蒙/
けいもううんどう /啓蒙運動/
けいもうかつどう /啓蒙活動/
けいもうざっし /啓蒙雑誌/
けいもうしょ /啓蒙書/
けいもうてきかつどう /啓蒙的活動/
けいやく /契約/
けいやくか /契約課/
けいやくかいじょ /契約解除/
けいやくかんけい /契約関係/
けいやくきかん /契約期間/
けいやくきん /契約金/
けいやくこうかい /契約更改/
けいやくこうしょう /契約交渉/
けいやくご /契約後/
けいやくさき /契約先/
けいやくしゃ /契約者/
けいやくしゃいん /契約社員/
けいやくしょ /契約書/
けいやくじ /契約時/
けいやくじこう /契約事項/
けいやくじょう /契約上/
けいやくじょうかのう /契約上可能/
けいやくせい /契約制/
けいやくせいりつ /契約成立/
けいやくちゅう /契約中/
けいやくないよう /契約内容/
けいやくはき /契約破棄/
けいやくひ /契約費/
けいやくぶん /契約分/
けいやくほう /契約法/
けいやくほうほう /契約方法/
けいやくやっかん /契約約款/
けいやくりょう /契約料/契約量/
けいゆ /経由/軽油/
けいゆう /系由/経由/
けいゆうびん /経由便/
けいゆしゃ /軽油車/
けいゆぜい /軽油税/
けいゆち /経由地/
けいゆびん /経由便/
けいよ /恵与/
けいよう /京葉/形容/掲揚/繋養/
けいようかいそく /京葉快速/
けいようぐち /京葉口/
けいようご /形容語/
けいようし /形容詞/
けいようしてき /形容詞的/
けいようじ /掲揚時/
けいようせん /京葉線/
けいようせんくかん /京葉線区間/
けいようせんとうきょうえき /京葉線東京駅/
けいようせんない /京葉線内/
けいようせんまいはまえき /京葉線舞浜駅/
けいようとうきょう /京葉東京/
けいようどうし /形容動詞/
けいようどうろ /京葉道路/
けいようむじゅん /形容矛盾/
けいよんりん /軽四輪/
けいら /警邏/
けいらく /経絡/
けいらん /鶏卵/
けいり /経理/計理/
けいりか /経理課/経理掛/
けいりかちょう /経理課長/
けいりがかり /経理掛/経理係/
けいりきん /経理金/
けいりし /計理士/
けいりじょう /経理上/
けいりてき /経理的/
けいりひかえ /経理控/
けいりぶ /経理部/
けいりぶじょうほう /経理部情報/
けいりゃく /計略/経略/
けいりゅう /渓流/繋留/稽留/
けいりゅうおん /継留音/
けいりゅうざお /渓流竿/
けいりょう /計量/軽量/
けいりょうおんがくがく /計量音楽学/
けいりょうか /軽量化/計量化/
けいりょうき /計量器/
けいりょうきゅう /軽量級/
けいりょうけん /計量研/
けいりょうこうしゅつりょく /軽量高出力/
けいりょうじょうほう /計量情報/
けいりょうだいしゃ /軽量台車/
けいりょうてき /計量的/
けいりょうてんそる /計量テンソル/
けいりょうば /軽量馬/
けいりょうひんば /軽量牝馬/
けいりん /競輪/桂林/経綸/
けいりんおう /競輪王/
けいりんかい /競輪界/
けいりんじょう /競輪場/
けいりんせんしゅ /競輪選手/
けいりんどう /啓林堂/
けいるい /係累/繋累/
けいれい /敬礼/
けいれき /経歴/
けいれきしょ /経歴書/
けいれつ /系列/勁烈/
けいれつか /系列化/
けいれつかい /系列下位/
けいれつがいしゃ /系列会社/
けいれつきょく /系列局/
けいれつこうか /系列効果/
けいれつごさ /系列誤差/
けいれつしせつ /系列施設/
けいれつてき /系列的/
けいれつてん /系列店/
けいれつない /系列内/
けいれん /痙攣/
けいろ /経路/毛色/
けいろう /敬老/
けいろうどう /軽労働/
けいろがい /経路外/
けいろしてい /経路指定/
けいろじょう /経路上/
けいろじょうほう /経路情報/
けいろじょうほうこうかん /経路情報交換/
けいろすう /経路数/
けいろせいぎょ /経路制御/
けいろせきぶん /経路積分/
けいろせってい /経路設定/
けいろせんたく /経路選択/
けいろたんさく /経路探索/
けいろちょう /経路長/
けいろひょう /経路表/
けいろへんこう /経路変更/
けいわ /計和/
けう /希有/稀有/
けおり /毛織り/
けおりもの /毛織物/
けかえし /蹴返し/
けが /怪我/
けがに /毛蟹/
けがにん /怪我人/
けがれ /汚れ/穢/
けがわ /毛皮/
けがわや /毛皮屋/
けぎらい /毛嫌い/
けげん /怪訝/
けごん /華嚴/華厳/
けさ /今朝/袈裟/畩/
けさがた /今朝方/
けさき /毛先/
けさしゅっしゃまえ /今朝出社前/
けさほど /今朝程/
けし /芥子/消し/
けしいん /消印/
けしき /景色/気色/
けしこみ /消込/
けしごむ /消しゴム/
けしさる /消し去る/
けしもく /ケシ目/Papaverales/Rhoeadales/
けしもくぐん /ケシ目群/
けしょう /化粧/化生/
けしょういがい /化粧以外/
けしょうしつ /化粧室/
けしょうすい /化粧水/
けしょうばこ /化粧箱/
けしょうばん /化粧板/
けしょうひん /化粧品/
けしょうひんがいしゃ /化粧品会社/
けしょうひんはんばい /化粧品販売/
けしょうひんや /化粧品屋/
けしょうめん /化粧面/
けしん /化身/
けずね /毛脛/
けせん /気仙/
けせんぬま /気仙沼/
けそう /懸想/
けそうぶみ /懸想文/
けた /桁/
けたいち /桁位置/
けたおち /桁落ち/
けたか /気高/
けたぐり /蹴手繰り/
けたごと /桁毎/
けたすう /桁数/
けたすうぶん /桁数分/
けたはずれ /けた外れ/桁外れ/
けたひょうじ /桁表示/
けため /桁目/
けだし /蓋し/
けち /吝/ケチ/
けちょう /怪鳥/
けっか /結果/欠課/結跏/
けっかい /決壊/欠壊/決潰/結界/
けっかく /結核/欠格/
けっかくきん /結核菌/
けっかくじこう /欠格事項/
けっかご /結果後/
けっかさくせい /結果作成/
けっかさんしょう /結果参照/
けっかしき /結果式/
けっかしだい /結果次第/
けっかそくほう /結果速報/
けっかてき /結果的/
けっかはっぴょう /結果発表/
けっかはっぴょうご /結果発表後/
けっかはんてい /結果判定/
けっかふざ /結跏趺坐/
けっかほうこく /結果報告/
けっかほうこくきじ /結果報告記事/
けっかよそう /結果予想/
けっかりすと /結果リスト/
けっかろん /結果論/
けっかろんてき /結果論的/
けっかん /血管/欠陥/穴間/缺陷/
けっかんかくちょう /血管拡張/
けっかんしゃ /欠陥車/
けっかんしょうひん /欠陥商品/
けっかんない /血管内/
けっかんひん /欠陥品/
けっき /決起/血気/蹶起/
けっきゅう /血球/結球/
けっきょ /穴居/
けっきょく /結局/
けっきん /欠勤/
けっこう /結構/決行/血行/欠行/欠航/結好/
けっこうかいてき /結構快適/
けっこうかんたん /結構簡単/
けっこうこうか /結構高価/
けっこうごうか /結構豪華/
けっこうしぜん /結構自然/
けっこうしょうがい /血行障害/
けっこうたいへん /結構大変/
けっこうだいたん /結構大胆/
けっこうちょうほう /結構重宝/
けっこうひさん /結構悲惨/
けっこうび /決行日/
けっこうふべん /結構不便/
けっこうへいき /結構平気/
けっこうべんり /結構便利/
けっこうまえ /結構前/
けっこうむかし /結構昔/
けっこうめんどう /結構面倒/
けっこうわだい /結構話題/
けっこん /結婚/血痕/
けっこんあいて /結婚相手/
けっこんかん /結婚観/
けっこんきねん /結婚記念/
けっこんきねんび /結婚記念日/
けっこんご /結婚後/
けっこんさんぎょう /結婚産業/
けっこんしき /結婚式/
けっこんしきじょう /結婚式場/
けっこんしきん /結婚資金/
けっこんしょうかいじょ /結婚紹介所/
けっこんじ /結婚時/
けっこんじき /結婚時期/
けっこんせいかつ /結婚生活/
けっこんぜんご /結婚前後/
けっこんそうだんじょ /結婚相談所/
けっこんたいしょく /結婚退職/
けっこんたいしょくきてい /結婚退職規定/
けっこんたいしょくきん /結婚退職金/
けっこんてきれいき /結婚適齢期/
けっこんとうしょ /結婚当初/
けっこんねんれい /結婚年齢/
けっこんばなし /結婚話/
けっこんひよう /結婚費用/
けっこんひろうえん /結婚披露宴/
けっこんほうどう /結婚報道/
けっこんまえ /結婚前/
けっこんものがたり /結婚物語/
けっこんゆびわ /結婚指輪/
けっこんりつ /結婚率/
けっこんれき /結婚歴/
けっさい /決裁/決済/
けっさいしょ /決裁書/
けっさいび /決裁日/
けっさく /傑作/結紮/
けっさくしゅう /傑作集/
けっさくすいり /傑作推理/
けっさくせん /傑作選/傑作撰/
けっさくば /傑作馬/
けっさつ /結紮/
けっさん /決算/
けっさんい /決算委/
けっさんき /決算期/
けっさんしょ /決算書/
けっさんじょう /決算上/
けっさんひょう /決算表/
けっさんほうこく /決算報告/
けっさんほうこくしょ /決算報告書/
けっし /決死/血祀/
けっしきそ /血色素/
けっしたい /決死隊/
けっして /決して/
けっしゃ /結社/
けっしゅう /結集/
けっしゅつ /傑出/
けっしょう /決勝/結晶/血漿/結漿/血笑/血症/
けっしょうがた /結晶型/
けっしょうけい /結晶系/
けっしょうけっか /決勝結果/
けっしょうこうぞう /結晶構造/
けっしょうしゅうりょうご /決勝終了後/
けっしょうしんしゅつ /決勝進出/
けっしょうせかい /結晶世界/
けっしょうせき /結晶石/
けっしょうせん /決勝戦/
けっしょうたいかい /決勝大会/
けっしょうてん /決勝点/
けっしょうにってい /決勝日程/
けっしょうばん /血小板/
けっしょうばんゆけつ /血小板輸血/
けっしょうび /決勝日/
けっしょうぶんかくせいざい /血漿分画製剤/
けっしょうほんるいだ /決勝本塁打/
けっしょく /欠食/血色/
けっしょくじどう /欠食児童/
けっしん /決心/結審/
けっせい /結成/血清/
けっせいしき /結成式/
けっせいせいぶん /血清成分/
けっせいちゅうしゃ /血清注射/
けっせいりゆう /結成理由/
けっせき /欠席/結石/
けっせきしゃ /欠席者/
けっせきにっすう /欠席日数/
けっせつ /結節/
けっせん /結線/血栓/決戦/決選/決戰/血戦/
けっせんじ /結線時/
けっせんじょうほう /結線情報/
けっせんず /結線図/
けっせんたいかい /決戦大会/
けっせんとうひょう /決選投票/
けっせんへんあつき /結線変圧器/
けっそう /血相/
けっそく /結束/欠測/
けっそくりょく /結束力/
けっそん /欠損/
けっそんち /欠損値/
けったく /結託/
けっちゃく /結着/決着/
けっちゅう /血中/
けっちゅうさんそのうど /血中酸素濃度/
けっちょう /結腸/
けっちん /血沈/
けってい /決定/
けっていあん /決定案/
けっていかのう /決定可能/
けっていかのうせい /決定可能性/
けっていき /決定木/決定機/
けっていきこう /決定機構/
けっていきじゅん /決定基準/
けっていぎ /決定木/
けっていけい /決定系/
けっていけいすう /決定係数/
けっていけん /決定権/
けっていけんげん /決定権限/
けっていご /決定後/
けっていしえん /決定支援/
けっていしゃ /決定者/
けっていしゅほう /決定手法/
けっていじ /決定時/
けっていじこう /決定事項/
けっていじょうきょう /決定状況/
けっていせい /決定性/
けっていせん /決定戦/
けっていせんりゃく /決定戦略/
けっていだ /決定打/
けっていてき /決定的/
けっていてきしゅんかん /決定的瞬間/
けっていばん /決定版/決定番/
けっていひょう /決定表/
けっていふかのう /決定不可能/
けっていふかのうせい /決定不可能性/
けっていほう /決定法/
けっていほうしき /決定方式/
けっていほうほう /決定方法/
けっていもんだい /決定問題/
けっていりょく /決定力/
けっていろん /決定論/
けっていろんしゃ /決定論者/
けっていろんてき /決定論的/
けってん /欠点/缺點/
けっとう /血統/決闘/結党/血糖/
けっとうがんりゅうじま /決闘巌流島/
けっとうしょ /血統書/
けっとうじてん /血統事典/血統辞典/
けっとうず /血統図/
けっとうち /血糖値/
けっとうてき /血統的/
けっとうてきかち /血統的価値/
けっとうひょうか /血統評価/
けっぱい /欠配/
けっぱく /潔白/
けっぱん /血判/
けっぴょう /結氷/
けっぴん /欠品/
けっぴんちゅう /欠品中/
けっぺき /潔癖/
けっぺきしょう /潔癖症/潔癖性/
けっぽう /血泡/
けつ /決/結/穴/欠/潔/訣/血/傑/桔/蕨/亅/偈/决/刔/厥/夬/孑/抉/杰/桀/歇/獗/碣/竭/纈/缺/襭/訐/譎/蹶/闕/頡/頁/
けつあつ /血圧/
けつあつけい /血圧計/
けつあつじょうしょう /血圧上昇/
けつあつそくていよう /血圧測定用/
けつい /決意/
けついん /欠員/闕員/
けつえき /血液/
けつえきがた /血液型/
けつえきけんさ /血液検査/
けつえきさいぼう /血液細胞/
けつえきせいざい /血液製剤/
けつえきちゅう /血液中/
けつえきはんのう /血液反応/
けつえきびょう /血液病/
けつえきりょう /血液量/
けつえん /血縁/結縁/
けつえんかんけい /血縁関係/
けつおう /傑王/
けつがん /頁岩/
けつぎ /決議/決義/
けつぎあん /決議案/
けつぎぶん /決議文/
けつげん /結言/
けつご /結語/
けつごう /結合/欠号/
けつごうかじゅう /結合荷重/
けつごうがた /結合型/
けつごうきこう /結合機構/
けつごうけい /結合系/
けつごうけいじょう /結合形状/
けつごうけいすう /結合係数/
けつごうし /結合子/
けつごうじょうたい /結合状態/
けつごうじょうほう /結合情報/
けつごうすう /結合数/
けつごうせい /結合性/
けつごうそく /結合則/
けつごうたんぱくしつ /結合蛋白質/
けつごうち /結合値/
けつごうていすう /結合定数/
けつごうてき /結合的/
けつごうど /結合度/
けつごうほう /結合法/
けつごうほうそく /結合法則/
けつごうみゃく /結合脈/
けつごうもう /結合網/
けつごうよう /結合用/
けつごうりつ /結合律/
けつごうりょく /結合力/
けつじ /結辞/
けつじつ /結実/
けつじょ /欠如/闕如/
けつじょう /欠場/決定/
けつぜい /血税/
けつぜん /蹶然/決然/
けつぞう /結像/
けつぞうきょり /結像距離/
けつぞうめん /結像面/
けつぞく /血族/
けつだん /決断/結団/
けつにょう /血尿/
けつばん /欠番/
けつぶつ /傑物/
けつべつ /訣別/決別/
けつぼう /欠乏/欠亡/
けつぼうしょう /欠乏症/
けつぼうせい /欠亡性/
けつまくえん /結膜炎/
けつまつ /結末/
けつみゃく /血脈/
けつめい /結盟/
けつゆうびょう /血友病/
けつゆうびょうかんじゃ /血友病患者/
けつらく /欠落/
けつらくぶぶん /欠落部分/
けつりゅう /血流/
けつりゅうおん /血流音/
けつりゅうりょう /血流量/
けつりょう /血量/
けつるい /血涙/
けつれい /欠礼/
けつれつ /決裂/
けつろ /結露/血路/
けつろたいさく /結露対策/
けつろぼうし /結露防止/
けつろん /結論/
けつろんしき /結論式/
けつろんてき /結論的/
けつろんぶ /結論部/
けづか /毛塚/
けづな /毛綱/
けづや /毛艶/
けとう /毛唐/
けどういん /祁答院/
けなげ /健気/
けなしだいら /毛無平/
けなみ /毛並/毛並み/
けにん /化人/
けぬき /鑷/
けねん /懸念/
けはい /気配/
けはひ /化粧/気配/
けばり /毛鉤/
けびいし /検非違使/
けびょう /仮病/
けまうち /毛馬内/
けまり /蹴鞠/
けまりうた /手毬歌/
けみかる /ケミカル/
けみがわ /検見川/
けみがわはま /検見川浜/
けむ /煙/烟/
けむし /毛虫/
けむり /煙/烟/
けもてら /化学療法/
けもの /獣/獸/
けものぞく /獣族/
けものみち /獣道/
けやき /欅/
けら /螻蛄/
けらい /家来/
けらく /快楽/
けろり /けろり/
けわい /化粧/
けん /件/研/権/県/見/間/嫌/験/犬/肩/券/顕/鍵/健/検/謙/拳/賢/軒/険/圏/兼/堅/剣/遣/憲/懸/絹/献/建/鹸/捲/樫/筧/硯/牽/喧/倦/倹/腱/虔/瞼/絢/縣/監/俔/儉/凵/劍/劔/劒/剱/劵/圈/妍/娟/嶮/幵/惓/愆/愃/慊/慳/搴/擧/舉/暄/椦/權/檢/歉/涓/狷/獻/甄/眩/眷/綣/繝/羂/臉/諠/謇/譴/蹇/釼/鉉/險/顯/顴/騫/驗/鵑/黔/鰹/巻/繭/乾/萱/卷/蜷/
けんあく /険悪/
けんあん /懸案/検案/
けんあんじこう /懸案事項/
けんい /権威/
けんいか /権威化/
けんいき /県域/
けんいしこう /権威指向/
けんいしゃ /権威者/
けんいしゅぎ /権威主義/
けんいしゅぎてき /権威主義的/
けんいち /健一/剣一/謙一/憲一/賢一/堅一/研一/乾一/建一/
けんいちろう /健一郎/顕一郎/謙一郎/健一朗/
けんいてき /権威的/
けんいん /牽引/検印/
けんいんしゃ /牽引車/
けんいんじ /牽引時/
けんいんそうち /牽引装置/
けんいんりょく /牽引力/
けんいんりょくぶそく /牽引力不足/
けんいんれっしゃ /牽引列車/
けんうん /絹雲/
けんえい /県営/兼営/
けんえき /検疫/権益/
けんえきかくほ /権益確保/
けんえきかくほろせん /権益確保路線/
けんえきかん /検疫官/
けんえきしゃ /権益者/
けんえきしょ /検疫所/
けんえきじょ /検疫所/
けんえつ /検閲/憲悦/
けんえつかん /検閲官/
けんえつさくじょ /検閲削除/
けんえつせいど /検閲制度/
けんえん /嫌煙/犬猿/
けんえんうんどう /嫌煙運動/
けんえんか /嫌煙家/
けんえんかつどう /嫌煙活動/
けんえんけん /嫌煙権/
けんえんしゃ /嫌煙者/
けんえんしゃがわ /嫌煙者側/
けんえんだんたい /嫌煙団体/
けんえんは /嫌煙派/
けんお /嫌悪/嫌惡/
けんおう /県央/
けんおうどう /圏央道/
けんおかん /嫌悪感/
けんおん /検温/建音/
けんおんき /検温器/
けんおんけん /建音研/
けんおんけんし /建音研資/
けんか /喧嘩/県下/堅果/献花/
けんかい /見解/研開/県会/狷介/
けんかいぎいん /県会議員/
けんかいこうぼ /研開公募/
けんかいほんぶ /研開本部/
けんかうり /喧嘩売/
けんかく /見覚/
けんかこうろん /喧嘩口論/
けんかごし /喧嘩腰/
けんかじょうず /喧嘩上手/
けんかだい /献花台/
けんかだいいち /県下第一/
けんかべつ /喧嘩別/
けんかりょうせいばい /喧嘩両成敗/
けんかん /建艦/
けんが /懸下/
けんがい /県外/圏外/
けんがく /見学/建学/
けんがくかい /見学会/
けんがくしゃ /見学者/
けんがくじかん /見学時間/
けんがくせいりけん /見学整理券/
けんがくほうこく /見学報告/
けんがくまえ /見学前/
けんがん /検眼/
けんき /嫌気/
けんきざい /嫌忌剤/
けんきせい /嫌気性/
けんきせいきん /嫌気性菌/
けんきせいせっちゃくざい /嫌気性接着剤/
けんきち /健吉/賢吉/
けんきゃく /健脚/
けんきゅう /研究/
けんきゅういいんかい /研究委員会/
けんきゅういん /研究員/
けんきゅうか /研究科/研究家/
けんきゅうかい /研究会/
けんきゅうかいいん /研究会員/
けんきゅうかいいんかい /研究科委員会/
けんきゅうかいかいさい /研究会開催/
けんきゅうかいかつどう /研究会活動/
けんきゅうかいかんじ /研究会幹事/
けんきゅうかいきょうさい /研究会共催/
けんきゅうかいけいしき /研究会形式/
けんきゅうかいごと /研究会毎/
けんきゅうかいし /研究会誌/
けんきゅうかいしりょう /研究会資料/
けんきゅうかいてきしきさい /研究会的色彩/
けんきゅうかいとうろく /研究会登録/
けんきゅうかいはっぴょう /研究会発表/
けんきゅうかいはつ /研究開発/
けんきゅうかいはつか /研究開発課/
けんきゅうかいはつきこう /研究開発機構/
けんきゅうかいはつしつ /研究開発室/
けんきゅうかいはつしょく /研究開発職/
けんきゅうかいはつせいか /研究開発成果/
けんきゅうかいはつどうこう /研究開発動向/
けんきゅうかいはつどりょく /研究開発努力/
けんきゅうかいはつのうりょく /研究開発能力/
けんきゅうかいはつぶ /研究開発部/
けんきゅうかいはつほんぶ /研究開発本部/
けんきゅうかいはつもくてき /研究開発目的/
けんきゅうかいほうこく /研究会報告/
けんきゅうかいほっそく /研究会発足/
けんきゅうかいめい /研究会名/
けんきゅうかいれんごう /研究会連合/
けんきゅうかだい /研究課題/
けんきゅうかちょう /研究科長/
けんきゅうかちょうしつ /研究科長室/
けんきゅうかつどう /研究活動/
けんきゅうかのう /研究可能/
けんきゅうかのうせい /研究可能性/
けんきゅうかん /研究官/
けんきゅうかんきょう /研究環境/
けんきゅうかんりかちょう /研究管理課長/
けんきゅうがくえんとし /研究学園都市/
けんきゅうき /研究機/
けんきゅうきかん /研究機関/研究期間/
けんきゅうきばん /研究基盤/
けんきゅうきょうぎかい /研究協議会/
けんきゅうきょうじゅかい /研究教授会/
けんきゅうきょうりょくか /研究協力課/
けんきゅうきょうりょくがかり /研究協力掛/
けんきゅうきよう /研究紀要/
けんきゅうぎじゅつぶ /研究技術部/
けんきゅうぎょうせき /研究業績/
けんきゅうけいかがいよう /研究経過概要/
けんきゅうけいかく /研究計画/
けんきゅうけいひ /研究経費/
けんきゅうけっか /研究結果/
けんきゅうこうえんかい /研究講演会/
けんきゅうこうりゅう /研究交流/
けんきゅうさっし /研究冊子/
けんきゅうしえん /研究支援/
けんきゅうしえんかんきょう /研究支援環境/
けんきゅうししん /研究指針/
けんきゅうしせつ /研究施設/
けんきゅうしつ /研究室/
けんきゅうしつがい /研究室外/
けんきゅうしつけんがく /研究室見学/
けんきゅうしつちょくつう /研究室直通/
けんきゅうしつない /研究室内/
けんきゅうしつめい /研究室名/
けんきゅうしつりょこう /研究室旅行/
けんきゅうしどう /研究指導/
けんきゅうしゃ /研究者/研究社/
けんきゅうしゃかん /研究者間/
けんきゅうしゃしゅっぱん /研究社出版/
けんきゅうしゃすう /研究者数/
けんきゅうしゃそうご /研究者相互/
けんきゅうしゃたち /研究者達/
けんきゅうしゃばんごう /研究者番号/
けんきゅうしゃほんにん /研究者本人/
けんきゅうしゃめいかん /研究者名鑑/
けんきゅうしゃようせい /研究者養成/
けんきゅうしゅうかい /研究集会/
けんきゅうしゅにん /研究主任/
けんきゅうしょ /研究所/研究書/
けんきゅうしょう /研究賞/
けんきゅうしょうかい /研究紹介/
けんきゅうしょく /研究職/
けんきゅうしょだい /研究所第/
けんきゅうしょちょう /研究所長/
けんきゅうしょめい /研究所名/
けんきゅうしょれんごう /研究所連合/
けんきゅうしりょう /研究資料/
けんきゅうしん /研究心/
けんきゅうじょ /研究所/
けんきゅうじょう /研究上/
けんきゅうじょうきょう /研究状況/
けんきゅうじょうほう /研究情報/
けんきゅうじょうほうこうかん /研究情報交換/
けんきゅうじょうほうしつ /研究情報室/
けんきゅうじょがい /研究所外/
けんきゅうじょしゅ /研究助手/
けんきゅうじょせい /研究助成/
けんきゅうじょない /研究所内/
けんきゅうじれい /研究事例/
けんきゅうせい /研究生/
けんきゅうせいか /研究成果/
けんきゅうせいかつ /研究生活/
けんきゅうせいかはっぴょう /研究成果発表/
けんきゅうせいさく /研究制作/
けんきゅうせん /研究船/
けんきゅうぜんぱん /研究全般/
けんきゅうそくほう /研究速報/
けんきゅうそしき /研究組織/
けんきゅうたいしょう /研究対象/
けんきゅうたいせい /研究体制/
けんきゅうだい /研究第/
けんきゅうだいざい /研究題材/
けんきゅうだいひょう /研究代表/
けんきゅうだいひょうしゃ /研究代表者/
けんきゅうだいもく /研究題目/
けんきゅうだんかい /研究段階/
けんきゅうちゅう /研究中/
けんきゅうてきかち /研究的価値/
けんきゅうてじゅん /研究手順/
けんきゅうとう /研究棟/
けんきゅうとうろん /研究討論/
けんきゅうとうろんかい /研究討論会/
けんきゅうとじょう /研究途上/
けんきゅうどうこう /研究動向/
けんきゅうないよう /研究内容/
けんきゅうなかま /研究仲間/
けんきゅうにっし /研究日誌/
けんきゅうねっしん /研究熱心/
けんきゅうのうりょく /研究能力/
けんきゅうはいけい /研究背景/
けんきゅうはっぴょう /研究発表/
けんきゅうはっぴょうかい /研究発表会/
けんきゅうはん /研究班/
けんきゅうはんい /研究範囲/
けんきゅうひ /研究費/
けんきゅうひそうがく /研究費総額/
けんきゅうひん /研究品/
けんきゅうぶ /研究部/
けんきゅうぶそく /研究不足/
けんきゅうぶもん /研究部門/
けんきゅうぶもんめい /研究部門名/
けんきゅうぶんかかい /研究分科会/
けんきゅうぶんや /研究分野/
けんきゅうほうこう /研究方向/
けんきゅうほうこく /研究報告/
けんきゅうほうこくかい /研究報告会/
けんきゅうほうこくしょ /研究報告書/
けんきゅうほうしん /研究方針/
けんきゅうほうほう /研究方法/
けんきゅうほんぶ /研究本部/
けんきゅうもくてき /研究目的/
けんきゅうもくひょう /研究目標/
けんきゅうよう /研究用/
けんきゅうよてい /研究予定/
けんきゅうりょういき /研究領域/
けんきゅうれい /研究例/
けんきゅうれんらくかい /研究連絡会/
けんきゅうろんぶん /研究論文/
けんきゅじょ /研究所/
けんきょ /謙虚/検挙/
けんきょう /牽強/県境/
けんきょうかい /県協会/
けんきょうちゅう /検鏡中/
けんきょうふかい /牽強附会/
けんきょしゃ /検挙者/
けんきょじ /検挙時/
けんきょりつ /検挙率/
けんきん /献金/兼勤/
けんぎ /嫌疑/県議/建議/
けんぎかい /県議会/
けんぎゅう /犬牛/
けんぎょう /兼業/検校/
けんぎょうしゅふ /兼業主婦/
けんけい /県警/
けんけいおんがくたい /県警音楽隊/
けんけつ /献血/
けんけつかいすう /献血回数/
けんけつしゃ /献血車/
けんけつすいしんしゃ /献血推進者/
けんけつだんたい /献血団体/
けんけつとうろくしゃしょう /献血登録者証/
けんけつまえ /献血前/
けんけんごうごう /喧喧囂囂/喧々囂々/
けんけんふくよう /拳拳服膺/
けんげきじん /剣劇人/
けんげん /権限/顕現/
けんげんいじょう /権限委譲/
けんげんしゅうちゅう /権限集中/
けんこ /腱固/
けんこう /健康/軒昂/兼行/驗效/箝口/
けんこうかがく /健康科学/
けんこうかんり /健康管理/
けんこうこつ /肩甲骨/肩胛骨/
けんこうざっし /健康雑誌/
けんこうしょうに /健康小児/
けんこうしょくひん /健康食品/
けんこうしんだん /健康診断/
けんこうじょう /健康上/
けんこうじょうたい /健康状態/
けんこうぜんたい /健康全体/
けんこうてき /健康的/
けんこうひがい /健康被害/
けんこうほう /健康法/
けんこうほけん /健康保険/健康保健/
けんこうほけんしょう /健康保険証/
けんこうほけんせいど /健康保険制度/
けんこうぼん /健康本/
けんこうもんだい /健康問題/
けんこうやれん /県高野連/
けんこく /建国/
けんこくきねんび /建国記念日/
けんこくとうじ /建国当時/
けんこんいってき /乾坤一擲/
けんご /健悟/研吾/堅固/建悟/憲吾/健五/健吾/謙吾/顕吾/
けんごう /剣豪/
けんさ /検査/
けんさいん /検査員/検査院/
けんさかん /検査官/
けんさき /剣先/
けんさきげん /検査期限/
けんさきじゅん /検査基準/
けんさく /検索/献策/研削/羂索/
けんさくかのう /検索可能/
けんさくきのう /検索機能/
けんさくけっか /検索結果/
けんさくこうもく /検索項目/
けんさくご /検索語/
けんさくごしてい /検索語指定/
けんさくさぎょう /検索作業/
けんさくしあげ /研削仕上/
けんさくしき /検索式/
けんさくしゅほう /検索手法/
けんさくしょり /検索処理/
けんさくじ /検索時/
けんさくじゅんい /検索順位/
けんさくじょうけん /検索条件/
けんさくたいしょう /検索対象/
けんさくたんまつ /検索端末/
けんさくちゅう /検索中/
けんさくふのう /検索不能/
けんさくほう /検索法/
けんさくほうほう /検索方法/
けんさくめいれい /検索命令/
けんさくもじれつ /検索文字列/
けんさくよう /検索用/
けんさけっか /検査結果/
けんさこうてい /検査工程/
けんさこうもく /検査項目/
けんさしゃ /検査者/
けんさしょうめい /検査証明/
けんさしょけん /検査所見/
けんさしようしょ /検査仕様書/
けんさしんこうかい /検査振興会/
けんさじ /検査時/
けんさじょ /検査所/
けんさじょう /検査場/
けんさそうち /検査装置/
けんさたいしょう /検査対象/
けんさだい /検査代/
けんさつ /検察/検札/賢察/
けんさつかん /検察官/
けんさつがわ /検察側/
けんさつきょく /検察局/
けんさつちょう /検察庁/
けんさてすうりょう /検査手数料/
けんさひょう /検査票/
けんさひよう /検査費用/
けんさび /検査日/
けんさふよう /検査不要/
けんさぶ /検査部/
けんさほう /検査法/
けんさぼ /検査簿/
けんさまえ /検査前/
けんさようし /検査用紙/
けんさん /研鑽/県産/
けんざい /健在/顕在/建材/
けんざいか /顕在化/
けんざかい /県境/
けんざぶろう /健三郎/
けんざん /検算/剣山/見参/験算/
けんし /犬歯/剣士/研資/検死/検視/研紙/絹糸/賢史/県史/
けんしき /見識/
けんしきしゃ /見識者/
けんしゃく /検車区/
けんしゅう /研修/検収/
けんしゅうい /研修医/
けんしゅういん /研修員/
けんしゅうかい /研修会/
けんしゅうかいかん /研修会館/
けんしゅうこ /検修庫/
けんしゅうしつ /研修室/
けんしゅうしゃいん /研修社員/
けんしゅうしょ /研修所/
けんしゅうじょ /研修所/
けんしゅうせい /研修生/
けんしゅうちゅう /研修中/
けんしゅうひ /研修費/
けんしゅうぶ /研修部/
けんしゅうりょこう /研修旅行/
けんしゅつ /検出/
けんしゅつかのうせい /検出可能性/
けんしゅつき /検出器/
けんしゅつきこう /検出機構/
けんしゅつこうりつ /検出効率/
けんしゅつしやく /検出試薬/
けんしゅつじ /検出時/
けんしゅつのうりょく /検出能力/
けんしゅつふかのう /検出不可能/
けんしゅつほう /検出法/
けんしゅつほうほう /検出方法/
けんしゅつりつ /検出率/
けんしょう /検証/憲章/健勝/懸賞/顕彰/肩章/腱鞘/
けんしょうあん /憲章案/
けんしょうえん /腱鞘炎/
けんしょうかいしゃく /憲章解釈/
けんしょうかのう /検証可能/
けんしょうきん /懸賞金/
けんしょうけい /検証系/
けんしょうけっか /検証結果/
けんしょうしえん /検証支援/
けんしょうしゅだん /検証手段/
けんしょうじっけん /検証実験/
けんしょうじょうけん /検証条件/
けんしょうば /顕彰馬/
けんしょうふかのう /検証不可能/
けんしょうほう /検証法/
けんしょうほうしき /検証方式/
けんしょうほうほう /検証方法/
けんしょうもんだい /検証問題/懸賞問題/
けんしょうろんぶん /懸賞論文/
けんしょく /兼職/
けんしん /検診/献身/謙信/検針/健晋/健診/剣心/
けんしんてき /献身的/
けんしんてきどりょく /献身的努力/
けんじ /健二/検事/賢二/研二/健司/賢治/健児/顕示/健治/研仁/健次/健之/憲司/憲治/憲二/研治/謙治/謙二/賢司/賢次/堅持/献辞/剣持/拳児/健士/健至/賢児/健爾/憲志/謙司/顕二/建司/研児/
けんじかん /検事官/
けんじがわ /検事側/
けんじきょく /検事局/
けんじつ /堅実/
けんじゃ /賢者/
けんじゅう /拳銃/
けんじゅつ /剣術/
けんじょう /献上/謙譲/見城/健常/
けんじょうきん /献上金/
けんじょうけい /謙譲形/
けんじょうご /謙譲語/
けんじょうしゃ /健常者/
けんじょうじ /健常児/
けんじょうひょうげん /謙譲表現/
けんじょうれい /県条例/
けんじろう /健次郎/顕次郎/健二郎/研二郎/
けんじん /賢臣/県人/賢人/
けんじんかい /県人会/
けんすい /懸垂/
けんすいしき /懸垂式/
けんすう /件数/軒数/検数/
けんすけ /健介/健輔/堅助/謙介/研介/
けんず /検図/
けんせい /牽制/権勢/県政/憲政/
けんせいあくそうきゅう /牽制悪送球/
けんせいきゅう /牽制球/
けんせいし /牽制死/
けんせき /譴責/
けんせきうん /巻積雲/
けんせつ /建設/
けんせつあと /建設跡/
けんせついよく /建設意欲/
けんせつか /建設課/
けんせつがいしゃ /建設会社/
けんせつきかい /建設機械/
けんせつぎょうしゃ /建設業者/
けんせつけいかく /建設計画/
けんせつこうがくけい /建設工学系/
けんせつこうじ /建設工事/
けんせつこうほち /建設候補地/
けんせつしょう /建設省;2001年1月の中央省庁再編で国土交通省に再編された/
けんせつしょうほうれい /建設省法令/
けんせつせん /建設線/
けんせつだいじん /建設大臣/
けんせつちゅう /建設中/
けんせつちゅうし /建設中止/
けんせつてき /建設的/
けんせつてきいけん /建設的意見/
けんせつてきないよう /建設的内容/
けんせつてきひはん /建設的批判/
けんせつとじょう /建設途上/
けんせつとちゅう /建設途中/
けんせつはんたい /建設反対/
けんせつひよう /建設費/建設費用/
けんせつほうきろせん /建設放棄路線/
けんせつまえ /建設前/
けんせつよう /建設用/
けんせつよていせん /建設予定線/
けんぜい /県税/
けんぜみ /研ゼミ/
けんぜみしりょう /研ゼミ資料/
けんぜん /健全/建前/
けんぜんいちにょ /拳禅一如/剣禅一如/
けんぜんせい /健全性/
けんそう /喧噪/喧騒/建掃/
けんそううん /巻層雲/
けんそく /検束/検測/
けんそん /謙遜/
けんぞう /健三/健蔵/建造/謙三/賢三/剣三/研造/健造/
けんぞうちゅう /建造中/
けんぞうひ /建造費/
けんぞうぶつ /建造物/
けんぞく /眷属/眷族/
けんた /健太/
けんたい /倦怠/検体/献体/
けんたいかい /県大会/
けんたいかん /倦怠感/
けんたいき /倦怠期/
けんたいとうろく /献体登録/
けんたろう /健太郎/謙太郎/謙多郎/謙太朗/
けんたん /県短/兼担/健啖/
けんたんぶん /兼担分/
けんだい /建大/
けんだいひょう /県代表/
けんだっぱ /乾闥婆/
けんち /検知/見地/見知/検地/
けんちく /建築/
けんちくおんきょう /建築音響/
けんちくか /建築家/
けんちくかんけい /建築関係/
けんちくがく /建築学/
けんちくがくじょう /建築学上/
けんちくがくせんこう /建築学専攻/
けんちくがっか /建築学科/
けんちくがっかい /建築学会/
けんちくきじゅんほう /建築基準法/
けんちくぎょう /建築業/
けんちくけい /建築系/
けんちくけいかく /建築計画/
けんちくけんきゅうじょ /建築研究所/
けんちくげんば /建築現場/
けんちくこうぞう /建築構造/
けんちくこうぞうかいせき /建築構造解析/
けんちくざい /建築材/
けんちくし /建築士/
けんちくちゅう /建築中/
けんちくてき /建築的/
けんちくてん /建築展/
けんちくひ /建築費/
けんちくひかいしゅう /建築費回収/
けんちくぶ /建築部/
けんちくぶつ /建築物/
けんちくや /建築屋/
けんちげん /検知限/
けんちじ /県知事/
けんちゃ /献茶/
けんちょ /顕著/
けんちょう /県庁/堅調/健聴/懸吊/検聴/
けんちょうしゃ /健聴者/
けんちょうしょざいち /県庁所在地/
けんちょうじ /健聴耳/
けんちょうまえ /県庁前/
けんてい /検定/献呈/
けんていいけん /検定意見/
けんていいん /検定員/
けんていきじゅん /検定基準/
けんていきょうか /検定強化/
けんていご /検定後/
けんていごうかく /検定合格/
けんていしけん /検定試験/
けんていしゅもく /検定種目/
けんていじたい /検定自体/
けんていせいど /検定制度/
けんていぜんぱん /検定全般/
けんていないよう /検定内容/
けんていび /検定日/
けんていふ /献呈譜/
けんていほう /検定法/
けんていほうしき /検定方式/
けんていほうほう /検定方法/
けんていまえ /検定前/
けんていまえこうしゅう /検定前講習/
けんていりょう /検定料/
けんていりょく /検定力/
けんてつ /建鉄/建鐵/賢哲/
けんでん /喧伝/
けんと /健人/憲人/県都/
けんとう /検討/見当/健闘/拳闘/
けんとういいんかい /検討委員会/
けんとうか /拳闘家/
けんとうかい /検討会/
けんとうかいし /検討開始/
けんとうかだい /検討課題/
けんとうきょく /県当局/
けんとうけっか /検討結果/
けんとうざいりょう /検討材料/
けんとうし /遣唐使/
けんとうしゃ /検討者/
けんとうずみ /検討済み/
けんとうたいしょう /検討対象/
けんとうだんかい /検討段階/
けんとうちがい /検討違い/見当違い/
けんとうちゅう /検討中/
けんとうぶ /県東部/
けんとうれい /検討例/
けんどう /剣道/県道/
けんどうわき /県道脇/
けんどじゅうらい /捲土重来/
けんどちょうらい /捲土重来/捲土重來/
けんない /県内/圏内/
けんなん /険難/県南/
けんにょう /検尿/
けんにん /兼任/検認/
けんのう /献納/権能/
けんのん /険呑/剣呑/
けんば /犬馬/
けんばいき /券売機/
けんばく /懸瀑/
けんばん /鍵盤/鍵板/
けんばんがっき /鍵盤楽器/
けんばんがっきそうしゃ /鍵盤楽器奏者/
けんばんごと /鍵盤毎/
けんばんすう /鍵盤数/
けんばんひだりて /鍵盤左手/
けんぱ /検波/
けんぱき /検波器/
けんぱく /建白/絹帛/
けんぱご /検波後/
けんぱしゅつりょく /検波出力/
けんぱぶ /検波部/
けんひ /県費/
けんび /兼備/顕微/
けんびきょう /顕微鏡/
けんびし /剣菱/
けんぴん /検品/
けんぶ /剣舞/兼部/
けんぶち /剣淵/
けんぶつ /見物/
けんぶつがわ /見物側/
けんぶつき /見物記/
けんぶつきゃく /見物客/
けんぶつちゅう /見物中/
けんぶつにん /見物人/
けんぶつばしょ /見物場所/
けんぶん /見聞/検分/
けんぶんしつちょくつう /研分室直通/
けんぶんろく /見聞録/
けんぷ /絹布/
けんべん /検便/
けんぺい /憲兵/
けんぺいたい /憲兵隊/
けんぺいりつ /建蔽率/
けんぺん /券片/
けんぼう /権謀/健忘/
けんぼうさいか /県防災課/
けんぼうしょう /健忘症/
けんぼうじゅっすう /権謀術数/
けんぽ /健保/
けんぽう /憲法/拳法/剣法/
けんぽうあん /憲法案/
けんぽういはん /憲法違反/
けんぽういん /憲法院/
けんぽうか /憲法下/拳法家/
けんぽうかいせい /憲法改正/
けんぽうかいせいはつぎ /憲法改正発議/
けんぽうかいせいろんしゃ /憲法改正論者/
けんぽうがくしゃ /憲法学者/
けんぽうきねんび /憲法記念日/
けんぽうげんあん /憲法原案/
けんぽうじたい /憲法自体/
けんぽうだいきゅうじょう /憲法第九条/
けんぽうだいじゅうさんじょう /憲法第一三条/
けんぽうちつじょ /憲法秩序/
けんぽうはんだん /憲法判断/
けんぽうはんれいしゅう /憲法判例集/
けんぽく /県北/
けんぽん /献本/
けんま /研磨/研摩/
けんまき /研磨機/
けんまく /劍幕/
けんまこん /研磨痕/
けんまざい /研磨剤/
けんみん /県民/建民/
けんみんかいかん /県民会館/
けんむ /兼務/建武/
けんめ /件目/
けんめい /懸命/賢明/件名/県名/
けんめん /券面/
けんもち /堅持/剣持/犬持/
けんもつ /監物/
けんもん /検問/
けんもんしょ /検問所/
けんもんじょ /検問所/
けんや /顕也/賢也/健弥/
けんやく /倹約/検約/
けんやくか /倹約家/
けんやくせい /検約性/
けんゆう /県有/
けんゆうかん /健友館/
けんゆうち /県有地/
けんよう /兼用/
けんようしゃ /兼用車/
けんようすい /懸壅垂/
けんらん /絢爛/
けんり /権利/
けんりおち /権利落ち/
けんりか /権利化/
けんりかくとく /権利獲得/
けんりかくほ /権利確保/
けんりかぶ /権利株/
けんりかんけい /権利関係/
けんりがいねん /権利概念/
けんりきかん /権利期間/
けんりきぞくしゅたい /権利帰属主体/
けんりきん /権利金/
けんりしゃ /権利者/
けんりしゅうちゅう /権利集中/
けんりしゅたい /権利主体/
けんりしゅちょう /権利主張/
けんりしょ /権利書/
けんりしんがい /権利侵害/
けんりじたい /権利自体/
けんりじょうやく /権利条約/
けんりだいこう /権利代行/
けんりだいこうしゃ /権利代行者/
けんりちゅう /権利中/
けんりつ /県立/
けんりつうらわこうこう /県立浦和高校/
けんりつこうこう /県立高校/
けんりつしんがっこう /県立進学校/
けんりつじょしこうこう /県立女子高校/
けんりつだい /県立大/
けんりつとしょかん /県立図書館/
けんりはっせい /権利発生/
けんりほうき /権利放棄/
けんりほうきけいやく /権利放棄契約/
けんりもんだい /権利問題/
けんりゅう /劍竜/
けんりょう /検量/見料/
けんりょうしつ /検量室/
けんりょく /権力/
けんりょくか /権力下/
けんりょくがわ /権力側/
けんりょくこうそう /権力抗争/
けんりょくしゃ /権力者/
けんりょくしゃしゅどう /権力者主導/
けんりょくしゅうちゅう /権力集中/
けんりょくてき /権力的/
けんりよう /券利用/
けんりりょう /権利料/
けんれん /研連/拳攣/
けんれんかいかく /牽攣乖隔/
けんろう /堅牢/
けんろく /兼六/
けんろくえん /兼六園/
けんろん /圏論/
けんろんてき /圏論的/
けんろんてきかいしゃく /圏論的解釈/
けんわ /健和/
げ /下/外/毛/夏/解/偈/觧/睨/拐/
げーと /ゲート/
げーむ /ゲーム/
げい /芸/迎/鯨/猊/倪/囈/皃/睨/藝/貎/霓/麑/
げいいん /鯨飲/
げいか /猊下/
げいぎ /芸妓/
げいげき /迎撃/
げいげきき /迎撃機/
げいげききのう /迎撃機能/
げいこ /藝子/
げいこうだい /芸工大/
げいごう /迎合/
げいごと /芸事/
げいしゃ /芸者/迎車/
げいしゃやく /芸者役/
げいしゅん /迎春/
げいじゅつ /芸術/藝術/
げいじゅついん /芸術院/
げいじゅつおんがく /芸術音楽/
げいじゅつおんがくろん /芸術音楽論/
げいじゅつか /芸術家/
げいじゅつかたち /芸術家達/
げいじゅつかつどう /芸術活動/
げいじゅつかんけい /芸術関係/
げいじゅつがっこう /芸術学校/
げいじゅつけんきゅうしょ /藝術研究所/
げいじゅつけんきゅうじょ /藝術研究所/
げいじゅつげきじょう /芸術劇場/
げいじゅつこうい /芸術行為/
げいじゅつこうがくぶ /芸術工学部/
げいじゅつさい /芸術祭/
げいじゅつさくひん /芸術作品/
げいじゅつし /芸術誌/
げいじゅつしじょうしゅぎ /芸術至上主義/
げいじゅつせい /芸術性/
げいじゅつだいがく /芸術大学/
げいじゅつてき /芸術的/
げいじゅつてきかち /芸術的価値/
げいじゅつひひょう /芸術批評/
げいじゅつひん /芸術品/
げいじゅつろん /芸術論/
げいせい /芸西/
げいたいかい /芸大会/
げいたっしゃ /芸達者/
げいたん /芸短/
げいだい /芸大/
げいとう /芸当/藝當/
げいにん /芸人/
げいのう /芸能/芸濃/
げいのうかい /芸能界/
げいのうかいいり /芸能界入/
げいのうかつどう /芸能活動/
げいのうかんけい /芸能関係/
げいのうきょく /芸能局/
げいのうしゃかい /芸能社会/
げいのうじん /芸能人/
げいのうせいかつ /芸能生活/
げいのうめん /芸能面/
げいのうやましろぐみ /芸能山城組/
げいひん /迎賓/
げいひんかん /迎賓館/
げいび /芸備/
げいびけい /猊鼻渓/
げいびせん /芸備線/
げいふう /芸風/
げいほく /芸北/
げいめい /芸名/
げいれき /芸歴/
げか /外科/
げかい /下界/外科医/外界/下回/
げかぎじゅつ /外科技術/
げかしつ /外科室/
げかしゅじゅつてき /外科手術的/
げかてき /外科的/
げかびょうとう /外科病棟/
げかん /下巻/
げき /激/撃/劇/隙/戟/逆/屐/檄/郤/闃/鬩/鷁/
げき> /激/
げきあせ /激汗/
げきあま /激甘/
げきか /激化/
げきから /激辛/
げきが /劇画/
げきがし /劇画誌/
げきくうかん /劇空間/
げきげん /激減/
げきこう /激昂/
げきこみ /激混/
げきさっか /劇作家/
げきさん /激賛/
げきしょ /激暑/
げきしょう /激賞/
げきしょく /激職/
げきしん /激震/
げきじゃく /激弱/
げきじょう /劇場/激情/
げきじょうか /激情家/
げきじょうがい /劇場街/
げきじょうこうえん /劇場公演/
げきじょうこうかい /劇場公開/
げきじょうこうかいじ /劇場公開時/
げきじょうこうかいばん /劇場公開版/
げきじょうそうかんとく /劇場総監督/
げきじょうない /劇場内/
げきじょうばん /劇場版/
げきじょうよう /劇場用/
げきじょうようさくひん /劇場用作品/
げきせん /激戦/
げきせんく /激戦区/
げきそう /激走/
げきぞう /激増/
げきたい /撃退/
げきたいほう /撃退法/
げきだん /劇団/
げきだんいん /劇団員/
げきだんしき /劇団四季/
げきだんしょぞく /劇団所属/
げきちゅう /劇中/
げきちゅうげき /劇中劇/
げきちゅうばんぐみ /劇中番組/
げきちょう /外記丁/
げきちん /撃沈/
げきちんは /撃沈破/
げきつい /撃墜/
げきついおう /撃墜王/
げきついすう /撃墜数/
げきつう /激痛/
げきてき /劇的/
げきてきこうか /劇的効果/
げきとう /激闘/
げきとつ /激突/
げきとつし /激突死/
げきど /激怒/
げきどう /激動/
げきなみだ /激涙/
げきは /撃破/
げきはつ /激発/
げきひょう /劇評/
げきひょうらん /劇評欄/
げきぶん /檄文/
げきへん /激変/
げきむ /激務/劇務/
げきめつ /撃滅/
げきやく /劇薬/
げきやす /激安/
げきやすこうくうけん /激安航空券/
げきやすてん /激安店/
げきりゅう /激流/
げきりん /逆鱗/
げきれい /激励/
げきれつ /激烈/
げきろん /激論/
げぎ /外儀/
げぐう /外宮/
げけつ /下血/
げげ /:-</
げこ /下戸/
げこう /下校/下向/
げこうご /下校後/
げこうじ /下校時/
げこくじょう /下剋上/
げさく /戯作/
げさくしゃ /戯作者/
げざい /下剤/
げざん /下山/
げし /夏至/
げしかく /原子核/
げしゃ /下車/
げしゃいん /下車印/
げしゃえき /下車駅/
げしゃじ /下車時/
げしゃぜんとむこう /下車前途無効/
げしゃとほ /下車徒歩/
げしゅく /下宿/
げしゅくさき /下宿先/
げしゅくせい /下宿生/
げしゅくにん /下宿人/
げしゅくや /下宿屋/
げしゅにん /下手人/
げじげじ /蚰蜒/
げじゅん /下旬/
げじゅんぶん /下旬分/
げじゅんへん /下旬編/
げす /下衆/下種/下司/
げすい /下水/
げすいこうじ /下水工事/
げすいしょり /下水処理/
げすいしょりしせつ /下水処理施設/
げすいしょりじょう /下水処理場/
げすいどう /下水道/
げすいどうきょうかいし /下水道協会誌/
げすいどうきょく /下水道局/
げすいどうせいび /下水道整備/
げすと /ゲスト/
げせわ /下世話/
げせん /下船/下賎/
げそく /下足/
げた /下駄/〓/
げたばこ /下駄箱/
げたん /下端/
げだい /外題/
げだつ /解脱/
げだん /下段/
げだんこうげき /下段攻撃/
げっか /月下/激化/
げっかひょうじん /月下氷人/
げっかん /月刊/月間/
げっかんあいどくしょ /月刊愛読書/
げっかんあさひ /月刊朝日/
げっかんげんご /月刊言語/
げっかんさくひん /月刊作品/
げっかんし /月刊誌/
げっかんしゅうけい /月間集計/
げっかんてんもん /月刊天文/
げっかんよていひょう /月間予定表/
げっきゅう /月給/
げっきゅうせい /月給制/
げっけい /月経/月計/
げっけいかん /月桂冠/
げっけいじゅ /月桂樹/
げっこう /月光/激昂/激高/
げっこうかめん /月光仮面/
げっこうちゅう /月光蟲/
げっさん /月産/
げっし /齧歯/齧齒/
げっしもく /齧歯目/
げっしゃ /月謝/
げっしゅう /月収/
げっしゅつ /月出/
げっしゅつたい /月出帯/
げっしゅつたいしょく /月出帯蝕/
げっしょ /月初/
げっしょう /月商/
げっしょく /月食/月蝕/
げっしょくじ /月食時/
げっしるい /齧歯類/げっ歯類/
げっすいきん /月水金/
げっぴょう /月評/
げっぷ /月賦/
げっぺい /月餅/
げっぽ /月歩/
げっぽう /月報/月俸/
げつ /月/囓/蘖/齧/
げつえい /月影/
げつか /月火/
げつかすい /月火水/
げつかん /月間/
げつがく /月額/
げつご /月後/
げつじ /月次/
げつど /月度/
げつぶん /月分/
げつまえ /月前/
げつまつ /月末/
げつまつしょり /月末処理/
げつまつじつ /月末日/
げつまつそうけい /月末総計/
げつまつはつばい /月末発売/
げつめん /月面/
げつめんじょう /月面上/
げつめんとし /月面都市/
げつめんなんちゃくりく /月面軟着陸/
げつもく /月木/
げつよう /月曜/
げつよういこう /月曜以降/
げつようごご /月曜午後/
げつようび /月曜日/
げつようびごろ /月曜日頃/
げつようよる /月曜夜/
げつり /月利/
げつれい /月例/月齢/
げつれいかい /月例会/
げつれいきょうぎかい /月例競技会/
げつれいけいざいほうこく /月例経済報告/
げつれいひょうじ /月齢表示/
げつれいほうこく /月例報告/
げて /下手/
げてもの /下手物/
げてん /下天/
げとう /夏油/
げどう /下道/外道/
げどく /解毒/
げどくざい /解毒剤/
げなん /下男/
げに /実に/
げねつ /解熱/
げねつざい /解熱剤/
げば /下馬/
げばひょう /下馬評/
げひ /下卑/
げひん /下品/
げび /下卑/
げほう /外法/
げぼく /下僕/
げらく /下落/
げり /下痢/
げりゃく /下略/
げりら /ゲリラ/
げるちん /ゲル沈/
げれつ /下劣/
げれんで /ゲレンデ/
げろ /下呂/
げろう /下郎/外郎/
げろおんせん /下呂温泉/
げろかん /下呂間/
げん /現/限/言/元/原/源/減/玄/絃/弦/諺/舷/幻/厳/訝/嫌/監/偐/儼/呟/嚴/广/愿/痃/眩/芫/衒/軒/験/彦/顏/
げん> /現/元/
げんあおもりえき /現青森駅/
げんあつ /減圧/
げんあつき /減圧器/
げんあつしょう /減圧症/
げんあつていし /減圧停止/
げんあん /原案/現案/
げんあんさくひん /原案作品/
げんあんどおり /原案通り/
げんいち /元一/源一/現位置/
げんいちろう /源一郎/
げんいん /原因/減員/現員/
げんいんかいめい /原因解明/
げんいんきゅうめい /原因究明/
げんいんしだい /原因次第/
げんいんついきゅう /原因追及/
げんいんふめい /原因不明/
げんいんぶんせき /原因分析/
げんうん /眩暈/
げんえい /幻影/
げんえいきゃく /幻影脚/
げんえき /現役/減益/原液/
げんえきいんたい /現役引退/
げんえきいんたいご /現役引退後/
げんえきかつやくば /現役活躍馬/
げんえきき /現役機/
げんえきけいかん /現役警官/
げんえきさいきょう /現役最強/
げんえきさいご /現役最後/
げんえきさいた /現役最多/
げんえきさいねんちょう /現役最年長/
げんえきじだい /現役時代/
げんえきじょしこうせい /現役女子高生/
げんえきせいびし /現役整備士/
げんえきせんしゅ /現役選手/
げんえきだいひょう /現役代表/
げんえきば /現役馬/
げんえきふっき /現役復帰/
げんえきらくごか /現役落語家/
げんおん /現音/原音/
げんおんしゅぎ /原音主義/
げんおんじょう /原音場/
げんおんせい /原音声/
げんおんついきゅう /原音追求/
げんか /原価/喧嘩/言下/減価/現下/現価/
げんかい /限界/厳戒/玄海/幻海/幻界/言海/
げんかいいっぱい /限界一杯/
げんかいいん /現会員/
げんかいかいぞうど /限界解像度/
げんかいかかく /限界価格/
げんかいこうど /限界高度/
げんかいしき /原価意識/
げんかいじ /限界時/
げんかいじたい /限界自体/
げんかいそうこう /限界走行/
げんかいそくど /限界速度/
げんかいち /限界値/
げんかいちいか /限界値以下/
げんかいちいじょう /限界値以上/
げんかいとくせい /限界特性/
げんかいない /限界内/
げんかいなだ /玄界灘/玄海灘/
げんかいふきん /限界付近/
げんかいりょういき /限界領域/
げんかく /厳格/幻覚/
げんかくしゅぎてき /厳格主義的/
げんかくしょうじょう /幻覚症状/
げんかくせいぶつ /原核生物/
げんかけいさん /原価計算/
げんかし /原歌詞/
げんかしょうきゃく /減価償却/
げんかしょうきゃくひ /減価償却費/
げんかしょうきゃくりつ /減価償却率/
げんかん /玄関/厳寒/
げんかんきん /現換金/
げんかんぐち /玄関口/
げんかんげんぞう /減感現像/
げんかんさき /玄関先/
げんかんすう /原関数/
げんかんとく /現監督/
げんかんまえ /玄関前/
げんかんりにん /現管理人/
げんが /原画/
げんがい /言外/
げんがく /弦楽/減額/衒学/絃楽/
げんがくがっそう /弦楽合奏/
げんがくさんじゅうそうきょく /弦楽三重奏曲/
げんがくしじゅうそう /弦楽四重奏/弦楽四重奏曲/
げんがくしじゅうそうきょく /弦楽四重奏曲/
げんがくしじゅうそうだん /弦楽四重奏団/
げんがくてき /衒学的/
げんがしゅう /原画集/
げんがぞう /原画像/
げんがっき /弦楽器/
げんがっきぐん /弦楽器群/
げんがっきそうしゃ /弦楽器奏者/
げんがっきょく /弦楽曲/
げんがてん /原画展/
げんき /元気/原器/原基/
げんきいっぱい /元気一杯/
げんきかい /現棋界/
げんきじるし /元気印/
げんきどうしょてん /源喜堂書店/
げんきもの /元気者/
げんきゃく /減却/
げんきゅう /言及/減給/
げんきゅうないよう /言及内容/
げんきょう /元凶/現況/
げんきょく /原曲/元曲/限局/原局/
げんきょくせい /限局性/
げんきょくどおり /原曲通り/
げんきよし /元気良/
げんきん /現金/厳禁/
げんきんいがい /現金以外/
げんきんか /現金化/
げんきんかいいん /現金会員/
げんきんかいいんかかく /現金会員価格/
げんきんかきとめ /現金書留/
げんきんかんけい /現金関係/
げんきんしゅうにゅう /現金収入/
げんきんしょうひん /現金賞品/
げんきんとうし /現金投資/
げんきんばらい /現金払/
げんきんふうとう /現金封筒/
げんきんよきん /現金預金/
げんぎ /原義/
げんぎょ /言語/
げんぎょう /現業/
げんぎょうきかん /現業機関/
げんぎょうぶもん /現業部門/
げんくう /源空/
げんくうこう /現空港/
げんけい /原形/原型/減刑/減軽/
げんけいかく /現計画/
げんけいしつ /原形質/
げんけいしつまく /原形質膜/
げんけいしつれんらく /原形質連絡/
げんけいてきようそ /原形的要素/
げんけん /原研/原券/
げんけんかいしゅう /原券回収/
げんけんぽう /現憲法/
げんげつ /限月/
げんげんご /原言語/
げんこう /原稿/現行/言行/元寇/減光/弦高/
げんこういっち /言行一致/
げんこういらい /原稿依頼/
げんこうがた /現行型/
げんこうきしゅ /現行機種/
げんこうけんぽう /現行憲法/
げんこうさくせい /原稿作成/
げんこうしめきり /原稿締切/
げんこうしゃ /玄光社/
げんこうしゃしゅ /現行車種/
げんこうしょうひん /現行商品/
げんこうじたい /原稿自体/
げんこうそうふさき /原稿送付先/
げんこうにゅうりょく /原稿入力/
げんこうはん /現行犯/
げんこうはんたいほ /現行犯逮捕/
げんこうはんにん /現行犯人/
げんこうばん /現行版/
げんこうひょうじゅん /現行標準/
げんこうひん /現行品/
げんこうほう /現行法/
げんこうほうか /現行法下/
げんこうほうき /現行法規/
げんこうほうきそうらん /現行法規総覧/
げんこうほうしき /現行方式/
げんこうほうそう /現行放送/
げんこうめい /原稿名/
げんこうよう /原稿用/
げんこうようし /原稿用紙/
げんこうりょう /原稿料/
げんこうりょうしゅうにゅう /原稿料収入/
げんこく /原告/現国/
げんこくがわ /原告側/
げんこくだん /原告団/
げんこつ /拳骨/
げんこん /現今/
げんこんたん /原根端/
げんご /言語/原語/源吾/幻語/源後/
げんごいぞん /言語依存/
げんごう /元号/
げんごうんよう /言語運用/
げんごおん /言語音/
げんごか /言語化/
げんごかいせき /言語解析/
げんごかいせきほう /言語解析法/
げんごかかのう /言語化可能/
げんごかくとく /言語獲得/
げんごかつどう /言語活動/
げんごかてい /言語過程/
げんごかん /言語感/
げんごかんかく /言語感覚/
げんごかんきょう /言語環境/
げんごがいねん /言語概念/
げんごがく /言語学/
げんごがくしゃ /言語学者/
げんごがくぜんたい /言語学全体/
げんごがくだいじてん /言語学大辞典/
げんごがくてき /言語学的/
げんごがくてきかんねん /言語学的観念/
げんごがくてきけんち /言語学的見地/
げんごがくてきこんきょ /言語学的根拠/
げんごきこう /言語機構/
げんごきじゅつ /言語記述/
げんごきのう /言語機能/
げんごきはん /言語規範/
げんごきょういく /言語教育/
げんごくうかん /言語空間/
げんごけい /言語系/
げんごけいせい /言語形成/
げんごけいせいよういん /言語形成要因/
げんごけいていぎ /言語系定義/
げんごけん /言語研/
げんごけんきゅうかい /言語研究会/
げんごけんきゅうしょ /言語研究所/
げんごけんきゅうじょ /言語研究所/
げんごげんしょう /言語現象/
げんごこうざ /言語講座/
げんごこうぞう /言語構造/
げんごしゅうとくのうりょく /言語習得能力/
げんごしょり /言語処理/
げんごしょりけい /言語処理系/
げんごしよう /言語使用/言語仕様/
げんごしようしゃ /言語使用者/
げんごしようしょ /言語仕様書/
げんごしようじょう /言語仕様上/
げんごしんりがく /言語心理学/
げんごじたい /言語自体/
げんごじっけん /言語実験/
げんごじょう /言語上/
げんごじょうほう /言語情報/
げんごせいせい /言語生成/
げんごせかい /言語世界/
げんごせっけい /言語設計/
げんごせっけいしゃ /言語設計者/
げんごせんよう /言語専用/
げんごぜんたい /言語全体/
げんごぜんぱん /言語全般/
げんごぞく /言語族/
げんごたいけい /言語体系/
げんごちしき /言語知識/
げんごていぎ /言語定義/
げんごてき /言語的/
げんごてきちしき /言語的知識/
げんごてきひょうげん /言語的表現/
げんごにゅうもん /言語入門/
げんごのうりょく /言語能力/
げんごはったつ /言語発達/
げんごはんきゅう /言語半球/
げんごばん /原語版/言語版/
げんごひょうげん /言語表現/
げんごぶんか /言語文化/
げんごぶんかない /言語文化内/
げんごへんか /言語変化/
げんごべつ /言語別/
げんごめい /言語名/
げんごもんだい /言語問題/
げんごや /言語屋/
げんごよう /言語用/
げんごりかい /言語理解/
げんごりろん /言語理論/
げんごろうまる /源五郎丸/
げんごろん /言語論/
げんさい /減殺/幻妻/衒妻/
げんさく /原作/
げんさくしゃ /原作者/
げんさくしょうせつ /原作小説/
げんさくだいほん /原作台本/
げんさくちゅう /原作中/
げんさくどうぶつ /原索動物/
げんさくひん /原作品/
げんさくぼん /原作本/
げんさくまんが /原作漫画/
げんさん /減算/原産/減産/
げんさんき /減算器/
げんさんごうせい /減算合成/
げんさんち /原産地/
げんざい /現在/原罪/
げんざいいち /現在位置/
げんざいかいしゅうちゅう /現在改修中/
げんざいかいちくちゅう /現在改築中/
げんざいかいはつちゅう /現在開発中/
げんざいかんりょう /現在完了/
げんざいぎょう /現在行/
げんざいぎろん /現在議論/
げんざいけい /現在形/
げんざいけいかくちゅう /現在計画中/
げんざいけんとうちゅう /現在検討中/
げんざいげんいん /現在原因/
げんざいさいしん /現在最新/
げんざいしこう /現在施行/
げんざいしこうちゅう /現在試行中/
げんざいしょぞく /現在所属/
げんざいしよう /現在使用/
げんざいしようちゅう /現在使用中/
げんざいしんこうけい /現在進行形/
げんざいしんこうちゅう /現在進行中/
げんざいじこく /現在時刻/
げんざいじゅんびちゅう /現在準備中/
げんざいせこう /現在施行/
げんざいせってい /現在設定/
げんざいせんたくちゅう /現在選択中/
げんざいだか /現在高/
げんざいち /現在値/現在地/
げんざいちょうさちゅう /現在調査中/
げんざいてもと /現在手元/
げんざいにっぽん /現在日本/
げんざいにゅうしゅか /現在入手可/
げんざいはいばんちゅう /現在廃盤中/
げんざいはつばい /現在発売/
げんざいはつばいちゅう /現在発売中/
げんざいふつう /現在不通/
げんざいぶんし /現在分詞/
げんざいまで /現在迄/
げんざいみしよう /現在未使用/
げんざいもんだい /現在問題/
げんざいやく /現在約/
げんざいらいにちちゅう /現在来日中/
げんざいりょう /原材料/
げんざいりょうひ /原材料費/
げんざいりょこうちゅう /現在旅行中/
げんざぶろう /源三郎/
げんざん /減算/
げんざんかいろ /減算回路/
げんざんき /減算器/
げんざんけっか /減算結果/
げんざんそうさ /減算操作/
げんし /原子/原始/減資/原資/幻視/原紙/元祀/
げんしかく /原子核/
げんしかくがく /原子核学/
げんしかくこうがく /原子核工学/
げんしかくこうがくせんこう /原子核工学専攻/
げんしかくこうがっか /原子核工学科/
げんしかくぶつりがく /原子核物理学/
げんしかんすう /原始関数/
げんしきのうてき /原始帰納的/
げんしきのうてきかんすうるい /原始帰納的函数類/
げんしけい /原子系/
げんしげんご /原始言語/
げんししき /原始式/原子式/
げんしじん /原始人/
げんしすう /原子数/
げんしだん /原子団/
げんしち /源七/
げんしちょうしゃ /現市庁舎/
げんしつ /言質/
げんしていこう /原子定項/
げんしてき /原始的/
げんしとう /原始島/
げんしどけい /原子時計/
げんしながわえきまえ /現品川駅前/
げんしはんけい /原子半径/
げんしばんごう /原子番号/
げんしぶつりがく /原子物理学/
げんしぶやえき /現渋谷駅/
げんしぶんし /原子分子/
げんしほうかい /原子崩壊/
げんしみつど /原子密度/
げんしゃ /減車/
げんしゃかい /現社会/
げんしゃちょう /現社長/
げんしゅ /厳守/元首/原種/原酒/
げんしゅう /減収/
げんしゅく /厳粛/
げんしゅしょう /現首相/
げんしゅつ /現出/
げんしょ /原書/原初/
げんしょう /現象/減少/現症/
げんしょうかてい /減少過程/
げんしょうがく /現象学/
げんしょうけいこう /減少傾向/
げんしょうしゅぎ /減少主義/
げんしょうしゅぎしゃ /減少主義者/
げんしょうしゅぎしゃてき /減少主義者的/
げんしょうしゅぎてき /減少主義的/
げんしょうじたい /現象自体/
げんしょうたいおう /現象対応/
げんしょうてき /現象的/
げんしょうぶん /減少分/
げんしょうめん /現象面/
げんしょうりつ /減少率/
げんしょうりょう /減少量/
げんしょうろん /現象論/
げんしょうろんてき /現象論的/
げんしょく /現職/原色/減食/減色/
げんしょくけいかん /現職警官/
げんしょくげきだん /原色劇団/
げんしょくばん /原色版/
げんしょばん /原書版/
げんしりきこうがっか /原子力工学科/
げんしりょう /原資料/原子量/
げんしりょく /原子力/
げんしりょくけんきゅうしょ /原子力研究所/
げんしりょくさんぎょう /原子力産業/
げんしりょくじだい /原子力時代/
げんしりょくせつび /原子力設備/
げんしりょくせん /原子力船/
げんしりょくねんりょう /原子力燃料/
げんしりょくはくしょ /原子力白書/
げんしりょくはつでん /原子力発電/
げんしりょくはつでんしょ /原子力発電所/
げんしりょくひこうき /原子力飛行機/
げんしりょくれっしゃ /原子力列車/
げんしろ /原子炉/
げんしろぶつりがく /原子炉物理学/
げんしろん /原子論/
げんしろんりしき /原始論理式/原子論理式/
げんしん /原審/原信/
げんしんごう /原信号/元信号/
げんじ /源氏/源治/玄二/言辞/
げんじそくど /現示速度/
げんじっかい /現実解/
げんじつ /現実/
げんじつおん /現実音/
げんじつか /現実化/
げんじつかん /現実感/
げんじつげんそく /現実原則/
げんじつしゃかい /現実社会/
げんじつしゅぎしゃ /現実主義者/
げんじつせい /現実性/
げんじつせかい /現実世界/
げんじつてき /現実的/
げんじつてきかいとう /現実的回答/
げんじつてきたいおう /現実的対応/
げんじつとうひ /現実逃避/
げんじつとうひちゅう /現実逃避中/
げんじつにんしき /現実認識/
げんじつは /現実派/
げんじつみ /現実味/
げんじつもんだい /現実問題/
げんじつろせん /現実路線/
げんじつろん /現実論/
げんじてん /現時点/
げんじな /源氏名/
げんじぼうけい /源氏傍系/
げんじものがたり /源氏物語/
げんじゃく /減弱/
げんじゃくきょり /減弱距離/
げんじゅう /厳重/現住/幻獣/
げんじゅうかい /幻獣界/
げんじゅうきょ /現住居/
げんじゅうしょ /現住所/
げんじゅうしょち /現住所地/
げんじゅうじてん /幻獣辞典/
げんじゅうち /現住地/
げんじゅうちゅうい /厳重注意/
げんじゅうみん /原住民/
げんじゅうろう /幻十郎/
げんじょう /現状/現場/原状/玄奘/
げんじょういじ /現状維持/
げんじょういじあん /現状維持案/
げんじょういじは /現状維持派/
げんじょうかいせつ /現状解説/
げんじょうかいぜん /現状改善/
げんじょうかいふく /原状回復/現状回復/
げんじょうかくにん /現状確認/
げんじょうきょう /現状況/
げんじょうさいだい /現状最大/
げんじょうさんぞう /玄奘三蔵/
げんじょうしゃけん /原乗車券/
げんじょうしゃけんがく /原乗車券額/
げんじょうしゃけんるい /原乗車券類/
げんじょうしんこく /現状申告/
げんじょうたい /現状態/
げんじょうちょうさ /現状調査/
げんじょうついにん /現状追認/
げんじょうにんしき /現状認識/
げんじょうはあく /現状把握/
げんじょうふっき /現状復帰/
げんじょうふっきめいれい /現状復帰命令/
げんじょうぶんせき /現状分析/
げんじょうほうこく /現状報告/現況報告/
げんじょうほうこくしょ /現状報告書/
げんじょうほぞん /現場保存/
げんじょうもんだい /現状問題/
げんじょうようにん /現状容認/
げんじろう /源二郎/
げんじん /原人/
げんすい /減衰/元帥/減水/元師/
げんすいき /減衰器/
げんすいきょくせん /減衰曲線/
げんすいけいど /減衰傾度/
げんすいしんどう /減衰振動/
げんすいじかい /減衰磁界/
げんすいじかん /減衰時間/
げんすいじょうすう /減衰定数/
げんすいせいげんは /減衰正弦波/
げんすいていすう /減衰定数/
げんすいとくせい /減衰特性/
げんすいは /減衰波/
げんすいはせいぶん /減衰波成分/
げんすいばく /原水爆/
げんすいばくきんし /原水爆禁止/
げんすいりつ /減衰率/
げんすいりょう /減衰量/
げんすいりょく /減衰力/
げんすいりょくちょうせい /減衰力調整/
げんすう /減数/元数/
げんすん /原寸/
げんすんだい /原寸大/
げんず /原図/
げんずけい /原図形/
げんせい /厳正/現世/現勢/現姓/原生/
げんせいかえん /原生花園/
げんせいけん /現政権/
げんせいしぶ /原生篩部/
げんせいしんりん /原生森林/
げんせいちゅうしんちゅう /原生中心柱/
げんせいど /現制度/
げんせいどうぶつ /原生動物/
げんせいひん /現製品/
げんせいもくぶ /原生木部/
げんせいりん /原生林/
げんせき /原石/原籍/
げんせつ /言説/
げんせりやく /現世利益/
げんせん /厳選/源泉/原潜/言泉/
げんせんちょうしゅう /源泉徴収/
げんせんちょうしゅうぜい /源泉徴収税/
げんせんちょうしゅうひょう /源泉徴収票/
げんせんぶんり /源泉分離/
げんぜい /減税/
げんぜいこうか /減税効果/
げんぜん /厳然/儼然/
げんそ /元素/原素/
げんそう /幻想/現送/
げんそうきょく /幻想曲/
げんそうこうきょうがく /幻想交響楽/
げんそうこうきょうきょく /幻想交響曲/
げんそうてき /幻想的/
げんそうぶんがく /幻想文学/
げんそく /原則/減速/舷側/
げんそくうんどう /減速運動/
げんそくがわ /減速側/
げんそくきんえん /原則禁煙/
げんそくご /減速後/
げんそくざい /減速剤/減速材/
げんそくしゃせん /減速車線/
げんそくじ /減速時/
げんそくちゅう /減速中/
げんそくてき /原則的/
げんそくど /減速度/
げんそくはんだん /減速判断/
げんそくひ /減速比/
げんそくほうこう /減速方向/
げんそくまえ /減速前/
げんそくむりょう /原則無料/
げんそくりょく /減速力/
げんそくろん /原則論/
げんそん /現存/減損/玄孫/
げんぞう /現像/原像/
げんぞうえき /現像液/
げんぞうおんど /現像温度/
げんぞうかいすう /現像回数/
げんぞうしょ /現像所/
げんぞうしょり /現像処理/
げんぞうじかん /現像時間/
げんぞうじょうけん /現像条件/
げんぞうよう /現像用/
げんぞうりょうむりょう /現像料無料/
げんぞん /現存/
げんぞんぶぶん /現存部分/
げんた /源太/元太/玄太/
げんたい /減退/
げんたいいん /現隊員/
げんたいけん /原体験/
げんたいせい /現体制/
げんたかちほてつどう /現高千穂鉄道/
げんたつ /厳達/
げんたろう /厳太郎/玄太郎/
げんたん /減反/
げんたんか /原単価/
げんだ /源田/
げんだい /現代/原題/
げんだいえいご /現代英語/
げんだいえいわじてん /現代英和辞典/
げんだいおんがく /現代音楽/
げんだいおんがくか /現代音楽家/
げんだいおんがくし /現代音楽調/
げんだいかがく /現代科学/現代化学/
げんだいかがくてき /現代科学的/
げんだいかな /現代仮名/
げんだいかなづかい /現代仮名遣/現代仮名遣い/
げんだいがっき /現代楽器/
げんだいきょうようぶんこ /現代教養文庫/
げんだいきょく /現代曲/
げんだいげいじゅつ /現代芸術/
げんだいげき /現代劇/
げんだいこうつうせいさく /現代交通政策/
げんだいこくご /現代国語/
げんだいこくごじてん /現代国語辞典/
げんだいご /現代語/
げんだいごやく /現代語訳/現代誤訳/
げんだいさっきょくか /現代作曲家/
げんだいし /現代史/
げんだいしそう /現代思想/
げんだいしそうにゅうもん /現代思想入門/
げんだいしゃかい /現代社会/
げんだいしゅうごうろん /現代集合論/
げんだいしょかん /現代書館/
げんだいしょどう /現代書道/
げんだいじん /現代人/
げんだいすうがく /現代数学/
げんだいすうがくしゃ /現代数学社/
げんだいせいかつ /現代生活/
げんだいせん /現代戦/
げんだいちゅうごく /現代中国/
げんだいちゅうごくご /現代中国語/
げんだいてき /現代的/
げんだいにほんご /現代日本語/
げんだいにほんじん /現代日本人/
げんだいのうがくしゅう /現代能楽集/
げんだいばん /現代版/
げんだいひょう /現代表/
げんだいひょうき /現代表記/
げんだいびじゅつ /現代美術/
げんだいびょう /現代病/
げんだいふう /現代風/
げんだいぶつり /現代物理/
げんだいぶつりがく /現代物理学/
げんだいぶんめい /現代文明/
げんだいぶんめいびょう /現代文明病/
げんだいへん /現代編/
げんだいめい /原題名/
げんだいもの /現代物/
げんだいようご /現代用語/
げんだいよみ /現代読み/
げんだいわか /現代和歌/
げんだんかい /現段階/
げんち /現地/言質/
げんちかかく /現地価格/
げんちかかりいん /現地係員/
げんちがし /現地貸/
げんちご /現地語/
げんちしじょう /現地試乗/
げんちしゅうごう /現地集合/
げんちしゅくはく /現地宿泊/
げんちしゅさい /現地主催/
げんちしゅざい /現地取材/
げんちじかん /現地時間/
げんちじかんたい /現地時間帯/
げんちじょうほう /現地情報/
げんちじん /現地人/
げんちせいさん /現地生産/
げんちせいふ /現地政府/
げんちちょうさ /現地調査/
げんちちょうたつ /現地調達/
げんちつうか /現地通貨/
げんちてはい /現地手配/
げんちてん /現地点/
げんちとうちゃく /現地到着/
げんちはつ /現地発/
げんちほうじん /現地法人/
げんちゃり /原チャリ/
げんちゅう /原註/原虫/
げんちゅうしんちゅう /原中心柱/
げんちょ /原著/
げんちょう /幻聴/現調/弦長/
げんちょさくしゃ /原著作者/
げんちょさくぶつ /原著作物/
げんちょしゃ /原著者/
げんちょしゃちゅう /原著者註/
げんちょしょ /原著書/
げんちょろんぶん /原著論文/
げんちよみ /現地読み/
げんちりょこうしゃ /現地旅行社/
げんちろくおん /現地録音/
げんつき /原付/
げんつきいっしゅ /原付一種/
げんつきしゃ /原付車/
げんつきじどうしゃ /原付自動車/
げんつきにしゅ /原付二種/
げんつきめんきょ /原付免許/
げんてい /限定/
げんていかいじょ /限定解除/
げんていかいじょしけん /限定解除試験/
げんていくうかん /限定空間/
げんていし /限定子/限定詞/
げんていしゃ /限定車/
げんていしゅ /限定酒/
げんていしょうひん /限定商品/
げんていしょく /限定色/
げんていじょうけん /限定条件/
げんていじょうけんか /限定条件下/
げんていじょうぞう /限定醸造/
げんていせいさん /限定生産/
げんていつき /限定付/
げんていてき /限定的/
げんていてんぽ /限定店舗/
げんていはつばい /限定発売/
げんていばん /限定版/限定盤/
げんていひん /限定品/
げんていみかいじょ /限定未解除/
げんていめんきょ /限定免許/
げんていゆにゅう /限定輸入/
げんていりようしゃ /限定利用者/
げんてん /原点/減点/原典/
げんてんしゅぎ /原典主義/
げんてんすう /減点数/
げんてんちゅうじつしゅぎ /原典忠実主義/
げんてんちょうか /減点超過/
げんてんのう /現天皇/
げんてんばん /原典版/
げんでぃれくとりー /現ディレクトリー/
げんとう /厳冬/幻灯/幻燈/舷灯/
げんとうき /厳冬期/
げんとうきよう /厳冬期用/
げんとうしゅ /現当主/
げんど /限度/
げんどう /言動/原動/
げんどうき /原動機/
げんどうきつき /原動機付/
げんどうふいっち /言動不一致/
げんどうりょく /原動力/源動力/
げんどがく /限度額/
げんな /元和/
げんない /源内/
げんなおし /験直し/
げんなま /現ナマ/現生/
げんに /現に/
げんにほんご /源日本語/現日本語/
げんにん /現任/
げんのう /玄能/言翁/玄翁/
げんはけい /原波形/
げんはんけつ /原判決/
げんば /現場/
げんばかんとく /現場監督/
げんばがわ /現場側/
げんばく /原爆/
げんばくいりょうほう /原爆医療法/
げんばくしりょうかん /原爆資料館/
げんばくとうか /原爆投下/
げんばけんしょう /現場検証/
げんばしどうぶ /現場指揮部/
げんばつ /厳罰/
げんばふきん /現場付近/
げんばふっき /現場復帰/
げんばん /原版/原盤/
げんばんしようりょう /原盤使用料/
げんぱい /減配/
げんぱつ /原発/
げんぱつおき /原発沖/
げんぱつきき /原発危機/
げんぱつけんせつ /原発建設/
げんぱつじこ /原発事故/
げんぱつすいしんかんけい /原発推進関係/
げんぱつすいしんは /原発推進派/
げんぱつはんたい /原発反対/
げんぱつもんだい /原発問題/
げんぱつようねんりょう /原発用燃料/
げんひしつ /原皮質/
げんひそう /原皮層/
げんひょうひ /原表皮/
げんびん /減便/
げんぴ /厳秘/
げんぴょう /原票/
げんぴん /現品/
げんぴんかこう /現品加工/
げんぶ /玄武/
げんぶがん /玄武岩/
げんぶつ /現物/原物/
げんぶつしきゅう /現物支給/
げんぶつしきゅうひん /現物支給品/
げんぶん /原文/
げんぶんいっち /言文一致/
げんぶんいっちうんどう /言文一致運動/
げんぶんそう /弦分奏/
げんぷ /厳父/原譜/
げんぷう /厳封/
げんぷく /元服/
げんぺい /源平/
げんぺいせいすいき /源平盛衰記/
げんぺいとうまでん /源平討魔伝/
げんぼ /原簿/
げんぼく /原木/
げんぼん /原本/
げんぽう /減法/減俸/現法/
げんぽん /原本/
げんま /幻魔/玄馬/
げんまい /玄米/
げんまいしょく /玄米食/
げんまいちゃ /玄米茶/
げんまき /弦巻/
げんまたいせん /幻魔大戦/
げんみつ /厳密/
げんみつかい /厳密解/
げんみつかがく /厳密科学/
げんみつせい /厳密性/
げんむ /幻夢/幻梦/
げんむせんき /幻夢戦記/
げんめ /限目/
げんめい /言明/厳命/
げんめつ /幻滅/減滅/
げんめつぎみ /幻滅気味/
げんめん /減免/
げんもう /減耗/原毛/
げんもく /眩目/
げんもけい /原模型/
げんもん /厳門/
げんや /原野/幻夜/
げんやくいん /現役員/
げんゆ /原油/
げんゆう /現有/
げんゆうき /現有機/
げんゆうしゃりょう /現有車両/
げんゆうせつび /現有設備/
げんゆうとっきゅうしゃ /現有特急車/
げんゆうひん /現有品/
げんゆかかく /原油価格/
げんゆりゅうしゅつ /原油流出/
げんよう /現用/幻幼/原葉/
げんようへいき /現用兵器/
げんり /原理/
げんりいがい /原理以外/
げんりけん /原理研/
げんりけんきゅう /原理研究/
げんりげんそく /原理原則/
げんりげんそくてき /原理原則的/
げんりしゅぎ /原理主義/
げんりしゅぎしゃ /原理主義者/
げんりじょう /原理上/
げんりすいさつ /原理推察/
げんりず /原理図/
げんりてき /原理的/
げんりゅう /源流/原流/
げんりゅういきふきん /源流域付近/
げんりゅうすい /源流水/
げんりゅうち /限流値/
げんりょう /限量/原料/減量/
げんりょうか /限量化/減量化/
げんりょうきごう /限量記号/
げんりょうし /限量子/
げんろう /元老/
げんろういん /元老院/
げんろく /元禄/
げんろくずし /元禄寿司/
げんろせん /現路線/
げんろん /原論/言論/
げんろんじゆう /言論自由/
げんろんせいげん /言論制限/
げんろんだんあつ /言論弾圧/
げんろんとうせい /言論統制/
げんろんぶん /原論文/
げんわかやま /現和歌山/
げんわく /眩惑/幻惑/
げんわくてき /幻惑的/
こ /子/個/小/庫/顧/湖/鼓/誇/雇/戸/弧/故/古/固/股/孤/狐/胡/鈷/跨/虎/菰/己/糊/袴/児/琥/娘/来/呼/枯/扈/姑/乎/コ/粉/木/⌒/箇/冴/女/个/估/來/兒/冱/凅/刳/呱/夸/徠/怙/杞/柧/桍/楜/沽/涸/滬/滸/濾/瓠/痼/瞽/箍/粐/罟/胯/葫/虍/乕/蛄/蝴/蠱/觚/詁/辜/錮/餬/鴣/皷/ヶ/壺/壷/炬/去/拠/虚/瑚/仔/
こ> /仔/小/
こーかさす /高加索/
こーす /コース/
こーち /コーチ/
こーでぃねーしょん /コーディネーション/
こーと /コート/
こーど /コード/
こーな /コーナ/
こーひー /コーヒー/珈琲/
こーぽ /コーポ/
こーらす /コーラス/
こーる /コール/
こーるど /コールド/
こーるばっく /コールバック/
こーん /コーン/
こあくつ /小圷/
こあくとう /小悪党/
こあくま /小悪魔/
こあくまてき /小悪魔的/
こあざ /小字/
こあし /小足/
こあみ /小網/
こあみちょう /小網町/
こあら /伊熊描/古荒/コアラ/
こい /恋/鯉/故意/戀/湖衣/濃/
こいうた /恋唄/恋歌/
こいがくぼ /恋ヶ窪/
こいがたき /恋敵/
こいがわ /鯉川/
こいき /小粋/
こいけ /小池/菰池/
こいけだ /小池田/
こいこ /恋子/
こいごころ /恋心/
こいし /小石/礫/
こいしかわ /小石川/
こいしわら /小石原/
こいじ /恋路/
こいずみ /小泉/
こいずみきょうこ /小泉今日子/
こいそ /小磯/
こいち /小市/
こいちじかん /小一時間/
こいちゃ /濃茶/
こいてき /故意的/
こいで /小出/
こいでほうこう /小出方向/
こいと /小糸/
こいとせいさくしょ /小糸製作所/
こいなか /恋仲/
こいにょうぼう /恋女房/
こいぬ /子犬/仔犬/小犬/
こいぬま /鯉沼/濃沼/
こいのぼり /鯉幟/
こいひとよ /恋一夜/
こいひめ /湖衣姫/
こいびと /恋人/
こいびとどうし /恋人同士/恋人同志/
こいびとやく /恋人役/
こいぶち /鯉淵/鯉渕/
こいぶみ /恋文/
こいぶみよこちょう /恋文横丁/
こいものがたり /恋物語/
こいわ /小岩/
こいわい /小岩井/
こいん /コイン/雇員/
こう /項/高/行/公/工/広/向/考/構/敲/後/光/衡/好/更/稿/甲/降/講/鉱/慌/厚/香/溝/購/口/航/皇/荒/鴻/校/酵/港/郊/耕/恒/浩/横/攻/抗/硬/巷/垢/肯/紅/晃/交/絞/紘/貢/砿/閤/鋼/膏/肱/拘/江/腔/幸/洪/康/弘/控/綱/黄/梗/糠/廣/昂/杭/剛/勾/興/庚/河/効/功/侯/孝/宏/絋/縞/候/坑/巧/喉/倖/后/孔/佼/耿/爻/乞/晧/睾/肛/胱/膠/鴿/国府/叩/亙/亘/亢/伉/佝/倥/傚/冓/冦/凰/匣/吭/吼/呷/咬/哄/哽/哮/啌/嚆/壙/媾/嫦/寇/峇/峺/崗/徨/怐/恆/恍/惶/慷/扣/扛/搆/攷/效/杲/昊/昴/晄/曠/昿/棡/椌/槁/槓/槹/汞/洽/洸/浤/淆/湟/溘/滉/烋/煌/熕/犒/狎/狡/猴/畊/皋/皎/皓/盍/矼/礦/磽/稾/窖/箜/篝/簧/絳/絖/絎/纐/缸/羔/肓/胛/薨/蚣/蛟/蝗/覯/訌/詬/誥/逅/遑/遘/鉤/鍠/鎬/鏗/鑛/閘/閧/闔/隍/靠/頏/餃/鬨/鱇/鵁/黌/斯う/耗/袷/鈎/恰/仰/肴/皐/衝/塙/頁/湊/劫/嵩/藁/桁/鮫/釦/蛤/尻/幌/岬/撹/虹/岡/神/
こう# /高#0/
こう> /高/広/
こうあ /興亜/
こうあせきゆ /興亜石油/
こうあっしつ /高圧室/
こうあっしゅく /高圧縮/
こうあつ /高圧/降圧/
こうあつせん /高圧線/
こうあつそうでんせん /高圧送電線/
こうあつちょくりゅう /高圧直流/
こうあつでんせん /高圧電線/
こうあつでんりゅう /高圧電流/
こうあつぶぶん /高圧部分/
こうあん /考案/公安/公案/
こうあんいいんかい /公安委員会/
こうあんかん /公安官/
こうあんかんけいしゃ /公安関係者/
こうあんきょく /公安局/
こうあんしつ /公安室/
こうあんしゃ /考案者/
こうあんじょうれい /公安条例/
こうあんちゅう /考案中/
こうあんとうきょく /公安当局/
こうい /行為/好意/高位/更衣/厚意/口胃/校医/好位/皇位/
こういき /広域/高域/
こういきかがく /広域科学/
こういききょうしん /高域共振/
こういききょうちょう /高域強調/
こういきけいさんき /広域計算機/
こういきこうえんまえ /広域公園前/
こういきさいせい /高域再生/
こういきせいぶん /高域成分/
こういきつうきんせん /広域通勤線/
こういきとくせい /高域特性/
こういきぶんさんかんきょう /広域分散環境/
こういきへんすうせんげん /広域変数宣言/
こういきろくおん /高域録音/
こういけいしょう /皇位継承/
こういしつ /更衣室/
こういしゃ /行為者/
こういしょう /後遺症/
こういじたい /行為自体/
こういじょ /更衣所/
こういち /浩一/康一/孝一/幸一/光一/高一/孝市/公一/功一/幸市/弘一/晃一/耕一/剛一/興一/興市/好一/好位置/宏一/巧一/航一/康市/晃市/高１/耿一/講一/鉱一/
こういちろう /浩一郎/興一郎/鴻一郎/幸一郎/晃一朗/光一郎/公一郎/宏一良/康一郎/耕一郎/幸一朗/
こういってん /紅一点/
こういてき /好意的/
こういど /高緯度/
こういどうよう /行為同様/
こういどちたい /高緯度地帯/
こういのうりょく /行為能力/
こういん /公印/工員/拘引/行員/光陰/荒淫/
こうう /降雨/
こううじ /降雨時/
こううりょう /降雨量/
こううりん /後右輪/
こううん /幸運/好運/耕耘/航運/
こううんかく /光雲閣/
こううんき /耕運機/耕耘機/
こううんてんだい /高運転台/
こううんふうん /幸運不運/
こうえい /光栄/公営/光影/後衛/後裔/
こうえいきぎょうたい /公営企業体/
こうえいきょう /好影響/
こうえいけいば /公営競馬/
こうえいしごく /光栄至極/
こうえいだんたい /公営団体/
こうえいとばく /公営賭博/
こうえいば /公営馬/
こうえいろん /公営論/
こうえき /交易/公益/公役/
こうえきせい /公益性/
こうえつ /校閲/
こうえねけん /高エネ研/高エネルギー研究所/高エネルギー物理学研究所/
こうえねるぎ /高エネルギー/
こうえねるぎー /高エネルギー/
こうえん /講演/公園/公演/後援/好演/光塩/高塩/後縁/
こうえんかい /講演会/後援会/
こうえんかいご /講演会後/
こうえんかいさんか /講演会参加/
こうえんかいすう /公演回数/
こうえんがわ /公園側/
こうえんきぼう /講演希望/
こうえんきょくもく /公演曲目/
こうえんけいしき /講演形式/
こうえんけんすう /講演件数/
こうえんしゃ /講演者/後援者/
こうえんしゃきん /講演謝金/
こうえんしゅう /講演集/
こうえんしゅうりょうご /講演終了後/
こうえんしょうざいとうよ /抗炎症剤投与/
こうえんしりょう /講演資料/
こうえんじ /高円寺/
こうえんじいせい /高円寺以西/
こうえんじえき /高円寺駅/
こうえんじかん /講演時間/公演時間/
こうえんじゅん /講演順/
こうえんじょうほう /公演情報/
こうえんじょがくいん /光塩女学院/
こうえんじょしがくいん /光塩女子学院/
こうえんせいびか /公園整備課/
こうえんだいめい /講演題名/
こうえんだいもく /講演題目/
こうえんちゅうし /公演中止/
こうえんちょう /公園町/
こうえんない /公園内/
こうえんないよう /公演内容/講演内容/
こうえんないようがいよう /講演内容概要/
こうえんはっぴょう /講演発表/
こうえんび /公演日/講演日/
こうえんまえ /公園前/
こうえんめい /公演名/
こうえんよこうしっぴつ /講演予稿執筆/
こうえんりょう /講演料/
こうえんろんぶんしゅう /講演論文集/
こうえんろんぶんしゅうひ /講演論文集費/
こうお /好悪/
こうおつ /甲乙/
こうおつつけ /甲乙付/
こうおん /高温/恒温/構音/硬音/高音/厚恩/
こうおんあつ /高音圧/
こうおんいき /高音域/
こうおんかくゆうごう /高温核融合/
こうおんがわ /高温側/高音側/
こうおんきょうちょう /高音強調/
こうおんこうあつ /高温高圧/
こうおんしつ /高音質/好音質/
こうおんしつついきゅう /高音質追及/
こうおんじ /高温時/
こうおんせいぶん /高音成分/
こうおんそう /恒温槽/
こうおんちょうでんどう /高温超伝導/
こうおんどうぶつ /恒温動物/
こうおんぶ /高音部/
こうか /効果/高価/高架/降下/工科/硬貨/硬化/考課/甲賀/校歌/黄禍/功科/晃華/孔果/
こうかい /公開/後悔/航海/高階/更改/黄海/公海/紅海/後回/狡獪/
こうかいか /公開可/
こうかいかぎ /公開鍵/
こうかいかぎあんごう /公開鍵暗号/
こうかいかのう /公開可能/
こうかいかんすう /高階関数/
こうかいがくせんこう /航海学専攻/
こうかいき /航海記/
こうかいきょか /公開許可/
こうかいきんし /公開禁止/
こうかいぎ /公会議/
こうかいこうえんかい /公開講演会/
こうかいこうざ /公開講座/
こうかいご /公開後/
こうかいさくひん /公開作品/
こうかいし /航海士/
こうかいしせつ /公開施設/
こうかいしつもんじょう /公開質問状/
こうかいしゅうちゅうこうぎ /公開集中講義/
こうかいしょけいじょう /公開処刑場/
こうかいじ /公開時/
こうかいじゅんび /公開準備/
こうかいじょうほう /公開情報/
こうかいずみ /公開済/
こうかいせいげん /公開制限/
こうかいぞうせいぶん /高解像成分/
こうかいぞうど /高解像度/
こうかいたいきょく /公開対局/
こうかいちゅう /航海中/
こうかいちょう /航海長/
こうかいちょうせんじょう /公開挑戦状/
こうかいちょくぜん /公開直前/
こうかいてん /高回転/
こうかいてんいき /高回転域/
こうかいてんいきよう /高回転域用/
こうかいてんがた /高回転型/
こうかいてんじ /高回転時/
こうかいてんそうこう /高回転走行/
こうかいてんよう /高回転用/
こうかいとうじ /公開当時/
こうかいとうろん /公開討論/
こうかいどう /公会堂/
こうかいなまほうそう /公開生放送/
こうかいはん /航海班/
こうかいはんてい /高階判定/
こうかいばん /公開版/
こうかいび /公開日/
こうかいほうほう /公開方法/
こうかいまえ /公開前/
こうかいもんだい /公開問題/
こうかいよてい /公開予定/
こうかいれんしゅう /公開練習/
こうかいろくおん /公開録音/
こうかいろくが /公開録画/
こうかいろんり /高階論理/
こうかえき /高架駅/
こうかおん /効果音/
こうかおんてき /効果音的/
こうかおんはっせいき /効果音発生器/
こうかか /高架化/
こうかかく /高価格/
こうかかくしこう /高価格志向/
こうかかこうじ /高架化工事/
こうかかじぎょう /高架化事業/
こうかがく /光化学/
こうかがくえん /晃華学園/
こうかき /効果器/
こうかきかえ /項書換え/
こうかきかえけい /項書き換え系/
こうかきょう /高架橋/
こうかく /降格/広角/甲殻/口角/攻殻/高角/厚角/交角/
こうかくがわ /広角側/
こうかくきどうたい /攻殻機動隊/甲殻機動隊/
こうかくけい /広角系/
こうかくさいぼう /厚角細胞/
こうかくじゅう /甲殻獣/
こうかくそしき /厚角組織/
こうかくそしきさいぼう /厚角組織細胞/
こうかくど /高角度/
こうかくほう /高角砲/
こうかくりつ /高確率/
こうかくるい /甲殻類/甲殼類/
こうかこうじ /高架工事/
こうかしきどうろ /高架式道路/
こうかした /高架下/
こうかしょう /効果小/
こうかじ /硬化時/
こうかじかん /硬化時間/
こうかじぎょう /高架事業/
こうかじゅう /高荷重/
こうかじゅつ /硬化術/
こうかじょう /高架上/
こうかせん /高架線/
こうかせんろ /高架線路/
こうかぜつだい /効果絶大/
こうかそくど /降下速度/
こうかそくどしゃ /高加速度車/
こうかたんだい /工科短大/
こうかだい /効果大/
こうかだいがく /工科大学/
こうかっせい /高活性/
こうかつ /狡猾/
こうかてき /効果的/
こうかどうろ /高架道路/
こうかはんてい /効果判定/
こうかばつぐん /効果抜群/
こうかひょう /考課表/
こうかふこうか /幸か不幸か/
こうかぶぶん /高架部分/
こうかぶん /効果分/
こうかみ /鴻上/
こうかろん /黄禍論/
こうかん /交換/好感/交感/交歓/鋼管/高官/公刊/公館/好漢/巷間/
こうかんあいて /交換相手/
こうかんいがい /交換以外/
こうかんいじょう /交換以上/
こうかんえき /交換駅/
こうかんか /交換可/
こうかんかい /交換会/交歓会/
こうかんかかく /交換価格/
こうかんかのう /交換可能/
こうかんかんけい /交換関係/
こうかんかんすう /交換関数/
こうかんがくせい /交換学生/
こうかんがた /交換型/
こうかんき /交換機/交換器/
こうかんきかん /交換期間/
こうかんきのう /交換機能/
こうかんきぼう /交換希望/
こうかんきょく /交換局/
こうかんけい /項関係/
こうかんけいしき /交換形式/
こうかんけん /交換研/
こうかんこうちん /交換工賃/
こうかんご /交換後/
こうかんしき /交換式/
こうかんしせつ /交換施設/
こうかんしゅ /交換手/
こうかんしゅだん /交換手段/
こうかんしょく /好感触/
こうかんしょり /交換処理/
こうかんしんけい /交感神経/
こうかんじ /交換時/
こうかんじかん /交換時間/
こうかんじき /交換時期/
こうかんじぎょうぶ /交換事業部/
こうかんじっけん /交換実験/
こうかんじゅし /交換樹脂/
こうかんじょ /交換所/
こうかんじょうけん /交換条件/
こうかんじょうやく /交換条約/
こうかんずみ /交換済/
こうかんせいぎょ /交換制御/
こうかんせつび /交換設備/
こうかんせつびせっち /交換設備設置/
こうかんだい /交換台/
こうかんちゅう /交換中/
こうかんちょくご /交換直後/
こうかんていど /交換程度/
こうかんてすうりょう /交換手数料/
こうかんど /高感度/好感度/
こうかんにっき /交換日記/
こうかんばいたい /交換媒体/
こうかんばり /交換針/
こうかんひりつ /交換比率/
こうかんひん /交換品/
こうかんひんど /交換頻度/
こうかんふよう /交換不要/
こうかんぶ /交換部/
こうかんぶひん /交換部品/
こうかんほうしき /交換方式/
こうかんほうそく /交換法則/
こうかんほうほう /交換方法/
こうかんまえ /交換前/
こうかんまく /交換膜/
こうかんもう /交換網/
こうかんもうじょう /交換網上/
こうかんよう /交換用/
こうかんようせんろ /交換用線路/
こうかんようふごう /交換用符号/
こうかんりつ /交換律/交換率/
こうかんりゅうがく /交換留学/
こうかんりゅうがくせいど /交換留学制度/
こうかんれき /交換歴/
こうが /甲賀/黄河/高雅/光画/
こうがい /口外/梗概/公害/郊外/口蓋/校外/構外/光害/坑外/港外/慷慨/慷概/笄/
こうがいえき /郊外駅/
こうがいおん /口蓋音/
こうがいがた /郊外型/
こうがいがわ /郊外側/
こうがいじ /紅孩児/
こうがいせん /郊外線/
こうがいそしょう /公害訴訟/
こうがいたいさく /公害対策/
こうがいてつどう /郊外鉄道/
こうがいてん /郊外店/
こうがいでんしゃ /郊外電車/
こうがいぼうし /公害防止/
こうがいもんだい /公害問題/
こうがいよう /郊外用/
こうがく /工学/後学/光学/高額/向学/溝壑/
こうがくいん /工学院/
こうがくいんだい /工学院大/
こうがくいんだいがく /工学院大学/
こうがくか /工学科/
こうがくかい /工学会/
こうがくかてい /工学課程/
こうがくかんけい /光学関係/
こうがくがっか /工学学科/
こうがくきき /光学機器/
こうがくきそ /工学基礎/
こうがくきょうしつ /工学教室/
こうがくけい /工学系/光学系/
こうがくけいけんきゅうか /工学系研究科/
こうがくけいさん /工学計算/
こうがくけん /工学研/
こうがくけんきゅう /工学研究/
こうがくけんきゅうか /工学研究科/
こうがくけんきゅうかい /工学研究会/
こうがくけんきゅうしつ /工学研究室/
こうがくけんきゅうしゃ /工学研究者/
こうがくけんきゅうしょ /工学研究所/
こうがくけんきゅうじょ /工学研究所/
こうがくけんびきょう /光学顕微鏡/
こうがくこう /工学校/
こうがくこうぎょう /光学工業/
こうがくこうざ /工学講座/
こうがくごうせい /光学合成/
こうがくし /工学士/
こうがくしき /光学式/
こうがくしゃ /工学社/工学者/好学社/
こうがくしゅうし /工学修士/
こうがくしょ /工学書/
こうがくしょうきん /高額賞金/
こうがくしょうひん /高額商品/
こうがくしょとくしゃ /高額所得者/
こうがくしん /向学心/
こうがくじ /光学事/
こうがくじっけん /工学実験/
こうがくじっけんしつ /工学実験室/
こうがくじょう /工学上/
こうがくせい /光学製/
こうがくせいのう /光学性能/
こうがくせっけい /光学設計/
こうがくせんこう /工学専攻/
こうがくせんこうしゅうし /工学専攻修士/
こうがくせんしゅう /工学専修/
こうがくてき /工学的/光学的/
こうがくてききそ /工学的基礎/
こうがくてきしきさい /工学的色彩/
こうがくてきそくてい /光学的測定/
こうがくてきほうほう /工学的方法/
こうがくとくせい /光学特性/
こうがくねん /高学年/
こうがくはかせ /工学博士/
こうがくはくし /工学博士/
こうがくぶ /工学部/
こうがくぶかい /工学部会/
こうがくぶかがく /工学部化学/
こうがくぶかがくけい /工学部化学系/
こうがくぶけいゆ /工学部経由/
こうがくぶけいゆう /工学部経由/
こうがくぶこうしゃ /工学部校舎/
こうがくぶしゅっしん /工学部出身/
こうがくぶしゅっしんしゃ /工学部出身者/
こうがくぶぜんたい /工学部全体/
こうがくぶちょう /工学部長/
こうがくぶてき /工学部的/
こうがくぶで /工学部出/
こうがくぶでんき /工学部電気/
こうがくぶない /工学部内/
こうがくぶひん /高額部品/
こうがくぶほんぶとう /工学部本部棟/
こうがくぶまえ /工学部前/
こうがくぼうえんきょう /光学望遠鏡/
こうがくめん /光学面/工学面/
こうがくや /工学屋/
こうがくようご /工学用語/
こうがくれき /高学歴/
こうがくろん /工学論/
こうがぐん /甲賀郡/
こうがしつ /高画質/
こうがしゃ /恒河沙/
こうがっか /工学科/工学課/
こうがっかい /工学会/
こうがぶ /光画部/
こうがりゅう /甲賀流/
こうがん /睾丸/紅顔/厚顔/
こうがんざい /抗癌剤/
こうがんむち /厚顔無恥/
こうき /後期/後記/工期/高貴/好奇/好機/広軌/香気/後気/光輝/幸毅/浩貴/公器/高機/好輝/工機/康熈/校規/綱紀/衡機/光樹/公起/幸喜/降旗/好気/
こうきあつ /高気圧/
こうきあつだん /高気圧団/
こうきかくじゅうたく /高規格住宅/
こうきかくどうろ /高規格道路/
こうきかてい /後期課程/
こうきがた /後期型/
こうきしけん /後期試験/
こうきしゃ /後期車/
こうきしん /好奇心/
こうきしんおうせい /好奇心旺盛/
こうきじてん /康煕字典/
こうきせい /好気性/
こうきせいきん /好気性菌/
こうきち /厚吉/孝吉/幸吉/康吉/耕吉/光吉/
こうきど /高輝度/
こうきのう /高機能/
こうきのうか /高機能化/
こうきはかせかてい /後期博士課程/
こうきみつ /高気密/
こうきみつか /高気密化/
こうきみつよう /高気密用/
こうきゅう /高級/恒久/講究/高給/公休/硬球/降級/考究/鋼球/後宮/降給/光球/
こうきゅうえん /好救援/
こうきゅうか /高級化/
こうきゅうかん /高級感/
こうきゅうかんりょう /高級官僚/
こうきゅうき /高級機/
こうきゅうきしゅ /高級機種/
こうきゅうぎょ /高級魚/
こうきゅうげんご /高級言語/
こうきゅうこうぐ /高級工具/
こうきゅうごびゅう /高級語彙/
こうきゅうざい /高級材/
こうきゅうしゃ /高級車/
こうきゅうしゃてき /高級車的/
こうきゅうしゅうかてい /光吸収過程/
こうきゅうしょうふ /高級娼婦/
こうきゅうじゅうたくがい /高級住宅街/
こうきゅうじゅうたくち /高級住宅地/
こうきゅうじょうようしゃ /高級乗用車/
こうきゅうてき /恒久的/
こうきゅうひん /高級品/
こうきゅうび /公休日/
こうきゅうりょうり /高級料理/
こうきゅうろく /講究録/
こうきょ /皇居/薨去/鉤距/
こうきょう /交響/公共/好況/広狭/口供/鋼橋/
こうきょういく /公教育/
こうきょうがく /交響楽/
こうきょうがくだん /交響楽団/
こうきょうきかん /公共機関/
こうきょうきょく /交響曲/
こうきょうきょくぜんしゅう /交響曲全集/
こうきょうくみきょく /交響組曲/
こうきょうこうこくきこう /公共広告機構/
こうきょうこうつう /公共交通/
こうきょうこうつうきかん /公共交通機関/
こうきょうこうつうせいび /公共交通整備/
こうきょうざい /公共財/
こうきょうし /交響詩/
こうきょうしせつ /公共施設/
こうきょうしん /公共心/
こうきょうじぎょう /公共事業/
こうきょうじぎょうひ /公共事業費/
こうきょうせい /公共性/
こうきょうだんたい /公共団体/
こうきょうてき /公共的/
こうきょうてきだんしょう /交響的断章/
こうきょうてきでんそう /公共的伝送/
こうきょうてきりえき /公共的利益/
こうきょうとうし /公共投資/
こうきょうとしょかん /公共図書館/
こうきょうどぶんぷ /光強度分布/
こうきょうぶつ /公共物/
こうきょうほうそう /公共放送/
こうきょうようすいいき /公共用水域/
こうきょく /鉤曲/
こうきん /公金/拘禁/抗菌/
こうきんかっせいたん /抗菌活性炭/
こうきんざい /抗菌剤/抗菌材/
こうきんせい /抗菌性/
こうきんり /高金利/
こうぎ /講義/抗議/広義/恒偽/高誼/厚誼/好誼/
こうぎいん /工技院/工業技術院/
こうぎいんゆうごうけん /工技院融合研/
こうぎうんどう /抗議運動/
こうぎかもく /講義科目/
こうぎけいしき /講義形式/
こうぎけん /航技研/
こうぎこうどう /抗議行動/
こうぎしつ /講義室/
こうぎしゅほう /抗議手法/
こうぎしりょう /講義資料/
こうぎじゅつぶ /光技術部/
こうぎじょう /抗議状/
こうぎせきぶん /広義積分/
こうぎたいしょう /抗議対象/
こうぎちゅう /講義中/
こうぎとう /講義搭/講義棟/
こうぎないよう /講義内容/
こうぎぶん /抗議文/
こうぎめい /講義名/
こうぎょう /工業/興業/鉱業/興行/航業/鋼業/
こうぎょうあいか /工業哀歌/
こうぎょうかい /工業会/興行界/
こうぎょうかがく /工業化学/
こうぎょうかんけい /興行関係/
こうぎょうきかく /工業規格/
こうぎょうきんし /興行禁止/
こうぎょうぎじゅつ /工業技術/
こうぎょうぎじゅついん /工業技術院/
こうぎょうけいそく /工業計測/
こうぎょうけん /鉱業権/
こうぎょうこうこう /工業高校/
こうぎょうこうとうせんもんがっこう /工業高等専門学校/
こうぎょうしゃ /興行者/
こうぎょうしょゆうけん /工業所有権/
こうぎょうしょゆうけんほう /工業所有権法/
こうぎょうしんぶん /工業新聞/
こうぎょうしんぶんしゃ /工業新聞社/
こうぎょうすうがくこうざ /工業数学講座/
こうぎょうせいせき /興業成績/興行成績/
こうぎょうせいひん /工業製品/
こうぎょうせっけいしゃ /工業設計者/
こうぎょうだいがく /工業大学/
こうぎょうち /工業地/
こうぎょうちたい /工業地帯/
こうぎょうちょうさかい /工業調査会/
こうぎょうてき /工業的/興業的/興行的/
こうぎょうとし /工業都市/
こうぎょうはいきぶつ /工業廃棄物/
こうぎょうよう /工業用/
こうぎょうりっこく /工業立国/
こうぎょうりょく /工業力/
こうぎょうれんめい /工業連盟/
こうぎょく /紅玉/硬玉/
こうぎろく /講義録/
こうく /校区/鉤矩/工区/
こうくう /航空/口腔/高空/
こうくういどう /航空移動/
こうくううちゅう /航空宇宙/
こうくううちゅうがっか /航空宇宙学科/
こうくううちゅうぎけん /航空宇宙技研/
こうくううんちん /航空運賃/
こうくうかいすうけん /航空回数券/
こうくうかもつ /航空貨物/
こうくうかんけい /航空関係/
こうくうがいしゃ /航空会社/
こうくうがいしゃがわ /航空会社側/
こうくうがっか /航空学科/
こうくうき /航空機/
こうくうきぎじゅつ /航空機技術/
こうくうきじこ /航空機事故/
こうくうきょうてい /航空協定/
こうくうきょく /航空局/
こうくうきよう /航空機用/
こうくうぎょうかい /航空業界/
こうくうぎょうせい /航空行政/
こうくうぎょらい /航空魚雷/
こうくうけん /航空券/
こうくうけんかんけい /航空券関係/
こうくうけんきゅうかい /航空研究会/
こうくうげか /口腔外科/
こうくうこうがっか /航空工学科/
こうくうこうげき /航空攻撃/
こうくうこうせん /航空高専/
こうくうごごびん /航空午後便/
こうくうさい /航空祭/
こうくうざっし /航空雑誌/
こうくうしゃしん /航空写真/
こうくうじえいたい /航空自衛隊/
こうくうじこくひょう /航空時刻表/
こうくうじゆうか /航空自由化/
こうくうじょうほう /航空情報/
こうくうせいのう /高空性能/
こうくうせん /航空戦/
こうくうせんとう /航空戦闘/
こうくうたい /航空隊/
こうくうてっこうばくだん /航空撤甲爆弾/
こうくうない /口腔内/
こうくうひ /航空費/
こうくうびん /航空便/
こうくうぶ /航空部/
こうくうぶたい /航空部隊/
こうくうへいりょく /航空兵力/
こうくうへんたい /航空編隊/
こうくうほう /航空法/
こうくうぼかん /航空母艦/
こうくうむせん /航空無線/
こうくうゆそう /航空輸送/
こうくうろ /航空路/
こうくうろせん /航空路線/
こうぐ /工具/
こうぐいっしき /工具一式/
こうぐう /厚遇/
こうぐち /高口/坑口/
こうぐてん /工具店/
こうぐるい /工具類/
こうぐん /皇軍/行軍/蝗軍/
こうけい /光景/後継/後経/項型/口径/後傾/皇兄/肯綮/黄経/
こうけいき /後継機/好景気/
こうけいきしゅ /後継機種/
こうけいさんけい /項計算系/
こうけいしゃ /後継者/
こうけいしゃしゅ /後継車種/
こうけいしゃなん /後継者難/
こうけいしゃぶそく /後継者不足/
こうけいしゃもんだい /後継者問題/
こうけいそうさい /後継総裁/
こうけいば /後継馬/
こうけっか /好結果/
こうけっかくざい /抗結核剤/
こうけつ /高潔/纐纈/絞結/硬結/
こうけつあつ /高血圧/
こうけん /貢献/後見/後件/硬券/光顕/公権/工研/高見/甲券/後験/
こうけんど /貢献度/
こうけんにゅうじょうけん /硬券入場券/
こうけんにん /後見人/
こうけんぶ /後件部/
こうけんりょく /公権力/
こうげい /工芸/工藝/
こうげいがくぶ /工芸学部/
こうげいし /工芸史/
こうげいせんいだい /工芸繊維大/
こうげいてん /工芸展/
こうげいひん /工芸品/
こうげき /攻撃/
こうげきか /攻撃下/
こうげきかいし /攻撃開始/
こうげきかいすう /攻撃回数/
こうげきかのう /攻撃可能/
こうげきがた /攻撃型/
こうげきがたうちゅうせん /攻撃型宇宙船/
こうげきがわ /攻撃側/
こうげきがわせんしゅ /攻撃側選手/
こうげきがわゆうり /攻撃側有利/
こうげきき /攻撃機/
こうげききかい /攻撃機会/
こうげきけん /攻撃権/
こうげきこうどう /攻撃行動/
こうげきさき /攻撃先/
こうげきさんか /攻撃参加/
こうげきしゅだん /攻撃手段/
こうげきしょうどう /攻撃衝動/
こうげきじ /攻撃時/
こうげきじゅん /攻撃順/
こうげきせい /攻撃性/
こうげきたい /攻撃隊/
こうげきだま /攻撃玉/
こうげきちゅう /攻撃中/
こうげきちょくぜん /攻撃直前/
こうげきてき /攻撃的/
こうげきてきいけん /攻撃的意見/
こうげきてきせいかく /攻撃的性格/
こうげきにんむ /攻撃任務/
こうげきは /攻撃派/
こうげきはんてい /攻撃判定/
こうげきほう /攻撃法/
こうげきほうほう /攻撃方法/
こうげきまほう /攻撃魔法/
こうげきめいれい /攻撃命令/
こうげきめん /攻撃面/
こうげきもくひょう /攻撃目標/
こうげきよう /攻撃用/
こうげきよういん /攻撃要員/
こうげきりょく /攻撃力/
こうげきわざ /攻撃技/
こうげつ /香月/
こうげん /公言/高原/光源/口減/巧言/広言/抗原/膠原/鉤玄/
こうげんがく /考現学/
こうげんがくかんけい /考現学関係/
こうげんきょうど /光源強度/
こうげんびょう /膠原病/
こうげんぶんぷ /抗原分布/
こうげんほうこう /光源方向/
こうげんれいしょく /巧言令色/
こうこ /公庫/江湖/考古/後顧/
こうこう /高校/孝行/航行/口腔/後行/膏肓/後攻/交媾/煌々/耿々/鉤校/
こうこういこう /高校以降/
こうこういちねん /高校一年/
こうこういちねんせい /高校一年生/
こうこういらい /高校以来/
こうこうえんげきぶ /高校演劇部/
こうこうがわ /高校側/
こうこうきょうかしょ /高校教科書/
こうこうきょうし /高校教師/
こうこうぎょう /鉱工業/
こうこうけっしょう /高校決勝/
こうこうこうざ /孝行講座/
こうこうさ /光行差/
こうこうしゅっしん /高校出身/
こうこうじ /高校時/
こうこうじだい /高校時代/
こうこうじだいいらい /高校時代以来/
こうこうじゅけん /高校受験/
こうこうじょし /高校女子/
こうこうじょせき /高校除籍/
こうこうすうがく /高校数学/
こうこうせい /高校生/後行性/
こうこうせいいか /高校生以下/
こうこうせいかつ /高校生活/
こうこうせいくらい /高校生位/
こうこうせいしょくん /高校生諸君/
こうこうせいりきし /高校生力士/
こうこうせかいし /高校世界史/
こうこうせんしゅけん /高校選手権/
こうこうそつぎょう /高校卒業/
こうこうそつぎょうご /高校卒業後/
こうこうそつぎょうじ /高校卒業時/
こうこうちゅう /航行中/
こうこうつうがく /高校通学/
こうこうてい /高高低/
こうこうていど /高校程度/
こうこうど /高高度/高々度/
こうこうどせいのう /高高度性能/
こうこうどひこう /高高度飛行/
こうこうない /口腔内/
こうこうにねんせい /高校二年生/
こうこうにゅうし /高校入試/
こうこうぶつり /高校物理/
こうこうぶもん /航行部門/
こうこうまで /高校迄/
こうこうめい /高校名/
こうこうやきゅう /高校野球/
こうこうやきゅうかい /高校野球界/
こうこうりつ /高効率/
こうこがく /考古学/
こうこがくしゃ /考古学者/
こうこがくしゃとう /考古学者等/
こうこがくしゃなど /考古学者等/
こうこがくてき /考古学的/
こうこがくはくぶつかん /考古学博物館/
こうこく /広告/皇国/公告/公国/興国/侯国/抗告/皇國/鴻鵠/廣告/
こうこくか /皇国化/
こうこくがいしゃ /広告会社/
こうこくきじ /広告記事/
こうこくきんし /広告禁止/
こうこくぎょう /広告業/
こうこくぎょうかい /広告業界/
こうこくぎょうしゃ /広告業者/
こうこくこうか /広告効果/
こうこくざっし /広告雑誌/
こうこくしかん /皇國史観/
こうこくしゃ /広告車/
こうこくしゃしん /広告写真/
こうこくしゅうにゅう /広告収入/
こうこくだんかい /広告段階/
こうこくちゅう /広告中/
こうこくとっきょ /広告特許/
こうこくぬし /広告主/
こうこくばいたい /公告媒体/広告媒体/
こうこくばんぐみ /広告番組/
こうこくひ /広告費/
こうこくび /公告日/
こうこくふか /広告不可/
こうこくぶん /広告文/
こうこくまんが /広告漫画/
こうこくや /広告屋/
こうこくよう /広告用/
こうこくらん /広告欄/
こうこくりょう /広告料/
こうこつ /恍惚/硬骨/甲骨/
こうこつかん /硬骨漢/
こうこつぎょ /硬骨魚/
こうこつぶん /甲骨文/
こうこつもじ /甲骨文字/
こうご /交互/口語/
こうごう /皇后/媾合/
こうごうしい /神々しい/
こうごうせい /光合成/
こうごうんてん /交互運転/
こうごか /口語化/
こうごかん /高互換/
こうごきたい /乞御期待/
こうごさよう /交互作用/
こうごそうさ /交互操作/
こうごたい /口語体/
こうごちょう /口語調/
こうごていり /交互定理/
こうごはっちゃく /交互発着/
こうごひょうげん /口語表現/
こうごぶん /口語文/
こうごやく /口語訳/
こうさ /交差/交叉/考査/較差/公差/甲佐/黄砂/
こうさい /高裁/交際/公済/公債/虹彩/光彩/高斎/香西/甲西/
こうさいかい /弘済会/
こうさいせんげん /交際宣言/
こうさいどう /廣済堂/
こうさいどうしゅっぱん /廣斉堂出版/
こうさいひ /交際費/
こうさいびょういん /公済病院/
こうさいぼう /膠細胞/
こうさいりょう /交際料/
こうさいりんどう /弘西林道/
こうさか /香坂/江坂/幸坂/高坂/神坂/香阪/上阪/上坂/
こうさかしょ /交差箇所/
こうさき /神前/
こうさく /交錯/耕作/工作/幸作/鋼索/鉤索/耕筰/
こうさくいん /工作員/
こうさくがく /工作学/
こうさくきかい /工作機械/
こうさくしつ /工作室/
こうさくしゃ /工作社/
こうさくしょ /工作所/
こうさくせいど /工作精度/
こうさくせつび /工作設備/
こうさくてつどう /鋼索鉄道/
こうさくよう /工作用/
こうさし /交差視/
こうさしょ /考査書/
こうさすう /交差数/
こうさちてん /交差地点/
こうさつ /考察/高察/絞殺/
こうさつかてい /考察過程/
こうさつちゅう /考察中/
こうさつぶそく /考察不足/
こうさてん /交差点/交叉点/
こうさてんじょう /交差点上/
こうさてんてまえ /交差点手前/
こうさてんない /交差点内/
こうさてんひょうしき /交差点標識/
こうさてんふきん /交差点付近/
こうさてんめい /交差点名/
こうさはんてい /交差判定/
こうさぶ /交差部/
こうさほう /交差法/
こうさほうよう /交差法用/
こうさん /高３/公算/公散/鉱産/降参/興産/抗酸/好酸/考算/
こうさんきん /抗酸菌/
こうさんきんびょうけんきゅうじょ /抗酸菌病研究所/
こうさんだい /公算大/
こうざ /口座/講座/高座/硬座/
こうざい /香西/鋼材/功罪/
こうざいりょう /好材料/
こうざき /神崎/
こうざしゃ /硬座車/
こうざしゅっせき /講座出席/
こうざちょう /講座長/
こうざつ /交雑/
こうざばんごう /口座番号/
こうざひ /講座費/
こうざふりかえ /口座振替/
こうざふりこみ /口座振込/
こうざぶろう /幸三郎/
こうざべつ /講座別/口座別/
こうざめい /口座名/講座名/
こうざめいぎ /口座名義/
こうざめいぎにん /口座名義人/
こうざめいしょう /口座名称/
こうざん /鉱山/高山/鑛山/甲山/
こうざんがくぶ /鉱山学部/
こうざんしょくぶつ /高山植物/
こうざんじ /高山寺/
こうざんびょう /高山病/
こうし /講師/格子/公私/講士/行使/孔子;春秋時代・魯の思想家/光子/公使/公司/厚志/甲子/子牛/孝子/嚆矢/犢/鉤止/郊祀/後肢/合志/考試/
こうしあい /好試合/
こうしあいひっし /好試合必至/
こうしいん /考試院/
こうしえん /甲子園/
こうしえんいがい /甲子園以外/
こうしえんかいかいしき /甲子園開会式/
こうしえんきゅうじょう /甲子園球場/
こうしえんぐち /甲子園口/
こうしえんぐちえき /甲子園口駅/
こうしえんざいじゅう /甲子園在住/
こうしえんしゅつじょう /甲子園出場/
こうしえんせん /甲子園線/
こうしえんたいかい /甲子園大会/
こうしかん /公使館/
こうしき /公式/硬式/項式/
こうしきか /公式化/
こうしきかいとう /公式回答/
こうしききそく /公式規則/
こうしききやく /公式規約/
こうしききろく /公式記録/
こうしききろくいん /公式記録員/
こうしきぎょうじ /公式行事/
こうしきけんかい /公式見解/
こうしきげんご /公式言語/
こうしきさいしんばん /公式最新版/
こうしきしゃざい /公式謝罪/
こうしきしゅとく /公式取得/
こうしきしりょう /公式資料/
こうしきじょう /公式上/
こうしきせん /公式戦/
こうしきせんにってい /公式戦日程/
こうしきせんはつ /公式戦初/
こうしきつうち /公式通知/
こうしきはっぴょう /公式発表/
こうしきばん /公式版/
こうしきぶんしょ /公式文書/
こうしきやきゅう /硬式野球/
こうしきよせんちゅう /公式予選中/
こうしきりょうきん /公式料金/
こうしきれんしゅう /公式練習/
こうしぎょらい /光子魚雷/
こうしけっしょう /高脂血症/
こうしけつごう /格子結合/
こうしこんどう /公私混同/
こうししゃれい /講師謝礼/
こうしじょう /格子状/
こうしせい /高姿勢/
こうしぞう /格子像/
こうしちょうりつ /高視聴率/
こうしつ /皇室/硬質/高質/
こうしつか /硬質化/
こうしつかんけい /皇室関係/
こうしつごようたつ /皇室御用達/
こうしつせんよう /皇室専用/
こうしつてんぱん /皇室典範/
こうしていすう /格子定数/
こうしてん /格子点/
こうしてんかんかく /格子点間隔/
こうしど /格子戸/
こうしはけん /講師派遣/
こうしぼう /高脂肪/
こうしゃ /後者/校舎/公社/降車/稿者/公舎/後車/
こうしゃきろく /降車記録/
こうしゃく /侯爵/候爵/公爵/講釈/
こうしゃくし /講釈師/
こうしゃくふじん /公爵夫人/
こうしゃぐち /降車口/
こうしゃさい /公社債/
こうしゃじ /降車時/
こうしゃせんよう /降車専用/
こうしゃない /校舎内/
こうしゃほう /高射砲/
こうしゃりん /後車輪/
こうしゅ /後手/攻守/好手/絞首/公主/好守/鉤取/
こうしゅう /講習/公衆/口臭/広州/甲州/紅萩/興収/抗州/
こうしゅうえいせい /公衆衛生/
こうしゅうえいせいがく /公衆衛生学/
こうしゅうおんど /江州音頭/
こうしゅうかい /講習会/
こうしゅうかいかいさい /講習会開催/
こうしゅうかいしりょう /講習会資料/
こうしゅうかいせん /公衆回線/
こうしゅうかいせんじょう /公衆回線上/
こうしゅうかいどう /甲州街道/
こうしゅうしつ /講習室/
こうしゅうせい /光周性/
こうしゅうせき /高集積/
こうしゅうせきか /高集積化/
こうしゅうちゅう /講習中/
こうしゅうでんわ /公衆電話/
こうしゅうでんわかいせん /公衆電話回線/
こうしゅうでんわもう /公衆電話網/
こうしゅうにゅう /高収入/
こうしゅうは /高周波/
こうしゅうはがた /高周波型/
こうしゅうはすう /高周波数/
こうしゅうはすういき /高周波数域/
こうしゅうはせいぶん /高周波成分/
こうしゅうはねつれん /高周波熱錬/
こうしゅうはぶぶん /高周波部分/
こうしゅうはよう /高周波用/
こうしゅうべんじょ /公衆便所/
こうしゅうよくじょう /公衆浴場/
こうしゅうわん /杭州湾/
こうしゅかいそう /甲種回送/
こうしゅく /拘縮/
こうしゅけい /絞首刑/
こうしゅそう /攻守走/
こうしゅだい /絞首台/
こうしゅつ /後出/
こうしゅつよう /高出葉/
こうしゅつりょく /高出力/
こうしゅつりょくそうしんき /高出力送信機/
こうしゅび /好守備/
こうしゅん /香春/
こうしょ /高所/向暑/
こうしょう /交渉/公称/高尚/公章/公証/校章/考証/鉱床/高承/好尚/公傷/口誦/公娼/口承/工匠/工廠/哄笑/厚相/行賞/工商/高唱/光昭/
こうしょうあいて /交渉相手/
こうしょうか /交渉可/
こうしょうかいし /交渉開始/
こうしょうかのう /交渉可能/
こうしょうきょく /公証局/
こうしょうきょくく /鉤章棘句/
こうしょうけん /交渉権/
こうしょうさいこう /公称最高/
こうしょうしだい /交渉次第/
こうしょうじ /光照寺/
こうしょうせいりつ /交渉成立/
こうしょうち /公称値/
こうしょうちゅう /交渉中/
こうしょうでんあつ /公称電圧/
こうしょうど /高照度/
こうしょうにん /公証人/
こうしょうぶ /好勝負/
こうしょうまどぐち /交渉窓口/
こうしょうめん /考証面/
こうしょうようりょう /公称容量/
こうしょうりょく /交渉力/
こうしょきょうふしょう /高所恐怖症/
こうしょく /更埴/交織/公職/好色/
こうしょくし /更埴市/
こうしょくせんきょほう /公職選挙法/
こうしょくついほう /公職追放/
こうしょとく /高所得/
こうしょとくしゃそう /高所得者層/
こうしょとくそう /高所得層/
こうしりょく /光子力/
こうしろう /幸四郎/
こうしん /更新/交信/行進/後進/恒真/口唇/高進/庚申/後身/昂進/亢進/
こうしんあいて /交信相手/
こうしんえつ /甲信越/
こうしんかのう /交信可能/
こうしんがた /更新型/
こうしんきょく /行進曲/
こうしんくう /高真空/
こうしんこうじ /更新工事/
こうしんこく /後進国/
こうしんしき /恒真式/
こうしんしけん /更新試験/
こうしんしゃ /更新車/
こうしんしゃりょう /更新車両/
こうしんしゅうき /更新周期/
こうしんしょり /更新処理/
こうしんじ /更新時/
こうしんじこく /更新時刻/
こうしんじょ /興信所/
こうしんじょちょうさ /興信所調査/
こうしんすう /交信数/
こうしんせい /恒真性/更新世/
こうしんぜんご /更新前後/
こうしんそうさ /更新操作/
こうしんち /更新値/
こうしんちほう /甲信地方/
こうしんちゅう /交信中/行進中/
こうしんどう /高振動/
こうしんび /更新日/
こうしんめいだい /恒真命題/
こうしんようきゅう /更新要求/
こうしんらい /高信頼/
こうしんらいか /高信頼化/
こうしんらいせい /高信頼性/
こうしんりょう /更新量/香辛料/更新料/
こうしんりょうてき /香辛料的/
こうしんりょく /向心力/
こうじ /工事/孝二/麹/晃司/高次/浩二/浩司/公示/宏治/康次/光司/孝治/交事/孝次/宏次/幸司/幸次/幸治/幸二/康司/貢司/小路/糀/光二/耕治/康治/晧司/公司/耕次/皓司/柑子/好餌/幸志/甲児/考爾/虹児/吼児/光次/功児/厚二/広治/康二/弘二/浩仁/耕司/耕二/香次/剛次/鉤餌/浩志/浩次/滉二/弘司/恒治/孝司/功志/広二/浩治/
こうじいぜん /工事以前/
こうじうんちん /公示運賃/
こうじえん /広辞苑/
こうじか /工事課/
こうじかい /高磁界/
こうじかんけいしゃ /工事関係者/
こうじかんれん /工事関連/
こうじき /光磁気/
こうじきょく /航時局/
こうじく /光軸/向軸/
こうじくうかん /高次空間/
こうじくかん /工事区間/
こうじくがた /向軸型/
こうじくがわ /向軸側/
こうじくけんさ /光軸検査/
こうじくしゅうせいそうち /光軸修正装置/
こうじくちょうせい /光軸調整/
こうじくほじ /光軸保持/
こうじげん /高次元/
こうじげんくうかん /高次元空間/
こうじげんば /工事現場/
こうじげんばん /高次元版/
こうじこう /高次項/
こうじこうぞう /高次構造/
こうじさいかい /工事再開/
こうじしゃ /工事車/
こうじしゅうりょう /工事終了/
こうじしんちょくぐあい /工事進捗具合/
こうじせっけい /工事設計/
こうじせっけいしょ /工事設計書/
こうじせっけいないよう /工事設計内容/
こうじそうごさよう /高次相互作用/
こうじそうごさようゆにっと /高次相互作用ユニット/
こうじたんとうぎょうしゃ /工事担当業者/
こうじたんにんしゃ /工事担任者/
こうじちゅう /工事中/
こうじつ /口実/後日/
こうじてつづき /工事手続/工事手続き/
こうじにんちもんだい /高次認知問題/
こうじねっと /高次ネット/
こうじば /高磁場/
こうじひ /工事費/
こうじぶ /工事部/
こうじほうほう /公示方法/
こうじまえ /工事前/
こうじまち /麹町/
こうじまちがくえん /麹町学園/
こうじまちてん /麹町店/
こうじまちでぐち /麹町出口/
こうじもーど /高次モード/
こうじや /工事屋/
こうじゅ /口授/坑儒/
こうじゅうしん /高重心/
こうじゅうりょく /高重力/
こうじゅつ /後述/口述/講述/公述/
こうじゅつしけん /口述試験/
こうじゅつにん /公述人/
こうじゅようしきそ /光受容色素/
こうじゅん /降順/恒順/公準/後順/
こうじゅんい /高順位/
こうじゅんかん /好循環/
こうじゅんしゃ /交殉社/
こうじゅんそうさ /後順走査/
こうじょ /控除/公序/
こうじょう /向上/工場/口上/甲状/恒常/厚情/荒城/交情/光条/鉤縄/
こうじょうあと /工場跡/
こうじょういよく /向上意欲/
こうじょううら /工場裏/
こうじょうきんむ /工場勤務/
こうじょうぐん /工場群/
こうじょうけん /好条件/
こうじょうけんがく /工場見学/
こうじょうけんせつ /工場建設/
こうじょうこう /向上校/
こうじょうさく /向上策/
こうじょうしゅっか /工場出荷/
こうじょうしゅっかじ /工場出荷時/
こうじょうしょ /口上書/
こうじょうしん /向上心/
こうじょうじっしゅう /工場実習/
こうじょうせい /恒常性/
こうじょうせん /甲状腺/
こうじょうちたい /工場地帯/
こうじょうちょう /工場長/
こうじょうちょくえいてん /工場直営店/
こうじょうてき /恒常的/
こうじょうど /向上度/
こうじょうない /工場内/
こうじょうほう /恒常法/
こうじょうほうじっけん /恒常法実験/
こうじょうりつ /向上率/
こうじょうろうどうしゃ /工場労働者/
こうじょうわたし /工場渡/
こうじょがく /控除額/
こうじょけい /控除計/
こうじょたいしょう /控除対象/
こうじょりつ /控除率/
こうじょりょうぞく /公序良俗/
こうじよう /工事用/
こうじりょう /工事料/
こうじりん /広辞林/
こうじろ /神代/
こうじろう /宏次郎/孝次郎/幸次郎/香次郎/広二郎/公二郎/康次郎/
こうじん /工人/後塵/幸甚/荒神/後陣/黄塵/公人/紅塵/
こうじんしゃ /工人舎/行人社/
こうじんぶつ /好人物/
こうすい /香水/硬水/降水/幸水/交綏/
こうすいい /高水位/
こうすいおん /高水温/
こうすいおんたいさく /高水温対策/
こうすいかくりつ /降水確率/
こうすいじゅん /高水準/
こうすいじゅんげんご /高水準言語/
こうすいじゅんじだいげき /高水準時代劇/
こうすいびん /香水瓶/
こうすいびんてん /香水瓶展/
こうすいりょう /降水量/
こうすう /工数/校数/口数/項数/
こうすうかんり /工数管理/
こうすうせつやく /工数節約/
こうすうてき /工数的/
こうすうにっぽう /工数日報/
こうすけ /耕助/幸輔/広介/功介/宏介/宏祐/耕輔/康祐/江介/廣祐/康介/
こうず /構図/神津/高津/国府津/
こうずい /洪水/
こうずか /好事家/
こうずけ /上野/
こうずけのすけ /上野介/
こうずしま /神津島/
こうずじま /神津島/
こうせ /興世/
こうせい /構成/更生/校正/後世/厚生/高生/恒星/攻勢/公正/抗生/佼正/幸生/較正/後生/向性/更正/校生/硬性/貢成/鋼製/佼成/耕生/高声/甲西/
こうせいあん /構成案/
こうせいいん /構成員/
こうせいいんがい /構成員外/
こうせいいんぜんいん /構成員全員/
こうせいおん /構成音/
こうせいか /厚生課/
こうせいかひ /後生花被/
こうせいかひるい /後生花被類/Metachlamydeae/
こうせいがく /構成学/
こうせいがくえん /佼成学園/
こうせいがくえんじょしこうこう /佼成学園女子高校/
こうせいき /構成機/
こうせいきき /構成機器/
こうせいきそく /構成規則/
こうせいぎんこう /恒生銀行/
こうせいけい /恒星系/
こうせいけいざいがく /厚生経済学/
こうせいけいせいそう /後生形成層/
こうせいげんり /構成原理/
こうせいさあびす /厚生サービス/
こうせいさい /高精細/
こうせいざい /抗生剤/
こうせいし /構成子/
こうせいしこう /構成子項/
こうせいしせつ /厚生施設/
こうせいしぶ /後生篩部/
こうせいしゃ /恒星社/鋼製車/校正者/
こうせいしゅぎ /構成主義/
こうせいしゅぎすうがく /構成主義数学/
こうせいしょう /厚生省;2001年1月の中央省庁再編で環境省と厚生労働省に再編された/
こうせいしん /公正心/
こうせいじょう /構成上/
こうせいじんいん /構成人員/
こうせいず /構成図/
こうせいずり /校正刷り/
こうせいせき /好成績/
こうせいたんい /構成単位/
こうせいだいじん /厚生大臣/
こうせいだんかい /校正段階/
こうせいちゅう /校正中/更生中/
こうせいちょう /高成長/
こうせいてき /構成的/
こうせいてきかたりろん /構成的型理論/
こうせいてきしょうめい /構成的証明/
こうせいてきじゅんじょすう /構成的順序数/
こうせいてきすうがく /構成的数学/
こうせいてきだいすうがく /構成的代数学/
こうせいてきぷろぐらみんぐ /構成的プログラミング/
こうせいてきろんり /構成的論理/
こうせいてん /構成点/
こうせいとりひき /公正取引/
こうせいど /高精度/
こうせいどか /高精度化/
こうせいどけいさん /高精度計算/
こうせいにん /構成人/
こうせいねん /好青年/
こうせいねんきん /厚生年金/
こうせいねんきんかいかん /厚生年金会館/
こうせいのう /高性能/
こうせいのうか /高性能化/
こうせいのか /高性能化/
こうせいば /校正場/
こうせいひ /構成比/
こうせいひりつ /構成比率/
こうせいびょういん /厚生病院/
こうせいぶ /構成部/厚生部/
こうせいぶっしつ /抗生物質/
こうせいぶっしついり /抗生物質入/
こうせいぶひん /構成部品/
こうせいぶんし /構成分子/
こうせいほう /構成法/校正法/
こうせいほうほう /構成方法/
こうせいまいすう /構成枚数/
こうせいもくぶ /後生木部/
こうせいよう /校正用/
こうせいようえき /校正用液/
こうせいようけん /構成要件/
こうせいようそ /構成要素/
こうせいりょく /構成力/
こうせいろうどうしょう /厚生労働省;労働省、厚生省が2001年1月の中央省庁再編で再編されたもの/
こうせいろん /構成論/
こうせき /功績/洪積/鉱石/口跡/航跡/鑛石/
こうせきせい /洪積世/
こうせきせんようれっしゃ /鉱石専用列車/
こうせつ /巧拙/降雪/公設/後節/高説/
こうせん /光線/交戦/鉱泉/口銭/交線/公選/好戦/抗戦/鋼線/高専/工専/工繊/工業高等専門学校/
こうせんけん /交戦権/
こうせんさく /鋼線索/
こうせんしゅ /好選手/
こうせんしゅっしん /高専出身/
こうせんじゅう /光線銃/
こうせんすい /鉱泉水/
こうせんせい /公選制/高専生/
こうせんそつぎょうしゃ /高専卒業者/
こうせんだい /工繊大/
こうせんちゅう /交戦中/
こうせんついせき /光線追跡/
こうせんついせきほう /光線追跡法/
こうせんてき /好戦的/
こうせんほう /公選法/
こうせんほういはん /公選法違反/
こうせんようそ /光線要素/
こうせんりょう /高線量/
こうぜつ /高舌/
こうぜん /公然/昂然/紅髯/
こうぜんじ /光善寺/
こうそ /酵素/公訴/控訴/皇祖/
こうそう /構想/高層/抗争/後送/降霜/好走/高僧/皇宗/航送/厚層/香草/
こうそういいんかい /構想委員会/
こうそうがた /厚層型/
こうそうけいかく /構想計画/
こうそうけんちくぶつ /高層建築物/
こうそうさせい /高操作性/
こうそうだんかい /構想段階/
こうそうちゅう /抗争中/
こうそうてんきず /高層天気図/
こうそうば /好走馬/
こうそうひっし /抗争必至/
こうそうぼく /高草木/
こうそうるい /好走塁/
こうそく /高速/拘束/光速/梗塞/校則/光束/航測/
こうそくあんていせい /高速安定性/
こうそくいか /光速以下/
こうそくいき /高速域/
こうそくいじょう /光速以上/
こうそくいってい /光速一定/
こうそくうんてん /高速運転/
こうそくか /高速化/
こうそくかいぞう /高速改造/
こうそくかいっぱん /高速化一般/
こうそくかいつう /高速開通/
こうそくかいてん /高速回転/
こうそくかいほう /高速解法/
こうそくかしゅほう /高速化手法/
こうそくかたいおう /高速化対応/
こうそくかんそう /高速乾燥/
こうそくがた /高速型/
こうそくくかん /高速区間/
こうそくぐん /高速群/
こうそくけい /高速系/
こうそくけいさん /高速計算/
こうそくけんさく /高速検索/
こうそくこうつうきかん /高速交通機関/
こうそくこうべ /高速神戸/
こうそくさつえい /高速撮影/
こうそくしけんしゃ /高速試験車/
こうそくしけんしゃりょう /高速試験車両/
こうそくしこう /高速思考/
こうそくしゃ /高速車/
こうそくしゃけいかく /高速車計画/
こうそくしゃりょう /高速車両/
こうそくしょり /高速処理/
こうそくしようりょう /高速使用料/
こうそくじ /高速時/
こうそくじどうしゃどう /高速自動車道/
こうそくじゅんこう /高速巡行/
こうそくじゅんこうちゅう /高速巡航中/
こうそくじょうけん /拘束条件/
こうそくすいろんほう /高速推論法/
こうそくせい /高速性/
こうそくせいのう /高速性能/
こうそくせん /高速線/高速船/
こうそくそうこう /高速走行/
こうそくそうこうじ /高速走行時/
こうそくそうこうちゅう /高速走行中/
こうそくぞうしょくろ /高速増殖炉/
こうそくたいきゅう /高速耐久/
こうそくたいりょうゆそう /高速大量輸送/
こうそくだい /高速代/
こうそくだん /高速弾/
こうそくちのう /高速知能/
こうそくちゅうせいし /高速中性子/
こうそくつうしん /高速通信/
こうそくてい /高速艇/
こうそくてつどう /高速鉄道/
こうそくてつどうもう /高速鉄道網/
こうそくてんそう /高速転送/
こうそくでんしけい /高速電子系/
こうそくど /光速度/高速度/
こうそくどいじょう /光速度以上/
こうそくどう /高速道/
こうそくどうけんせつ /高速道建設/
こうそくどうろ /高速道路/
こうそくどうろかんけい /高速道路関係/
こうそくどうろけいゆ /高速道路経由/
こうそくどうろじょう /高速道路上/
こうそくどうろそうこう /高速道路走行/
こうそくどうろだい /高速道路代/
こうそくどうろもう /高速道路網/
こうそくどうろもんだい /高速道路問題/
こうそくどうろりょうきん /高速道路料金/
こうそくどさつえい /高速度撮影/
こうそくどじょうたい /高速度状態/
こうそくばん /高速版/
こうそくびょうが /高速描画/
こうそくへんかん /高速変換/
こうそくめん /高速面/
こうそくもんだい /校則問題/
こうそくりきがく /高速力学/
こうそくりきがくけんきゅうじょ /高速力学研究所/
こうそくりょうきん /高速料金/
こうそくりょく /拘束力/
こうそくれっしゃ /高速列車/
こうそくろ /高速炉/
こうそくろせん /高速路線/
こうそくろせんしゃ /高速路線車/
こうそけい /酵素系/
こうそこうか /公租公課/
こうそしつ /好素質/
こうそしん /控訴審/
こうそつ /高卒/
こうそつじょし /高卒女子/
こうそつていど /高卒程度/
こうそつまえ /高卒前/
こうぞ /楮/
こうぞう /構造/孝三/孝蔵/幸三/浩三/肯三/弘蔵/耕三/行三/
こうぞうか /構造化/
こうぞうかいせき /構造解析/
こうぞうかげんご /構造化言語/
こうぞうかぶんしょ /構造化文書/
こうぞうかりょういき /構造化領域/
こうぞうがか /構造画家/
こうぞうがた /構造型/
こうぞうきょうぎ /構造協議/
こうぞうけってい /構造決定/
こうぞうけっていしゅほう /構造決定手法/
こうぞうけん /構造研/
こうぞうけんきゅうしつ /構造研究室/
こうぞうこうがくけい /構造工学系/
こうぞうざい /構造材/
こうぞうざいへんこう /構造材変更/
こうぞうしき /構造式/
こうぞうしゅぎ /構造主義/
こうぞうしゅぎてき /構造主義的/
こうぞうじしょ /構造辞書/
こうぞうじたい /構造自体/
こうぞうじょう /構造上/
こうぞうじょうかいほう /構造上解放/
こうぞうじょうほう /構造情報/
こうぞうず /構造図/
こうぞうせい /構造性/
こうぞうせっけい /構造設計/
こうぞうせん /構造線/
こうぞうそうかん /構造相関/
こうぞうたい /構造体/
こうぞうたいちゅう /構造体中/
こうぞうてき /構造的/
こうぞうてきけっかん /構造的欠陥/
こうぞうてきせいやく /構造的制約/
こうぞうてきもんだい /構造的問題/
こうぞうにんしき /構造認識/
こうぞうふきょう /構造不況/
こうぞうぶつ /構造物/
こうぞうぶん /構造文/
こうぞうへんこう /構造変更/
こうぞうや /構造屋/
こうぞうりきがく /構造力学/
こうぞく /後続/皇族/航続/
こうぞくおん /後続音/
こうぞくきょり /航続距離/後続距離/
こうぞくし /後続子/
こうぞくしゃ /後続車/
こうぞくしゃぐん /後続車群/
こうぞくじかん /航続時間/
こうぞくせつ /後続節/
こうぞくは /後続波/
こうぞくば /後続馬/
こうぞくぼいん /後続母音/
こうぞくみぶん /皇族身分/
こうぞくめいれい /後続命令/
こうぞくりょく /航続力/
こうぞくれっしゃ /後続列車/
こうた /小唄/小歌/晃太/幸田/恒太/
こうたい /交代/後退/交替/抗体/剛体/
こうたいあつ /高耐圧/
こうたいいき /広帯域/ブロードバンド/
こうたいいきおん /広帯域音/
こうたいいきじゅしんき /広帯域受信機/
こうたいか /鋼体化/抗体価/
こうたいがた /後退型/
こうたいこうげんはんのう /抗体抗原反応/
こうたいごう /皇太后/
こうたいし /皇太子/
こうたいしょう /好対照/
こうたいせい /交替制/
こうたいだいにゅう /後退代入/
こうたいとう /後退灯/
こうたいないぶ /鋼体内部/
こうたいは /後退波/
こうたいよう /向太陽/
こうたく /光沢/光澤/
こうたに /甲谷/
こうたり /神足/
こうたろう /浩太郎/孝太郎/幸太郎/輝太郎/廣太郎/光太郎/高太郎/晃太朗/耕太郎/弘太郎/
こうたん /後端/降誕/
こうたんさい /降誕祭/
こうだ /黄田/好田/幸田/香田/古宇田/光田/好打/神田/国府田/甲田/行田/國府田/
こうだい /工大/広大/後代/航大/
こうだいさい /工大祭/
こうだいさいじっこういいんかい /工大祭実行委員会/
こうだいじ /高台寺/
こうだえき /江田駅/
こうだか /甲高/
こうだく /黄濁/
こうだしゃ /好打者/
こうだちょう /幸田町/
こうだまりこ /國府田マリ子/
こうだりつ /高打率/
こうだん /講談/公団/講壇/後段/高段/降壇/巷談/降段/光弾/
こうだんし /皇男子/講談師/好男子/
こうだんしゃ /講談社/
こうだんしゃしゅっぱん /講談社出版/
こうだんしゃしんしょ /講談社新書/
こうだんしゃばん /講談社版/
こうだんしゃぶんこ /講談社文庫/
こうだんしゃまんがしょう /講談社漫画賞/
こうだんせん /公団線/
こうだんねつ /高断熱/
こうだんねつか /高断熱化/
こうだんねつじゅうたく /高断熱住宅/
こうだんねつよう /高断熱用/
こうだんぼん /講談本/
こうだんめいさくぶんこ /講談名作文庫/
こうち /高知/公知/高地/後置/巧遅/巧緻/拘置/耕地/幸地/河内/好地/狡知/狡智/
こうちいほく /高知以北/
こうちえき /高知駅/
こうちえきまえ /高知駅前/
こうちきほう /後置記法/
こうちく /構築/
こうちくかのう /構築可能/
こうちくかんきょう /構築環境/
こうちくがくてきようつう /構築学的腰痛/
こうちくぎじゅつ /構築技術/
こうちくし /構築子/
こうちくじ /構築時/
こうちくちゅう /構築中/
こうちくぶつ /構築物/
こうちくほう /構築法/
こうちくほうほう /構築方法/
こうちくよう /構築用/
こうちくれい /構築例/
こうちけん /高知県/
こうちけんじん /高知県人/
こうちこうこう /高知高校/
こうちし /後置詞/高知市/
こうちしき /後置式/
こうちしょ /拘置所/
こうちしょうぎょう /高知商業/
こうちじょうほう /公知情報/
こうちせい /巧緻性/
こうちだい /高知大/
こうちだいがく /高知大学/
こうちちく /高知地区/
こうちのう /高知能/
こうちのうけんきゅうしゃ /工知能研究者/
こうちぶんけん /公知文献/
こうちほうめん /高知方面/
こうちゃ /紅茶/
こうちゃいろ /紅茶色/
こうちゃいんりょう /紅茶飲料/
こうちゃく /降着/膠着/
こうちゃくご /膠着語/
こうちゃくじょうたい /膠着状態/
こうちゃくせいど /降着制度/
こうちゃつうしん /紅茶通信/
こうちゅう /甲虫/甲冑/校注/工注/
こうちゅうきゅう /好中球/
こうちゅうじつ /高忠実/
こうちょ /好著/光緒/
こうちょう /好調/校長/高調/紅潮/腔腸/高潮/公聴/
こうちょうかい /公聴会/
こうちょうしつ /校長室/
こうちょうじ /好調時/
こうちょうせんせい /校長先生/
こうちょうだいこう /校長代行/
こうちょうどうぶつ /腔腸動物/
こうちょうは /高調波/
こうちょうはかんけい /高調波関係/
こうちょうはこうぞう /高調波構造/
こうちょうはせいぶん /高調波成分/
こうちょうはぼうがい /高調波妨害/
こうちょうはもんだい /高調波問題/
こうちょうりょく /高張力/
こうちょく /硬直/交直/
こうちょくか /硬直化/
こうちょくじかん /硬直時間/
こうちょくせつぞく /交直接続/
こうちょくせつぞくぎじゅつ /交直接続技術/
こうちょくせつぞくてん /交直接続点/
こうちょくてんかんき /交直転換器/
こうちょくりゅう /交直流/
こうちょくりゅうきゅうこうしょく /交直流急行色/
こうちょくりゅうしゃりょう /交直流車両/
こうちょくりゅうでんしゃ /交直流電車/
こうちょくりゅうでんしゃしょく /交直流電車色/
こうちょくりょうよう /交直両用/
こうちょくりょうようしゃ /交直両用車/
こうちょくりょうようでんしゃ /交直両用電車/
こうちん /工賃/
こうちんぎん /高賃金/
こうつ /刻子/
こうつい /項対/
こうつう /交通/
こうつうあんぜん /交通安全/
こうつうあんぜんきょういく /交通安全教育/
こうつうあんぜんけいはつ /交通安全啓発/
こうつうあんぜんしゅうかん /交通安全週間/
こうつうあんない /交通案内/
こうつういじ /交通遺児/
こうつういはん /交通違反/
こうつうえいだん /交通営団/
こうつうかいかん /交通会館/
こうつうかがくかん /交通科学館/
こうつうかくめい /交通革命/
こうつうかんきょう /交通環境/
こうつうがかり /交通係/
こうつうきかくか /交通企画課/
こうつうきかん /交通機関/
こうつうきせい /交通規制/
こうつうきそく /交通規則/
こうつうきっぷ /交通切符/
こうつうきょういく /交通教育/
こうつうきょく /交通局/
こうつうきょくはっこう /交通局発行/
こうつうきょくまえ /交通局前/
こうつうぎょうせい /交通行政/
こうつうぎょうせいぜんぱん /交通行政全般/
こうつうけいかん /交通警官/
こうつうけんきゅうしつ /交通研究室/
こうつうこうえん /交通公園/
こうつうこうきょうきかん /交通公共機関/
こうつうこうしゃ /交通公社/
こうつうこうどう /交通行動/
こうつうさいばんしょ /交通裁判所/
こうつうし /交通史/
こうつうしどうか /交通指導課/
こうつうしゃ /交通社/
こうつうしゃかい /交通社会/
こうつうしゅだん /交通手段/
こうつうしんごう /交通信号/
こうつうしんぶん /交通新聞/
こうつうじこ /交通事故/
こうつうじこししゃ /交通事故死者/
こうつうじじょう /交通事情/
こうつうじゃくしゃ /交通弱者/
こうつうじゅうたい /交通渋滞/
こうつうじゅよう /交通需要/
こうつうじょうきょう /交通状況/
こうつうじょうほう /交通情報/
こうつうせいげん /交通制限/
こうつうせいさく /交通政策/
こうつうせいり /交通整理/
こうつうせんそう /交通戦争/
こうつうぜんか /交通前科/
こうつうぜんたい /交通全体/
こうつうたいけい /交通体系/
こうつうどうとく /交通道徳/
こうつうはく /交通博/
こうつうはくぶつかん /交通博物館/
こうつうひ /交通費/
こうつうひせいさんひょう /交通費清算表/
こうつうひほじょ /交通費補助/
こうつうひょうしき /交通標識/
こうつうひろば /交通広場/
こうつうほういはん /交通法違反/
こうつうほうき /交通法規/
こうつうもう /交通網/
こうつうもうせいび /交通網整備/
こうつうもんだい /交通問題/
こうつうようりょう /交通容量/
こうつうりょう /交通量/
こうつうりょうぞうか /交通量増加/
こうつごう /好都合/
こうづ /国府津/
こうづき /上月/神月/香月/
こうづけ /上野/
こうづけのすけ /上野介/
こうづしま /神津島/
こうてい /肯定/工程/高低/皇帝/行程/校庭/公定/公邸/校訂/皇弟/高弟/鉤悌/黄帝/航程/
こうていいき /高低域/
こうていえき /口蹄疫;家畜伝染病/foot and mouse disease/
こうていえんぶきょく /皇帝円舞曲/
こうていさ /高低差/
こうていせいしょほう /公定正書法/
こうていてい /高低低/
こうていてき /肯定的/
こうていてきひょうか /肯定的評価/
こうていは /肯定派/
こうていぶあい /公定歩合/
こうてき /公的/好適/
こうてきかんきん /公的換金/
こうてききかん /公的機関/
こうてききせい /公的規制/
こうてききんゆう /公的金融/
こうてきけんきゅうきかん /公的研究機関/
こうてきざいげん /公的財源/
こうてきしかく /公的資格/
こうてきしきん /公的資金/
こうてきしゅ /好敵手/
こうてきしゅうし /公的収支/
こうてきせきにん /公的責任/
こうてきとばくじょう /公的賭博場/
こうてきねんきん /公的年金/
こうてきほいくせいど /公的保育制度/
こうてきほじょ /公的補助/
こうてつ /鋼鉄/更迭/
こうてつせい /鋼鉄製/
こうてん /交点/好転/後天/公転/荒天/好天/後転/好点/光点/
こうてんきど /光点輝度/
こうてんきどう /公転軌道/
こうてんしゅうき /公転周期/
こうてんせい /後天性/
こうてんせいめんえきふぜんしょうこうぐん /後天性免疫不全症候群/
こうてんそくど /公転速度/
こうてんてき /後天的/
こうてんてきがくしゅう /後天的学習/
こうてんてきしつごしょう /後天的失語症/
こうてんてきめんえき /後天的免疫/
こうでい /拘泥/
こうでら /香寺/
こうでん /光電/香典/香奠/
こうでんあつ /高電圧/
こうでんあつか /高電圧化/
こうでんかん /光電管/
こうでんこうか /光電効果/
こうでんし /光電子/
こうでんしぞうばいかん /光電子増倍管/
こうでんしゃ /弘電社/高電社/
こうでんそくこう /光電測光/
こうでんぱ /光電波/
こうでんへんかん /光電変換/
こうでんへんかんこうがく /光電変換工学/
こうでんめん /光電面/
こうとう /口頭/高等/恒等/後頭/口答/高騰/喉頭/江東/公党/降等/好投/
こうとうか /高等科/
こうとうかんすう /恒等関数/
こうとうがっこう /高等学校/
こうとうきょういく /高等教育/
こうとうぎじゅつ /高等技術/
こうとうく /江東区/
こうとうくしらかわ /江東区白河/
こうとうくすみよし /江東区住吉/
こうとうけいさつ /高等警察/
こうとうしき /恒等式/
こうとうしけん /口頭試験/
こうとうしもん /口頭試問/
こうとうしゃぞう /恒等写像/
こうとうしゅ /好投手/
こうとうせいぶつ /高等生物/
こうとうせんもんがっこう /高等専門学校/
こうとうだい /勾当台/
こうとうてき /恒等的/
こうとうどうぶつ /高等動物/
こうとうはっぴょう /口頭発表/
こうとうひししょくぶつ /高等被子植物/
こうとうぶ /後頭部/高等部/
こうとうへんかん /恒等変換/
こうとうむけい /荒唐無稽/
こうとうよう /後頭葉/
こうとく /神徳/公徳/行徳/光徳/康徳/
こうとくせん /高徳線/
こうとくてん /高得点/
こうとりい /公取委/
こうど /高度/光度/硬度/
こうどう /行動/講堂/公道/坑道/黄道/皇道/香道/孝道/
こうどういがい /行動以外/
こうどうかがく /行動科学/
こうどうがく /行動学/
こうどうきはん /行動規範/
こうどうきょり /行動距離/
こうどうけいかく /行動計画/
こうどうけっか /行動結果/
こうどうげんり /行動原理/
こうどうしゅぎ /行動主義/
こうどうしゅぎしゃ /行動主義者/
こうどうしゅぎりろん /行動主義理論/
こうどうしゅたい /行動主体/
こうどうしょく /行動食/
こうどうしよう /公道仕様/
こうどうしんりがく /行動心理学/
こうどうじっけん /行動実験/
こうどうじょう /行動上/
こうどうせいぎょ /行動制御/
こうどうせいり /行動生理/
こうどうそうこう /公道走行/
こうどうそうこうかのう /公道走行可能/
こうどうそうこうふか /公道走行不可/
こうどうたいけい /行動体系/
こうどうちゅう /行動中/
こうどうてき /行動的/
こうどうでえた /行動データ/
こうどうにゅうもん /香道入門/
こうどうは /行動派/皇道派/
こうどうはんい /行動範囲/
こうどうはんけい /行動半径/
こうどうふのう /行動不能/
こうどうよう /公道用/
こうどうようしき /行動様式/
こうどうよてい /行動予定/
こうどうりょく /行動力/
こうどか /高度化/
こうどきょういく /高度教育/
こうどきょくせん /光度曲線/
こうどきょくせんかいせき /光度曲線解析/
こうどく /講読/購読/鉱毒/
こうどくかんきょう /購読環境/
こうどくきかん /講読期間/
こうどくけいこう /購読傾向/
こうどくしゃ /講読者/購読者/
こうどくしゃそう /購読者層/
こうどくしゃゆうし /購読者有志/
こうどくちゅう /購読中/
こうどくちょうさ /購読調査/
こうどくほうほう /講読方法/
こうどくりつちょうさ /購読率調査/
こうどくりょう /講読量/講読料/購読料/
こうどくれき /購読歴/
こうどけい /好時計/高度計/
こうどさ /高度差/
こうどじゅんのう /高度順応/
こうどじゅんのうど /高度順応度/
こうどじょうほうか /高度情報化/
こうどじょうほうかしゃかい /高度情報化社会/
こうどじょうほうしゃかい /高度情報社会/
こうどじょうほうつうしん /高度情報通信/
こうどせいちょう /高度成長/
こうどせいまい /高度精米/
こうどそくてい /光度測定/高度測定/
こうどつうしん /高度通信/
こうどば /高度場/
こうどへんか /高度変化/
こうどりよう /高度利用/
こうない /校内/構内/港内/坑内/
こうないえん /口内炎/
こうないがわ /港内側/
こうないこうじ /構内工事/
こうないびん /校内便/
こうないふみきり /構内踏切/
こうないほうそう /構内放送/
こうなん /甲南/港南/江南/硬軟/香南/
こうなんく /港南区/
こうなんくきんこう /港南区近郊/
こうなんご /江南語/
こうなんじん /江南人/
こうなんだい /甲南大/港南台/
こうなんだいがく /甲南大学/
こうなんだいてん /港南台店/
こうなんちょう /甲南町/
こうなんてつどう /興南鉄道/
こうに /高２/
こうにちうんどう /抗日運動/
こうにちえいが /抗日映画/
こうにゅう /購入/
こうにゅういよく /購入意欲/
こうにゅううかがい /購入伺い/
こうにゅうか /購入可/
こうにゅうかかく /購入価格/
こうにゅうかのう /購入可能/
こうにゅうがく /購入額/
こうにゅうがくぜんぶ /購入額全部/
こうにゅうきぼう /購入希望/
こうにゅうきぼうかかく /購入希望価格/
こうにゅうきぼうきんがく /購入希望金額/
こうにゅうきんがく /購入金額/
こうにゅうけいかく /購入計画/
こうにゅうけいろ /購入経路/
こうにゅうけんとう /購入検討/
こうにゅうこうほ /購入候補/
こうにゅうご /購入後/
こうにゅうさき /購入先/
こうにゅうしきん /購入資金/
こうにゅうしゃ /購入者/
こうにゅうしゃがわふたん /購入者側負担/
こうにゅうしゃしゅ /購入車種/
こうにゅうじ /購入時/
こうにゅうじかかく /購入時価格/
こうにゅうじき /購入時期/
こうにゅうじていか /購入時定価/
こうにゅうじてん /購入時点/
こうにゅうすうりょう /購入数量/
こうにゅうずみ /購入済/
こうにゅうたいしょう /購入対象/
こうにゅうち /購入地/
こうにゅうちょくご /購入直後/
こうにゅうてん /購入店/
こうにゅうとうしょ /購入当初/
こうにゅうとうじ /購入当時/
こうにゅうどうき /購入動機/
こうにゅうねんげつ /購入年月/
こうにゅうはんだん /購入判断/
こうにゅうひ /購入費/
こうにゅうひょう /購入票/
こうにゅうひん /購入品/
こうにゅうび /購入日/
こうにゅうぶつ /購入物/
こうにゅうほう /購入法/
こうにゅうほうほう /購入方法/
こうにゅうまえ /購入前/
こうにゅうもうしこみ /購入申込み/
こうにゅうもくてき /購入目的/
こうにゅうもと /購入元/
こうにゅうよてい /購入予定/
こうにゅうよやく /購入予約/
こうにん /後任/公認/
こうにんかんとく /後任監督/
こうにんきょうぎ /公認競技/
こうにんきろく /公認記録/
こうにんこう /公認校/
こうにんしかく /公認資格/
こうにんしゃ /後任者/
こうにんしゃりょう /公認車両/
こうにんしよう /公認仕様/
こうにんしんぱんいん /公認審判員/
こうにんじんじ /後任人事/
こうにんせいしょほう /公認正書法/
こうにんたいかい /公認大会/
こうねつ /光熱/高熱/
こうねつすいりょう /光熱水料/
こうねつひ /光熱費/
こうねん /後年/降年/光年/高年/
こうねんき /更年期/
こうねんきしょうがい /更年期障害/
こうねんさき /光年先/
こうねんしょうど /高燃焼度/
こうねんぽう /高年俸/
こうの /河野/甲野/香野/
こうのう /効能/後納/
こうのうど /高濃度/
こうのうりつ /高能率/
こうのす /鴻巣/
こうのすけ /幸之助/
こうのだい /国府台/
こうのとり /鸛/
こうは /硬派/光波/
こうはい /後輩/荒廃/交配/高配/興廃/後背/降灰/
こうはいきん /広背筋/
こうはいじんこう /後背人口/
こうはいたち /後輩達/
こうはいとう /高配当/
こうはいぶ /後背部/
こうはく /工博/紅白/赤白/
こうはくうたがっせん /紅白歌合戦/
こうはた /光畑/
こうはつ /後発/好発/
こうはつうしん /光波通信/
こうはつたい /後発隊/
こうはません /興浜線/
こうはまみなみせん /興浜南線/
こうはら /香原/
こうはん /後半/広汎/広範/公判/孔版/鋼鈑/撹拌/
こうはんい /広範囲/
こうはんいん /甲板員/
こうはんかいし /後半開始/
こうはんかいしちょくご /後半開始直後/
こうはんき /後半期/
こうはんご /公判後/
こうはんせん /後半戦/
こうはんそうこう /降坂走行/
こうはんねん /後半年/
こうはんぶ /後半部/
こうはんぶぶん /後半部分/
こうはんめん /後半面/
こうば /工場/
こうばい /公倍/購買/勾配/公売/紅梅/
こうばいいよく /購買意欲/
こうばいかんりか /購買管理課/
こうばいかんわ /勾配緩和/
こうばいくかん /勾配区間/
こうばいけいしゃ /勾配傾斜/
こうばいしゃ /購買者/
こうばいしょう /紅梅賞/
こうばいすう /公倍数/
こうばいそう /購買層/
こうばいたんとう /購買担当/
こうばいぶ /購買部/
こうばいほう /勾配法/
こうばいほうほう /購買方法/
こうばいよく /購買欲/
こうばいりつ /高倍率/勾配率/
こうばいりょく /購買力/
こうばく /宏漠/広漠/
こうばたい /好馬体/
こうばん /交番/項番/甲板/降板/鋼板/工番/降番/
こうばんげき /降番劇/
こうばんじょう /甲板上/
こうひ /校費/公費/高飛/公比/向日/工費/侯妃/黄扉/
こうひさくげん /工費削減/
こうひしゅっちょう /公費出張/
こうひじょせい /公費助成/
こうひつ /硬筆/
こうひょう /公表/好評/講評/公評/
こうひょうか /高評価/
こうひょうきょか /公表許可/
こうひょうきんし /公表禁止/
こうひょうけん /公表権/
こうひょうけんいんりょうすう /公表牽引両数/
こうひょうげん /項表現/
こうひょうち /公表値/
こうひょうはつばいちゅう /好評発売中/
こうひょうほうほう /公表方法/
こうひょうまえ /公表前/
こうひん /公賓/
こうひんい /高品位/
こうひんしつ /高品質/
こうひんしつか /高品質化/
こうひんど /高頻度/
こうび /後尾/交尾/後備/
こうびき /交尾器/
こうびしゃ /後尾車/
こうびん /後便/
こうふ /甲府/交付/公布/江府/坑夫/工夫/鉱夫/
こうふう /校風/
こうふえき /甲府駅/
こうふか /高負荷/
こうふかん /甲府間/
こうふきん /交付金/
こうふく /幸福/降伏/降服/口福/
こうふくかん /幸福感/
こうふくし /高福祉/
こうふくしこうふたん /高福祉高負担/
こうふくしこっか /高福祉国家/
こうふくじ /洪福寺/
こうふくついきゅう /幸福追求/
こうふくど /幸福度/
こうふし /甲府市/
こうふししゅうへん /甲府市周辺/
こうふしんせいしょ /交付申請書/
こうふじぎょうしょ /甲府事業所/
こうふじょうきょう /交付状況/
こうふちょう /好不調/
こうふぼんち /甲府盆地/
こうふみなみ /甲府南/
こうふん /興奮/公憤/口吻/昂奮/亢憤/亢奮/
こうふんじょうたい /興奮状態/
こうふんせい /興奮性/
こうふんど /興奮度/
こうふんぱたん /興奮パタン/
こうぶ /後部/光武/
こうぶざせき /後部座席/
こうぶざせきかくだい /後部座席拡大/
こうぶしゃりょう /後部車両/
こうぶせき /後部席/
こうぶつ /好物/鉱物/
こうぶつかせき /鉱物化石/
こうぶつけい /鉱物系/
こうぶつずかん /鉱物図鑑/
こうぶつせい /鉱物性/
こうぶつや /鉱物屋/
こうぶつゆ /鉱物油/
こうぶん /構文/後文/公文/
こうぶんかい /高分解/
こうぶんかいせき /構文解析/
こうぶんかいせきき /構文解析器/
こうぶんかいせきぎ /構文解析木/
こうぶんかいせきほう /構文解析法/
こうぶんかいのう /高分解能/
こうぶんき /構文木/
こうぶんきそく /構文規則/
こうぶんきそくじょう /構文規則上/
こうぶんぎ /構文木/
こうぶんこう /構文項/
こうぶんし /高分子/
こうぶんしかがく /高分子化学/
こうぶんしき /構文式/
こうぶんしけんきゅうじょ /高分子研究所/
こうぶんしざいりょう /高分子材料/
こうぶんしぶっしつ /高分子物質/
こうぶんしゃ /光文社/
こうぶんしゃぶんこ /光文社文庫/
こうぶんしょ /公文書/
こうぶんじょう /構文上/
こうぶんじょうほう /構文情報/
こうぶんていぎ /構文定義/
こうぶんてき /構文的/
こうぶんてきせいやく /構文的制約/
こうぶんとう /構文糖/
こうぶんどう /弘文堂/
こうぶんぷ /項分布/
こうぶんようそ /構文要素/
こうぶんりょういき /構文領域/
こうぶんろん /構文論/
こうぶんろんてき /構文論的/
こうへい /公平/幸平/浩平/康平/耕平/工兵/恒平/高平/
こうへいせい /公平性/
こうへいれつ /高並列/
こうへいれつけいさんき /高並列計算機/
こうへき /後壁/厚壁/
こうへきいけいさいぼう /厚壁異形細胞/
こうへきさいぼう /厚壁細胞/
こうへきそしき /厚壁組織/
こうへきそしきさいぼう /厚壁組織細胞/
こうへん /後編/後篇/
こうへんきゅう /好返球/
こうへんさいぼう /孔辺細胞/
こうへんすうきごう /項変数記号/
こうべ /神戸/頭/首/
こうべえいぎょうしょ /神戸営業所/
こうべえき /神戸駅/
こうべきいと /神戸生絲/
こうべきんぺん /神戸近辺/
こうべこうじょう /神戸工場/
こうべこうそく /神戸高速/
こうべこうそくてつどう /神戸高速鉄道/
こうべこくさいかいかん /神戸国際会舘/
こうべし /神戸市/
こうべしえい /神戸市営/
こうべしこうつうきょく /神戸市交通局/
こうべしざいじゅう /神戸市在住/
こうべしすいどうきょく /神戸市水道局/
こうべしてん /神戸支店/
こうべしでん /神戸市電/
こうべしない /神戸市内/
こうべしないおうふく /神戸市内往復/
こうべしにしく /神戸市西区/
こうべしみん /神戸市民/
こうべしゅっしん /神戸出身/
こうべしょうせんだいがく /神戸商船大学/
こうべしんこうつう /神戸新交通/
こうべしんぶん /神戸新聞/
こうべしんぶんはい /神戸新聞杯/
こうべじぎょうしょ /神戸事業所/
こうべじょがくいん /神戸女学院/
こうべじょしだい /神戸女子大/
こうべせいこう /神戸製鋼/
こうべせいこうしょ /神戸製鋼所/
こうべせん /神戸線/
こうべそうごう /神戸総合/
こうべだい /神戸大/
こうべだいがく /神戸大学/
こうべだいこう /神戸大工/
こうべちゅうおう /神戸中央/
こうべちょう /神戸町/
こうべつ /項別/
こうべてん /神戸店/
こうべでんてつ /神戸電鉄/
こうべにほんでんき /神戸日本電気/
こうべぶんか /神戸文化/
こうべべん /神戸弁/
こうべほうめん /神戸方面/
こうべや /神戸屋/
こうべん /抗弁/
こうほ /候補/侯補/好捕/
こうほあん /候補案/
こうほいちらん /候補一覧/
こうほう /広報/後方/工法/公報/廣報/航法/高峰/
こうほういっき /後方一気/
こうほういっち /後方一致/
こうほうえんご /後方援護/
こうほうか /広報課/
こうほうかいてん /後方回転/
こうほうかくにん /後方確認/
こうほうかじゅう /後方荷重/
こうほうかつどう /広報活動/
こうほうがかり /広報係/
こうほうぎじゅつ /航法技術/
こうほうけいかいにんむ /後方警戒任務/
こうほうけん /航法研/
こうほうし /広報紙/公報紙/広報誌/
こうほうしかい /後方視界/
こうほうしかく /後方死角/
こうほうしつ /広報室/
こうほうしゃ /後方車/
こうほうしりょう /広報資料/
こうほうそとがわ /後方外側/
こうほうたんち /後方探知/
こうほうたんとう /広報担当/
こうほうたんとうしゃ /広報担当者/
こうほうついそう /後方追走/
こうほうてき /広報的/
こうほうはいき /後方排気/
こうほうばんごう /公報番号/
こうほうぶ /広報部/
こうほうぶいん /広報部員/
こうほうぶつ /広報物/
こうほうゆうどういん /後方誘導員/
こうほがそ /候補画素/
こうほきょく /候補曲/
こうほく /港北/江北/
こうほくく /港北区/
こうほぐん /候補群/
こうほしゃ /候補者/候補車/
こうほしゃあつめ /候補者集め/
こうほしゃいがい /候補者以外/
こうほしゃえんぜつ /候補者演説/
こうほしゃごと /候補者毎/
こうほしゃしんにん /候補者信任/
こうほしゃすう /候補者数/
こうほしゃひょうか /候補者評価/
こうほじゅんい /候補順位/
こうほずけい /候補図形/
こうほせい /候補生/
こうほせつ /侯補節/
こうほせんたく /候補選択/
こうほち /候補地/
こうほとうろく /候補登録/
こうほにちじ /候補日時/
こうほば /候補馬/
こうほび /候補日/
こうほん /校本/稿本/
こうぼ /公募/酵母/
こうぼう /攻防/興亡/好防/公房/工房/高望/光芒/弘法/鉤芒/
こうぼうき /興亡記/
こうぼうせん /攻防戦/
こうぼうだいし /弘法大師/
こうぼきん /酵母菌/
こうぼく /公僕/高木/香木/
こうぼじんいん /公募人員/
こうぼろんぶん /公募論文/
こうま /好摩/仔馬/子馬/
こうまい /高邁/
こうまく /硬膜/
こうまつがく /考末学/
こうまん /高慢/
こうみ /香味/小海/
こうみせん /小海線/
こうみつ /高密/
こうみつど /高密度/
こうみゃく /鉱脈/
こうみょう /巧妙/功名/光明/
こうみょうしん /功名心/
こうみょうじ /弘明寺/
こうみん /公民/
こうみんかん /公民館/
こうみんけんうんどう /公民権運動/
こうみんけんていし /公民権停止/
こうむ /公務/工務/
こうむいん /公務員/
こうむいんしけん /公務員試験/
こうむいんしゅくしゃ /公務員宿舎/
こうむいんほう /公務員法/
こうむいんもんだい /公務員問題/
こうむしっこうぼうがい /公務執行妨害/
こうむてん /工務店/
こうむぶ /公務部/工務部/
こうむら /高村/甲村/
こうめ /小梅/
こうめい /工明/高名/公明/校名/孔明;諸葛亮の字(あざな)/孝明/
こうめいいけ /光明池/
こうめいかい /工明会/
こうめいかいひ /工明会費/
こうめいてい /孝明帝/
こうめいとう /公明党/
こうめん /後面/
こうもう /膏盲/孔孟/紅毛/鴻毛/噛耗/咬耗/
こうもうへきがん /紅毛碧眼/
こうもく /項目/綱目/
こうもくあん /項目案/
こうもくごと /項目毎/
こうもくすう /項目数/
こうもくち /項目値/
こうもくちゅう /項目中/
こうもくない /項目内/
こうもくないよう /項目内容/
こうもくひょう /項目票/
こうもくべつ /項目別/
こうもくべつさくいん /項目別索引/
こうもくめい /項目名/
こうもと /孝本/河本/甲本/
こうもり /蝙蝠/幸森/
こうもん /肛門/校門/後門/粫門/閘門/黄門/孔紋/
こうもんさま /黄門様/
こうもんじけん /校門事件/
こうもんせんこう /孔紋穿孔/孔紋せん孔/
こうや /荒野/広野/高野/狗也/曠野/功也/幸也/紺屋/
こうやうち /高野内/
こうやぎ /香焼/
こうやく /公約/口約/膏薬/
こうやくいはん /公約違反/
こうやくすう /公約数/
こうやぐち /高野口/
こうやさん /高野山/
こうやせん /交野線/
こうやだい /高野台/
こうやま /光山/高山/
こうやれん /高野連/
こうゆ /香油/
こうゆう /交友/公有/交遊/孔融/校友/
こうゆうかんけい /交友関係/
こうゆうしょう /交遊抄/
こうゆうせんど /高優先度/
こうよ /公誉/
こうよう /紅葉/効用/高揚/公用/後葉/江陽/光洋/広葉/昂揚/甲陽/綱要/黄葉/宏陽/
こうようえん /甲陽園/
こうようえんえき /甲陽園駅/
こうようえんせん /甲陽園線/
こうようかいせん /公用回線/
こうようかん /高揚感/
こうようご /公用語/
こうようじゅ /広葉樹/
こうようせいこう /光洋精工/
こうようせん /甲陽線/
こうようぶん /公用文/
こうようりょう /高容量/
こうよく /高翼/
こうら /甲羅/甲良/
こうらい /高麗/
こうらいがわ /高麗川/
こうらいこうくう /高麗航空/
こうらいご /高麗語/
こうらいしば /高麗芝/
こうらいにんじん /高麗人参/
こうらく /行楽/攻落/後楽/
こうらくえん /後楽園/
こうらくえんきゅうじょう /後楽園球場/
こうらくえんたいかい /後楽園大会/
こうらくえんゆうえんち /後楽園遊園地/
こうらくきゃく /行楽客/
こうらくしゃ /行楽車/
こうらくち /行楽地/
こうらくれっしゃ /行楽列車/
こうらん /高覧/香蘭/攪乱/撹亂/攪亂/鉤欄/
こうらんじょがっこう /香蘭女学校/
こうり /公理/氷/功利/高利/小売/公吏/小売り/冰/
こうりえん /香里園/
こうりか /公理化/
こうりかかく /小売価格/
こうりがし /高利貸/
こうりき /高力/
こうりぎょう /小売業/
こうりけい /公理系/
こうりざとう /氷砂糖/
こうりしょう /小売商/
こうりずしき /公理図式/
こうりたいけい /公理体系/
こうりつ /効率/公立/高率/後立/
こうりつか /効率化/
こうりつがっこう /公立学校/
こうりつがっこうきょういん /公立学校教員/
こうりつこうこう /公立高校/
こうりつこうじょう /効率向上/
こうりつしょうがっこう /公立小学校/
こうりつじゅうし /効率重視/
こうりつじょう /効率上/
こうりつせい /効率性/
こうりつだいがく /公立大学/
こうりつちゅうがく /公立中学/
こうりつちゅうがっこう /公立中学校/
こうりつてき /効率的/
こうりつてききじ /効率的記事/
こうりつてきな /効率的な/
こうりつとしょかん /公立図書館/
こうりつほいくえん /公立保育園/
こうりつほいくしょ /公立保育所/
こうりつよし /効率良/
こうりてき /公理的/
こうりてきしゅうごうろん /公理的集合論/
こうりてきほうほう /公理的方法/
こうりてん /小売店/
こうりてんしゅ /小売店主/
こうりね /小売値/
こうりまわり /高利回り/
こうりみず /氷水/
こうりゃく /後略/攻略/
こうりゃくちゅう /攻略中/
こうりゃくほう /攻略法/
こうりゃくほうほう /攻略方法/
こうりゃくぼん /攻略本/
こうりやま /郡山/
こうりやまえき /郡山駅/
こうりやまこうじょうせい /郡山工場製/
こうりゅう /交流/興隆/拘留/勾留/後流;伴流/紅龍/蛟竜;「こうりょう」とも/蛟龍/亢竜;「こうりょう」とも/幸流/
こうりゅうか /交流化/交流課/
こうりゅうかい /交流会/
こうりゅうかいかん /交流会館/
こうりゅうかいせい /交流回生/
こうりゅうかいせいしゃ /交流回生車/
こうりゅうかんけい /交流関係/
こうりゅうがた /交流型/
こうりゅうき /交流機/
こうりゅうきき /交流機器/
こうりゅうくかん /交流区間/
こうりゅうくかんない /交流区間内/
こうりゅうしゃりょう /交流車両/
こうりゅうしゅうかい /交流集会/
こうりゅうしんごう /交流信号/
こうりゅうじ /広隆寺/
こうりゅうじあい /交流試合/
こうりゅうじあいしゅつじょう /交流試合出場/
こうりゅうせん /交流戦/
こうりゅうせんよう /交流専用/
こうりゅうちく /交流地区/
こうりゅうでんか /交流電化/
こうりゅうでんかくかん /交流電化区間/
こうりゅうでんげん /交流電源/
こうりゅうでんしゃ /交流電車/
こうりゅうはつでんき /交流発電機/
こうりゅうばん /交流版/
こうりゅうほうしき /交流方式/
こうりょ /考慮/
こうりょう /荒涼/光量/稿料/衡量/講料/香料/校了/綱領/広陵/亢竜;「こうりゅう」とも/蛟竜;「こうりゅう」とも/
こうりょうせいぎょ /光量制御/
こうりょうぶそく /光量不足/
こうりょがい /考慮外/
こうりょく /効力/抗力/
こうりょじかん /考慮時間/
こうりょちゅう /考慮中/
こうりりえき /小売利益/
こうりろんてき /公理論的/
こうりん /後輪/光臨/降臨/光輪/
こうりんくどう /後輪駆動/
こうりんくどうしゃ /後輪駆動車/
こうりんじく /後輪軸/
こうりんぼう /香林坊/
こうれい /恒例/好例/高齢/交霊/降霊/
こうれいか /高齢化/
こうれいかしゃかい /高齢化社会/
こうれいぎょうじ /恒例行事/
こうれいしゃ /高齢者/
こうれしゃふくし /高齢者福祉/
こうれつ /後列/項列/
こうれべる /高レベル/
こうれべるがくしゅう /高レベル学習/
こうれん /鉤連/拘攣/
こうろ /航路/高炉/行路/香炉/香露/鈩/
こうろう /功労/高楼/高樓/絳蝋/
こうろうしゃ /功労者/
こうろうしょう /功労賞/
こうろうたて /功労盾/
こうろく /公録/
こうろけん /航路権/
こうろさ /行路差/
こうろもう /航路網/
こうろん /口論/公論/
こうろんおつばく /甲論乙駁/
こうわ /講話/講和/興和/高話/
こうわかいぎ /講和会議/
こうわきのう /交話機能/
こうわじょうやく /講和条約/
こうわほう /口話法/
こうわん /港湾/
こうわんかんりち /港湾管理地/
こえ /声/越/肥/聲/
こえい /孤影/
こえいもん /虎衛門/
こえしつ /声質/
こえじ /越路/
こえずか /肥塚/
こえだめ /肥だめ/
こえづか /肥塚/
こえなかじま /越中島/
こえんゆう /小円遊/
こおう /呼応/
こおどり /小躍り/
こおに /小鬼/
こおり /氷/郡/冰/桑折/
こおりざとう /氷砂糖/
こおりだ /凍田/
こおりみず /氷水/
こおりやま /郡山/
こおろぎ /蛩/蟋蟀/
こか /固化/古歌/瓠果/
こかいいん /子会員/
こかいがわ /小貝川/
こかく /顧客/
こかげ /木陰/
こかじ /小鍛治/
こかつ /枯渇/涸渇/
こかわ /粉河/胡川/
こかん /股間/
こかんきょう /古環境/
こかんせつ /股関節/
こかんぶぶん /股間部分/
こが /古賀/古河/
こがい /戸外/庫外/小粥/個飼い/
こがいしゃ /子会社/小会社/
こがいしゃか /子会社化/
こがく /古楽/
こがた /小型/小形/
こがたか /小型化/
こがたかん /小型艦/
こがたき /小型機/
こがたけいさんき /小型計算機/
こがたけいりょう /小型軽量/
こがたけいりょうか /小型軽量化/
こがたげんてい /小型限定/
こがたこうせいのう /小型高性能/
こがたしゃ /小型車/
こがたじどうにりん /小型自動二輪/
こがたじゃぐちちょっけつ /小型蛇口直結/
こがたじょうようしゃ /小型乗用車/
こがたせんぱく /小型船舶/
こがたでんねつ /小型電熱/
こがたな /小刀/
こがたにりん /小型二輪/
こがたにりんか /小型二輪化/
こがたにりんしゃ /小型二輪車/
こがたばん /小型版/
こがたひこうき /小型飛行機/
こがっき /古楽器/子楽器/
こがね /黄金/小金/
こがねい /小金井/
こがねいし /小金井市/
こがねいろ /黄金色/
こがねはら /小金原/
こがねまる /小金丸/
こがまさお /古賀政男/
こがめ /子亀/
こがら /小柄/
こがらし /木枯し/木枯/凩/
こがわ /古川/
こがわせ /小為替/
こがん /湖岸/
こき /古希/呼気/子器/子機/古稀/
こきお /古希男/
こきざみ /小刻み/
こきたない /小汚い/
こきのう /子機能/
こきみ /小気味/
こきゃく /顧客/
こきゃくかんりよう /顧客管理用/
こきゃくがわ /顧客側/
こきゃくまんぞくど /顧客満足度/
こきゃくめい /顧客名/
こきゅう /呼吸/固給/胡弓/
こきゅうおん /呼吸音/
こきゅうき /呼吸器/
こきゅうきかん /呼吸器官/
こきゅうきけい /呼吸器系/
こきゅうきけいしっかん /呼吸器系疾患/
こきゅうきのう /呼吸機能/
こきゅうこん /呼吸根/
こきゅうこんなん /呼吸困難/
こきゅうていこう /呼吸抵抗/
こきゅうていし /呼吸停止/
こきゅうほう /呼吸法/
こきょう /故郷/
こきろく /古記録/
こきん /古今/
こきんしゅう /古今集/
こぎって /小切手/
こぎて /漕ぎ手/
こぎれい /小綺麗/
こく /国/刻/告/酷/黒/鵠/克/穀/詰/谷/剋/哭/圀/國/尅/斛/梏/槲/轂/釛/棘/石/
こくい /国威/黒衣/
こくいっこく /刻一刻/
こくいん /刻印/
こくう /穀雨/虚空/
こくうん /国運/黒雲/
こくえい /国営/
こくえいてん /国営店/
こくえいほうそう /国営放送/
こくえいりょこうしゃ /国営旅行社/
こくえき /国益/
こくえん /黒鉛/黒煙/
こくおう /国王/
こくかんこんよう /国漢混用/
こくがい /国外/
こくがいさん /国外産/
こくがいしゃ /国外車/
こくがいだっしゅつ /国外脱出/
こくがいとうぼう /国外逃亡/
こくがいはつ /国外発/
こくがいひん /国外品/
こくがいりゅうがく /国外留学/
こくがく /國學/
こくがくいん /国学院/國學院/
こくがくいんくがやま /国学院久我山/
こくがくいんだい /国学院大/
こくがくしゃ /国学者/
こくぎ /国技/国議/
こくぎかん /国技館/
こくけん /国研/
こくけんばん /黒鍵盤/
こくげん /刻限/
こくこ /国庫/
こくこうしりつ /国公私立/
こくこうりつ /国公立/
こくこく /刻々/刻刻/
こくご /国語/
こくごう /国号/
こくごおん /国語音/
こくごがく /国語学/
こくごがくしゃ /国語学者/
こくごきょういく /国語教育/
こくごきょうし /国語教師/
こくごきょうしつ /国語教室/
こくごしんぎかい /国語審議会/
こくごじしょ /国語辞書/
こくごじてん /国語辞典/
こくごだいじてん /国語大辞典/
こくごてき /国語的/
こくごのうりょく /国語能力/
こくごりょく /国語力/
こくさい /国際/国債/國際/
こくさいうちゅうだいがく /国際宇宙大学/
こくさいうちゅうねん /国際宇宙年/
こくさいえいぞう /国際映像/
こくさいおんがくさい /国際音楽祭/
こくさいか /国際化/国際課/
こくさいかいかん /国際会舘/
こくさいかいぎ /国際会議/
こくさいかいぎかいさい /国際会議開催/
こくさいかいぎじょう /国際会議場/
こくさいかいぎろんぶん /国際会議論文/
こくさいかいせん /国際回線/
こくさいかきのう /国際化機能/
こくさいかくしき /国際格式/
こくさいかたいおう /国際化対応/
こくさいかばん /国際化版/
こくさいかぶぶん /国際化部分/
こくさいかもつびん /国際貨物便/
こくさいかもつよう /国際貨物用/
こくさいかわせ /国際為替/
こくさいかんかく /国際感覚/
こくさいかんけい /国際関係/
こくさいかんしゅうほうじょう /国際慣習法上/
こくさいがくせい /国際学生/
こくさいがくせいしょう /国際学生証/
こくさいがっかい /国際学会/
こくさいきかく /国際規格/
こくさいきかくあん /国際規格案/
こくさいきかくか /国際規格化/
こくさいきかくげんあん /国際規格原案/
こくさいきかくさくせい /国際規格作成/
こくさいきかん /国際機関/
こくさいきのう /国際機能/
こくさいきやく /国際規約/
こくさいきゅう /国際級/
こくさいきゅうじょたい /国際救助隊/
こくさいきょうそう /国際競争/国際競走/
こくさいきょうそうか /国際競走化/
こくさいきょうつうご /国際共通語/
こくさいきょうてい /国際協定/
こくさいきょうどうけんきゅう /国際共同研究/
こくさいきょく /国際局/
こくさいきりすときょうだい /国際基督教大/
こくさいきりすときょうだいがく /国際基督教大学/
こくさいきろく /国際記録/
こくさいくうこう /国際空港/
こくさいぐんだん /国際軍団/
こくさいけいざいかい /国際経済界/
こくさいけいりん /国際競輪/
こくさいけっさい /国際決済/
こくさいけっさいぎんこう /国際決済銀行/
こくさいけん /国際研/
こくさいけんきゅうしょ /国際研究所/
こくさいけんまくはり /国際研幕張/
こくさいげんゆかかく /国際原油価格/
こくさいこうき /国際光器/
こくさいこうぎょう /国際航業/国際興行/国際興業/
こくさいこうくう /国際航空/
こくさいこうくううんちん /国際航空運賃/
こくさいこうくうしゃしん /国際航空写真/
こくさいこうけん /国際貢献/
こくさいこうにん /国際公認/
こくさいこうりゅう /国際交流/
こくさいこうりゅうだんたい /国際交流団体/
こくさいこうろ /国際航路/
こくさいこどもけんしょう /国際子供憲章/
こくさいご /国際語/
こくさいさいばんしょ /国際裁判所/
こくさいざっし /国際雑誌/
こくさいしほうさいばん /国際司法裁判/
こくさいしゃかい /国際社会/
こくさいしゅうかん /国際週間/
こくさいしょうたい /国際招待/
こくさいしょうたいきょうそう /国際招待競走/
こくさいしょく /国際色/
こくさいしんぜん /国際親善/
こくさいしんぱん /国際審判/
こくさいしんぱんいん /国際審判員/
こくさいじかん /国際時間/
こくさいじょうせい /国際情勢/
こくさいじょうやく /国際条約/
こくさいじょうやくしゅう /国際条約集/
こくさいじんどうほう /国際人道法/
こくさいせいぎ /国際正義/
こくさいせいじ /国際政治/
こくさいせいじがく /国際政治学/
こくさいせいじがくしゃ /国際政治学者/
こくさいせいじし /国際政治史/
こくさいせつぞく /国際接続/
こくさいせん /国際線/
こくさいせんげん /国際宣言/
こくさいせんこうくう /国際線航空/
こくさいせんじゅよう /国際線需要/
こくさいせんよう /国際線用/
こくさいせんよやく /国際線予約/
こくさいたいかい /国際大会/
こくさいたんいけい /国際単位系/
こくさいだいがく /国際大学/
こくさいつう /国際通/
こくさいつうこうぜい /国際通行税/
こくさいつうしん /国際通信/
こくさいてがた /国際手形/
こくさいてき /国際的/
こくさいてきごかい /国際的誤解/
こくさいてきちめいど /国際的知名度/
こくさいてきちょさくけん /国際的著作権/
こくさいてきひなん /国際的非難/
こくさいでんき /国際電気/
こくさいでんでん /国際電電/
こくさいでんわ /国際電話/
こくさいでんわきょく /国際電話局/
こくさいとし /国際都市/
こくさいはつおんきごう /国際発音記号/
こくさいひかく /国際比較/
こくさいひほうかん /国際秘宝館/
こくさいひょうき /国際表記/
こくさいひょうじゅん /国際標準/
こくさいひょうじゅんか /国際標準化/
こくさいひょうじゅんかきかん /国際標準化機関/
こくさいびん /国際便/
こくさいふんそう /国際紛争/
こくさいぶ /国際部/
こくさいぶんかいかん /国際文化会館/
こくさいぶんかかいかん /国際文化会館/
こくさいへいわ /国際平和/
こくさいへいわねん /国際平和年/
こくさいほう /国際法/
こくさいほういはん /国際法違反/
こくさいほうがくしゃ /国際法学者/
こくさいほうがくてき /国際法学的/
こくさいほうき /国際法規/
こくさいほうじょう /国際法上/
こくさいほうそう /国際放送/
こくさいほうてき /国際法的/
こくさいめんきょ /国際免許/
こくさいめんきょしょう /国際免許証/
こくさいもじきかく /国際文字規格/
こくさいもんだい /国際問題/
こくさいゆうびんかわせ /国際郵便為替/
こくさいりかい /国際理解/
こくさいりがく /国際理学/
こくさいりょきゃく /国際旅客/
こくさいりょこうしゃ /国際旅行社/
こくさいれっしゃ /国際列車/
こくさいれんごう /国際連合/
こくさいれんめい /國際聯盟/
こくさく /国策/
こくさくじぎょう /国策事業/
こくさん /国産/
こくさんき /国産機/
こくさんけいじどうしゃ /国産軽自動車/
こくさんさいこうきゅう /国産最高級/
こくさんしゃ /国産車/
こくさんしゃたいかい /国産車大会/
こくさんたしゃ /国産他社/
こくさんはつ /国産初/
こくさんばん /国産盤/
こくさんひん /国産品/
こくさんまい /国産米/
こくし /酷使/国士/国試/国史/
こくしかん /国士舘/
こくしかんだいがく /国士舘大学/
こくしだい /国士大/
こくしびょう /黒死病/
こくしむそう /国士無双/
こくしょ /国書/酷暑/
こくしょう /国生/國生/
こくしょかんこうかい /国書刊行会/
こくしょく /黒色/
こくしょくしゅ /黒色腫/
こくしょくとそう /黒色塗装/
こくじ /告示/酷似/国事/国字/国璽/刻時/
こくじぎょうじ /国事行事/
こくじこうい /国事行為/
こくじしょうしょ /国璽尚書/
こくじせってん /刻時節点/
こくじょう /国情/
こくじょく /国辱/
こくじん /黒人/
こくじんおんがく /黒人音楽/
こくじんけい /黒人系/
こくじんじょせい /黒人女性/
こくじんたち /黒人達/
こくじんだんせい /黒人男性/
こくじんてき /黒人的/
こくじんどれい /黒人奴隷/
こくじんもんだい /黒人問題/
こくすい /国粋/
こくすいしゅぎしゃ /国粋主義者/
こくせい /国政/国勢/
こくせいせんきょ /国政選挙/
こくせいちょうさ /国勢調査/
こくせき /国籍/
こくせきしょゆうしゃ /国籍所有者/
こくせきじょうこう /国籍条項/
こくせきじんしゅ /国籍人種/
こくせきほう /国籍法/
こくせきりだつ /国籍離脱/
こくせつ /国設/
こくせん /国選/
こくせんべんごし /国選弁護士/
こくせんべんごにん /国選弁護人/
こくぜ /国是/
こくぜい /国税/
こくぜいきょく /国税局/
こくぜいちょう /国税庁/
こくそ /告訴/
こくそう /穀倉/
こくそけん /告訴権/
こくそざた /告訴沙汰/
こくぞく /国賊/
こくた /穀田/
こくたい /国体/國軆/
こくたいごじ /國軆護持/国体護持/
こくたいだいひょうせんしゅ /国体代表選手/
こくたいふくしゃ /黒体輻射/
こくたいほうしゃ /黒体放射/
こくたいよせん /国体予選/
こくたん /黒檀/
こくだい /国大/
こくち /告知/
こくちきじ /告知記事/
こくちょう /国鳥/
こくてい /国定/
こくていこうえん /国定公園/
こくてつ /国鉄/
こくてつうさえき /国鉄宇佐駅/
こくてつえき /国鉄駅/
こくてつかいたいじ /国鉄解体時/
こくてつがた /国鉄型/
こくてつし /国鉄史/
こくてつしながわえき /国鉄品川駅/
こくてつしゃりょう /国鉄車両/
こくてつしょく /国鉄色/
こくてつじだい /国鉄時代/
こくてつせん /国鉄線/
こくてつぜんせん /国鉄全線/
こくてつちょくつう /国鉄直通/
こくてつでんしゃ /国鉄電車/
こくてつにしのみやえき /国鉄西宮駅/
こくてつはいしろせん /国鉄廃止路線/
こくてつはいせんあと /国鉄廃線跡/
こくてん /黒点/
こくてんぐん /黒点群/
こくでん /国電/
こくでんくかん /国電区間/
こくとう /黒糖/
こくとうげんまい /黒糖玄米/
こくど /国土/
こくどう /国道/
こくどういちごうせん /国道一号線/
こくどうせん /国道線/
こくどうぞい /国道沿/
こくどうにごうせん /国道二号線/
こくどけいかく /国土計画/
こくどこうつうしょう /国土交通省;建設省、運輸省、国土庁が2001年1月の中央省庁再編で再編されたもの/
こくどしゃ /国土舎/
こくどちょう /国土庁;2001年1月の中央省庁再編で国土交通省に再編された/
こくどちりいん /国土地理院/
こくない /国内/
こくないかかく /国内価格/
こくないがい /国内外/
こくないくうこう /国内空港/
こくないさいてい /国内最低/
こくないさん /国内産/
こくないしゅっぱん /国内出版/
こくないしょうひん /国内商品/
こくないしよう /国内仕様/
こくないじじょう /国内事情/
こくないせい /国内製/
こくないせいひん /国内製品/
こくないせん /国内線/
こくないせんうんちん /国内線運賃/
こくないせんかんかく /国内線感覚/
こくないせんくろじ /国内線黒字/
こくないせんのりつぎ /国内線乗継ぎ/
こくないせんぶぶん /国内線部分/
こくないせんよう /国内専用/国内線用/
こくないぜんいき /国内全域/
こくないぜんせいせき /国内全成績/
こくないぜんたい /国内全体/
こくないだいりてん /国内代理店/
こくないちょうたつ /国内調達/
こくないつうしん /国内通信/
こくないていか /国内定価/
こくないてき /国内的/
こくないでんわりょうきん /国内電話料金/
こくないはっけん /国内発券/
こくないはつばい /国内発売/
こくないはつばいぶん /国内発売分/
こくないはんばい /国内販売/
こくないばん /国内版/国内盤/
こくないひん /国内品/
こくないびん /国内便/
こくないぶん /国内分/
こくないほう /国内法/
こくないほうき /国内法規/
こくないほしょう /国内保証/
こくないみはつばい /国内未発売/
こくないむけ /国内向/
こくないめんきょしょう /国内免許証/
こくないもんだい /国内問題/
こくないよう /国内用/
こくないようこがたしゃ /国内用小型車/
こくないりゅうがく /国内留学/
こくないりょこう /国内旅行/
こくないれっしゃ /国内列車/
こくなん /国難/
こくね /古久根/
こくはく /告白/酷薄/穀帛/
こくはつ /告発/
こくはつじょう /告発状/
こくはつぶんしょう /告発文章/
こくばん /黒板/
こくひ /国費/
こくひべんごし /国費弁護士/
こくひょう /酷評/
こくひん /国賓/
こくびゃく /黒白/
こくふ /国府/
こくふく /克服/
こくふだ /国府田/
こくぶ /国分/国府/
こくぶん /国分/国文/
こくぶんがく /国文学/
こくぶんじ /国分寺/
こくぶんじえき /国分寺駅/
こくぶんじえきていしゃ /国分寺駅停車/
こくぶんじかいどう /国分寺街道/
こくぶんじかん /国分寺間/
こくぶんじし /国分寺市/
こくぶんちょう /国分町/
こくぶんぽう /国文法/
こくへん /黒変/
こくべつ /告別/
こくべつしき /告別式/
こくほ /国保/
こくほう /国宝/國寶/
こくぼ /小久保/
こくぼう /国防/
こくぼうぐん /国防軍/
こくぼうしょう /国防省/
こくぼうじょう /国防上/
こくぼうそうしょう /国防総省/
こくぼうだいじん /国防大臣/
こくぼうちょうかん /国防長官/
こくぼうひさくげん /国防費削減/
こくぼうほう /国防法/
こくみん /国民/
こくみんかいぎ /国民会議/
こくみんかんじょう /国民感情/
こくみんき /国民機/
こくみんきゅうかむら /国民休暇村/
こくみんぎかい /国民議会/
こくみんけんこうほけん /国民健康保険/
こくみんしゃこうそう /国民車構想/
こくみんしゅくしゃ /国民宿舎/
こくみんしゅけん /国民主権/
こくみんしんさ /国民審査/
こくみんせい /国民性/
こくみんせいかつ /国民生活/
こくみんせいふ /国民政府/
こくみんぜんたい /国民全体/
こくみんちょうようれい /国民徴用令/
こくみんてき /国民的/
こくみんてきいったいせい /国民的一体性/
こくみんてきえいゆう /国民的英雄/
こくみんてきばんぐみ /国民的番組/
こくみんてきびしょうじょ /国民的美少女/
こくみんとう /国民党/
こくみんとうごう /国民統合/
こくみんとうひょう /国民投票/
こくみんどうし /国民同士/
こくみんないぶ /国民内部/
こくみんねんきん /国民年金/
こくみんひとりひとり /国民一人一人/
こくみんふくしぜい /国民福祉税/
こくみんふざい /国民不在/
こくむ /国務/
こくむいん /国務院/
こくむしょう /国務省/
こくむだいじん /国務大臣/
こくめい /克明/国名/
こくもつ /穀物/
こくやく /国躍/
こくゆう /国有/
こくゆうか /国有化/
こくゆうかいご /国有化以後/
こくゆうご /国有後/
こくゆうち /国有地/
こくゆうりん /国有林/
こくようせき /黒曜石/
こくら /小倉/
こくらえき /小倉駅/
こくらえきまえ /小倉駅前/
こくらかん /小倉間/
こくらがわ /小倉側/
こくらきた /小倉北/
こくらきたくやくしょ /小倉北区役所/
こくらけいば /小倉競馬/
こくらけいばじょう /小倉競馬場/
こくらこうこう /小倉高校/
こくらこうじょう /小倉工場/
こくらしゅっしん /小倉出身/
こくらじょう /小倉城/
こくらせん /小倉線/
こくらみなみ /小倉南/
こくりつ /国立/
こくりつえんげいじょう /国立演芸場/
こくりつかげきじょう /国立歌劇場/
こくりつきょうぎじょう /国立競技場/
こくりつけん /国立研/
こくりつけんきゅうきかん /国立研究機関/
こくりつげきじょう /国立劇場/
こくりつこうえん /国立公園/
こくりつこうえんない /国立公園内/
こくりつしょうにびょういん /国立小児病院/
こくりつじゅんかんきびょう /国立循環器病/
こくりつだい /国立大/
こくりつだいがく /国立大学/
こくりつだいがくせい /国立大学生/
こくりつだいせい /国立大生/
こくりつてんもんだい /国立天文台/
こくりつのうがくどう /国立能楽堂/
こくりつびじゅつかん /国立美術館/
こくりゅう /黒竜/黒龍/
こくりょう /国領/
こくりょく /国力/
こくるい /穀類/
こくれん /国連/國聯/
こくれんあんぽり /国連安保理/
こくれんかいぎじょう /国連会議場/
こくれんかんけい /国連関係/
こくれんき /国連旗/
こくれんぐん /国連軍/
こくれんけつぎ /国連決議/
こくれんけんしょう /国連憲章/
こくれんしょくいん /国連職員/
こくれんじむそうちょう /国連事務総長/
こくれんじんけんかいぎ /国連人権会議/
こくろう /国労/
こぐし /小串/
こぐち /小口/木口/
こぐちはいそうぎょう /小口配送業/
こぐま /小熊/
こぐれ /小暮/
こぐんふんとう /孤軍奮闘/
こけ /苔/
こけい /固形/固型/
こけいぶつ /固形物/
こけつ /虎穴/固結/纐纈/
こけら /柿/
こけらおとし /柿落し/
こけん /估券/沽券/狐拳/
こげちゃ /焦茶/
こげちゃいろ /焦げ茶色/
こげつ /木月/湖月/鼓月/
こげつき /焦げ付き/
こげんた /子源太/
ここ /個々/此処/CoCo/爰/
ここあ /ココア/
ここう /孤高/餬口/股肱/
ここから /----- ここから ----- ここから ----- ここから ----- ここから -----/-------------------------------ここから-------------------------------/
ここく /故国/
ここじん /個々人/個個人/
ここち /心地/
ここちよし /心地好/
ここに /個々に/此処に/
ここの /九/
ここのえ /九重/
ここのえほんぽたまざわ /九重本舗玉澤/
ここのか /9日/九日/９日/
ここのつ /九つ/
ここまで /----- ここまで ----- ここまで ----- ここまで ----- ここまで -----/-------------------------------ここまで-------------------------------/
ここらへん /ここら辺/
こころ /心/
こころあたり /心当り/
こころいき /心意気/
こころえ /心得/
こころおち /心落ち/
こころから /心から/
こころがけ /心掛け/
こころがまえ /心構え/
こころくばり /心配り/
こころざし /志/
こころづかい /心遣い/
こころづくし /心尽くし/心尽し/
こころづけ /心付け/
こころづもり /心積もり/
こころなし /心無/
こころのこり /心残り/
こころまち /心待ち/
こころみ /試み/試/
ここん /古今/
ここんてい /古今亭/
ここんとうざい /古今東西/
こご /古語/
こごえ /小声/
こごしょう /子児姓/
こごじてん /古語辞典/
こごた /小牛田/
こごたちょう /小牛田町/
こごと /小言/
こさい /湖西/
こさか /小坂/
こさかい /小堺/
こさかた /小坂田/
こさかだ /小坂田/
こさく /小作/
こささ /小笹/
こさざ /小佐々/
こさじやまもり /小匙山盛/小匙山盛り/
こさつ /古刹/
こさはら /古佐原/
こさめ /小雨/
こさん /古参/
こさんじ /小三治/
こさんば /小三馬/
こざ /古座/
こざいく /小細工/
こざかい /小坂井/
こざかいなだ /小境灘/
こざかな /小魚/
こざがわ /古座川/
こざき /駒崎/
こざさ /小笹/
こざしき /跨座式/
こざわ /涸沢/
こし /腰/越/虎視/古志/枯死/輿/古紙/
こしお /小潮/
こしかけ /腰掛け/腰掛/
こしかた /来し方/
こしかわ /越川/
こしが /越賀/
こしがみ /漉紙/
こしがや /越谷/
こしき /甑/古式/
こしきり /越桐/
こしこでん /古史古伝/
こしじ /越路/
こしじそう /越路荘/
こしたんたん /虎視眈々/虎視眈眈/
こしだ /越田/
こしだか /腰高/
こしつ /個室/固執/痼疾/
こしつしんだい /個室寝台/
こしつふう /個室風/
こしづか /越塚/
こしなか /越中/
こしなげ /腰投げ/
こしぬけ /腰抜け/
こしの /越廼/
こしのかんばい /越乃寒梅/
こしば /小柴/古柴/
こしぼね /腰骨/
こしまき /腰巻/
こしみず /輿水/小清水/
こしみはる /越美晴/
こしむら /越村/
こしもと /腰元/越元/
こしゃく /小癪/
こしやまそう /越山荘/
こしゅ /固守/戸主/古酒/鼓手/
こしゅう /固執/個集/
こしゅつ /庫出/
こしょ /古書/
こしょいち /古書市/
こしょう /故障/湖沼/呼称/胡椒/小姓/楜/小性/壷漿/壺漿/
こしょうか /コショウ科/Piperaceae/
こしょうかしょ /故障箇所/
こしょうぎ /小将棋/
こしょうげんいん /故障原因/
こしょうしゃ /故障者/故障車/
こしょうしゃぞくしゅつ /故障者続出/
こしょうしょりひょう /故障処理票/
こしょうしんだん /故障診断/
こしょうじ /故障時/
こしょうじせいのう /故障時性能/
こしょうせい /故障性/
こしょうちゅう /故障中/
こしょうはっせい /故障発生/
こしょうはっせいじ /故障発生時/
こしょうひんど /故障頻度/
こしょうぶひん /故障部品/
こしょうへんこう /呼称変更/
こしょうまえ /故障前/
こしょうまち /故障待ち/
こしょうもく /コショウ目/Piperales/
こしょうりつ /故障率/
こしょうれき /故障歴/
こしょがい /古書街/
こしょく /古色/
こしょくそうぜん /古色蒼然/
こしょてん /古書店/古書展/
こしょてんがい /古書店街/
こしょり /呼処理/
こしろ /古代/小代/
こじ /誇示/故事/孤児/古寺/固持/固辞/弧児/古字/居士/
こじか /子鹿/小鹿/
こじき /乞食/古事記/
こじせいご /故事成語/
こじだい /子時代/
こじつ /故実/
こじま /小島/児島/小嶋/戸島/古島/
こじまかん /児島間/
こじまわん /児島湾/
こじゅう /扈従/
こじゅうと /小姑/小舅/
こじょう /古城/湖上/
こじょうれんけつ /弧状連結/
こじらいれき /故事来歴/
こじり /鐺/
こじろう /小次郎/
こじわ /小じわ/
こじん /個人/故人/古人/
こじんあて /個人宛/
こじんい /個人医/
こじんいけん /個人意見/
こじんえんぎ /個人演技/
こじんおいぬき /個人追抜/
こじんかいいん /個人会員/
こじんかん /個人間/
こじんかんきょう /個人環境/
こじんがくしゅう /個人学習/
こじんきゃく /個人客/
こじんきょうぎ /個人競技/
こじんきろく /個人記録/
こじんぎしゅうだん /個人技集団/
こじんけいえい /個人経営/
こじんけんきん /個人献金/
こじんこうげき /個人攻撃/
こじんこうしょう /個人交渉/
こじんこうどう /個人行動/
こじんこうほ /個人候補/
こじんこじん /個人個人/個人々々/
こじんごと /個人毎/
こじんさ /個人差/
こじんさべつ /個人差別/
こじんさんか /個人参加/
こじんざいさんほご /個人財産保護/
こじんし /個人誌/
こじんしきべつ /個人識別/
こじんしゃけん /個人車検/
こじんしゅぎ /個人主義/
こじんしゅぎてき /個人主義的/
こじんしゅみ /個人趣味/
こじんしょうごう /個人照合/
こじんしょうひ /個人消費/
こじんしょゆう /個人所有/
こじんしょゆうしゃ /個人所有者/
こじんしょゆうぶつ /個人所有物/
こじんしょゆうりつ /個人所有率/
こじんしよう /個人使用/
こじんしようひん /個人使用品/
こじんじぎょうぬし /個人事業主/
こじんじしょ /個人辞書/
こじんじしん /個人自身/
こじんじょうほう /個人情報/
こじんせい /個人性/
こじんせいかつ /個人生活/
こじんせいかつぜんぱん /個人生活全般/
こじんせいくうかん /個人性空間/
こじんせいじょうほう /個人性情報/
こじんせいせき /個人成績/
こじんせきにん /個人責任/
こじんせってい /個人設定/
こじんせつ /古人説/
こじんせん /個人戦/
こじんせんしゅけん /個人選手権/
こじんせんりょうけい /個人線量計/
こじんぜんしゅう /個人全集/
こじんぜんたい /個人全体/
こじんそうび /個人装備/
こじんたいしゅうだん /個人対集団/
こじんたく /個人宅/
こじんたんい /個人単位/
こじんてき /個人的/
こじんてきいけん /個人的意見/
こじんてきいみ /個人的意味/
こじんてきかんさつ /個人的観察/
こじんてきかんじょう /個人的感情/
こじんてきかんそう /個人的感想/
こじんてききじ /個人的記事/
こじんてききぼう /個人的希望/
こじんてきけんかい /個人的見解/
こじんてきしゃくど /個人的尺度/
こじんてきしゅかん /個人的主観/
こじんてきしゅみ /個人的趣味/
こじんてきしんじょう /個人的信条/
こじんてきしんねん /個人的信念/
こじんてきじじょう /個人的事情/
こじんてきすいそく /個人的推測/
こじんてきたいけん /個人的体験/
こじんてきたちば /個人的立場/
こじんてきつごう /個人的都合/
こじんてきな /個人的な/
こじんてきないよう /個人的内容/
こじんてきはんだん /個人的判断/
こじんてきはんのう /個人的反応/
こじんてきようきゅう /個人的要求/
こじんてきようぼう /個人的要望/
こじんてきよっきゅう /個人的欲求/
こじんてきりかい /個人的理解/
こじんてきりよう /個人的利用/
こじんでんき /個人伝記/
こじんとうしか /個人投資家/
こじんどうし /個人同士/
こじんどうてい /個人同定/
こじんない /個人内/
こじんねんぴょう /個人年表/
こじんはっこう /個人発行/
こじんはつめいか /個人発明家/
こじんばいばい /個人売買/
こじんばいばいらん /個人売買欄/
こじんびょういん /個人病院/
こじんべつ /個人別/
こじんべつしゅうけい /個人別集計/
こじんめい /個人名/
こじんめいる /個人メール/
こじんもんだい /個人問題/
こじんゆしゅつ /個人輸出/
こじんゆにゅう /個人輸入/
こじんよう /個人用/
こじんようかくちょう /個人用拡張/
こじんより /個人寄/
こじんりょこう /個人旅行/
こじんりょこうしゃ /個人旅行者/
こじんれんしゅう /個人練習/
こじんわざ /個人技/
こすい /湖水/鼓吹/
こすいちほう /湖水地方/
こすう /個数/戸数/
こすうばい /個数倍/
こすうぶん /個数分/
こすぎ /小杉/
こすぎえき /小杉駅/
こすぎえきふきん /小杉駅付近/
こすけがわ /小助川/
こすげ /小菅/
こすだ /小須田/
こすと /コスト/
こすど /小須戸/
こすぷれ /コスプレ/
こすみ /小角/
こすも /コスモ/
こすもしょうけん /コスモ証券/
こすもす /秋桜/
こすもせきゆ /コスモ石油/
こずえ /梢/
こせ /小瀬/
こせい /個性/古生/
こせいかひ /古生花被/
こせいかひるい /古生花被類/Archichlamydeae/
こせいせん /湖西線/
こせいせんがわ /湖西線側/
こせいだい /古生代/
こせいてき /個性的/
こせいぶつ /古生物/
こせいぶつがくしゃ /古生物学者/
こせがれ /小悴/
こせき /戸籍/小関/古跡/古関/
こせきか /戸籍課/
こせきかしょくいん /戸籍課職員/
こせきかんり /戸籍管理/
こせきしょうほん /戸籍抄本/
こせきじょう /戸籍上/
こせきとうほん /戸籍謄本/
こせきほう /戸籍法/
こせきめい /戸籍名/
こせつてん /子節点/
こせん /古銭/
こせんきょう /跨線橋/
こせんじょう /古戦場/
こぜに /小銭/
こぜりあい /小競合/
こそく /姑息/
こそし /古曽志/
こそだて /子育て/
こぞう /小僧/子象/
こぞうずし /小僧寿司/
こぞって /挙って/
こぞの /小園/
こたい /個体/固体/鼓隊/固態/
こたいかん /個体間/
こたいぐん /個体群/
こたいぐんぜんたい /個体群全体/
こたいぐんない /個体群内/
こたいさ /個体差/
こたいしきべつ /個体識別/
こたいしきべつかのう /個体識別可能/
こたいしんどう /固体振動/
こたいじょうほう /個体情報/
こたいすう /個体数/
こたいたち /個体達/
こたいたんい /個体単位/
こたいちきゅう /固体地球/
こたいちゅう /固体中/
こたいていすう /個体定数/
こたいてき /固体的/
こたいでんし /固体電子/
こたいでんしこうがく /固体電子工学/
こたいとくせい /個体特性/
こたいない /個体内/
こたいないぶ /個体内部/
こたいはっせい /個体発生/
こたいへんすう /個体変数/
こたえ /答/答え/
こたえかた /答え方/
こたか /小高/
こたけ /小竹/
こたち /子達/
こたつ /炬燵/
こたつや /炬燵屋/
こたに /小谷/
こたび /此度/
こたろう /小太郎/虎太郎/
こたん /古淡/枯淡/
こだい /古代/誇大/
こだいいらい /古代以来/
こだいかいしゃく /誇大解釈/
こだいきかい /古代機械/
こだいきんきご /古代近畿語/
こだいこ /小太鼓/
こだいこうこく /誇大広告/
こだいし /古代史/
こだいしけんきゅうか /古代史研究家/
こだいしんわ /古代神話/
こだいじん /古代人/
こだいじんるい /古代人類/
こだいせんでん /誇大宣伝/
こだいぞめ /古代染/
こだいちゅうごく /古代中国/
こだいちょうせんご /古代朝鮮語/
こだいとしょかん /古代図書館/
こだいにほんご /古代日本語/
こだいぶんか /古代文化/
こだいぶんめい /古代文明/
こだいへん /古代篇/
こだいもうそう /誇大妄想/
こだいもじ /古代文字/
こだいら /小平/
こだいらし /小平市/
こだいらしつだちょう /小平市津田町/
こだか /小高/
こだし /小出し/
こだち /木立/小太刀/
こだつの /小立野/
こだと /古田土/
こだなか /小田中/
こだぬき /子狸/
こだま /児玉/木霊/小玉/谺/兒玉/
こだまし /児玉氏/
こだわり /拘泥/拘泥り/
こち /故知/乞/鯒/東風/
こちゃく /固着/
こちょう /誇張/胡蝶/蝴蝶/弧長/
こちょうひょうげん /誇張表現/
こちら /此方/
こちり /古地理/
こっ /国/
こっか /国家/国歌/国花/國家/黒化/】/）/］/』/
こっかい /国会/黒海/告解/
こっかいぎいん /国会議員/
こっかいぎけつ /国会議決/
こっかいぎじどう /国会議事堂/
こっかいぎじどうまえ /国会議事堂前/
こっかいぎじろく /国会議事録/
こっかいちゅうけい /国会中継/
こっかいとしょかん /国会図書館/
こっかいはつげん /国会発言/
こっかいまえ /国会前/
こっかかん /国家間/国家観/
こっかがいねん /国家概念/
こっかきかく /国家規格/
こっかきかん /国家機関/
こっかきみつ /国家機密/
こっかぎょうじ /国家行事/
こっかく /骨格/
こっかくきん /骨格筋/
こっかくじょうほう /骨格情報/
こっかけいびきこう /国家警備機構/
こっかけんりょく /国家権力/
こっかげんしゅ /国家元首/
こっかこうむいん /国家公務員/
こっかこうむいんほう /国家公務員法/
こっかしかく /国家資格/
こっかしけん /国家試験/
こっかしけんめんじょ /国家試験免除/
こっかしじょうしゅぎ /国家至上主義/
こっかしゃかい /国家社会/
こっかしゅぎ /国家主義/
こっかしゅどう /国家主導/
こっかしんどう /国家神道/
こっかじょうそうぶ /国家上層部/
こっかせいしょう /国歌斉唱/
こっかせんりゃく /国家戦略/
こっかぜんたい /国家全体/
こっかそうとう /国歌相当/
こっかたいこっか /国家対国家/
こっかたいせい /国家体制/
こっかたんい /国家単位/
こっかてき /国家的/
こっかばいしょう /国家賠償/
こっかひみつ /国家秘密/
こっかびちくぶん /国家備蓄分/
こっかほしょう /国家補償/
こっかめい /国家名/
こっかよさん /国家予算/
こっかよさんぜんたい /国家予算全体/
こっかん /酷寒/骨幹/
こっき /国旗/黒旗/克己/
こっきけいよう /国旗掲揚/
こっきしん /克己心/
こっきそうとう /国旗相当/
こっきゅう /黒球/
こっきょう /国境/
こっきょうえき /国境駅/
こっきょうがっさく /国共合作/
こっきょうせん /国境線/
こっきょうないせん /国共内戦/
こっくぴっと /コックピット/
こっけい /滑稽/
こっけん /国権/黒鍵/国憲/国研/
こっけんじょう /国権上/
こっこ /国庫/
こっこう /国交/国光/
こっこうこうしょう /国交交渉/
こっこうせいじょうか /国交正常化/
こっこうりつ /国公立/
こっこうりつだい /国公立大/
こっこうりつだいがく /国公立大学/
こっこく /刻々/
こっし /骨子/
こっせつ /骨折/
こっせつしゃ /骨折者/
こっせつちりょうちゅう /骨折治療中/
こっそうがく /骨相学/
こっちょう /骨頂/
こっとう /骨董/
こっとうかち /骨董価値/
こっとうてきかち /骨董的価値/
こっとうひん /骨董品/
こっぱ /木ッ端/木端/木っ端/
こっぱみじん /木ッ端微塵/木端微塵/木っ端微塵/
こっぱやくにん /木ッ端役人/
こっぷ /コップ/
こっぽら /コッポラ/
こつ /骨/惚/忽/乞/笏/コツ/兀/榾/
こつえん /忽焉/
こつがら /骨柄/
こつくり /木造/
こつじょう /骨状/
こつじょうこうへきいけいさいぼう /骨状厚壁異形細胞/
こつずい /骨髄/
こつずいいしょく /骨髄移植/
こつずいていきょう /骨髄提供/
こつずいていきょうしゃ /骨髄提供者/
こつぜん /忽然/
こつぜんと /忽然と/
こつそしょうしょう /骨粗鬆症/骨粗鬚症/
こつづみ /小鼓/
こつにく /骨肉/
こつばん /骨盤/
こつぶ /小粒/
こつまくえん /骨膜炎/
こつるせん /小鶴線/
こづか /小塚/
こづかい /小遣い/小使い/
こづつみ /小包/
こづる /小鶴/
こづるせん /小鶴線/
こづれ /子連れ/
こて /小手/鏝/鐺/籠手/
こてい /固定/湖底/
こていいち /固定位置/
こていか /固定化/
こていかんねん /固定観念/
こていがいねん /固定概念/
こていがた /固定型/
こていきゅう /固定給/
こていきょく /固定局/
こていきりかえ /固定切替/
こていきんり /固定金利/
こていぐ /固定具/
こていしき /固定式/
こていしさん /固定資産;有形固定資産、無形固定資産、投資等の3つ/
こていしさんぜい /固定資産税/
こていしゃ /固定者/
こていしょうすう /固定小数/
こていしょうすうてん /固定小数点/
こていしょうすうてんえんざん /固定小数点演算/
こていしょうすうてんがた /固定小数点型/
こていしょうすうてんすう /固定小数点数/
こていじゅうざ /固定銃座/
こていじょうけん /固定条件/
こていそうさ /固定操作/
こていたん /固定端/
こていち /固定値/
こていちょう /固定長/
こていちょうきてきごうりつ /固定長期適合率/
こていてき /固定的/
こていてきていぎかん /固定的定義観/
こていてん /固定点/
こていにゅうりょく /固定入力/
こていにゅうりょくかいじょ /固定入力解除/
こていはっせいげん /固定発生源/
こていはば /固定幅/
こていひ /固定費/
こていひょう /固定票/
こていひりつ /固定比率/
こていふさい /固定負債/
こていぶつ /固定物/
こていへんせい /固定編成/
こていへんせいしゃりょう /固定編成車両/
こていほう /固定法/
こていほうしき /固定方式/
こていほうとう /固定砲塔/
こていほうほう /固定方法/
こていまど /固定窓/
こていもじれつ /固定文字列/
こていよう /固定用/
こていよく /固定翼/
こてがわ /古手川/小手川/
こてき /鼓笛/
こてきたい /鼓笛隊/
こてさき /小手先/
こてさし /小手指/
こてしらべ /小手調べ/
こてつ /小鉄/
こてなげ /小手投げ/
こてわざ /小手技/
こてん /古典/個展/
こてんがっき /古典楽器/
こてんき /古典機/
こてんきかんしゃ /古典機関車/
こてんけい /古典系/
こてんご /古典語/
こてんしゅうごうろん /古典集合論/
こてんしゅぎ /古典主義/
こてんじだい /古典時代/
こてんせいぶつがく /古典生物学/
こてんそうたいろん /古典相対論/
こてんちゅう /古典中/
こてんてき /古典的/
こてんてきかがく /古典的化学/
こてんてきしゅほう /古典的手法/
こてんてきじょうけんづけ /古典的条件付/
こてんてきめいさく /古典的名作/
こてんは /古典派/
こてんぶつり /古典物理/
こてんぶつりがいねん /古典物理概念/
こてんぶんぽう /古典文法/
こてんらくご /古典落語/
こてんりきがく /古典力学/
こてんりろん /古典理論/
こてんろん /古典論/
こてんろんり /古典論理/
こてんろんりじょう /古典論理上/
こでら /小寺/
こと /事/琴/言/異/古都/殊/亊/糊塗/
こといみ /言忌み/
ことう /孤島/小藤/湖東/厚東/
ことうだんち /湖東団地/
ことえり /言選り/
ことかぜごうき /琴風豪規/
ことがうめ /琴ヶ梅/
ことがら /事柄/
ことこまか /事細か/
ことごと /事々/
ことごとく /悉く/尽く/
ことさら /殊更/
ことし /今年/
ことしあき /今年秋/
ことしいじょう /今年以上/
ことしいちばん /今年一番/
ことしかいさい /今年開催/
ことしかいそう /今年改装/
ことしかんれき /今年還暦/
ことしくれ /今年暮/
ことしこうはん /今年後半/
ことしさいご /今年最後/
ことしさいしょ /今年最初/
ことしさいだい /今年最大/
ことししょとうはっこう /今年初頭発行/
ことしじゅう /今年中/
ことしすえ /今年末/
ことしぜんはん /今年前半/
ことしちゅう /今年中/
ことしぢゅう /今年中/
ことしなついこう /今年夏以降/
ことしはつ /今年初/
ことしはる /今年春/
ことしぶん /今年分/
ことじたい /事自体/
ことづけ /言付け/事付/
ことづて /言傳て/
ことてんざん /琴天山/
ことでん /琴電/
こととい /言問/
ことなし /事無/
ことなる /異なる/
ことに /殊に/琴似/
ことにしき /琴錦/
ことね /琴音/
ことの /琴乃/琴野/
ことのついで /事の序/
ことのは /言の葉/
ことのほか /殊の外/
ことはじめ /事始め/
ことば /言葉/詞/
ことばあそび /言葉遊び/
ことばかず /言葉数/
ことばがり /言葉狩り/
ことばじしん /言葉自身/
ことばじたい /言葉自体/
ことばじり /言葉尻/
ことばづかい /言葉遣い/
ことばぶそく /言葉不足/
ことばめん /言葉面/
ことひら /琴平/
ことひらせん /琴平線/
ことひらはつおかやまいき /琴平発岡山行/
ことひらはつおかやまゆき /琴平発岡山行/
ことふじ /琴富士/
ことぶき /寿/壽/
ことぶきそう /寿荘/
ことぶきや /壽屋/寿屋/
ことべっぷ /琴別府/
ことほどさように /事程左様に/
ことみ /琴美/
ことり /小鳥/
ことりたち /小鳥達/
ことりよう /小鳥用/
ことわざ /諺/
ことわり /理/
こどう /鼓動/
こどうぐ /小道具/
こどく /孤独/蠱毒/
こどくかん /孤独感/
こどほう /弧度法/
こどまり /小泊/
こども /子供/小人/子ども/
こどもあいて /子供相手/
こどもかい /子供会/
こどもかいいん /子供会員/
こどもごころ /子供心/
こどもじだい /子供時代/
こどもずき /子供好き/
こどもそうだんしつ /子供相談室/
こどもたち /子供達/
こどもなみ /子供並/
こどもばんぐみ /子供番組/
こどもふく /子供服/
こどもべや /子供部屋/
こどもよう /子供用/
こどもりょうきん /子供料金/
こな /粉/紛/
こない /来ない/庫内/
こなか /小中/
こなかい /小仲井/
こなかだい /小仲台/
こなから /二合半/
こながい /小長井/
こなきじじい /子泣爺/
こなぐすり /粉薬/
こなごな /粉々/紛々/
こなじょう /粉状/
こなせっけん /粉せっけん/
こなつ /小夏/
こなふき /粉吹き/
こなみ /小波/
こなみじん /粉微塵/
こなや /粉屋/
こなゆき /粉雪/
こならい /小習/
こなんきせん /湖南汽船/
こにし /小西/
こにしき /小錦/
こにしろく /小西六/
こにもつ /小荷物/
こにもつゆそう /小荷物輸送/
こにんずう /小人数/
こぬき /小貫/
こぬま /小沼/
こね /コネ/
こねこ /子猫/小猫/仔猫/
この /此の/此/斯の/
このーど /子ノード/
このあいだ /この間/
このうら /金浦/
このえ /近衛/
このえちょう /近江町/
このかた /此方/
このかん /この間/
このころ /この頃/
このご /此期/
このごろ /この頃/此頃/
このしゅ /この種/
このしろ /鮗/
このたび /この度/此度/
このとき /この時/
このは /木の葉/
このはな /此花/
このへん /此邊/
このまえ /この前/
このみ /好み/木の実/この身/木實/好/
このみち /此路/
このよ /この世/
このわた /海鼠腸/
このんで /好んで/
こはぎ /小萩/
こはく /琥珀/
こはくいろ /琥珀色/
こはくちゅう /琥珀中/
こはぜ /鞐/
こはた /戸畑/古畑/木幡/小幡/
こはば /小幅/
こはま /小濱/
こはまおんせんえき /小浜温泉駅/
こはまけいゆ /小浜経由/
こはまちょう /小浜町/
こはら /小原/
こはり /小針/
こはる /小春/
こはるびより /小春日和/
こはん /湖畔/個販/
こば /古馬/古葉/木場/古場/
こばい /故買/
こばいや /故買屋/
こばか /小馬鹿/
こばし /小橋/
こばじん /古馬陣/
こばた /小幡/
こばたけ /小畑/
こばち /小鉢/
こばちりょうり /小鉢料理/
こばな /小鼻/
こばなし /小話/小噺/
こばなれ /子離れ/
こばやかわ /小早川/
こばやし /小林/古林/
こばやしあきら /小林旭/
こばると /コバルト/
こばん /小判/
こばんがた /小判型/
こばんごう /子番号/
こばんざめ /コバンザメ/小判鮫/
こひつじ /子羊/小羊/
こひとり /子一人/
こひなた /小日向/
こひやま /小桧山/
こひょう /小兵/
こひるいまき /小比類巻/
こび /媚び/媚/
こびき /木挽/
こびと /小人/
こびん /小瓶/小壜/
こぴー /コピー/
こぴーき /コピー機/
こぴーようし /コピー用紙/
こぴーらいと /コピーライト/
こふう /古風/
こふくげきじょう /鼓腹撃壤/
こふじ /小藤/
こふみ /湖吹美/
こふん /古墳/
こぶ /鼓舞/瘤/
こぶし /拳/擧/舉/辛夷/
こぶた /子豚/
こぶちざわ /小淵沢/
こぶつえいぎょうほう /古物営業法/
こぶつしょう /古物商/故物商/
こぶどう /古武道/
こぶね /小舟/
こぶへい /こぶ平/
こぶり /小降り/
こぶん /古文/子分/
こぶんけん /古文献/
こへい /雇兵/
こべ /小部/
こべつ /個別/戸別/
こべつか /個別化/
こべつぐたいてき /個別具体的/
こべつげきは /個別撃破/
こべつしどう /個別指導/
こべつしょうひぜい /個別消費税/
こべつせいぎょ /個別制御/
こべつそうだん /個別相談/
こべつたいおう /個別対応/
こべつちゅうもん /個別注文/
こべつちょうり /個別調理/
こべつてき /個別的/
こべつとうひょう /個別投票/
こべつはいそう /個別配送/
こべつほうもん /個別訪問/
こべつりがい /個別利害/
こべや /小部屋/
こほく /湖北/
こほり /氷/
こぼけ /小歩危/
こぼね /小骨/
こぼり /小堀/古保里/
こぼりじゅうけん /小堀住研/
こま /駒/細/狛/コマ/独楽/齣/小間/
こまーしゃる /コマーシャル/
こまあらし /駒嵐/
こまい /駒井/
こまいずみ /駒泉/
こまいぬ /狛/狛犬/
こまえ /駒枝/狛江/小前/
こまえし /狛江市/
こまおくり /コマ送り/駒送り/
こまおと /駒音/
こまおとし /齣落/
こまか /細か/
こまがた /駒形/
こまがだけ /駒ヶ岳/
こまがね /駒ヶ根/
こまがみね /駒ヶ峯/
こまがわなかの /駒川中野/
こまき /小牧/駒木/
こまきやま /小牧山/
こまぎれ /細切れ/
こまく /鼓膜/
こまくじょう /鼓膜上/
こまくめん /鼓膜面/
こまくめんじょう /鼓膜面上/
こまぐみ /駒組み/
こまけん /小間研/
こまごま /細々/
こまごめ /駒込/
こまごめえき /駒込駅/
こまさい /駒祭/
こまざき /駒崎/
こまざわ /駒沢/
こまざわえいぎょうしょ /駒沢営業所/
こまざわがくえん /駒沢学園/
こまざわこうえん /駒沢公園/
こまざわたいいくかん /駒沢体育館/
こまざわだい /駒沢大/
こまざわだいがくえき /駒沢大学駅/
こまざわりくじょう /駒沢陸上/
こますう /コマ数/
こませ /駒瀬/
こまぞん /駒損/
こまた /小俣/
こまたすくい /小股掬い/
こまたんい /駒単位/
こまだ /駒田/
こまだい /駒大/駒台/
こまち /小町/
こまちや /小町谷/
こまつ /小松/コマツ/
こまつえき /小松駅/
こまつがわ /小松川/
こまつくうこう /小松空港/
こまつさきょう /小松左京/
こまつざき /小松崎/
こまつしま /小松島/
こまつしまし /小松島市/
こまつせいさくしょ /小松製作所/
こまつだ /小松田/
こまつな /小松菜/
こまつばら /小松原/
こまつびん /小松便/
こまど /小窓/
こまどく /駒得/
こまば /駒場/
こまばきょうぎじょう /駒場競技場/
こまばさい /駒場祭/
こまばとうだい /駒場東大/
こまばとうだいまえ /駒場東大前/
こまばりょう /駒場寮/
こまみや /駒宮/
こまむら /駒村/
こまめ /小まめ/小忠実/細目/
こまりょう /駒寮/
こまる /小丸/
こまわり /小回り/
こまんど /コマンド/
こまんどめい /コマンド名/
こみ /込/込み/
こみかた /混み方/
こみけ /コミケ/
こみだし /小見出し/
こみち /小道/小路/径/徑/蹊/小径/子径/
こみちしょぼう /径書房/
こみっく /コミック/
こみっと /コミット/
こみなとてつどう /小湊鉄道/
こみね /小峰/小峯/
こみみ /小耳/
こみや /小宮/
こみやま /込山/小宮山/
こみゅにけーしょん /コミュニケーション/
こむ /込/
こむかい /小向/
こむかいこうじょう /小向工場/
こむぎ /小麦/
こむぎいろ /小麦色/
こむぎこ /小麦粉/
こむぎこせいひん /小麦粉製品/
こむぎそうば /小麦相場/
こむすび /小結/
こむすびざんりゅう /小結残留/
こむすめ /小娘/
こむそう /虚無僧/
こむた /小牟田/
こむら /古村/小村/腓/
こむらがえり /腓返り/
こむろ /小室/
こむろふきん /小室付近/
こむろほうめん /小室方面/
こめ /米/※/個目/
こめあぶら /米油/
こめいじ /古明地/
こめがふくろ /米ヶ袋/
こめこうじ /米麹/
こめこめ /米米/
こめじるし /※/
こめそうば /米相場/
こめたに /米谷/
こめだ /米田/
こめだわら /米俵/
こめつき /米搗き/
こめつぶ /米粒/
こめつぶだい /米粒大/
こめでぃー /コメディー/
こめでぃあん /コメディアン/
こめどころ /米所/
こめぬか /米糠/
こめの /米野/
こめひょう /米兵/
こめびつ /米櫃/
こめぶくろ /米袋/
こめや /米屋/
こめん /湖面/
こめんと /コメント/
こも /菰/薦/
こもごも /交々/交/
こもじ /小文字/
こもじか /小文字化/
こもだ /菰田/小茂田/
こもち /子持ち/子持/
こもどし /小戻し/
こもどり /小戻り/
こもの /小物/薦野/菰野/
こものいれ /小物入/
こものせんもん /小物専門/
こものるい /小物類/
こもり /子守り/古森/小森/子守/
こもりうた /子守唄/子守歌/
こもりや /小森谷/
こもりやく /子守役/
こもりよう /子守用/
こもれび /木洩れ日/木洩日/
こもろ /小諸/
こもん /顧問/古文/小紋/
こもんかいぎ /顧問会議/
こもんじょ /古文書/
こもんべんごし /顧問弁護士/
こや /小屋/
こやぎ /子山羊/
こやく /子役/
こやくはいゆう /子役俳優/
こやぐち /小屋口/
こやさこ /小屋迫;姓/
こやし /肥やし/
こやす /子安/
こやだいら /小屋平/
こやち /小谷内/
こやづ /小谷津/
こやなぎ /小柳/
こやなぎるみこ /小柳ルミ子/
こやの /小谷野/
こやま /小山/湖山/古山/
こやまだい /小山台/
こやまだいこうこう /小山台高校/
こゆ /児湯/
こゆう /固有/個有/
こゆううんどう /固有運動/
こゆううんどうそくど /固有運動速度/
こゆうかいせき /固有解析/
こゆうかんすう /固有関数/
こゆうご /固有語/
こゆうしつりょう /固有質量/
こゆうしゅうはすう /固有周波数/
こゆうしんけいしつ /固有新形質/
こゆうしんどう /固有振動/
こゆうしんどうすう /固有振動数/
こゆうじゅうりょくじょう /固有重力場/
こゆうせい /固有性/
こゆうち /固有値/
こゆうちかいせき /固有値解析/
こゆうちひ /固有値比/
こゆうちぶんかい /固有値分解/
こゆうちぶんかいていり /固有値分解定理/
こゆうちぶんさん /固有値分散/
こゆうちぶんぷ /固有値分布/
こゆうちもんだい /固有値問題/
こゆうへんすう /固有変数/
こゆうへんすうじょうけん /固有変数条件/
こゆうべくとる /固有ベクトル/
こゆうめい /固有名/個有名/
こゆうめいし /固有名詞/
こゆき /小雪/
こゆび /小指/
こゆびいっぽん /小指一本/
こよい /今宵/
こよう /雇用/雇傭/
こようけいやく /雇用契約/
こようさべつ /雇用差別/
こようしゃ /雇用者/
こようたい /固溶体/
こよみ /暦/
こら /子等/児等/
こらい /古来/
こらいしゅ /古来種/
こらむ /コラム/
こり /狐狸/
こりー /コリー/
こりつ /孤立/
こりつけい /孤立系/
こりつご /孤立語/
こりつしき /孤立式/
こりつすうじ /孤立数字/
こりつすうじにんしき /孤立数字認識/
こりつたんご /孤立単語/
こりつてん /孤立点/
こりつはっせい /孤立発声/
こりつぶんし /孤立分子/
こりょ /顧慮/
こりょう /湖陵/
こりょうり /小料理/
こりょうりや /小料理屋/
こりようかい /狐狸妖怪/
これ /此/是/惟/之/斯れ/旃/
これいじょう /これ以上/
これお /是雄/
これかた /是方/
これくしょん /コレクション/
これさだ /是定/
これしき /是しき/
これだけ /是だけ/
これとう /惟任/
こればかり /是許/
これほど /是程/
これまで /是迄/
これら /コレラ/
ころ /頃/転/
ころあい /頃合/
ころう /固陋/虎狼/
ころし /殺し/
ころしや /殺し屋/
ころな /コロナ/
ころも /衣/
ころもがえ /衣更え/
ころもがわ /頃川/
ころんびあ /哥倫比亞/
こわ /聲/声/
こわいろ /声色/聲色/
こわき /小脇/
こわきえん /小湧園/
こわきえんまえ /小涌園前/
こわく /蠱惑/
こわくてき /蠱惑的/
こわけ /小分け/
こわざ /小技/
こわだ /古和田/
こわだか /声高/聲高/
こわだんぱん /強談判/
こわっぱ /小童/
こわね /声音/聲音/
こわもて /強面/
こわれもの /壊れ物/
こゑ /聲/
こん /今/混/根/金/魂/紺/痕/婚/懇/昆/艮/琴/恨/昏/梱/困/墾/坤/コン/近/献/建/壼/崑/很/悃/棍/渾/溷/滾/狠/獻/琿/菎/蒟/袞/跟/鯀/鯤/鶤/
こん> /今/
こんい /懇意/
こんいろ /紺色/
こんいん /婚姻/
こんいんかのうねんれい /婚姻可能年齢/
こんいんかんれんほうき /婚姻関連法規/
こんいんご /婚姻後/
こんいんじょう /婚姻状/
こんいんとどけ /婚姻届/
こんか /今夏/婚家/
こんかい /今回/
こんかいこうにゅう /今回購入/
こんかいさくせい /今回作成/
こんかいはつ /今回初/
こんかいはつしゅつじょう /今回初出場/
こんかいはつとうじょう /今回初登場/
こんかいはつばい /今回発売/
こんかいぶん /今回分/
こんかん /根幹/根冠/
こんかんちりょう /根幹治療/
こんが /混芽/
こんがいこうしょう /婚外交渉/
こんがっき /今学期/
こんがん /懇願/
こんき /根気/今期/婚期/今季/
こんきさいご /今季最後/
こんきぜつぼう /今期絶望/
こんきはつかんそう /今季初完走/
こんきはつしゅい /今季初首位/
こんきはつしょうり /今季初勝利/
こんきはつゆうしょう /今期初優勝/
こんきまつ /今季末/
こんきゃく /困却/
こんきゅう /困窮/
こんきょ /根拠/
こんきょち /根拠地/
こんきょはくじゃく /根拠薄弱/
こんきょふめい /根拠不明/
こんぎ /婚儀/
こんく /困苦/
こんくーる /コンクール/
こんくらべ /根競べ/
こんくりーと /コンクリート/
こんけい /根茎/根系/
こんけつ /混血/混結/
こんけつど /混血度/
こんげつ /今月/
こんげついっぱい /今月一杯/
こんげつげじゅん /今月下旬/
こんげつごう /今月号/
こんげつじゅう /今月中/
こんげつすえ /今月末/
こんげつちゅう /今月中/
こんげつちゅうじゅん /今月中旬/
こんげつど /今月度/
こんげつはつばい /今月発売/
こんげつぶん /今月分/
こんげつまつ /今月末/
こんげつまつひっちゃく /今月末必着/
こんげん /根源/根元/
こんげんちりょう /根源治療/
こんげんてき /根源的/根元的/
こんこう /混交/混淆/渾淆/金光/
こんこっかいちゅう /今国会中/
こんこん /懇々/滾滾/昏昏/渾渾/
こんご /今後/
こんごいっさい /今後一切/
こんごう /混合/金剛/根号/今号/
こんごういん /金剛院/
こんごうえき /混合液/
こんごうき /混合気/
こんごうきそく /混合規則/
こんごうきょういく /混合教育/
こんごうきょうりょくおんせん /混合強力温泉/
こんごうこうげき /混合攻撃/
こんごうこうつう /混合交通/
こんごうざわ /金剛沢/
こんごうしゃ /金剛砂/
こんごうしよう /混合仕様/
こんごうしんかい /金剛神界/
こんごうじ /金剛寺/
こんごうせいすうもんだい /混合整数問題/
こんごうせき /金剛石/
こんごうせん /混合戦/
こんごうづえ /金剛杖/
こんごうていりょう /混合定量/
こんごうてき /混合的/
こんごうでんそう /混合伝送/
こんごうひ /混合比/
こんごうぶ /混合部/
こんごうぶつ /混合物/
こんごうへんせい /混合編成/
こんごうりき /金剛力/
こんごうりゅう /金剛流/
こんごうれっしゃ /混合列車/
こんごけんとう /今後検討/
こんごとうじょう /今後登場/
こんごとも /今後共/
こんごもんだい /今後問題/
こんさーと /コンサート/
こんさい /根菜/混載/
こんさるたんと /コンサルタント/
こんさるてぃんぐ /コンサルティング/
こんざい /混在/
こんざつ /混雑/
こんざつかいしょう /混雑解消/
こんざつかいしょうもくてき /混雑解消目的/
こんざつかんわ /混雑緩和/
こんざつけいすう /混雑係数/
こんざつしだい /混雑次第/
こんざつじ /混雑時/
こんざつじょうきょう /混雑状況/
こんざつじょうたい /混雑状態/
こんざつど /混雑度/
こんざつりつ /混雑率/
こんしーずん /今シーズン/
こんしゅう /今週/今秋/
こんしゅういっしゅうかん /今週一週間/
こんしゅういっぱい /今週一杯/
こんしゅうきんようび /今週金曜日/
こんしゅうごう /今週号/
こんしゅうじゅう /今週中/
こんしゅうちゅう /今週中/
こんしゅうはつばい /今週発売/
こんしゅうぶん /今週分/
こんしゅうまつ /今週末/
こんしゅうまつごろ /今週末頃/
こんしゅん /今春/
こんしょう /混晶/
こんしょく /混織/混色/
こんしょくこう /混色光/
こんしろ /紺白/
こんしん /懇親/渾身/混信/渾心/根針/
こんしんかい /懇親会/
こんしんかいひ /懇親会費/
こんしんかいひよう /懇親会費用/
こんしんじょきょよう /混信除去用/
こんじ /今時/今次/恨事/根治/
こんじき /金色/
こんじきどう /金色堂/
こんじゃく /今昔/
こんじゃくものがたり /今昔物語/
こんじょう /根性/今生/懇情/紺青/
こんじょうなし /根性無/
こんじょうもの /根性物/
こんじょうよう /根状葉/
こんじょうわる /根性悪/
こんすい /昏睡/
こんすたんちのーぷる /君府/
こんせい /混成/混声/懇請/金精/
こんせいおん /混声音/
こんせいがっしょう /混声合唱/
こんせいがっしょうだん /混声合唱団/
こんせいき /今世紀/
こんせいきさいご /今世紀最後/
こんせいきしょとう /今世紀初頭/
こんせいきぜんはん /今世紀前半/
こんせいきちゅう /今世紀中/
こんせき /痕跡/今夕/
こんせききかん /痕跡器官/
こんせきてき /痕跡的/
こんせつ /懇切/今節/
こんせつていねい /懇切丁寧/
こんせぷと /コンセプト/
こんせん /混線/混戦/
こんせんげんしょう /混線現象/
こんせんさす /コンセンサス/
こんせんじ /混戦時/
こんせんじょうたい /混戦状態/
こんせんちゅう /混戦中/
こんせんと /コンセント/
こんせんとぴっくす /コンセントピックス/
こんせんもよう /混戦模様/混線模様/
こんぜつ /根絶/
こんぜん /婚前/混然/渾然/
こんぜんいったい /渾然一体/
こんぜんこうしょう /婚前交渉/
こんぜんせい /婚前姓/
こんそーしあむ /コンソーシアム/
こんそう /混走/
こんたいかい /今大会/
こんたくと /コンタクト/
こんたん /魂胆/根端/
こんだ /金田/今田/
こんだく /混濁/
こんだて /献立/
こんだてひょう /献立表/
こんだん /懇談/
こんだんかい /懇談会/
こんだんかいかいさい /懇談会開催/
こんち /根治/
こんちゃ /紺茶/
こんちゅう /昆虫/昆蟲/
こんちゅうがく /昆虫学/
こんちゅうき /昆虫記/
こんちゅうけい /昆虫系/
こんちゅうさいしゅう /昆虫採集/
こんちゅうしゃしんか /昆虫写真家/
こんちゅうしょく /昆虫食/
こんちゅうたち /昆虫達/
こんちゅうもう /昆虫網/
こんちゅうや /昆虫屋/
こんちゅうるい /昆虫類/
こんちょう /今朝/
こんてい /根底/
こんていてき /根底的/
こんてくすと /コンテクスト/
こんてすと /コンテスト/
こんてな /コンテナ/
こんてんつ /コンテンツ/
こんでぃしょん /コンディション/
こんでんさ /コンデンサ/
こんとう /今冬/昏倒/
こんとうよてい /今冬予定/
こんとら /コントラ/
こんとらすと /コントラスト/
こんとろーる /コントロール/
こんとん /混沌/渾沌/
こんど /今度/
こんどう /混同/近藤/金堂/金藤/
こんなん /困難/
こんなんせい /困難性/
こんにち /今日/
こんにちてき /今日的/
こんにちは /今日は/
こんにゃく /菎蒻/蒟蒻/
こんにゃくもんどう /菎蒻問答/
こんにゅう /混入/
こんねん /今年/
こんねんど /今年度/
こんねんどいっぱい /今年度一杯/
こんねんどさいご /今年度最後/
こんねんどちゅう /今年度中/
こんねんどとうしょ /今年度当初/
こんねんどない /今年度内/
こんねんどにゅうしゃ /今年度入社/
こんねんどよう /今年度用/
こんねんばん /今年版/
こんの /今野/昆野/紺野/金野/
こんのくん /今野君/
こんのみさこ /紺野美沙子/
こんばーた /コンバータ/
こんばーと /コンバート/
こんばい /困憊/
こんばしょ /今場所/
こんばん /今晩/
こんばんは /今晩は/
こんぱ /コンパ/
こんぱい /困憊/
こんぱいら /コンパイラ/
こんぱいる /コンパイル/
こんぱく /魂魄/
こんぱくと /コンパクト/
こんぱす /コンパス/
こんぱち /コンパチ/
こんぱにおん /コンパニオン/
こんぱん /今般/
こんひ /根被/
こんび /コンビ/
こんびなーと /コンビナート/
こんびにえんす /コンビニエンス/
こんびねーしょん /コンビネーション/
こんぴゅーた /コンピュータ/
こんぴゅーたー /コンピューター/
こんぴら /金比羅/
こんぴらづけ /今平積/
こんふ /コンフィ/
こんふぃ /コンフィ/
こんぶ /昆布/
こんぷれっくす /コンプレックス/
こんへんちょう /混変調/
こんぺき /紺碧/
こんぼう /こん棒/懇望/混紡/棍棒/
こんぽーねんと /コンポーネント/
こんぽう /梱包/
こんぽうざい /梱包材/
こんぽうざいりょう /梱包材料/
こんぽうしゅだん /梱包手段/
こんぽうだいきん /梱包代金/
こんぽうてすうりょう /梱包手数料/
こんぽうひ /梱包費/
こんぽん /根本/
こんぽんげんり /根本原理/
こんぽんてき /根本的/
こんぽんてきかいけつ /根本的解決/
こんぽんてきけんり /根本的権利/
こんぽんてきたいさく /根本的対策/
こんぽんてきにんしき /根本的認識/
こんぽんてきもんだい /根本的問題/
こんま /コンマ/，/
こんめい /混迷/昆明/昏迷/
こんもう /懇望/根毛/
こんや /今夜/紺屋/
こんやく /婚約/
こんやくしゃ /婚約者/
こんやくせんげん /婚約宣言/
こんやくちゅう /婚約中/
こんやくゆびわ /婚約指輪/
こんやくりょこう /婚約旅行/
こんやまち /紺屋町/
こんよう /混用/
こんよく /混浴/
こんらん /混乱/
こんらんぐあい /混乱具合/
こんらんじ /混乱時/
こんらんじょうたい /混乱状態/
こんらんちゅう /混乱中/
こんりゅう /建立/根粒/根瘤/
こんりんざい /金輪際/
こんれい /婚礼/
こんろ /コンロ/焜炉/
こんろん /昆倫/崑崘/崑崙/
こんわ /懇話/混和/
こんわかい /懇話会/
こんわく /困惑/
こんわくがお /困惑顔/
ご /後/語/御/誤/護/五/吾/碁/悟/午/檎/醐/互/娯/瑚/梧/呉/児/伍/５/庫/宕/5/兒/唔/寤/忤/晤/沍/牾/珸/篌/茣/蜈/齬/子/壺/壷/炬/胡/冴/期/后/
ご< /御/
ご> /御/誤/
ご? /誤/
ごーすと /ゴースト/
ごーる /ゴール/
ごあいきょう /御愛嬌/御愛敬/
ごあいこ /ご愛顧/御愛顧/
ごあいさつ /ご挨拶/御挨拶/
ごあいよう /ご愛用/御愛用/
ごあんしん /御安心/
ごあんない /御案内/ご案内/
ごい /語彙/五井/五位/恋/語意/伍井/戀/
ごいいかかくてい /五位以下確定/
ごいけん /御意見/
ごいけんなど /御意見等/
ごいけんばん /御意見番/
ごいけんむよう /御意見無用/
ごいけんやく /御意見役/
ごいこう /御意向/
ごいこうもく /語彙項目/
ごいし /碁石/
ごいすう /語彙数/
ごいそ /語彙素/
ごいぞく /御遺族/
ごいたい /御遺体/
ごいち /吾一/
ごいちどうさま /御一同様/
ごいちどく /御一読/
ごいっこう /御一行/御一考/
ごいっこうさま /御一行様/
ごいっしょ /御一緒/ご一緒/脚一緒/
ごいっしん /御一新/
ごいっちょう /御一聴/
ごいっとうさま /御一統様/
ごいっぽう /御一報/
ごいてき /語彙的/
ごいらい /ご依頼/御依頼/
ごいりよう /御入用/
ごいんきょ /御隠居/
ごう /号/合/豪/強/郷/剛/轟/濠/拷/壕/劫/傲/業/噛/刧/哈/嗷/囂/敖/毫/熬/盒/號/軣/遨/鼇/
ごうい /合意/
ごういあん /合意案/
ごういきこう /合意機構/
ごういけいせい /合意形成/
ごういけいせいしゅだん /合意形成手段/
ごういけいせいほう /合意形成法/
ごういけいせいほうしき /合意形成方式/
ごういけいせいほうほう /合意形成方法/
ごういご /合意後/
ごういしゅだん /合意手段/
ごういしょ /合意書/
ごういじこう /合意事項/
ごういじこうさくせい /合意事項作成/
ごういたいしょう /合意対象/
ごういてつづき /合意手続/合意手続き/
ごういてん /合意点/
ごういど /合意度/
ごういないよう /合意内容/
ごういぶんしょ /合意文書/
ごういほうしき /合意方式/
ごういほうほう /合意方法/
ごういん /強引/
ごうう /豪雨/
ごうおん /轟音/号音/
ごうか /豪華/劫火/業火/
ごうかあいぞうばん /豪華愛蔵版/
ごうかい /豪快/
ごうかいちりゅうひん /豪華一流品/
ごうかいなべ /豪快鍋/
ごうかきゃくせん /豪華客船/
ごうかく /合格/
ごうかくいん /合格印/
ごうかくしゃ /合格者/
ごうかくしゅくがかい /合格祝賀会/
ごうかくしょう /合格証/
ごうかくしょうしょ /合格証書/
ごうかくじ /合格時/
ごうかくつうち /合格通知/
ごうかくてん /合格点/
ごうかくはっぴょう /合格発表/
ごうかくりつ /合格率/
ごうかくりょく /合格力/
ごうかけんらん /豪華絢爛/
ごうかせん /豪華船/
ごうかばん /豪華版/
ごうかふろく /豪華付録/
ごうかぼん /豪華本/
ごうかれっしゃ /豪華列車/
ごうかん /号館/強姦/
ごうかんざい /強姦罪/
ごうかんじけん /強姦事件/
ごうかんない /号館内/
ごうかんま /強姦魔/
ごうがい /号外/號外/
ごうがしゃ /恒河沙/
ごうき /号機/剛毅/剛気/剛己/豪毅/豪気/豪鬼/
ごうきゅう /号泣/
ごうきん /合金/
ごうきんせい /合金製/
ごうぎ /合議/豪儀/
ごうぎせい /合議制/
ごうく /合区/
ごうけい /合計/豪渓/
ごうけいがく /合計額/
ごうけいきんがく /合計金額/
ごうけいじかん /合計時間/
ごうけいち /合計値/
ごうけいてん /合計点/
ごうけいてんすう /合計点数/
ごうけいとくてん /合計得点/
ごうけいほんすう /合計本数/
ごうけつ /豪傑/
ごうけつじ /豪血寺/
ごうけん /合憲/剛健/剛堅/
ごうげい /傲睨/
ごうげつ /法月/
ごうこん /合コン/
ごうご /豪語/傲語/
ごうごう /囂囂/轟々/
ごうし /郷士/合資/合志/合祀/
ごうしがいしゃ /合資会社/
ごうしつ /号室/
ごうしゃ /号車/豪奢/
ごうしゃばんごう /号車番号/
ごうしゅう /豪州/
ごうしゅうさん /豪州産/
ごうしょう /号証/豪商/合焦/
ごうじ /合字/剛司/
ごうじょう /強情/
ごうすう /号数/
ごうせい /合成/豪勢/合性/剛性/合生/
ごうせいおん /合成音/
ごうせいおんせい /合成音声/
ごうせいか /合成化/
ごうせいかがく /合成化学/
ごうせいかわ /合成革/
ごうせいかん /剛性感/
ごうせいかんみりょう /合成甘味量/
ごうせいぎょうれつ /剛性行列/
ごうせいご /合成語/
ごうせいしょくひん /合成食品/
ごうせいじゅし /合成樹脂/
ごうせいすう /合成数/
ごうせいせんざい /合成洗剤/
ごうせいそうち /合成装置/
ごうせいぞくせい /合成属性/
ごうせいちゃくしょくりょう /合成着色料/
ごうせいはんのう /合成反応/
ごうせいひん /合成品/
ごうせいぶそく /剛性不足/
ごうせいほう /合成法/
ごうせいほうしき /合成方式/
ごうせいほぞんりょう /合成保存料/
ごうせいゆ /合成油/
ごうせいりょく /合成力/
ごうせつ /豪雪/
ごうせつちいき /豪雪地域/
ごうせつちたい /豪雪地帯/
ごうせん /号線/合線/合繊/
ごうぜん /轟然/傲然/
ごうそ /強訴/
ごうそっきゅう /剛速球/
ごうそっきゅうとうしゅ /豪速球投手/
ごうぞく /豪族/
ごうた /剛太/
ごうたい /剛体/
ごうたいうんどう /剛体運動/
ごうたいぼう /剛体棒/
ごうたん /豪胆/
ごうだ /合田/郷田/剛田/
ごうだつ /強奪/
ごうだん /強談/
ごうち /郷地/
ごうちょく /剛直/
ごうちん /轟沈/
ごうつ /江津/
ごうつくばり /業突張/
ごうづ /江津/
ごうてい /豪邸/
ごうとう /強盗/号棟/
ごうとくじ /豪徳寺/
ごうど /神戸/
ごうどう /合同/
ごうどうえんそうかい /合同演奏会/
ごうどうかいぎ /合同会議/
ごうどうかんけい /合同関係/
ごうどうかんそく /合同観測/
ごうどうがくしゅうかい /合同学習会/
ごうどうけんきゅうかい /合同研究会/
ごうどうこうえん /合同公演/
ごうどうこうぎょう /合同興業/
ごうどうし /合同誌/
ごうどうしゅせい /合同酒精/
ごうどうじょうざんほう /合同乗算法/
ごうどうせい /合同性/
ごうどうせいてつ /合同製鐵/
ごうどうたいいくさい /合同体育祭/
ごうどうたいかい /合同大会/
ごうどうとうかせい /合同等価性/
ごうどうへんかん /合同変換/
ごうどうほう /合同法/
ごうどうれんしゅう /合同練習/
ごうの /郷野/
ごうのうら /郷ノ浦/
ごうはら /業腹/郷原/
ごうはん /合板/
ごうばつ /劫罰/
ごうばん /合板/
ごうひ /合否/
ごうひつ /合筆/
ごうひはんてい /合否判定/
ごうびょう /業病/
ごうびん /合瓶/
ごうふく /剛腹/剛愎/
ごうへき /剛壁/
ごうへん /合片/
ごうべん /合弁/
ごうべんか /合弁花/
ごうべんかるい /合弁花類/Gamopetalae/Sympetalae/
ごうほう /合法/号砲/号俸/
ごうほうか /合法化/
ごうほうせい /合法性/
ごうほうてき /合法的/
ごうほうらいらく /豪放磊落/
ごうほうり /合法裏/
ごうほうろん /合法論/
ごうぼう /号棒/
ごうま /降魔/
ごうまん /傲慢/
ごうめ /号目/合目/
ごうめい /合名/
ごうめいがいしゃ /合名会社/
ごうもう /剛毛/
ごうもくてき /合目的/
ごうもん /拷問/
ごうゆう /豪遊/傲遊/遨遊/
ごうよく /強欲/強慾/
ごうり /合理/
ごうりか /合理化/
ごうりかがく /合理科学/
ごうりかはんたい /合理化反対/
ごうりき /合力/強力/剛力/
ごうりしゅぎ /合理主義/
ごうりしゅぎてき /合理主義的/公理主義的/
ごうりせい /合理性/
ごうりてき /合理的/
ごうりてきいみ /合理的意味/
ごうりてきせつめい /合理的説明/
ごうりゃく /劫掠/
ごうりゅう /合流/
ごうりゅうし /合流子/
ごうりゅうしゃせん /合流車線/
ごうりゅうしゃせんふきん /合流車線付近/
ごうりゅうじ /合流時/
ごうりゅうせい /合流性/
ごうりゅうちてん /合流地点/
ごうりゅうちょくご /合流直後/
ごうりゅうてん /合流点/
ごうりゅうば /剛竜馬/
ごうりゅうへん /合流編/
ごうりょく /合力/
ごうれい /号令/
ごうれいしき /号令式/
ごえ /声/聲/
ごえい /護衛/
ごえいか /御詠歌/
ごえいかん /護衛艦/
ごえいくうぼ /護衛空母/
ごえいくちくかん /護衛駆逐艦/
ごえいこうどう /護衛行動/
ごえいてん /ご栄転/御栄転/
ごえいへい /護衛兵/
ごえいへいりょく /護衛兵力/
ごえつ /呉越;春秋時代の呉国と越国。転じて仲の悪いこと/
ごえつどうしゅう /呉越同舟;仲の悪いもの同士が居合せること/
ごえもん /五右衛門/五衛門/
ごえもんぶろ /五右衛門風呂/
ごえん /誤嚥/御縁/
ごえんじょ /ご援助/御援助/
ごえんりょ /御遠慮/
ごおうぼ /ご応募/御応募/
ごおん /呉音/語音/御恩/
ごおんこ /ご恩顧/御恩顧/
ごおんめいりょうど /語音明瞭度/
ごおんりょうかいど /語音了解度/
ごか /五箇/五霞/
ごかい /誤解/五階/5階/五回/碁界/
ごかいせつ /御解説/
ごかいそう /ご会葬/御会葬/
ごかいちょう /御開帳/
ごかいとう /御回答/ご回答/
ごかく /互格/互角/五角/
ごかくいじょう /互格以上/
ごかくけい /五角形/
ごかくにん /ご確認/御確認/
ごかご /御加護/
ごかしょう /五個荘/
ごかじょう /五カ条/
ごかせ /五ヶ瀬/
ごかぞく /ご家族/御家族/
ごかっけい /五角形/
ごかって /御勝手/
ごかつやく /御活躍/ご活躍/後活躍/
ごかつよう /御活用/
ごかてい /ご家庭/御家庭/
ごかん /互換/語幹/五感/語感/語間/五官/後漢;中国の王朝/
ごかんいがい /五感以外/
ごかんおう /五冠王/
ごかんかのうせい /互換可能性/
ごかんき /互換機/
ごかんきしゅ /互換機種/
ごかんきじょう /互換機上/
ごかんきよう /互換機用/
ごかんしょ /後漢書/
ごかんしん /御関心/
ごかんせい /互換性/
ごかんせいようきゅう /互換性要求/
ごかんそう /御感想/
ごかんど /互換度/
ごかんひょう /互換表/
ごかんひん /互換品/
ごかんべん /御勘弁/
ごかんまつ /語幹末/
ごかんよう /ご寛容/御寛容/
ごがく /語学/
ごがくかもく /語学科目/
ごがくがくしゅうよう /語学学習用/
ごがくがっこう /語学学校/
ごがくくんれん /語学訓練/
ごがくこうざ /語学講座/
ごがくさんこうしょ /語学参考書/
ごがくてき /語学的/
ごがくよう /語学用/
ごがくりょく /語学力/
ごがつ /五月/5月/５月/皐月/
ごがつさい /五月祭/
ごがつびょう /五月病/
ごがん /護岸/
ごき /誤記/語気/御器/語基/
ごきおく /御記憶/
ごきげん /御機嫌/
ごきそ /御器所/
ごきたい /御期待/ご期待/
ごきにゅう /ご記入/御記入/
ごきぶり /ゴキブリ/
ごきぼう /御希望/ご希望/
ごきゃく /五脚/
ごきゅう /誤球/
ごきゅうけい /御休憩/
ごきょう /五橋/五経/
ごきょうさ /御教唆/
ごきょうさん /御協賛/
ごきょうじ /御教示/ご教示/
ごきょうじゅ /御教授/
ごきょうだい /御兄弟/
ごきょうどう /後教導/
ごきょうみ /御興味/
ごきょうみお /御興味/
ごきょうりょく /御協力/ご協力/御強力/
ごきょか /御許可/
ごきんじょ /御近所/ご近所/
ごぎ /語義/
ごぎてき /語義的/
ごぎょう /五行/
ごぎょうせつ /五行説/
ごぎろん /御議論/
ごく /獄/極/語句/
ごくあく /極悪/
ごくあくだい /極悪台/
ごくあくどうめい /極悪同盟/
ごくあくにん /極悪人/
ごくあくひどう /極悪非道/
ごくい /極意/
ごくいちぶ /極一部/
ごくう /悟空/御供/
ごくかいせき /語句解析/
ごくかいせつ /語句解説/
ごくかん /極寒/
ごくけい /極刑/
ごくげつ /極月/
ごくごく /極々/
ごくさい /極彩/
ごくさいしき /極彩色/
ごくさむ /極寒/
ごくし /獄死/
ごくしゅう /極宗/
ごくしょう /極小/
ごくしょうすう /極少数/極小数/
ごくしょうりょう /極小量/極少量/
ごくしょき /極初期/
ごくしん /極信/
ごくじょう /極上/
ごくじょうひん /極上品/
ごくせつめい /語句説明/
ごくそく /極促/
ごくそつ /獄卒/
ごくちゅう /獄中/
ごくつぶし /穀潰し/
ごくていおん /極低温/
ごくていおんいき /極低音域/
ごくていおんそうち /極低温装置/
ごくていおんれいきゃく /極低温冷却/
ごくていそく /極低速/
ごくていそくじ /極低速時/
ごくとうぐんじほうてい /極東軍事法廷/
ごくどう /極道/
ごくどうし /極道史/
ごくひ /極秘/
ごくひじこう /極秘事項/
ごくひじっけん /極秘実験/
ごくひじょうほう /極秘情報/
ごくひん /極貧/
ごくびしょう /極微小/
ごくふつう /極普通/
ごくぶと /極太/
ごくぼそ /極細/
ごくぼそびき /極細挽き/
ごくみ /ゴクミ/
ごくもん /獄門/
ごくもんだけ /獄門岳/
ごくもんとう /獄門島/
ごくらく /極楽/
ごくらくちょう /極楽鳥/
ごくろう /御苦労/ご苦労/
ごくろうさま /御苦労様/ご苦労さま/
ごけ /後家/碁笥/
ごけい /互恵/語形/
ごけいいか /五桂以下/
ごけいけん /御経験/
ごけた /五桁/
ごけっこん /御結婚/ご結婚/
ごけっせき /ご欠席/御欠席/
ごけつ /五傑/
ごけにん /御家人/
ごけん /護憲/
ごけんきゅう /御研究/
ごけんこう /御健康/
ごけんしょう /ご健勝/御健勝/
ごけんそん /御謙遜/
ごけんとう /ご検討/御検討/御健闘/
ごけんは /護憲派/
ごけんれんごう /護憲連合/
ごげん /語源/
ごげんいしき /語源意識/
ごげんせつ /語源説/
ごげんてき /語源的/
ごげんどおり /語源通り/
ごこ /5個/
ごこう /後光/五劫/五香/
ごこうい /御好意/ご厚意/ご好意/御厚意/
ごこうえん /御講演/
ごこうぎ /ご高誼/御高誼/ご厚誼/御厚誼/
ごこうし /ご厚志/御厚志/
ごこうしょう /ご高承/
ごこうじょう /ご厚情/御厚情/
ごこうにゅう /御購入/
ごこうはい /ご高配/御高配/
ごこうらん /ご高覧/御高覧/
ごこうりょ /御考慮/
ごこく /後刻/護国/
ごこくかいかん /護国会館/
ごこくじ /護国寺/
ごこち /心地/
ごころ /心/
ごこん /語根/
ごこんじょう /ご懇情/御懇情/
ごご /午後/午后/
ごご#じ /午後#0時/午後#1時/午後#2時/
ごご#じはん /午後#0時半/
ごごう /五合/
ごごうめ /五合目/
ごごうめひろば /五合目広場/
ごごち /心地/
ごごはんきゅう /午後半休/
ごごびん /午後便/
ごさ /誤差/
ごさい /後妻/五歳/
ごさかいせき /誤差解析/
ごさかいせきや /誤差解析屋/
ごさかくさんほう /誤差拡散法/
ごさかくど /誤差角度/
ごさかくりつ /誤差確率/
ごさかんすう /誤差関数/
ごさきじゅん /誤差基準/
ごさぎゃくでんぱん /誤差逆伝搬/
ごさく /吾作/
ごさくうかん /誤差空間/
ごさこう /誤差項/
ごさしひょう /誤差指標/
ごさしゅう /御査収/
ごさしんごう /誤差信号/
ごさじょうほう /誤差情報/
ごさでんぱがた /誤差伝播型/
ごさとくせい /誤差特性/
ごさとくせいきょくめん /誤差特性曲面/
ごさどう /誤作動/
ごさはんい /誤差範囲/
ごさひょうか /誤差評価/
ごさひょうめん /誤差表面/
ごさぶんさんほう /誤差分散法/
ごさぼう /誤差棒/
ごさよういん /誤差要因/
ごさん /誤算/午餐/
ごさんか /御参加/ご参加/
ごさんかた /御三方/
ごさんけ /御三家/
ごさんこう /御参考/
ごさんしゅう /御参集/
ごさんしょう /御参照/
ごさんどう /御賛同/御参同/
ごさんれつ /ご参列/御参列/
ござ /茣蓙/蓙/後座/茣蓆/
ございしょ /御在所/
ごし /五指/腰/
ごしあい /五試合/
ごしえん /ご支援/御支援/
ごしき /五色/
ごしじ /御指示/
ごしちちょう /五七調/
ごしっくたい /ゴシック体/
ごしつぎ /御質疑/
ごしつぎごとうろん /御質疑御討論/
ごしつもん /御質問/ご質問/
ごしつもんなど /御質問等/
ごしてい /御指定/
ごしてき /御指摘/
ごしどう /御指導/ご指導/
ごしなん /御指南/
ごしま /五島/
ごしめい /御指名/
ごしゃく /語釈/
ごしゅうぎ /御祝儀/
ごしゅうしょうさま /御愁傷様/
ごしゅうしん /ご執心/御執心/
ごしゅうち /御周知/
ごしゅうにん /ご就任/御就任/
ごしゅうめ /五週目/
ごしゅこう /御趣向/
ごしゅし /御主旨/
ごしゅじん /ご主人/御主人/
ごしゅちょう /御主張/
ごしゅっしん /御出身/
ごしゅっせい /御出席/
ごしゅっせき /御出席/ご出席/
ごしゅつえん /御出演/
ごしゅみ /御趣味/
ごしゅるい /五種類/
ごしゅん /呉春/
ごしょ /御所/
ごしょいずみ /御所泉/
ごしょう /後生/五章/
ごしょうかい /御紹介/ご照会/ご紹介/御照会/
ごしょうきょ /誤消去/
ごしょうたい /御招待/ご招待/
ごしょうだいじ /後生大事/
ごしょうだく /御承諾/
ごしょうち /ご承知/御承知/
ごしょうのう /御笑納/
ごしょうみ /御賞味/
ごしょうらん /御笑覧/
ごしょがわら /五所川原/
ごしょがわらえき /五所川原駅/
ごしょく /誤植/五色/
ごしょくじ /御食事/
ごしょぞく /御所属/
ごしょの /御所野/
ごしょのうら /御所浦/
ごしょめい /御署名/
ごしょもう /御所望/
ごしよう /御使用/ご使用/誤使用/
ごしん /誤信/誤診/護身/誤審/
ごしんえい /御真影/
ごしんじゅつ /護身術/
ごしんせつ /御親切/
ごしんせん /五新線/
ごしんたい /御神体/
ごしんたく /ご神託/御神託/
ごしんぱい /ご心配/御心配/
ごじ /誤字/５時/5時/護持/五時/五次/
ごじあい /ご自愛/御自愛/
ごじさん /ご持参/
ごじしん /御自身/
ごじせい /御時世/御時勢/ご時勢/
ごじたく /御自宅/
ごじだつじ /誤字脱字/
ごじだつじとう /誤字脱字等/
ごじだつじなど /誤字脱字等/
ごじっぽ /五十歩/
ごじっぽひゃっぽ /五十歩百歩/
ごじつ /後日/
ごじつたん /後日譚/
ごじつだん /後日談/
ごじつちゅう /後日注/
ごじてん /語辞典/
ごじひ /御慈悲/ご慈悲/
ごじぶん /御自分/
ごじぶんりゅう /御自分流/
ごじまん /御自慢/
ごじみゃく /五次脈/
ごじゅう /五十/五重/
ごじゅうおくねん /五十億年/
ごじゅうおん /五十音/
ごじゅうおんじゅん /五十音順/
ごじゅうおんず /五十音図/
ごじゅうおんもじ /五十音文字/
ごじゅうしょ /ご住所/御住所/
ごじゅうそう /五重奏/
ごじゅうにんまち /五十人町/
ごじゅうねん /五十年/
ごじゅっぽ /五十歩/
ごじゅっぽひゃっぽ /五十歩百歩/
ごじゅつ /後述/
ごじゅん /語順/
ごじゅんせつ /五旬節/
ごじゅんび /御準備/
ごじゆう /御自由/
ごじょ /互除/互助/
ごじょう /五条/五條/互譲/誤乗/
ごじょうえき /五条駅/
ごじょうざか /五条坂/
ごじょうしゃ /誤乗車/
ごじょうしゃこ /五条車庫/
ごじょうだん /御冗談/
ごじょうめ /五城目/
ごじょかい /互助会/
ごじょげん /御助言/
ごじょほう /互除法/
ごじょりょく /御助力/
ごじら /ゴジラ/
ごじん /御仁/吾人/
ごじんたい /御神体/
ごじんりょく /御尽力/
ごすい /午睡/
ごすいさつ /御推察/
ごすいしょう /御推奨/
ごすいせん /御推薦/
ごすう /語数/
ごすうせいげん /語数制限/
ごすけ /吾助/
ごすんくぎ /五寸釘/
ごず /牛頭/
ごずいい /御随意/
ごずみ /後炭/
ごずめず /牛頭馬頭/
ごせ /御所/
ごせい /悟性/語勢/互生/碁聖/
ごせいうん /ご盛運/御盛運/
ごせいえい /御清栄/ご清栄/御盛栄/
ごせいえん /御声援/
ごせいきゅう /ご請求/御請求/
ごせいぎょう /ご盛業/御盛業/
ごせいこう /御成功/
ごせいこん /御成婚/
ごせいこんきねん /御成婚記念/
ごせいしょう /御清祥/ご清勝/ご清祥/御清勝/
ごせいたん /御生誕/
ごせいようじょ /互生葉序/
ごせいらん /御清覧/
ごせつぞく /誤接続/
ごせつめい /御説明/
ごせん /五線/五泉/五千/互選/
ごせんえん /五千円/
ごせんえんぜんご /五千円前後/
ごせんし /五線紙/
ごせんぞ /ご先祖/御先祖/
ごせんふ /五線譜/
ごせんもん /御専門/
ごぜ /瞽女/
ごぜん /午前/御前/御膳/
ごぜん#じ /午前#1時/午前#0時/午前#2時/
ごぜんかいぎ /御前会議/
ごぜんげんざい /午前現在/
ごぜんさま /午前様/
ごぜんちゅう /午前中/
ごぜんはつ /午前発/
ごぜんはんきゅう /午前半休/
ごぜんびん /午前便/
ごぜんぶ /午前部/
ごぜんやま /御前山/
ごそう /護送/五艘/
ごそうさ /誤操作/
ごそうしゃ /護送車/
ごそうせんだん /護送船団/
ごそうぞう /御想像/
ごそうだん /御相談/ご相談/
ごそうにゅう /誤挿入/
ごそうふ /ご送付/御送付/
ごそくろう /ご足労/御足労/
ごそつぎょう /御卒業/
ごそんがん /御尊顔/
ごそんじ /御存じ/
ごそんぷ /御尊父/
ごそんぷさま /御尊父様/
ごぞく /語族/五族/
ごぞんじ /御存知/ご存じ/ご存知/御存じ/
ごぞんち /御存知/
ごたい /五体/
ごたいおう /御対応/
ごたいめん /御対面/
ごたいりく /五大陸/
ごたく /御託/五択/
ごたくせん /ご託宣/御託宣/
ごたしょう /ご多祥/御多祥/
ごたぶん /御他聞/御多分/
ごたぼう /御多忙/ご多忙/
ごたぼうちゅう /御多忙中/
ごたま /五玉/
ごたようちゅう /ご多用中/御多用中/
ごたろう /五太郎/
ごたん /五反/
ごたんい /語単位/
ごたんだ /五反田/
ごたんだえき /五反田駅/
ごたんだしゅうへん /五反田周辺/
ごたんとう /御担当/
ごたんばせんぞい /御殿場線沿/
ごたんばほうめん /御殿場方面/
ごだい /伍代/五代/
ごだいけっとうひょう /五代血統表/
ごだいこ /五大湖/
ごだいご /後醍醐/
ごだつ /誤脱/
ごだん /五段/
ごだんかい /五段階/
ごちそう /御馳走/ご馳走/
ごちゃく /御着/五着/
ごちゅう /語中/
ごちゅうい /御注意/ご注意/
ごちゅうこく /御忠告/
ごちゅうもく /御注目/
ごちゅうもん /御注文/ご注文/
ごちょう /語調/伍長/語長/
ごちょうせい /誤調整/
ごっかん /極寒/
ごつうか /誤通過/
ごつうち /ご通知/御通知/
ごつごう /御都合/ご都合/
ごつごうしゅぎ /御都合主義/
ごつぼ /五坪/
ごづめづ /牛頭馬頭/
ごて /後手/
ごてい /五帝/
ごていあん /御提案/
ごていきょう /御提供/
ごていしゅ /御亭主/
ごていしゅつ /御提出/
ごていじ /御提示/
ごていせい /御訂正/
ごていねい /御丁寧/
ごてがち /後手勝/
ごてばん /後手番/
ごてひっしょう /後手必勝/
ごてゆうり /後手有利/
ごてん /御殿/
ごてんした /御殿下/
ごてんば /御殿場/
ごてんばせん /御殿場線/
ごてんやま /御殿山/
ごでん /誤伝/
ごでんじゅ /御伝授/
ごと /毎/事/言/五斗/亊/如/
ごとう /後藤/五島/五嶋/語頭/誤答/五頭/
ごとうあんし /吾当安此/
ごとうくん /後藤君/
ごとうごう /誤統合/
ごとうじ /後藤寺/
ごとうじょう /御登場/
ごとうすう /誤答数/
ごとうち /御当地/
ごとうちゃく /ご到着/御到着/
ごとうれっとう /五島列島/
ごとうろん /御討論/
ごとく /五徳/
ごとに /毎に/
ごど /五度/
ごどうさ /誤動作/
ごどうはい /御同輩/
ごどうはん /御同伴/
ごどうやく /御同役/
ごどく /語読/誤読/
ごなん /御難/
ごにゅう /五入/
ごにゅうかい /御入会/
ごにゅうじょう /御入場/
ごにゅうりょく /誤入力/
ごにん /誤認/五人/5人/
ごにんしき /誤認識/
ごにんじょうほう /誤認情報/
ごね /ゴネ/
ごねん /五年/
ごねんかん /五年間/
ごねんめ /五年目/
ごのうせん /五能線/
ごのへ /五戸/
ごのみ /好み/
ごは /語派/
ごはい /誤配/
ごはいさつ /御拝察/
ごはいりょ /ご配慮/御配慮/
ごはき /御破棄/
ごはさん /ご破算/御破算/
ごはっこう /誤発行/
ごはっちゅう /御発注/
ごはってん /ご発展/御発展/
ごはっと /御法度/ご法度/
ごはっぴょう /御発表/
ごはつげん /御発言/
ごはん /御飯/ご飯/
ごはんえい /ご繁栄/御繁栄/
ごはんきゅうしょく /御飯給食/
ごはんじょう /ご繁盛/御繁盛/
ごはんだん /誤判断/御判断/
ごはんてい /誤判定/
ごば /後場/
ごばく /誤爆/
ごばらい /後払い/
ごばん /碁盤/五番/
ごばんがい /五番街/
ごばんしょうぶ /五番勝負/
ごばんめ /五番目/
ごひき /五匹/
ごひはん /御批判/
ごひひょう /御批評/
ごひゃく /五百/
ごひゃくまんごく /五百万石/
ごひょうじ /誤表示/
ごび /語尾/
ごびへんか /語尾変化/
ごびゅう /誤謬/
ごふ /護符/
ごふう /碁風/
ごふうふ /御夫婦/
ごふく /五福/呉服/
ごふくや /呉服屋/
ごふこう /御不幸/
ごふさい /御夫妻/
ごふざい /御不在/
ごふじん /御夫人/御婦人/
ごふたん /御負担/
ごふべん /御不便/
ごふまん /御不満/
ごふめい /御不明/
ごふん /五分/
ごふんかん /五分間/
ごぶ /五分/
ごぶがり /五分刈り/
ごぶごぶ /五分五分/
ごぶさた /御無沙汰/ご無沙汰/
ごぶじ /御無事/
ごぶれい /御無礼/
ごぶん /誤聞/五分/
ごへい /語弊/
ごへんかん /誤変換/
ごへんきゃく /御返却/
ごへんこう /御変更/
ごへんじ /御返事/ご返事/
ごへんそう /ご返送/御返送/
ごへんとう /御返答/
ごべん /五弁/
ごべんたつ /御鞭撻/
ごほう /誤報/語法/
ごほうこく /御報告/ご報告/
ごほうし /ご奉仕/ご芳志/御奉仕/御芳志/
ごほうじ /御法事/
ごほうどう /誤報道/
ごほうねん /ご放念/御放念/
ごほうび /ご褒美/御褒美/
ごほうめい /ご芳名/御芳名/
ごほく /吾北/
ごほんぎ /五本木/
ごほんけ /御本家/
ごほんぞん /御本尊/
ごほんにん /御本人/
ごほんらい /語本来/
ごぼいん /五母音/
ごぼう /御坊/牛蒡/
ごま /胡麻/護摩/
ごまあぶら /胡麻油/
ごまがら /胡麻殻/
ごまつ /語末/
ごまどうふ /胡麻豆腐/
ごまのはぐさか /ゴマノハグサ科/Scrophulariaceae/
ごまのはぐさもく /Personales/ゴマノハグサ目/
ごまん /五万/
ごまんえつ /御満悦/
ごまんきつ /御満喫/
ごまんにん /五万人/
ごみ /五味/ゴミ/塵/埖/塵芥/護美/込/
ごみおか /五味岡/
ごみばこ /ゴミ箱/
ごみぶん /御身分/
ごみや /五味屋/
ごむ /ゴム/護謨/
ごむこうぎょう /ゴム工業/
ごむたい /御無体/
ごむよう /御無用/
ごめい /五名/
ごめいとう /御名答/
ごめいふく /御冥福/
ごめいわく /御迷惑/ご迷惑/
ごめん /御免/
ごめんこうむる /蒙御免/
ごめんどう /御面倒/
ごめんなさい /(_o_)/
ごもく /五目/
ごもくぎょうざ /五目餃子/
ごもくぞうすい /五目雑炊/
ごもるてがか /ゴモルテガ科/Gomortegaceae/
ごもん /御紋/御門/
ごや /小屋/
ごやく /誤訳/語訳/
ごやくせいしょ /語訳聖書/
ごゆうじん /御友人/
ごゆうどう /誤誘導/
ごゆうよ /御猶予/
ごよう /御用/誤用/ご用/
ごようい /御用意/
ごようおさめ /御用納め/
ごようがくしゃ /御用学者/
ごようきき /御用聞/
ごようきゅう /御要求/
ごようけんせつ /五洋建設/
ごようしゃ /御容赦/御容謝/
ごようじん /御用心/
ごようす /御様子/
ごようたし /御用達/
ごようたつ /御用達/
ごようだつ /御用達/
ごようちょう /御用帳/
ごようてい /御用邸/
ごようはじめ /御用始め/
ごようぶんかじん /御用文化人/
ごようぼう /御要望/
ごようめい /ご用命/御用命/
ごようろん /語用論/
ごよく /五欲/
ごよてい /御予定/
ごよやく /御予約/
ごらいこう /ご来光/御来光/
ごらいじょう /ご来場/御来場/
ごらいてん /ご来店/御来店/
ごらいりん /ご来臨/御来臨/
ごらく /娯楽/
ごらくえいが /娯楽映画/
ごらくきじ /娯楽記事/
ごらくさく /娯楽作/
ごらくさくひん /娯楽作品/
ごらくしせつ /娯楽施設/
ごらくしつ /娯楽室/
ごらくしゅっし /娯楽出資/
ごらくじだいげき /娯楽時代劇/
ごらくせい /娯楽性/
ごらくたいさく /娯楽大作/
ごらくてき /娯楽的/
ごらくばんぐみ /娯楽番組/
ごらくぼん /娯楽本/
ごらくよう /娯楽用/
ごらん /御覧/ご覧/
ごり /鮴/
ごりかい /御理解/ご理解/
ごりっぱ /御立派/
ごりむちゅう /五里霧中/
ごりやく /御利益/ご利益/
ごりゅう /五竜/
ごりゅうい /御留意/
ごりゅうせい /ご隆盛/御隆盛/
ごりょう /御陵/御寮/
ごりょうかい /御了解/
ごりょうかく /五稜郭/
ごりょうけ /御両家/
ごりょうしゃ /御料車/
ごりょうしょう /御了承/ご了承/
ごりょうしん /御両親/ご両親/
ごりょうにん /御両人/御寮人/
ごりょうぼくじょう /御料牧場/
ごりょうめい /御両名/
ごりょこう /御旅行/
ごりよう /ご利用/御利用/
ごりん /五輪/五厘/
ごりんかいさい /五輪開催/
ごりんさんか /五輪参加/
ごりんだいひょう /五輪代表/
ごりんよせん /五輪予選/
ごるふ /ゴルフ/
ごれい /誤例/
ごれんらく /御連絡/ご連絡/
ごろ /頃/語呂/
ごろー /ＧＯＲＯ/
ごろあわせ /語呂合せ/
ごろう /ＧＯＲＯ/五郎/伍朗/悟朗/悟郎/
ごろうじん /御老人/
ごろうまる /五郎丸/
ごろく /語録/
ごろごろ /ゴロゴロ/
ごろね /ごろ寝/
ごろべえ /五郎兵衛/
ごん /言/権/厳/魂/艮/金/嚴/權/諢/
ごんぎょう /勤行/
ごんぐ /欣求/
ごんげ /権化/
ごんげん /権現/
ごんご /言語/
ごんごどうだん /言語道断/言語道斷/
ごんじゃ /権者/
ごんずい /権瑞/
ごんぞう /権造/
ごんだ /権田/
ごんどう /権藤/
ごんどうくじら /巨頭鯨/
ごんべえ /権兵衛/
ごんりょう /艮陵/
さ /差/左/鎖/査/佐/砂/裟/沙/茶/唆/嵯/詐/作/瑳/叉/些/磋/紗/狭/做/嗟/嗄/嵳/扠/搓/柤/槎/渣/狹/瑣/莎/蹉/挫/早/蓑/乍/簑/娑/再/
さーかす /サーカス/
さーかむすくらいぶ /サーカムスクライブ/
さーくる /サークル/
さーち /サーチ/
さーば /サーバ/
さーばー /サーバー/
さーびす /サービス/
さーふぃん /サーフィン/
さーぶ /サーブ/
さーべい /サーベイ/
さい /際/再/歳/最/才/妻/菜/祭/細/裁/載/斎/採/西/砕/差異/災/済/彩/犀/催/哉/齋/砦/斉/債/采/栽/塞/宰/蔡/殺/サイ/晒/崔/儕/摧/寨/樶/淬/濟/灑/犲/猜/碎/綵/縡/纔/腮/豺/賽/釵/霽/靫/顋/齊/凄/衰/悽/佐井/財/偲/責/切/鰓/差位/柴/洒/
さい< /再/歳/
さい> /再/最/歳/
さい? /再/最/
さいあい /最愛/
さいあく /最悪/
さいあくじょうけん /最悪条件/
さいあくち /最悪値/
さいあんてい /最安定/
さいいじょう /差異以上/
さいいち /才一/
さいいちろう /斉一郎/
さいいん /西院/
さいいんざい /催淫剤/
さいいんよう /再引用/
さいうしゃせん /最右車線/
さいうへん /最右辺/
さいうよく /最右翼/
さいうん /彩雲/
さいえい /再映/
さいえん /才媛/再演/菜園/再縁/最遠/
さいえんす /サイエンス/
さいえんちょう /再延長/
さいえんてぃすと /サイエンティスト/
さいえんてん /最遠点/
さいえんぽう /最遠方/
さいえんもの /再演物/
さいおう /塞翁/再往/最奥/
さいおうぼ /再応募/
さいおおぜき /再大関/
さいおおて /最大手/
さいおく /最奥/
さいおんじ /西園寺/西恩寺/
さいおんじこう /西園寺公/
さいか /最下/裁可/災禍/載荷/雑賀/
さいかい /再開/最下位/再会/斎戒/際会/西海/
さいかいこうちゃく /再下位降着/
さいかいご /再開後/
さいかいしゃく /再解釈/
さいかいじ /再開時/
さいかいそう /最下位層/
さいかいぞう /再改造/
さいかいだっしゅつ /最下位脱出/
さいかいはつ /再開発/
さいかかい /最下階/
さいかきゅう /最下級/
さいかぎょう /最下行/
さいかく /才覚/
さいかくにん /再確認/
さいかくはん /再撹拌/
さいかこう /再加工/
さいかそう /最下層/
さいかそく /再加速/
さいかそくじ /再加速時/
さいかだん /最下段/
さいかっせいか /再活性化/
さいかつどう /再活動/
さいかにゅう /再加入/
さいかねつ /再加熱/
さいかぶ /最下部/
さいかや /さいか屋/
さいかりゅう /最下流/
さいかわ /斉川/犀川/
さいかん /細管/再刊/才幹/
さいかんはだん /細管破断/
さいが /齋賀/雑賀/
さいがい /災害/最外/
さいがいがわ /最外側/
さいがいしゅうぶぶん /最外周部分/
さいがいじ /災害時/
さいがいじょうほう /災害情報/
さいがいたいさくほんぶ /災害対策本部/
さいがいぶ /最外部/
さいがくしゅう /再学習/
さいがわ /犀川/
さいき /再帰/再起/斎木/斉木/才気/祭器/債鬼/佐伯/催奇/再記/妻木/彩木/
さいきかこうがた /再帰下降型/
さいきかんすう /再帰関数/
さいきかんぱつ /才気煥発/
さいきがた /再帰型/
さいきけい /再帰形/
さいきこうか /再帰降下/
さいきしき /再帰式/
さいきじょきょほう /再帰除去法/
さいきせい /最輝星/再帰性/
さいきそうしん /再帰送信/
さいきだいめいし /再帰代名詞/
さいきていぎ /再帰定義/
さいきていり /再帰定理/
さいきてき /再帰的/
さいきてきかんすう /再帰的関数/
さいきてきこうぞう /再帰的構造/
さいきてきじしょがくしゅう /再帰的辞書学習/
さいきてきていぎ /再帰的定義/
さいきてきてつづき /再帰的手続き/
さいきてきとうろく /再帰的登録/
さいきどう /再起動/
さいきどうじ /再起動時/
さいきふのう /再起不能/
さいきへんしゅう /再帰編集/
さいきゅう /最急/
さいきゅうこうか /最急降下/
さいきゅうこうかほう /最急降下法/
さいきゅうしゅう /再吸収/
さいきゅうゆ /再給油/
さいきょ /再挙/
さいきょう /最強/西京/埼京/
さいきょういく /再教育/
さいきょうく /西京区/
さいきょうせつ /最強説/
さいきょうせん /埼京線/
さいきょうせんえんちょう /埼京線延長/
さいきょうせんかいそく /埼京線快速/
さいきょうせんじゅうじょうえき /埼京線十条駅/
さいきよびだし /再帰呼び出し/
さいきん /最近/細菌/
さいきんごう /最近号/
さいきんしゅっぱん /最近出版/
さいきんじょうほう /最近情報/
さいきんせいえんしょう /細菌性炎症/
さいきんちゅうもく /最近注目/
さいきんはっけん /最近発見/
さいきんはっぴょう /最近発表/
さいきんはつばい /最近発売/
さいきんひょうばん /最近評判/
さいきんほうえい /最近放映/
さいきんぼう /最近傍/
さいきんりゅうこう /最近流行/
さいきんりん /最近隣/
さいきんりんたんさく /最近隣探索/
さいきんわだい /最近話題/
さいぎ /猜疑/祭儀/
さいぎしん /猜疑心/
さいぎてき /猜疑的/
さいぎゃくてん /再逆転/
さいぎょうほうし /西行法師/
さいぎんみ /再吟味/
さいく /細工/
さいくつ /採掘/
さいくつけん /採掘権/
さいくつしゃ /採掘車/
さいくもの /細工物/
さいくりんぐ /サイクリング/
さいくる /サイクル/
さいくん /細君/
さいぐさ /三枝/
さいぐんび /再軍備/
さいけい /再掲/
さいけいこく /再警告/最恵国/
さいけいさい /再掲載/
さいけいさん /再計算/
さいけいそく /再計測/
さいけいやく /再契約/
さいけいやくきん /再契約金/
さいけいれい /最敬礼/
さいけっせい /再結成/
さいけっせいご /再結成後/
さいけっせいじ /再結成時/
さいけってい /再決定/
さいけつ /採決/採血/裁決/
さいけついいん /裁決委員/
さいけつごう /再結合/
さいけつほうほう /採血方法/
さいけん /再見/再建/債券/債権/
さいけんぎじゅつぶ /債券技術部/
さいけんけいかく /再建計画/
さいけんさ /再検査/
さいけんさく /再検索/
さいけんしゃ /債権者/再検者/
さいけんしょう /再検証/
さいけんじゅつ /再建術/
さいけんとう /再検討/
さいけんほうき /債権放棄/
さいげつ /歳月/
さいげん /再現/際限/
さいげんかのう /再現可能/
さいげんせい /再現性/
さいげんてじゅん /再現手順/
さいげんど /再現度/
さいげんぶ /再現部/
さいげんりつ /再現率/
さいこ /最古/才子/採子/西湖/
さいこう /最高/再考/採光/再興/採鉱/催行/
さいこうい /最高位/
さいこういせん /最高位戦/
さいこうおん /最高音/
さいこうかい /再公開/
さいこうかいてんすう /最高回転数/
さいこうかかく /最高価格/
さいこうがく /最高額/
さいこうがくふ /最高学府/
さいこうきおん /最高気温/
さいこうきかん /最高機関/
さいこうきしゅ /最高機種/
さいこうきぼうがく /最高希望額/
さいこうきみつ /最高機密/
さいこうきゅう /最高級/
さいこうきゅうかほう /最高急下法/
さいこうきゅうき /最高級機/
さいこうきゅうじてんしゃ /最高級自転車/
さいこうきゅうひん /最高級品/
さいこうきょようそくど /最高許容速度/
さいこうきろく /最高記録/
さいこうきんがく /最高金額/
さいこうくかん /最高区間/
さいこうけっさく /最高傑作/
さいこうけつあつ /最高血圧/
さいこうけんい /最高権威/
さいこうけんいきかん /最高権威機関/
さいこうけんりょくしゃ /最高権力者/
さいこうげんどがく /最高限度額/
さいこうこうど /最高高度/
さいこうさい /最高裁/
さいこうさいさいばんかん /最高裁裁判官/
さいこうさいはんけつ /最高裁判決/
さいこうさいはんじ /最高裁判事/
さいこうさいばんしょ /最高裁判所/
さいこうさく /最高作/
さいこうさつ /再考察/
さいこうしはん /最高師範/
さいこうしゅつりょく /最高出力/
さいこうしん /最高神/
さいこうしんぱんいん /最高審判員/
さいこうじ /再工事/
さいこうじそく /最高時速/
さいこうすいじゅん /最高水準/
さいこうせい /再構成/
さいこうせいこうしき /再構成公式/
さいこうせいしんごう /再構成信号/
さいこうせいせき /最高成績/
さいこうせいほう /再構成法/
さいこうせいりつ /再構成率/
さいこうせきにん /最高責任/
さいこうせきにんしゃ /最高責任者/
さいこうそく /最高速/
さいこうそくしよう /最高速仕様/
さいこうそくど /最高速度/
さいこうそくどじ /最高速度時/
さいこうそくどせいのう /最高速度性能/
さいこうたん /最後端/
さいこうち /最高値/
さいこうちく /再構築/
さいこうちくちゅう /再構築中/
さいこうちてん /最高地点/
さいこうちゃくじゅん /最高着順/
さいこうちょう /最高潮/
さいこうてん /最高点/
さいこうとくてん /最高得点/
さいこうねぶつ /最高値物/
さいこうはつ /最後発/
さいこうび /最後尾/
さいこうふ /再交付/
さいこうぶ /最後部/最高部/
さいこうへんさち /最高偏差値/
さいこうほう /最後方/最高峰/
さいこうほうき /最高法規/
さいこうれつ /最後列/
さいこく /催告/
さいこくじょう /催告状/
さいこさん /最古参/
さいころ /サイコロ/賽子/骰子/
さいこん /再婚/細根/
さいこんりつ /再婚率/
さいご /最後/最期/西醐/
さいごう /西郷/
さいごうせい /再合成/
さいごうたかもり /西郷隆盛/
さいごうてるひこ /西郷輝彦/
さいごく /西国/
さいごっぺ /最後屁/
さいごつうちょう /最後通牒/
さいごまで /最後迄/
さいごん /西貢/
さいさ /最左/歳差/
さいさい /歳々/再載/再々/彩々/
さいさいばん /再採番/
さいさいらいにち /再再来日/
さいさうんどう /才差運動/歳差運動/
さいさき /幸先/
さいさくきじ /製作記事/
さいさくせい /再作成/
さいさどく /再査読/
さいさへん /最左辺/
さいさん /採算/再三/
さいさんさいし /再三再四/
さいさんしゅつ /再算出/
さいさんせい /採算制/採算性/
さいさんてき /採算的/
さいさんどがいし /採算度外視/
さいし /妻子/再試/再四/才子/祭祀/孥/斉志/載祀/
さいしあい /再試合/
さいしき /彩色/
さいしけん /再試験/
さいしげんか /再資源化/
さいしこう /再試行/
さいしつ /祭室/
さいしつもん /再質問/
さいしどう /再始動/
さいしもん /再試問/
さいしゃけん /再車検/
さいしゅ /採取/
さいしゅう /最終/採集/
さいしゅうあん /最終案/
さいしゅういんさつぶつ /最終印刷物/
さいしゅうかい /最終回/
さいしゅうかくにん /最終確認/
さいしゅうかん /最終巻/
さいしゅうがくねん /最終学年/
さいしゅうがくれき /最終学歴/
さいしゅうがぞう /最終画像/
さいしゅうがた /最終型/
さいしゅうがったい /最終合体/
さいしゅうきょく /最終曲/
さいしゅうぎょう /最終行/
さいしゅうくみ /最終組/
さいしゅうけい /最終景/再集計/
さいしゅうけいろ /最終経路/
さいしゅうけっか /最終結果/
さいしゅうけっせん /最終決戦/
さいしゅうけってい /最終決定/
さいしゅうけっていけん /最終決定権/
さいしゅうげんこう /最終原稿/
さいしゅうこう /最終稿/最終項/
さいしゅうこうえん /最終公演/最終講演/
さいしゅうこうぎ /最終講義/
さいしゅうごう /最終号/
さいしゅうさく /最終作/
さいしゅうしめきり /最終締切/
さいしゅうしゅう /最終週/
さいしゅうしゅだん /最終手段/
さいしゅうしゅっそうとうろく /最終出走登録/
さいしゅうしゅつじょうしゃ /最終出場者/
さいしゅうしゅつりょく /最終出力/
さいしゅうしょう /最終章/
さいしゅうしょうひしゃ /最終消費者/
さいしゅうしょうりつ /最終勝率/
さいしゅうしょうりつひょう /最終勝率表/
さいしゅうしょく /再就職/
さいしゅうしょり /最終処理/
さいしゅうしんぶん /済州新聞/
さいしゅうじゅんい /最終順位/
さいしゅうじょうたい /最終状態/
さいしゅうず /最終図/
さいしゅうせいさんがた /最終生産型/
さいしゅうせいせき /最終成績/
さいしゅうせきにん /最終責任/
さいしゅうせつ /最終節/
さいしゅうせん /最終戦/
さいしゅうせんこうかい /最終選考会/
さいしゅうせんそう /最終戦争/
さいしゅうそくど /最終速度/
さいしゅうぞうび /最終増備/
さいしゅうだん /最終段/
さいしゅうだんかい /最終段階/
さいしゅうち /最終値/
さいしゅうちてん /最終地点/
さいしゅうて /最終手/
さいしゅうていり /最終定理/
さいしゅうてき /最終的/
さいしゅうてきせきにん /最終的責任/
さいしゅうてきていあん /最終的提案/
さいしゅうでんしゃ /最終電車/
さいしゅうとう /済州島/
さいしゅうとうひょう /最終投票/
さいしゅうとうろくば /最終登録馬/
さいしゅうとっきゅう /最終特急/
さいしゅうねん /最終年/
さいしゅうねんど /最終年度/
さいしゅうはいりつ /最終敗率/
さいしゅうはっぴょう /最終発表/
さいしゅうはんだん /最終判断/
さいしゅうはんてい /最終判定/
さいしゅうばいりつ /最終倍率/
さいしゅうばん /最終版/
さいしゅうひみつへいき /最終秘密兵器/
さいしゅうび /最終日/
さいしゅうびごご /最終日午後/
さいしゅうびさいしゅうくみ /最終日最終組/
さいしゅうびぜんじつ /最終日前日/
さいしゅうびん /最終便/
さいしゅうぶぶん /最終部分/
さいしゅうへいき /最終兵器/
さいしゅうへんこうじこく /最終変更時刻/
さいしゅうへんせい /最終編成/
さいしゅうべんろん /最終弁論/
さいしゅうほうこく /最終報告/
さいしゅうほうこくしょ /最終報告書/
さいしゅうみつもりしょ /最終見積書/
さいしゅうめん /最終面/
さいしゅうもくてきち /最終目的地/
さいしゅうもくひょう /最終目標/
さいしゅうもくひょうち /最終目標値/
さいしゅうよせん /最終予選/
さいしゅうよそう /最終予想/
さいしゅうり /再修理/
さいしゅうれん /最終連/
さいしゅうろく /再収録/
さいしゅうろんこく /最終論告/
さいしゅうろんぶん /最終論文/
さいしゅうわ /最終話/
さいしゅじゅつ /再手術/
さいしゅっか /再出荷/
さいしゅっぱつ /再出発/
さいしゅつ /歳出/
さいしゅつば /再出馬/
さいしゅんかん /再春館/
さいしょ /最初/最所/才所/
さいしょう /最小/最少/宰相/
さいしょういそう /最小位相/
さいしょういそうじょうけん /最小位相条件/
さいしょうか /最小化/最少化/
さいしょうかいてんはんけい /最小回転半径/
さいしょうかげんり /最小化原理/
さいしょうかちょうげんかい /最小可聴限界/
さいしょうかちょうち /最小可聴値/
さいしょうかもんだい /最小化問題/
さいしょうかんかく /最小間隔/
さいしょうき /最小期/
さいしょうきじゅつりょう /最小記述量/
さいしょうきろく /最小記録/
さいしょうぎ /最小木/
さいしょうげん /最小限/最小元/最少限/
さいしょうげんすいりょう /最小減衰量/
さいしょうげんど /最小限度/最少限度/
さいしょうこうせい /最小構成/
さいしょうこうばいすう /最小公倍数/
さいしょうこゆうち /最小固有値/
さいしょうじじょう /最小２乗/最小二乗/最小2乗/
さいしょうじじょうかい /最小二乗解/最小2乗解/
さいしょうじじょうごさ /最小二乗誤差/最少二乗誤差/最小2乗誤差/
さいしょうじじょうてき /最小二乗的/
さいしょうじじょうほう /最小二乗法/最小2乗法/
さいしょうせい /最小性/
さいしょうせっていち /最少設定値/
さいしょうそいんし /最小素因子/
さいしょうたんい /最小単位/最少単位/
さいしょうち /最小値/
さいしょうちきじゅん /最小値基準/
さいしょうてん /最小点/
さいしょうとくてん /最少得点/
さいしょうはんか /最小汎化/
さいしょうはんけい /最小半径/
さいしょうふどうてん /最小不動点/
さいしょうへいきんじじょうごさすいてい /最小平均2乗誤差推定/
さいしょうりょう /最小量/
さいしょうろんり /最小論理/
さいしょかい /最初回/
さいしょき /最初期/
さいしょきか /再初期化/
さいしょく /彩色/才色/菜食/
さいしょくしゅぎしゃ /菜食主義者/
さいしょくみんちか /再植民地化/
さいしょほど /最初程/
さいしょり /再処理/
さいしょりこうじょう /再処理工場/
さいしょりしせつ /再処理施設/
さいしよう /再使用/
さいしようきょだく /再使用許諾/
さいしん /最新/細心/再審/最深/西神/祭神/
さいしんうちゅうろん /最新宇宙論/
さいしんえい /最新鋭/再新鋭/
さいしんかん /最新刊/最新巻/
さいしんかんきょう /最新環境/
さいしんがた /最新型/
さいしんき /最新機/
さいしんきしゅ /最新機種/
さいしんきじ /最新記事/
さいしんぎじゅつ /最新技術/
さいしんけいさんき /最新計算機/
さいしんけんきゅうどうこう /最新研究動向/
さいしんごう /最新号/
さいしんさ /再審査/
さいしんさく /最新作/
さいしんしき /最新式/
さいしんじじょう /最新事情/
さいしんじょうきょう /最新状況/
さいしんじょうほう /最新情報/
さいしんせい /再申請/
さいしんどうこう /最新動向/
さいしんばん /最新版/最新盤/
さいしんぼん /最新本/
さいしんろくおん /最新録音/
さいじ /細事/祭事/催事/斉次/斎次/
さいじき /歳時記/
さいじざひょう /斉次座標/斎次座標/
さいじっけん /再実験/
さいじっこう /再実行/
さいじっこうきのう /再実行機能/
さいじっそう /再実装/
さいじつ /祭日/
さいじつげん /再実現/
さいじゃく /最弱/
さいじゅうし /最重視/
さいじゅうてん /最重点/再充填/
さいじゅうてんかだい /最重点課題/
さいじゅうでん /再充電/
さいじゅうよう /最重要/
さいじゅうようかだい /最重要課題/
さいじゅうようし /最重要視/
さいじゅうようてん /最重要点/
さいじゅけん /再受験/
さいじゅしん /再受診/
さいじゅんかん /再循環/
さいじょ /才女/
さいじょう /西条/西城/最上/西條/齋城/斎場/
さいじょうい /最上位/
さいじょういきしゅ /最上位機種/
さいじょうえい /再上映/
さいじょうかい /最上階/
さいじょうかいさ /最上階差/
さいじょうきゅう /最上級/
さいじょうきゅうきしゅ /最上級機種/
さいじょうきゅうしゃ /最上級者/
さいじょうぎょう /最上行/
さいじょうじじょうかい /最小2乗解/
さいじょうせき /最上席/
さいじょうだん /最上段/
さいじょうぶ /最上部/
さいじょうよう /最重要/
さいじょうりゅう /最上流/
さいじん /才人/
さいすん /採寸/
さいず /サイズ/
さいせい /再生/再製/採精/
さいせいおん /再生音/
さいせいおんがく /再生音楽/
さいせいおんじょう /再生音場/
さいせいかのう /再生可能/
さいせいが /再生画/
さいせいがわ /再生側/
さいせいき /最盛期/再生器/再生機/
さいせいきのう /再生機能/
さいせいきゅう /再請求/
さいせいぎじゅつ /再生技術/
さいせいけい /再生系/
さいせいげんかい /再生限界/
さいせいさん /再生産/
さいせいさんこうぞう /再生産構造/
さいせいさんせい /再生産性/
さいせいさんひん /再生産品/
さいせいし /再生紙/
さいせいしげん /再生資源/
さいせいしつ /再生室/
さいせいしゅつりょく /再生出力/
さいせいしんごう /再生信号/
さいせいじ /再生時/最盛時/
さいせいじかん /再生時間/
さいせいじょうたい /再生状態/
さいせいせい /再生成/
さいせいせいぎょ /再生制御/
さいせいせんよう /再生専用/
さいせいせんようがわ /再生専用側/
さいせいせんようき /再生専用機/
さいせいそうち /再生装置/
さいせいたん /最西端/
さいせいちゅう /再生中/
さいせいのうりょく /再生能力/
さいせいばり /再生針/
さいせいひん /再生品/
さいせいび /再整備/
さいせいふのう /再生不能/
さいせいよう /再生用/
さいせいり /再整理/
さいせいりよう /再生利用/
さいせき /採石/砕石/
さいせきじょう /採石場/
さいせきどうしょう /砕石道床/
さいせっきん /最接近/
さいせっけい /再設計/
さいせってい /再設定/
さいせつ /細説/砕屑/再説/
さいせつぞく /再接続/
さいせつぶつ /砕屑物/
さいせん /細線/再選/再戦/賽銭/西線/
さいせんか /細線化/
さいせんたん /最先端/
さいせんたんぎじゅつ /最先端技術/
さいせんたんてきかつどう /最先端的活動/
さいせんちゃく /最先着/
さいぜん /最善/最前/菜膳/
さいぜんさく /最善策/
さいぜんしゅ /最善手/
さいぜんせん /最前線/
さいぜんふきん /最前付近/
さいぜんぶ /最前部/
さいぜんれつ /最前列/
さいそう /再送/
さいそうさ /再操作/
さいそうしん /再送信/
さいそうしんきょく /再送信局/
さいそうてん /再装填/
さいそうふ /再送付/
さいそうぶん /再送分/
さいそく /催促/最速/細則/
さいそくきろく /最速記録/
さいそくしゃせん /最速車線/
さいそくたつ /最速達/
さいそくてい /再測定/
さいそくとっきゅう /最速特急/
さいそくばく /再束縛/
さいそくれっしゃ /最速列車/
さいぞう /才蔵/
さいた /最多/斉田/才田/財田/齊田/斎田/
さいたあんだ /最多安打/
さいたい /妻帯/臍帯/
さいたいしゃ /妻帯者/
さいたかいさい /最多開催/
さいたかね /最高値/
さいたく /採択/
さいたくりつ /採択率/
さいたくろんぶん /採択論文/
さいたしゅつじょう /最多出場/
さいたしょう /最多勝/
さいたしょうとうしゅ /最多勝投手/
さいたそうび /最多装備/
さいたとうるい /最多盗塁/
さいたとくひょう /最多得票/
さいたま /埼玉/
さいたまけん /埼玉県/
さいたまけんあさかし /埼玉県朝霞市/
さいたまけんうらわし /埼玉県浦和市/
さいたまけんかすし /埼玉県加須市/
さいたまけんぎょうだし /埼玉県行田市/
さいたまけんくまがや /埼玉県熊谷/
さいたまけんけい /埼玉県警/
さいたまけんじん /埼玉県人/
さいたまけんない /埼玉県内/
さいたまけんみん /埼玉県民/
さいたまけんわらびし /埼玉県蕨市/
さいたまざいじゅう /埼玉在住/
さいたまし /さいたま市;2001年5月1日に浦和、大宮、与野三市が合併してできた市/
さいたまだい /埼玉大/
さいたまだいがく /埼玉大学/
さいたまちほうばん /埼玉地方版/
さいたまほうめん /埼玉方面/
さいたゆうしょうしゃ /最多優勝者/
さいたん /最短/採炭/
さいたんいっち /最短一致/
さいたんえきかんきょり /最短駅間距離/
さいたんかい /最短解/
さいたんがくしゅう /最短学習/
さいたんきょり /最短距離/
さいたんけいろ /最短経路/
さいたんさつえいきょり /最短撮影距離/
さいたんしゅすう /最短手数/
さいたんしょうてんきょり /最短焦点距離/
さいたんじかん /最短時間/
さいたんろ /最短路/
さいだ /斎田/斉田/
さいだい /最大/細大/埼大/歳代/
さいだいいそう /最大位相/
さいだいか /最大化/
さいだいかいてんすう /最大回転数/
さいだいかくだいりつ /最大拡大率/
さいだいかくりつ /最大確率/
さいだいかっそうきょり /最大滑走距離/
さいだいかりょく /最大火力/
さいだいがかく /最大画角/
さいだいき /最大期/
さいだいきぼ /最大規模/
さいだいきゅう /最大級/
さいだいきょうど /最大強度/
さいだいきょよう /最大許容/
さいだいけいしゃ /最大傾斜/
さいだいけんいんりょく /最大牽引力/
さいだいげん /最大限/最大元/
さいだいげんかい /最大限界/
さいだいげんかつよう /最大限活用/
さいだいげんじょうほ /最大限譲歩/
さいだいげんどりょく /最大限努力/
さいだいげんり /最大原理/
さいだいこうかそくど /最大降下速度/
さいだいこうふく /最大幸福/
さいだいこうやくすう /最大公約数/
さいだいこうやくすうてき /最大公約数的/
さいだいこすう /最大個数/
さいだいこゆうち /最大固有値/
さいだいこんざつりつ /最大混雑率/
さいだいしゃてい /最大射程/
さいだいしゅうはすう /最大周波数/
さいだいしゅつりょく /最大出力/
さいだいしょうひでんりょく /最大消費電力/
さいだいしんぱくすう /最大心拍数/
さいだいしんぷく /最大振幅/
さいだいじ /西大寺/
さいだいじゅうりょう /最大重量/
さいだいじょうほうようりょう /最大情報容量/
さいだいじょうほうりょう /最大情報量/
さいだいすう /最大数/
さいだいせいし /最大静止/
さいだいせいどうりょく /最大制動力/
さいだいせいのう /最大性能/
さいだいせんそく /最大戦速/
さいだいぜんかく /最大全角/
さいだいたすう /最大多数/
さいだいち /最大値/
さいだいちょう /最大長/
さいだいでんあつ /最大電圧/
さいだいでんりょく /最大電力/
さいだいとくひょう /最大得票/
さいだいはば /最大幅/
さいだいひきょり /最大飛距離/
さいだいみこみ /最大見込み/
さいだいみしよう /最大未使用/
さいだいもくひょう /最大目標/
さいだいようりょう /最大容量/
さいだいよさんがく /最大予算額/
さいだいりかく /最大離角/
さいだいりりくじゅうりょう /最大離陸重量/
さいだいりろん /最大理論/
さいだいれんぞく /最大連続/
さいだん /裁断/祭壇/
さいだんき /裁断器/
さいち /佐一/才知/
さいちゅう /最中/
さいちゅうおう /最中央/
さいちゅうせん /再抽選/
さいちゅうにゅう /再注入/
さいちょう /最長/最澄/
さいちょういっち /最長一致/
さいちょうえきかんきょり /最長駅間距離/
さいちょうかたみちきっぷ /最長片道切符/
さいちょうきょり /最長距離/
さいちょうけいろ /最長経路/
さいちょうさ /再調査/
さいちょうじょうしゃじかん /最長乗車時間/
さいちょうせい /再調整/最長性/
さいちょうせん /再挑戦/
さいちょうてじゅん /最長手順/
さいちょうてん /最長点/
さいちょうふとうきょり /最長不倒距離/
さいちょうれつ /最長列/
さいついか /再追加/
さいてい /最低/裁定/最底/
さいていあん /再提案/
さいていいっしゅうかん /最低一週間/
さいていうんちんがく /最低運賃額/
さいていうんちんくかん /最低運賃区間/
さいていうんちんせいど /最低運賃制度/
さいていおん /最低音/
さいていおんど /最低温度/
さいていかかくたい /最低価格帯/
さいていがく /最低額/
さいていきおん /最低気温/
さいていきじゅん /最低基準/
さいていきぼうがく /最低希望額/
さいていきゅう /最低級/
さいていぎ /再定義/
さいていけいやくぶん /最低契約分/
さいていげん /最低限/
さいていげんていこう /最低限抵抗/
さいていげんど /最低限度/
さいていげんひつよう /最低限必要/
さいていさいあく /最低最悪/
さいていしゃ /査定者/
さいていしゃかんきょり /最低車間距離/
さいていしゃはば /最低車幅/
さいていしゅう /裁定集/
さいていしゅつ /再提出/
さいていじ /最低次/再提示/
さいていじゅうりょう /最低重量/
さいていじょうけん /最低条件/
さいていせい /再訂正/
さいていせん /最低線/
さいていそくど /最低速度/
さいていたんい /最低単位/
さいていち /最低値/
さいていちじょうこう /最低地上高/
さいていちゃくじゅん /最低着順/
さいていちんぎん /最低賃金/
さいていちんぎんぶん /最低賃金分/
さいていてん /最低点/
さいていとうひょうすう /最低投票数/
さいていひつよう /最低必要/
さいていまち /裁定待ち/
さいていりょうきん /最低料金/
さいていりようきかん /最低利用期間/
さいてき /最適/最的/
さいてきいち /最適位置/
さいてきか /最適化/
さいてきかあり /最適化有り/
さいてきかい /最適解/
さいてきかしゅほう /最適化手法/
さいてきかせいぎょ /最適化制御/
さいてきかなし /最適化無し/
さいてきかぶ /最適化部/
さいてきかほう /最適化法/
さいてきかまえ /最適化前/
さいてきかもんだい /最適化問題/
さいてきかりろん /最適化理論/
さいてきかんり /最適管理/
さいてききょり /最適距離/
さいてきけいろしゅほう /最適経路手法/
さいてきざせきりつ /最適座席率/
さいてきじょうけん /最適条件/
さいてきせい /最適性/
さいてきせいぎょ /最適制御/
さいてきせいぎょかい /最適制御解/
さいてきせいぎょそく /最適制御則/
さいてきせいぎょもんだい /最適制御問題/
さいてきせっしゅりょう /最適摂取量/
さいてきせんりゃく /最適戦略/
さいてきち /最適値/
さいてきはいち /最適配置/
さいてげん /最低限/
さいてん /採点/祭典/
さいてんけっか /採点結果/
さいてんけん /再点検/
さいてんしつ /採点室/
さいてんしゃ /採点者/
さいてんしゅうけい /採点集計/
さいてんひょう /採点表/
さいてんほうほう /採点方法/
さいてんようし /採点用紙/
さいと /西都/サイト/
さいとう /斉藤/斎藤/齋藤/齊藤/
さいとうかん /再投函/
さいとうぐみ /斎藤組/
さいとうけいこ /斉藤慶子/
さいとうけん /斉藤研/
さいとうこう /再投稿/
さいとうし /再投資/
さいとうじょう /再登場/
さいとうにゅう /再投入/
さいとうひょう /再投票/
さいとうひょうせいきゅう /再投票請求/
さいとうろく /再登録/
さいとえい /再渡英/
さいとそう /再塗装/
さいとつにゅうかくど /再突入角度/
さいど /再度/サイド/彩度/
さいどう /細動/
さいどかくにん /再度確認/
さいどぎろん /再度議論/
さいどく /再読/
さいどけいさい /再度掲載/
さいどしつもん /再度質問/
さいどちょうせん /再度挑戦/
さいどとうこう /再度投稿/
さいどぼしゅう /再度募集/
さいどらいほう /再度来訪/
さいない /最内/
さいないしゅう /最内周/
さいないわく /最内枠/
さいなん /災難/
さいなんかん /最難関/
さいなんたん /最南端/
さいなんとう /最南東/
さいなんとうたん /最南東端/
さいにゅう /歳入/再入/
さいにゅうか /再入荷/
さいにゅうかい /再入会/
さいにゅうかのう /再入可能/
さいにゅうがく /再入学/
さいにゅうけっかん /歳入欠陥/
さいにゅうこう /再入校/
さいにゅうこく /再入国/
さいにゅうこくきょか /再入国許可/
さいにゅうしょう /再入賞/
さいにゅうじょう /再入場/
さいにゅうもん /再入門/
さいにゅうりょく /再入力/
さいにょう /採尿/
さいにん /再任/再認/
さいにんしき /再認識/
さいねん /再燃/
さいねんしょう /最年少/
さいねんしょうきろく /最年少記録/
さいねんしょうゆうしょうしゃ /最年少優勝者/
さいねんちゃく /再粘着/
さいねんちゃくせいぎょ /再粘着制御/
さいねんちょう /最年長/
さいねんちょうゆうしょうしゃ /最年長優勝者/
さいのう /才能/臍嚢/塞納/
さいのうしゅく /再濃縮/
さいのうてき /才能的/
さいのかわら /賽の河原/
さいのめ /賽の目/
さいはい /采配/再拝/
さいはいそう /再配送/
さいはいち /再配置/
さいはいちかのう /再配置可能/
さいはいふ /再配布/再配付/
さいはいふかつどう /再配布活動/
さいはいふかのう /再配布可能/再配付可能/
さいはいふげんきん /最配布厳禁/
さいはいふじゆう /再配付自由/
さいはいぶん /再配分/
さいはく /西伯/
さいはっけん /再発見/
さいはっこう /再発行/
さいはっこうしんせいしょ /再発行申請書/
さいはっしん /再発進/再発信/
さいはっそう /再発送/
さいはつ /再発/
さいはつおん /再発音/
さいはつばい /再発売/
さいはつばいばん /再発売版/
さいはつばん /再発版/
さいはつぶつ /再発物/
さいはん /最汎/再販/再版/再犯/
さいはんかかくいじ /再販価格維持/
さいはんさいはつ /再版再発/
さいはんしてい /再販指定/
さいはんしょうひん /再販商品/
さいはんせいど /再販制度/
さいはんばい /再販売/
さいはんもと /再販元/
さいはんろん /再反論/
さいばい /栽培/
さいばいほう /栽培法/
さいばん /裁判/採番/
さいばんかん /裁判官/
さいばんかんかつ /裁判管轄/
さいばんざた /裁判沙汰/
さいばんしえん /裁判支援/
さいばんしょ /裁判所/
さいばんしょはんけつ /裁判所判決/
さいばんせいど /裁判制度/
さいばんちゅう /裁判中/
さいばんちょう /裁判長/
さいばんてつづき /裁判手続/
さいばんとうそう /裁判闘争/
さいばんねん /最晩年/
さいひ /採否/歳費/
さいひかく /差異比較/
さいひはん /再批判/
さいひょうか /再評価/
さいひょうじ /再表示/
さいひんち /最頻値/
さいび /最微/
さいびこう /最微光/
さいびょうが /再描画/
さいふ /財布/採譜/
さいふくよう /再複葉/
さいふっとう /再沸騰/
さいぶ /細部/
さいぶん /細分/
さいぶんか /細分化/再分化/
さいぶんかつ /再分割/細分割/
さいぶんぱい /再分配/
さいぶんるい /再分類/細分類/
さいへん /再編/
さいへんかん /再変換/
さいへんき /再編期/
さいへんきょく /再編曲/
さいへんこう /再変更/
さいへんしゅう /再編集/
さいへんしゅうばん /再編集版/
さいへんせい /再編成/
さいべんきょう /再勉強/
さいほう /裁縫/再報/西方/
さいほうえい /再放映/
さいほうじょうど /西方浄土/
さいほうそう /再放送/
さいほうそうかいし /再放送開始/
さいほうそうじ /再放送時/
さいほうそうちゅう /再放送中/
さいほうそうようきゅう /再放送要求/
さいほうばこ /裁縫箱/
さいほうもん /再訪問/
さいほきゅう /再補給/
さいほくたん /最北端/
さいぼう /細胞/細砲/細棒/
さいぼうえん /最望遠/
さいぼうかっせいそうち /細胞活性装置/
さいぼうかん /細胞間/
さいぼうがい /細胞外/
さいぼうがいきしつ /細胞外基質/
さいぼうけんだくえき /細胞懸濁液/
さいぼうこうがく /細胞工学/
さいぼうこん /細胞塊/
さいぼうしつ /細胞質/
さいぼうしゅうき /細胞周期/
さいぼうしん /細胞診/
さいぼうじたい /細胞自体/
さいぼうせいぶつがく /細胞生物学/
さいぼうでんい /細胞電位/
さいぼうない /細胞内/
さいぼうひょうめん /細胞表面/
さいぼうぶんれつ /細砲分裂/
さいぼうへき /細胞壁/
さいぼうほんたい /細胞本体/
さいぼうまく /細胞膜/
さいぼうめんえきふぜん /細胞免疫不全/
さいぼうりゅう /細胞流/
さいぼしゅう /再募集/
さいぽすと /再ポスト/
さいまつ /歳末/
さいまつしょうり /歳末勝利/
さいみつ /最密/細密/
さいみゃく /細脈/
さいみょうじ /斎明寺/
さいみん /催眠/
さいみんしょうほう /催眠商法/
さいみんじゅつ /催眠術/
さいみんじゅつし /催眠術師/
さいみんちょうたい /細明朝体/
さいむ /債務/
さいむしゃ /債務者/
さいむしょうかん /債務償還/
さいむぶん /債務分/
さいむもんだい /債務問題/
さいめい /斉明/
さいめいちょう /細明朝/
さいめんきょ /再免許/
さいめんきょしんせい /再免許申請/
さいもく /細目/
さいもと /斉本/
さいもん /柴門/紫門/彩文/
さいもんどき /彩文土器/
さいもんふみ /柴門ふみ/
さいやく /災厄/
さいやすね /最安値/
さいゆう /最尤/
さいゆうき /西遊記/
さいゆうしゅう /最優秀/
さいゆうしゅうかしょうしょう /最優秀歌唱賞/
さいゆうしゅうこば /最優秀古馬/
さいゆうしゅうしょう /最優秀賞/
さいゆうしゅうしょうがいば /最優秀障害馬/
さいゆうしゅうしんじんしょう /最優秀新人賞/
さいゆうしゅうせんしゅ /最優秀選手/
さいゆうしゅうせんしゅしょう /最優秀選手賞/
さいゆうしゅうとうしゅ /最優秀投手/
さいゆうすいてい /最尤推定/
さいゆうすいていほう /最尤推定法/
さいゆうせん /最優先/
さいゆうとうれっしゃ /最優等列車/
さいゆうほう /最尤法/
さいゆうりょく /最有力/
さいゆうりょくかぶ /最有力株/
さいゆうりょくこうほ /最有力候補/
さいゆしゅつ /再輸出/
さいゆにゅう /再輸入/
さいよう /採用/
さいようか /採用課/
さいようくぶん /採用区分/
さいようしけん /採用試験/
さいようしつ /採用室/
さいようじき /採用時期/
さいようじょうけん /採用条件/
さいようたんとう /採用担当/
さいようぶ /採用部/
さいようりゆう /採用理由/
さいようれい /採用例/
さいらい /再来/
さいり /再履/犀利/
さいりしゅう /再履修/
さいりしゅうしゃ /再履修者/
さいりゃく /才略/
さいりゅう /細流/
さいりゅうど /細粒度/
さいりょう /最良/裁量/宰領/才量/
さいりょうか /最良化/
さいりょうがえ /再両替/
さいりょうけん /裁量権/
さいりょうじょうけん /最良条件/
さいりょうはんい /裁量範囲/
さいりよう /再利用/
さいりようかのう /再利用可能/
さいりようせい /再利用性/
さいりようほう /再利用法/
さいるい /催涙/
さいれい /祭礼/
さいれんさい /再連載/
さいろう /豺狼/
さいろく /採録/再録/載録/
さいろくおん /再録音/
さいろくばん /再録版/
さいろくろんぶん /採録論文/
さいろん /再論/
さいわい /幸い/幸/倖/
さいわいく /幸区/
さいわいちょう /幸町/
さいわかて /最若手/
さいわき /才脇/
さいわん /才腕/
さいん /サイン/
さいんかい /サイン会/
さう /然/
さうさぶ /操作部/
さうんど /サウンド/
さえ /冴/
さえき /佐伯/冴木/差益/
さえきく /佐伯区/
さえぐさ /三枝/
さえこ /沙絵子/冴子/さえ子/佐栄子/冴虎/小枝子/左枝子/
さえざえ /冴々/
さえじま /冴島/
さえだ /佐枝/
さえつ /査閲/
さえど /佐江戸/
さえば /冴羽/
さえみ /三絵美/
さお /竿/棹/杆/佐保/
さおとめ /五月女/早乙女/
さおり /沙織/小緒里/小織/里織/佐織/早織/
さか /坂/酒/阪/逆/茶菓/
さかい /酒井/堺/境/坂井/境井/酒伊/酒居/左海/阪井/界/
さかいがわ /境川/
さかいし /堺市/
さかいしない /堺市内/
さかいすじ /堺筋/
さかいすじせん /堺筋線/
さかいだ /境田/
さかいで /坂出/
さかいでえき /坂出駅/
さかいでがわ /坂出側/
さかいでふきん /坂出付近/
さかいでまるがめかん /坂出丸亀間/
さかいまさあき /堺正章/
さかいみなと /境港/
さかいめ /境目/
さかうえ /坂上/
さかうち /坂内/
さかうらみ /逆怨み/逆恨み/
さかえ /栄/榮/
さかえだ /栄田/
さかえだに /栄谷/
さかえまち /栄町/
さかお /阪尾/
さかかく /坂角/
さかがみ /坂上/阪上/
さかがわ /坂川/
さかき /榊/坂木/坂城/賢木/
さかきた /坂北/
さかきばら /榊原/
さかきばらおんせんぐち /榊原温泉口/
さかくら /坂倉/阪倉/
さかぐち /坂口/阪口/
さかぐちあんご /坂口安吾/
さかぐら /酒蔵/
さかげ /逆毛/
さかこし /坂越/
さかさ /逆/逆さ/
さかさい /逆井/
さかざき /坂崎/
さかした /坂下/阪下/
さかしま /逆/倒/
さかしら /賢しら/
さかずき /杯/盃/柧/盞/觚/
さかずめ /坂詰/
さかた /坂田/阪田/酒田/
さかたかん /酒田間/
さかたきんとき /坂田金時/
さかたに /阪谷/
さかだい /酒代/
さかだち /逆立ち/
さかづき /杯/盃/
さかて /逆手/酒手/
さかと /坂戸/
さかとったり /逆とったり/
さかど /坂戸/
さかな /魚/肴/
さかなが /阪長/
さかなし /坂梨/
さかなたち /魚達/
さかなへん /魚偏/
さかなや /魚屋/
さかなりょうり /魚料理/
さかにわ /坂庭/
さかね /坂根/
さかの /坂野/
さかのうえ /坂上/
さかのうえたむらまろ /坂上田村麻呂/
さかはぎ /逆剥/
さかば /酒場/
さかびき /逆引き/
さかびん /酒瓶/
さかべ /坂部/
さかほぎ /坂祝/
さかま /坂間/
さかまきおんせん /逆巻温泉/坂巻温泉/
さかまち /坂町/
さかみず /酒水/
さかみち /坂道/坂路/
さかみちはっしん /坂道発進/
さかむし /酒蒸し/
さかむら /坂村/
さかもぎ /逆茂木/
さかもと /坂本/阪本/坂元/酒本/阪元/
さかもときゅう /坂本九/
さかもとせん /阪本線/
さかもとりゅういち /坂本龍一/
さかもとりょうま /坂本竜馬/
さかもり /酒盛/
さかや /酒屋/
さかやき /月代/
さかり /盛り/盛/
さかりば /盛り場/
さかわ /坂和/佐川/栄和/
さかわがわ /酒匂川/
さかん /左官/佐官/差換/主典/
さが /性/佐賀/嵯峨/
さがえ /寒河江/
さがえき /嵯峨駅/佐賀駅/
さがく /差額/
さがくぶん /差額分/
さがけん /佐賀県/
さがけんしゅっしん /佐賀県出身/
さがけんとすし /佐賀県鳥栖市/
さがし /佐賀市/
さがしもの /捜し物/探し物/
さがしょう /佐賀商/
さがしょうぎょう /佐賀商業/
さがた /嵯峨田/
さがだい /佐賀大/
さがだいがく /佐賀大学/
さがちょう /佐賀町/
さがね /嵯峨根/
さがの /嵯峨野/
さがのせき /佐賀関/
さがのせん /嵯峨野線/
さがみ /相模/相摸/
さがみおおつか /相模大塚/
さがみおおの /相模大野/
さがみおおのいき /相模大野行/
さがみおおのえき /相模大野駅/
さがみおおのゆき /相模大野行/
さがみおおはし /相模大橋/
さがみがわ /相模川/
さがみがわかこう /相模川河口/
さがみがわかわら /相模川河原/
さがみこ /相模湖/
さがみこえき /相模湖駅/
さがみこほうめん /相模湖方面/
さがみじゅうかん /相模縦貫/
さがみせん /相模線/
さがみせんよう /相模線用/
さがみてつどう /相模鉄道/
さがみはら /相模原/
さがみはらきゅうじょう /相模原球場/
さがみはらし /相模原市/
さがみはらしみん /相模原市民/
さがみはらしゅうへん /相模原周辺/
さがみはらせん /相模原線/
さがみわん /相模湾/
さがやま /嵯峨山/
さがら /相楽/相良/
さがらぐん /相楽郡/
さがり /下がり/
さがる /下ル/
さがわ /佐川/
さがわきゅうびん /佐川急便/
さがん /左眼/左岸/
さき /先/崎/碕/埼/嵜/咲/早紀/沙貴/沙樹/早記/左記/前/早岐/尖/
さきいき /先行き/
さきいと /先糸/
さきえ /咲恵/
さきおくり /先送り/
さきおととい /一昨昨日/
さきおととし /一昨昨年/
さきがけ /先駆け/魁/先掛/
さきぐあい /咲具合/
さきこ /佐紀子/沙樹子/咲子/
さきごう /先号/
さきごろ /先頃/
さきさま /先様/
さきざき /先々/先崎/
さきた /咲田/崎田/
さきだか /先高/
さきち /佐吉/
さきづけ /先付け/
さきと /崎戸/
さきどり /先取り/
さきのり /先乗/
さきはま /咲浜/崎浜/
さきばらい /先払い/先払/
さきばん /先番/
さきほど /先程/
さきまけ /先負/
さきまわり /先回り/
さきみ /咲美/
さきもの /先物/
さきものがい /先物買/
さきものとりひき /先物取引/
さきや /崎谷/
さきやま /崎山/咲山/
さきゅう /砂丘/
さきゆき /先行き/
さきょう /左京/
さきょうく /左京区/
さきよみ /先読/先読み/
さきよみきごう /先読み記号/
さきわたし /先渡し/
さきん /砂金/差金/
さぎ /詐欺/鷺/
さぎさか /匂坂/
さぎさわ /鷺沢/
さぎざい /詐欺罪/
さぎし /詐欺師/
さぎしち /鷺七/
さぎしょうほう /詐欺商法/
さぎじけん /詐欺事件/
さぎぬま /鷺沼/
さぎぬまかん /鷺沼間/
さぎょう /作業/サ行/
さぎょうい /作業衣/
さぎょういき /作業域/
さぎょういん /作業員/
さぎょうかせつ /作業仮説/
さぎょうかだい /作業課題/
さぎょうかてい /作業過程/
さぎょうかんきょう /作業環境/
さぎょうきおく /作業記憶/
さぎょうきかい /作業機械/
さぎょうきじゅん /作業基準/
さぎょうぎ /作業着/
さぎょうけいたい /作業形態/
さぎょうこうりつ /作業効率/
さぎょうざひょう /作業座標/
さぎょうしゃ /作業者/作業車/
さぎょうしゅうりょう /作業終了/
さぎょうしょ /作業所/
さぎょうじ /作業時/
さぎょうじかん /作業時間/
さぎょうじたい /作業自体/
さぎょうじゅうじ /作業従事/
さぎょうじゅうじしゃ /作業従事者/
さぎょうせん /作業船/
さぎょうだい /作業台/
さぎょうちゅう /作業中/
さぎょうづくえ /作業机/
さぎょうていげん /作業低減/
さぎょうてき /作業的/
さぎょうてじゅん /作業手順/
さぎょうとちゅう /作業途中/
さぎょうどう /作業道/
さぎょうないよう /作業内容/
さぎょうにってい /作業日程/
さぎょうにんずう /作業人数/
さぎょうのうりつ /作業能率/
さぎょうば /作業場/
さぎょうひょう /作業表/
さぎょうび /作業日/
さぎょうふく /作業服/
さぎょうぶんせき /作業分析/
さぎょうぶんせきぎょうむ /作業分析業務/
さぎょうぶんせきしえん /作業分析支援/
さぎょうぶんたん /作業分担/
さぎょうへいめん /作業平面/
さぎょうべつ /作業別/
さぎょうほうこく /作業報告/
さぎょうほうこくしょ /作業報告書/
さぎょうほうしん /作業方針/
さぎょうよう /作業用/
さぎょうようりょういき /作業用領域/
さぎょうりょう /作業量/
さぎょうりょういき /作業領域/
さく /策/作/索/錯/冊/昨/窄/柵/朔/搾/咋/削/佐久/炸/捉/做/册/嘖/柞/槊/筴/筰/簀/縒/鑿/齪/辟/酢/乍/
さくい /作意/作為/
さくいちゅうしゅつ /作為抽出/
さくいてき /作為的/
さくいてきえいぞう /作為的映像/
さくいん /索引/
さくいんご /索引語/
さくいんさくせいきのう /索引作成機能/
さくか /昨夏/さく果/朔果/
さくかんとく /作監督/
さくが /作画/
さくがかんとく /作画監督/
さくがぎじゅつ /作画技術/
さくがら /作柄/
さくがりょく /作画力/
さくがん /削岩/
さくがんき /削岩機/
さくきまで /昨季迄/
さくぎ /昨木/
さくぎれ /索切/
さくげつ /昨月/
さくげん /削減/
さくげんきょうそう /削減競争/
さくげんこうか /削減効果/
さくげんとう /削減等/
さくげんは /削減派/
さくげんほう /削減法/
さくこん /昨今/
さくご /錯誤/
さくごえ /柵越え/
さくさく /昨々/
さくさん /酢酸/
さくさんがんゆうりょう /酢酸含有量/
さくざつ /錯雑/
さくし /索師/作詩/錯視/作詞/策士/佐久市/
さくしか /作詞家/
さくしさっきょく /作詞作曲/
さくししゃ /作詞者/作詩者/
さくししゃめい /作詞者名/
さくししょう /作詩賞/
さくしのざわ /佐久市野沢/
さくしゃ /作者/
さくしゃいがい /作者以外/
さくしゃじしん /作者自身/
さくしゃじせんしゅう /作者自選集/
さくしゃたち /作者達/
さくしゃふめい /作者不明/
さくしゃべつ /作者別/
さくしゃほんにん /作者本人/
さくしゃめい /作者名/
さくしゅ /搾取/
さくしゅう /昨秋/作州/
さくしゅうろうにん /作州浪人/
さくしゅつ /作出/
さくしゅん /昨春/
さくじ /作事/
さくじつ /昨日/朔日/
さくじつしんや /昨日深夜/
さくじつはっそう /昨日発送/
さくじつはつばい /昨日発売/
さくじょ /削除/
さくじょう /柵状/
さくじょうじゅうそしき /柵状柔組織/
さくじょうそしき /柵状組織/
さくじょかのう /削除可能/
さくじょきそく /削除規則/
さくじょこうひょう /削除公表/
さくじょする /削除する/
さくじょていあん /削除提案/
さくじょどうぎ /削除動議/
さくじょほうほう /削除方法/
さくず /作図/
さくせい /作成/作製/
さくせいあん /作成案/
さくせいいらい /作成依頼/
さくせいかた /作成方/
さくせいかてい /作成過程/
さくせいかのう /作成可能/
さくせいかんきょう /作成環境/
さくせいがいしゃ /作成会社/
さくせいがわ /作成側/
さくせいきじ /作成記事/
さくせいきじゅん /作成基準/
さくせいきのう /作成機能/
さくせいきょひ /作成拒否/
さくせいぎけつ /作成議決/
さくせいご /作成後/
さくせいごうい /作成合意/
さくせいさぎょう /作成作業/
さくせいさくじょ /作成削除/
さくせいさんせいは /作成賛成派/
さくせいしえん /作成支援/
さくせいしゃ /作成者/作製者/
さくせいしゃいがい /作成者以外/
さくせいしょうにん /作成承認/
さくせいじ /作成時/作製時/
さくせいじき /作成時期/
さくせいじょう /作成上/作製上/
さくせいせきにんしゃ /作成責任者/
さくせいちゅう /作成中/
さくせいていあん /作成提案/
さくせいていあんしゃ /作成提案者/
さくせいてじゅん /作成手順/
さくせいとうじ /作成当時/
さくせいとうひょう /作成投票/
さくせいどうぎ /作成動議/
さくせいはいふ /作成配布/
さくせいはんたい /作成反対/
さくせいひ /作成費/
さくせいび /作成日/
さくせいふか /作成不可/
さくせいぶ /作成部/
さくせいぶぶん /作成部分/
さくせいほう /作成法/
さくせいほうしき /作成方式/
さくせいほうほう /作成方法/
さくせいまえ /作成前/
さくせいまち /作成待ち/
さくせいもくひょう /作成目標/
さくせいよう /作成用/
さくせいようきゅう /作成要求/
さくせいようせい /作成要請/
さくせいようりょう /作成要領/
さくせいりゆう /作成理由/
さくせいれい /作成例/
さくせいろん /作成論/
さくせつ /作設/
さくせん /作戦/作戰/
さくせんきゅう /作戦級/
さくせんこうどう /作戦行動/
さくせんじたい /作戦自体/
さくせんばん /作戦盤/
さくせんへんこう /作戦変更/
さくそう /錯綜/
さくぞうぶ /作像部/
さくたき /作滝/
さくたろう /朔太郎/
さくだい /作題/
さくだん /炸弾/
さくちゅう /作中/
さくちゅうじんぶつ /作中人物/
さくちょう /錯聴/昨朝/佐久町/
さくつけ /作付/作付け/
さくづ /作図/
さくづけ /作付/作付け/
さくてい /策定/
さくてき /索敵/
さくてきがわ /索敵側/
さくてきき /索敵機/
さくてきけいかく /索敵計画/
さくてきこうげき /索敵攻撃/
さくてきにんむ /索敵任務/
さくとう /昨冬/作陶/作東/
さくとうりょう /作陶料/
さくどう /策動/索道/
さくなみ /作並/
さくなみえき /作並駅/
さくにゅう /搾乳/
さくにゅうよう /搾乳用/
さくねん /昨年/
さくねんあき /昨年秋/
さくねんいっぱい /昨年一杯/
さくねんくれ /昨年暮/
さくねんど /昨年度/
さくねんどうよう /昨年同様/
さくねんどばん /昨年度版/
さくねんなつ /昨年夏/
さくねんはる /昨年春/
さくねんひ /昨年比/
さくねんまつ /昨年末/
さくねんらい /昨年来/
さくのべ /作延/
さくはつ /炸発/
さくばく /索漠/索莫/索寞/
さくばん /昨晩/
さくばんしんや /昨晩深夜/
さくひょう /作表/
さくひょうきのう /作表機能/
さくひん /作品/
さくひんいご /作品以後/
さくひんいちらん /作品一覧/
さくひんか /作品化/
さくひんかいせつ /作品解説/
さくひんぐん /作品群/
さくひんしゅう /作品集/
さくひんしょう /作品賞/
さくひんしょうかい /作品紹介/
さくひんじたい /作品自体/
さくひんじょう /作品上/
さくひんじょうえいかい /作品上映会/
さくひんすう /作品数/
さくひんせかい /作品世界/
さくひんぜんたい /作品全体/
さくひんぜんぶ /作品全部/
さくひんたち /作品達/
さくひんちゅう /作品中/
さくひんべつ /作品別/
さくひんめい /作品名/
さくひんめいふしょう /作品名不詳/
さくひんもくろく /作品目録/
さくふ /作譜/
さくふう /作風/
さくふしゃ /作譜者/
さくぶん /作文/
さくぶんぎじゅつ /作文技術/
さくぶんりょく /作文力/
さくへんきょく /作編曲/
さくほう /作法/
さくぼう /策謀/朔望/
さくぼうげつ /朔望月/
さくま /佐久間/
さくません /佐久間線/
さくまち /佐久町/
さくみ /朔美/作見/
さくめ /作目/
さくもつ /作物/
さくや /昨夜/
さくやく /炸薬/
さくやま /作山/咲山/
さくゆ /搾油/
さくら /桜/櫻/佐倉/砂倉/紗倉/
さくらい /桜井/櫻井/
さくらいえき /桜井駅/
さくらいせん /桜井線/
さくらいろ /桜色/
さくらえ /桜江/
さくらおか /桜丘/
さくらおかじょし /桜丘女子/
さくらかわ /桜川/
さくらがい /桜貝/
さくらがおか /桜ヶ丘/桜ケ丘/櫻ヶ丘/桜丘/
さくらがほう /櫻画報/
さくらがわ /桜川/
さくらぎ /桜樹/桜木/
さくらぎちょう /桜木町/櫻木町/
さくらぎちょうえきまえ /桜木町駅前/
さくらぎちょうかん /桜木町間/
さくらぐみ /桜組/
さくらこ /桜子/
さくらこうじ /桜小路/
さくらざわ /桜沢/
さくらし /佐倉市/
さくらしんまち /桜新町/
さくらじま /桜島/
さくらじまごう /桜島号/
さくらじましゅうへん /桜島周辺/
さくらじません /桜島線/
さくらじまふきん /桜島付近/
さくらじょうすい /桜上水/
さくらぜんせん /桜前線/
さくらそうか /サクラソウ科/
さくらそうもく /サクラソウ目/Primulales/
さくらそうもくぐん /サクラソウ目群/
さくらだ /桜田/
さくらだい /桜台/
さくらだじゅんこ /桜田淳子/
さくらだもんえき /桜田門駅/
さくらづつみ /桜堤/
さくらどおり /桜通/
さくらにく /桜肉/
さくらのみや /桜宮/
さくらば /桜庭/櫻庭/
さくらばし /桜橋/
さくらふじ /桜富士/
さくらまち /桜町/
さくらまつり /桜祭/
さくらむし /桜蒸し/
さくらもと /桜本/
さくらん /錯乱/
さくらんじょうたい /錯乱状態/
さくりゃく /策略/
さくれい /作例/
さくれつ /炸裂/
さくろう /索郎/
さぐち /佐口/
さぐん /鎖群/
さけ /酒/鮭/
さけい /左傾/
さけうりば /酒売場/
さけかす /酒粕/
さけかわ /鮭川/
さけてん /酒店/
さけのみ /酒飲/
さけびごえ /叫び声/
さけびん /酒瓶/
さけみ /酒見/
さけめ /裂目/裂け目/
さける /辟/
さけるい /酒類/
さげ /下げ/
さげん /左舷/
さげんせつがん /左舷接岸/
さこ /迫/佐古/逧/
さこう /酒匂/佐甲/鎖交/酒向/
さこえ /迫江/
さこく /鎖国/
さこくせいさく /鎖国政策/
さこだ /迫田/
さこつ /鎖骨/
さこん /左近/
さごじょう /沙悟浄/
ささ /笹/佐々/篠/
ささい /些細/瑣細/
ささえ /支え/
ささお /笹尾/
ささおか /笹岡/佐佐岡/
ささかみ /笹神/
ささかわ /笹川/
ささがわ /笹川/
ささき /佐々木/笹木/笹氣/
ささぎ /大角豆/
ささくら /笹倉/
ささぐり /篠栗/
ささこ /笹子/
ささこもち /笹子餅/
ささざき /笹崎/
ささざわ /笹沢/
ささした /笹下/
ささじま /笹島/
ささずし /笹寿司/
ささせ /笹瀬/
ささたに /笹谷/
ささだ /笹田/
ささつ /査察/
ささつせん /笹津線/
ささづか /笹塚/
ささぬま /笹沼/
ささの /笹野/
ささのうち /笹之内/
ささはら /笹原/佐々原/
ささべ /笹部/
ささめゆき /細雪/
ささもと /笹本/篠本/
ささもり /笹森/
ささや /笹谷/
ささやか /細やか/
ささやとうげ /笹谷峠/
ささやま /笹山/篠山/
ささら /簓/
ささり /佐々里/
さざ /佐々/
さざえ /蠑螺/
さざなみ /さざ波/漣/細波/小波/
さざれ /細/
さざんか /サザンカ/
さし /砂嘴/
さしあし /差脚/差し足/
さしあみ /刺し網/
さしいれ /差入れ/差入/差し入れ/
さしえ /挿絵/插繪/插絵/挿し絵/
さしおさえ /差押/
さしかえ /差替/差し替え/
さしがさ /差し傘/
さしがね /差金/指矩/指金/差し金/
さしき /挿し木/佐敷/
さしきず /刺し傷/
さしさわり /差障り/差し障り/
さしず /指図/
さしだ /指田/
さしだしにん /差出人/
さしだしにんべつ /差出人別/
さしつかえ /差し支え/
さして /指し手/差し手/
さしで /差し出/
さしとめ /差止/
さしどめ /差止め/
さしなわ /差し縄/
さしね /さし値/指値/
さしの /指野/
さしば /差歯/差し歯/
さしひき /差引/差し引き/
さしま /猿島/
さしみ /刺身/
さしみよう /刺身用/
さしむかい /差向い/
さしもどし /差戻し/差し戻し/
さしもの /指物/
さしゅ /詐取/
さしゅう /査収/
さしゅうごう /差集合/
さしょう /詐称/査証/些少/瑣小/
さしょうしゃ /詐称者/
さしわたし /差渡し/
さしんしつ /左心室/
さしんぼう /左心房/
さじ /匙/些事/佐治/瑣事/佐冶/
さじかげん /匙加減/
さじき /桟敷/
さじきせき /桟敷席/
さじま /佐島/
さじょう /砂上/鎖錠/叉状/
さじょうそうち /鎖錠装置/
さじん /砂塵/
さすが /流石/
さすけ /佐助/
さすだ /佐須田/
さすぺんど /サスペンド/
さすれば /然爲れば/
さず /左図/
させ /佐瀬/
させい /嗄声/
させつ /左折/
させつしゃ /左折車/
させつしんごう /左折信号/
させつじ /左折時/
させぼ /佐世保/
させぼいき /佐世保行/
させぼこうせん /佐世保高専/
させぼし /佐世保市/
させぼせん /佐世保線/
させぼへんせい /佐世保編成/
させぼゆき /佐世保行/
させん /左遷/鎖線/
させんけい /左線形/
さそ /誘/
さそいみず /誘い水/
さそう /佐宗/
さそく /左側/
さそり /蠍/蝎/
さそりおとこ /蠍男/
さそりざ /蠍座/
さそん /差損/
さぞ /嘸/
さた /沙汰/沙多/佐屋/佐多/
さたけ /佐竹/佐武/
さたみさき /佐多岬/
さたろう /佐太郎/
さたん /左端/嗟嘆/嗟歎/
さだ /定/貞/禎/佐田/偵/
さだあき /貞明/禎章/
さだい /佐大/
さだいえ /定家/
さだいじん /左大臣/
さだえ /貞江/
さだお /貞夫/貞男/貞雄/定男/定夫/定雄/
さだおか /定岡/
さだおき /貞煕/
さだかた /定方/貞方/
さだかつ /定勝/
さだき /貞木/定樹/貞樹/
さだきち /定吉/
さだこ /貞子/
さだとし /貞俊/
さだのぶ /定伸/
さだはる /貞治/
さだひこ /貞彦/定彦/
さだひろ /定宏/貞広/
さだまつ /貞松/定松/
さだみさき /佐田岬/
さだみち /貞通/
さだみつ /貞光/
さだめ /定め/宿命/
さだめごと /定め事/
さだやす /定康/
さだゆき /貞行/
さだよし /貞芳/
さだん /左段/
さち /幸/倖/佐知/
さちえ /佐智恵/
さちお /佐千男/幸雄/幸夫/
さちこ /幸子/早智子/佐知子/祥子/佐智子/
さちよ /祥代/
さっ /早/
さっか /作家/
さっかー /サッカー/
さっかいくせいききん /作家育成基金/
さっかかつどう /作家活動/
さっかく /錯覚/
さっかしょう /擦過傷/
さっかじん /作家陣/
さっかせかいぶもん /作家世界部門/
さっかたち /作家達/
さっかにほんぶもん /作家日本部門/
さっかべつ /作家別/
さっかべつたんこうぼん /作家別単行本/
さっかめい /作家名/
さっかれん /作家連/
さっかん /作監/
さっき /殺気/先刻/
さっきゅう /早急/
さっきょう /作凶/
さっきょく /作曲/
さっきょくか /作曲家/
さっきょくかめい /作曲家名/
さっきょくご /作曲後/
さっきょくしゃ /作曲者/
さっきょくしゃめい /作曲者名/
さっきょくしょう /作曲賞/
さっきょくじき /作曲時期/
さっきょくねんだい /作曲年代/
さっきょくほう /作曲法/
さっきょくほうほう /作曲方法/
さっきょくよう /作曲用/
さっきん /殺菌/
さっきんこうか /殺菌効果/
さっきんざい /殺菌剤/
さっこん /昨今/
さっさ /佐々/
さっし /冊子/
さっしょう /殺傷/殺生/
さっしょうせき /殺生石/
さっしょうのうりょく /殺傷能力/
さっしょうりょく /殺傷力/
さっしん /刷新/殺身/
さっすい /撒水/
さっすう /冊数/
さっせい /殺生/殺青/
さっせつ /殺節/
さっそう /颯爽/
さっそく /早速/
さっそくにゅうしゅ /早速入手/
さっち /察知/
さっちも /三進も/
さっちゃー /サッチャー/
さっちゅう /殺虫/
さっちゅうざい /殺虫剤/
さって /幸手/
さってし /幸手市/
さっと /颯と/
さっとう /殺到/
さっぷ /撒布/
さっぷうけい /殺風景/
さっぽう /殺法/
さっぽろ /札幌/
さっぽろいかだいがく /札幌医科大学/
さっぽろいだい /札幌医大/
さっぽろえき /札幌駅/
さっぽろえきふきん /札幌駅付近/
さっぽろかいわい /札幌界隈/
さっぽろかん /札幌間/
さっぽろきねん /札幌記念/
さっぽろきんこう /札幌近郊/
さっぽろけいばじょう /札幌競馬場/
さっぽろこうさい /札幌高裁/
さっぽろこくさい /札幌国際/
さっぽろざいじゅう /札幌在住/
さっぽろし /札幌市/
さっぽろしきたくきた /札幌市北区北/
さっぽろしこうつうきょく /札幌市交通局/
さっぽろししゅうへん /札幌市周辺/
さっぽろしてん /札幌支店/
さっぽろしない /札幌市内/
さっぽろしゅうへん /札幌周辺/
さっぽろたいかい /札幌大会/
さっぽろだいがく /札幌大学/
さっぽろてん /札幌店/
さっぽろなかじまたいいく /札幌中島体育/
さっぽろはっちゃく /札幌発着/
さっぽろはつ /札幌発/
さっぽろばん /札幌版/
さっぽろびん /札幌便/
さっぽろほうめん /札幌方面/
さっぽろまるやまきゅうじょう /札幌円山球場/
さっぽろみなみこうこう /札幌南高校/
さっぽろめいぶつ /札幌名物/
さつ /冊/札/察/殺/擦/撮/薩/刷/拶/撒/册/刹/扎/箚/紮/颯/
さつい /殺意/
さつうばこ /茶通箱/
さつえい /撮影/撮映/
さつえいいち /撮影位置/
さつえいうらばなし /撮影裏話/
さつえいかい /撮影会/撮映会/
さつえいかのう /撮影可能/
さつえいかんかく /撮影間隔/
さつえいかんとく /撮影監督/
さつえいき /撮影器/
さつえいきざい /撮影器材/撮影機材/
さつえいきょり /撮影距離/
さつえいぎじゅつ /撮影技術/
さつえいけっか /撮影結果/
さつえいげんば /撮影現場/
さつえいこうか /撮影効果/
さつえいこうてきち /撮影好適地/
さつえいご /撮影後/
さつえいしゃ /撮影者/
さつえいじ /撮影時/
さつえいじかん /撮影時間/
さつえいじかんたい /撮影時間帯/
さつえいじょ /撮影所/
さつえいじょうきょう /撮影状況/
さつえいじょうけん /撮影条件/
さつえいずみ /撮影済/
さつえいせんよう /撮影専用/
さつえいぜんぱん /撮影全般/
さつえいたいしょう /撮影対象/
さつえいたいしょうぶつ /撮影対象物/
さつえいだい /撮影台/
さつえいち /撮影地/
さつえいちゅう /撮影中/
さつえいばいりつ /撮影倍率/
さつえいばしょ /撮影場所/
さつえいひょうてき /撮影標的/
さつえいふうけい /撮影風景/
さつえいぶ /撮影部/
さつえいほう /撮影法/
さつえいほうほう /撮影方法/
さつえいまえ /撮影前/
さつえいもくてき /撮影目的/
さつえいよう /撮影用/
さつえいりょこう /撮影旅行/
さつがい /殺害/
さつがいしゃ /殺害者/
さつがいじけん /殺害事件/
さつき /皐/五月/皐月/佐月/
さつきがおか /五月丘/
さつきしょう /皐月賞/
さつきしょうば /皐月賞馬/
さつきだ /五月田/
さつきちょう /五月町/
さつきやま /五月山/
さつこう /殺光/
さつじん /殺人/殺陣/
さつじんき /殺人鬼/
さつじんげんば /殺人現場/
さつじんこうい /殺人行為/
さつじんざい /殺人罪/
さつじんしゃ /殺人者/
さつじんしょうどう /殺人衝動/
さつじんじけん /殺人事件/
さつじんてき /殺人的/
さつじんてきこんざつ /殺人的混雑/
さつじんはん /殺人犯/
さつじんもうそう /殺人妄想/
さつじんようにんしゃ /殺人容認者/
さつすう /冊数/
さつぞう /撮像/
さつぞうけい /撮像系/
さつたば /札束/
さつぬません /札沼線/
さつばつ /殺伐/
さつま /薩摩/
さつまじる /薩摩汁/
さつまはん /薩摩藩/
さつまはんとう /薩摩半島/
さつめ /冊目/
さつゆう /殺熊/
さつようえいきゃくほん /撮影用脚本/
さつりく /殺戮/
さづか /佐塚/
さて /偖/扨/
さてい /査定/
さていかかく /査定価格/
さていじょうけん /査定条件/
さておき /扨措き/
さてつ /砂鉄/蹉跌/
さてん /茶店/
さでん /佐伝/
さと /里/智/郷/聡/理/聰/
さといも /里芋/
さといもか /サトイモ科/
さといももく /サトイモ目/Arales/Spathiflorae/
さとう /佐藤/砂糖/佐東/差等/左党/
さとういり /砂糖入/
さとうけん /佐藤研/
さとうにしき /佐藤錦/
さとうみず /砂糖水/
さとえ /さと江/
さとおや /里親/
さとがえり /里帰り/
さとこ /聡子/里子/佐登子/郷子/沙都子/砂登子/理子/智子/
さとごころ /里心/
さとし /聡/敏/哲/聡志/覚/慧/悟/智/智嗣/諭/賢/悟史/理/叡/覚志/恵/聖/知/智史/理史/里志/聰/覺/訓/智志/聡史/
さとしょう /里庄/
さとなか /里中/
さとなかまちこ /里中満智子/
さとひろ /理洋/
さとふか /里深/
さとみ /里美/聡巳/悟美/恵規/聡美/里見/沙都美/智美/
さとみつ /理満/
さとみはっけんでん /里見八犬伝/
さとむら /里村/
さとやま /里山/
さとり /悟り/
さとる /達/悟/覚/智/哲/聡/了/覺/逹/知/暁;名/
さど /佐渡/
さどう /作動/茶道/差動/佐道/
さどうおん /作動音/
さどうせいげん /差動制限/
さどうちゅう /作動中/
さどうふりょう /作動不良/
さどがや /佐渡谷/
さどきせん /佐渡汽船/
さどく /査読/
さどくいいん /査読委員/
さどくいらい /査読依頼/
さどくきてい /査読規定/
さどくけっか /査読結果/
さどくし /査読子/
さどくしゃ /査読者/
さどくほうこく /査読報告/
さどくほうしき /査読方式/
さどやま /佐渡山/
さどわら /佐土原/
さない /佐内/左内/
さなえ /早苗/差波江/早生/早植/
さなか /最中/
さながら /宛ら/
さなぎ /佐薙/蛹/
さなげ /猿投/
さなげやま /猿投山/
さなごうち /佐那河内/
さなだ /真田/
さなだたいへいき /真田太平記/
さなだゆきむら /真田幸村/
さなみ /佐奈美/
さなる /佐鳴/
さぬき /讃岐/佐貫/
さぬきかがわ /讃岐香川/
さぬきしおやえき /讃岐塩屋駅/
さぬきじん /讃岐人/
さぬきはくちょう /讃岐白鳥/
さぬま /砂沼/
さねあつ /実篤/
さねちか /実近/
さねとう /実藤/實藤/
さねとみ /実美/
さねはる /実治/
さの /佐野/
さのう /佐納/左脳/
さのかわ /佐野川/
さのさか /佐野坂/
さのし /佐野市/
さのしろう /佐野史郎/
さのるみ /佐野ルミ/
さは /左派/
さはい /差配/
さはら /佐原/薩哈剌/
さはん /茶飯/
さはんじ /茶飯事/
さば /鯖/佐波/鯆/
さばえ /鯖江/
さばおり /鯖折り/
さばき /捌/
さばきやく /捌役/
さばく /砂漠/佐幕/
さばくちたい /砂漠地帯/
さばくちゅう /砂漠中/
さばし /佐橋/
さばずし /鯖鮨/
さび /錆/鏥/寂/銹/
さびしろ /淋代/
さびどめ /さび止め/錆び止め/錆止め/
さぴえんす /サピエンス/
さぶ /サブ/佐武/
さぶきごう /サブ記号/
さぶさーきっと /サブサーキット/
さぶしょ /三仏生/
さぶろう /三郎/三朗/
さぶん /差分/
さぶんかい /差分解/
さぶんきかい /差分機械/
さぶんきかん /差分機関/
さぶんきんじ /差分近似/
さぶんけいしき /差分形式/
さぶんじょうほう /差分情報/
さぶんてん /差分点/
さぶんほう /差分法/
さぶんほうていしき /差分方程式/
さぷらい /サプライ/
さへん /左辺/サ変/
さへんち /左辺値/
さべつ /差別/
さべついしき /差別意識/
さべついと /差別意図/
さべつか /差別化/
さべつかいしょう /差別解消/
さべつかんじょう /差別感情/
さべつこうい /差別行為/
さべつこうぞう /差別構造/
さべつご /差別語/
さべつごひはん /差別語批判/
さべつしそう /差別思想/
さべつしゃ /差別者/
さべつしゅぎ /差別主義/
さべつしゅぎしゃ /差別主義者/
さべつじけん /差別事件/
さべつじったい /差別実態/
さべつせい /差別性/
さべつたいぐう /差別待遇/
さべつたいしょう /差別対象/
さべつてき /差別的/
さべつてきいしき /差別的意識/
さべつてきいと /差別的意図/
さべつてきこうい /差別的行為/
さべつてきしこう /差別的思考/
さべつてきひょうげん /差別的表現/
さべつてきようご /差別的用語/
さべつはいし /差別廃止/
さべつはつげん /差別発言/
さべつひはん /差別批判/
さべつひょうげん /差別表現/
さべつひょうげんは /差別表現派/
さべつもんだい /差別問題/
さべつよう /差別用/
さべつようご /差別用語/
さべつようごぎろん /差別用語議論/
さべつようごは /差別用語派/
さべつようごひはん /差別用語批判/
さべつりゆう /差別理由/
さべつろんしゃ /差別論者/
さべん /左弁/
さほ /沙穂/左保/
さほう /作法/左方/差法/
さほこ /佐保子/
さほど /然程/
さぼう /砂防/茶房/
さぼてんもく /サボテン目/Cactales/
さぽーと /サポート/
さま /様/樣/
さまかた /様方/
さまさま /様様/
さまざま /様々/
さまざまな /様々な/
さまたげ /妨げ/
さまつ /瑣末/些末/
さまつじこう /瑣末事項/
さまに /様似/
さまほん /様本/
さまりー /サマリー/
さみず /三水/
さみだれ /五月雨/
さむえ /作務衣/
さむかわ /寒川/
さむかわちょう /寒川町/
さむがり /寒がり/
さむがわ /寒川/
さむけ /寒気/
さむさ /寒さ/
さむざむ /寒々/
さむぞら /寒空/
さむらい /士/侍/壻/
さめ /鮫/雨/
さめかわ /鮫川/
さめがい /醒ケ井/
さめしま /鮫島/
さめじま /鮫島/
さめす /鮫州/
さも /然も/
さもん /査問/左門/
さや /沙耶/鞘/莢/
さやあて /鞘当て/鞘当/
さやいんげん /莢隠元/
さやえんどう /莢豌豆/
さやか /沙也加/
さやこ /彩也子/清子/
さやま /狭山/佐山/
さやまし /狭山市/
さゆう /左右/←→/
さゆううち /左右打ち/
さゆうかくにん /左右確認/
さゆうぎゃく /左右逆/
さゆうぎゃくかいてん /左右逆回転/
さゆうぎゃくぞう /左右逆像/
さゆうけんよう /左右兼用/
さゆうこうご /左右交互/
さゆうさ /左右差/
さゆうじく /左右軸/
さゆうじょうげ /左右上下/
さゆうそうしょう /左右相称/
さゆうそうしょうか /左右相称花/
さゆうそうしょうけい /左右相称形/
さゆうそくめん /左右側面/
さゆうたいしょう /左右対称/
さゆうたいしょうせい /左右対称性/
さゆうたいしょうめん /左右対称面/
さゆうたん /左右端/
さゆうどう /左右動/
さゆうどくりつ /左右独立/
さゆうはんてん /左右反転/
さゆうひたいしょう /左右非対称/
さゆうほうこう /左右方向/
さゆうりょうたん /左右両端/
さゆうりょうのう /左右両脳/
さゆうりょうほう /左右両方/
さゆり /小百合/早百合/沙由里/
さよ /小夜/
さよう /作用/佐用/左様/左用/左葉/
さようかく /作用角/
さようきじょ /作用機序/
さようし /作用子/
さようじゅんじょ /作用順序/
さようそ /作用素/
さようそろん /作用素論/
さようてん /作用点/
さようでんきょく /作用電極/
さようはんさよう /作用反作用/
さようはんさようそく /作用反作用則/
さようほぞんそく /作用保存則/
さよく /左翼/
さよくしゅ /左翼手/
さよくてき /左翼的/
さよこ /佐代子/小夜子/紗世子/沙夜子/
さら /皿/更/沙羅/
さらいげつ /再来月/
さらいしゅう /再来週/
さらいねん /再来年/
さらう /攫/
さらうんど /サラウンド/
さらかず /皿数/
さらがた /皿型/
さらさ /更紗/
さらさら /更々/
さらし /晒/
さらしくび /晒し首/
さらしな /更科/更級/
さらしなぐん /更級郡/
さらす /晒/
さらせにあもく /サラセニア目/Sarraceniales/
さらそうじゅ /沙羅双樹/
さらだ /サラダ/
さらち /更地/
さらに /更に/
さらぬ /然らぬ/
さらば /然らば/
さらべつ /更別/
さらまんだ /沙羅蔓蛇/沙羅曼蛇/
さらりーまん /サラリーマン/
さり /紗理/
さりとて /然りとて/
さりゅうさいさい /茶流彩彩/
さりょう /査領/
さる /猿/沙流/申/サル/
さるがき /桾/
さるがく /猿学/
さるくら /猿倉/
さるぐつわ /猿轡/
さるぐんだん /猿軍団/
さるげんとどくさか /サルゲントドクサ科/Sargentodoxaceae/
さること /然ること/
さるすべり /サルスベリ/百日紅/
さるた /猿田/
さるとび /猿飛/
さるとびさすけ /猿飛佐助/
さるどし /猿年/
さるばし /猿橋/
さるふぁざい /サルファ剤/
さるふつ /猿払/
さるまね /猿真似/
さるめんかじゃ /猿面冠者/
さるめんかんじゃ /猿面冠者/
さるや /猿谷/
さるやま /猿山/
さるわたり /猿渡/
されき /砂礫/
されこうべ /髑髏/
さろま /佐呂間/
さわ /沢/澤/佐和/佐波/
さわい /沢井/澤井/
さわいり /沢入/
さわうち /澤内/沢内/
さわおか /澤岡/
さわかい /茶話会/
さわき /沢木/澤木/
さわくり /沢栗/
さわぐち /沢口/
さわこ /佐和子/
さわざき /澤崎/沢崎/
さわすぎ /沢杉/
さわた /佐和田/
さわたり /沢渡/
さわだ /沢田/澤田/澤多/
さわだあやこ /沢田亜矢子/
さわだけん /澤田研/
さわだけんじ /沢田研二/
さわち /皿鉢/
さわちりょうり /皿鉢料理/
さわとうげ /沢峠/
さわのぼり /沢登/澤登/
さわはた /澤幡/
さわまつ /沢松/
さわむら /沢村/澤村/
さわむらしょう /沢村賞/
さわもと /澤本/
さわや /沢弥/澤谷/
さわやま /沢山/佐和山/
さわら /佐原/早良/鰆/椹/
さわらし /佐原市/
さわらび /早蕨/
さわわたり /沢渡/
さわん /左腕/
さわんとうしゅ /左腕投手/
さん /三/算/参/酸/散/山/産/賛/讃/餐/蚕/纂/惨/桟/傘/珊/燦/撒/３/3/杉/刪/參/簒/彡/慘/戔/攅/棧/汕/潸/爨/粲/繖/纉/芟/蠶/衫/讚/贊/跚/鑽/鑚/驂/斬/嶄/蒜/蚕儚/
さんあくにん /三悪人/
さんい /賛意/三位/
さんいいかかくてい /三位以下確定/
さんいち /三一/
さんいちしょぼう /三一書房/
さんいつ /散逸/散佚/
さんいつかてい /散逸過程/
さんいつけい /散逸系/
さんいん /山陰/参院/産院/
さんいんせん /参院選/山陰線/
さんいんせんきょうとぐち /山陰線京都口/
さんいんちほう /山陰地方/
さんいんとっきゅう /山陰特急/
さんいんほうそう /山陰放送/
さんいんほうめん /山陰方面/
さんいんほんかいぎ /参院本会議/
さんいんほんせん /山陰本線/
さんいんほんせんけいゆ /山陰本線経由/
さんいんほんせんけいゆう /山陰本線経由/
さんえい /三栄/
さんえいちょう /三栄町/
さんえき /三駅/
さんえんしゅぎ /三猿主義/
さんおう /三桜/
さんおくえんじけん /三億円事件/
さんか /参加/酸化/讃歌/産科/傘下/賛歌/山窩/惨禍/
さんかあんない /参加案内/
さんかい /三階/3回/三回/参会/散会/散開/山海/山塊/
さんかいご /散会後/
さんかいしき /参加意識/
さんかいじゅく /山海塾/
さんかいめ /３回目/三回目/
さんかうけつけ /参加受付/
さんかかくじ /参加各自/
さんかかくそしき /参加各組織/
さんかかくてい /参加確定/
さんかかのう /参加可能/
さんかかんりょうご /参加完了後/
さんかがいじん /参加外人/
さんかがた /参加型/
さんかきかん /参加期間/
さんかきぼう /参加希望/
さんかきぼうしゃ /参加希望者/
さんかきん /参加金/
さんかく /△/▽/三角/▼/▲/参画/贊畫/3角/
さんかくいた /三角板/
さんかくか /三角化/
さんかくかんけい /三角関係/
さんかくかんすう /三角関数/三角函数/
さんかくきん /三角巾/
さんかくぎょうれつ /三角行列/3角行列/
さんかくけい /三角形/3角形/
さんかくけいぶんかつ /三角形分割/
さんかくじょうぎ /三角定規/
さんかくす /三角州/
さんかくそくりょう /三角測量/
さんかくちゅう /三角柱/
さんかくちょうてん /三角頂点/
さんかくてん /三角点/
さんかくとう /三角塔/
さんかくは /三角波/
さんかくはけい /三角波形/
さんかくひ /三角比/
さんかくひょうじばん /三角表示版/
さんかくほう /三角法/
さんかくぼうし /三角帽子/
さんかくまど /三角窓/
さんかくやろう /三角野郎/
さんかけいしき /参加形式/
さんかけってい /参加決定/
さんかけん /参加券/
さんかげつ /三ヶ月/三箇月/三カ月/
さんかこう /参加校/
さんかこく /参加国/
さんかごきぼう /参加御希望/
さんかさくひん /参加作品/
さんかしかく /参加資格/
さんかしせい /参加姿勢/
さんかしゃ /参加者/
さんかしゃいしき /参加者意識/
さんかしゃうけつけちゅう /参加者受付中/
さんかしゃかくい /参加者各位/
さんかしゃかん /参加者間/
さんかしゃこじん /参加者個人/
さんかしゃしめい /参加者氏名/
さんかしゃすう /参加者数/
さんかしゃぜんいん /参加者全員/
さんかしゃそうすう /参加者総数/
さんかしゃたすう /参加者多数/
さんかしゃたち /参加者達/
さんかしゃにんずう /参加者人数/
さんかしゃぼしゅう /参加者募集/
さんかしゃめい /参加者名/
さんかしゃめいぼ /参加者名簿/
さんかしゃゆうし /参加者有志/
さんかしょ /三個所/
さんかしょう /参加賞/参加章/参加証/
さんかしょうひきかえけん /参加賞引換券/
さんかしょうへき /参加障壁/
さんかしんせい /参加申請/
さんかじ /参加時/
さんかじき /参加時期/
さんかじゅん /参加順/
さんかじゅんび /参加準備/
さんかじょうけん /参加条件/
さんかじんこう /参加人口/
さんかすう /参加数/
さんかせんしゅ /参加選手/
さんかそしき /参加組織/
さんかそしきすう /参加組織数/
さんかた /三方/
さんかだいがく /参加大学/
さんかだいきん /参加代金/
さんかだいすう /参加台数/
さんかだんたい /参加団体/
さんかちゅう /参加中/
さんかっけい /三角形/3角形/
さんかっけいがた /三角形型/
さんかとうろく /参加登録/
さんかとうろくきぼう /参加登録希望/
さんかとうろくひ /参加登録費/
さんかどう /酸化銅/
さんかにんずう /参加人数/
さんかにんずうぶん /参加人数分/
さんかねつ /酸化熱/
さんかば /参加馬/
さんかひ /参加費/
さんかひむりょう /参加費無料/
さんかひょうめい /参加表明/
さんかひよう /参加費用/
さんかび /参加日/
さんかふのう /参加不能/
さんかぶつ /酸化物/
さんかほうこく /参加報告/
さんかほうほう /参加方法/
さんかぼしゅう /参加募集/
さんかまえ /参加前/
さんかまく /酸化膜/
さんかむりょう /参加無料/
さんかめいぼ /参加名簿/
さんかもうしこみ /参加申し込み/参加申込/
さんかもうしこみあんない /参加申込案内/
さんかもうしこみしょ /参加申込書/
さんかようこう /参加要項/
さんかよてい /参加予定/
さんかよていしゃ /参加予定者/
さんかよていび /参加予定日/
さんかりつ /参加率/
さんかりょう /参加料/
さんかん /参観/山間/三巻/三韓/
さんかんおう /三冠王/
さんかんがく /産官学/
さんかんしおん /三寒四温/
さんかんしき /三管式/
さんかんせん /三冠戦/
さんかんちゅうしんちゅう /三環中心柱/
さんかんば /三冠馬/
さんかんび /参観日/
さんかんぶ /山間部/
さんが /参賀/山河/
さんがい /三階/惨害/三界/
さんがく /山岳/産学/産額/算額/
さんがくおう /山岳王/
さんがくかい /山岳会/
さんがくかん /産学官/
さんがくきょうどう /産学共同/
さんがくくかん /山岳区間/
さんがくしゃしん /山岳写真/
さんがくせん /山岳線/
さんがくたび /山岳旅/
さんがくちたい /山岳地帯/
さんがくぶけい /山岳部系/
さんがくよう /山岳用/
さんがくりん /山岳林/
さんがくれっしゃ /山岳列車/
さんがくろせん /山岳路線/
さんがつ /三月/３月/弥生/
さんがにち /三が日/三箇日/
さんがね /三ケ根/
さんがねさん /三ヶ根山/
さんがん /三眼/三願/
さんがんし /三眼視/
さんき /算機/三機/
さんきし /三騎士/
さんきち /三吉/
さんきゃく /三脚/
さんきゃくしよう /三脚使用/
さんきゃくぶぶん /三脚部分/
さんきゃくよう /三脚用/
さんきゅう /産休/山九/三級/
さんきゅうだん /三球団/
さんきょう /山峡/三共/三強/三協/
さんきょうしょうじ /三協商事/
さんきょうせいやく /三共製薬/
さんきょうだい /三兄弟/
さんきょくめ /三曲目/
さんきん /三禁/
さんきんこうたい /参勤交替/参勤交代/
さんぎ /参議/
さんぎいん /参議院/
さんぎいんぎいん /参議院議員/
さんぎいんせんきょ /参議院選挙/
さんぎいんせんじ /参議院選時/
さんぎょう /産業/三行/
さんぎょうおうようぶもん /産業応用部門/
さんぎょうか /産業化/
さんぎょうかい /産業界/
さんぎょうかいかん /産業会館/
さんぎょうかくめい /産業革命/
さんぎょうかくめいじだい /産業革命時代/
さんぎょうかつどう /産業活動/
さんぎょうきかい /産業機械/
さんぎょうきょうかい /産業協会/
さんぎょうこうがっか /産業工学科/
さんぎょうこうきょう /産業公共/
さんぎょうこうぞう /産業構造/
さんぎょうしせつ /産業施設/
さんぎょうしゃかい /産業社会/
さんぎょうしゃかいいこう /産業社会以降/
さんぎょうしゃかいいぜん /産業社会以前/
さんぎょうしゃりょう /産業車両/
さんぎょうしょう /産業省/
さんぎょうじょう /産業上/
さんぎょうじょうほう /産業情報/
さんぎょうてき /産業的/
さんぎょうとしょ /産業図書/
さんぎょうどうろ /産業道路/
さんぎょうどくせんか /産業独占化/
さんぎょうはいきぶつ /産業廃棄物/
さんぎょうべつ /産業別/
さんぎょうぼうえき /産業貿易/
さんぎょうぼうえきかん /産業貿易館/
さんぎょうめ /3行目/
さんぎょうよう /産業用/
さんく /産駒/
さんぐう /参宮/
さんぐらす /サングラス/
さんぐん /三軍/
さんけ /産気/三家/
さんけい /産経/山系/参詣/散形/
さんけいえん /三渓園/
さんけいおおさかはい /産経大阪杯/
さんけいかじょ /散形花序/
さんけいしょう /産経賞/
さんけいしんぶん /産経新聞/
さんけいしんぶんしゃ /産経新聞社/
さんけた /三桁/
さんけたていど /三桁程度/
さんけたほう /三桁法/
さんけつ /酸欠/三傑/
さんけつし /酸欠死/
さんけつじょうたい /酸欠状態/
さんけん /三研/散見/三権/三軒/産研/
さんけんぶんりつ /三権分立/
さんげ /散華/
さんげき /惨劇/
さんげたん /參鶏湯/
さんげん /山弦/三元/
さんげんしょく /三原色/
さんげんじゃや /三軒茶屋/
さんげんじゃやほうめん /三軒茶屋方面/
さんげんぢゃや /三軒茶屋/
さんこ /3個/三顧/
さんこう /参考/山行/3項/三項/三高/三興/三光/三晃/三江/三皇/
さんこういけん /参考意見/
さんこうかんけい /3項関係/
さんこうきせん /三光汽船/
さんこうざい /散孔材/
さんこうしつ /参考室/
さんこうしゅってん /参考出展/
さんこうしゅっぴん /参考出品/
さんこうしょ /参考書/
さんこうしょせき /参考書籍/
さんこうしょるい /参考書類/
さんこうしりょう /参考資料/
さんこうじこう /参考事項/
さんこうず /参考図/
さんこうせいうん /散光星雲/
さんこうせん /三江線/
さんこうち /参考値/
さんこうていど /参考程度/
さんこうとしょ /参考図書/
さんこうにん /参考人/
さんこうぶんけん /参考文献/
さんこうぶんけんなど /参考文献等/
さんこうぶんけんめい /参考文献名/
さんこうぶんれい /参考文例/
さんこうもく /3項目/
さんこうれいぶん /参考例文/
さんこうろんぶん /参考論文/
さんこのれい /三顧の礼/
さんご /珊瑚/産後/
さんごう /三劫/三号/参號/三郷/
さんごうかん /三号館/
さんごかい /珊瑚海/
さんごかいかいせん /珊瑚海海戦/
さんごく /三国/三石/
さんごくし /三国志;中国の歴史書。正史のひとつ。著者は陳寿/三国史/
さんごくしかんけい /三国史関係/
さんごくしじだい /三国史時代/
さんごくじだい /三国時代/
さんごくどうめい /三国同盟/
さんごしょう /珊瑚礁/
さんごせい /珊瑚製/
さんさ /三叉/
さんさい /三才/山菜/三歳/
さんさく /散策/散索/
さんさくどう /散策道/
さんさくひん /三作品/
さんさつ /三冊/
さんさろ /三叉路/
さんさん /三々/燦々/
さんさんごご /三々五々/
さんさんななびょうし /三三七拍子/
さんざい /散財/散在/
さんざん /散々/惨々/
さんし /三枝/三誌/産仔/
さんしあい /三試合/
さんした /三下/
さんしまい /三姉妹/
さんしゃ /三者/三社/三舎/山車/
さんしゃいん /サンシャイン/
さんしゃきょうどう /三社共同/
さんしゃく /参酌/
さんしゃくだま /三尺玉/
さんしゃさんよう /三者三様/
さんしゃぼんたい /三者凡退/
さんしゅ /三種/
さんしゅう /参集/3週/
さんしゅうかん /三週間/
さんしゅうしゃ /三修社/
さんしゅうめ /三週目/
さんしゅつ /算出/産出/
さんしゅつかんすう /算出関数/
さんしゅつきじゅん /算出基準/
さんしゅつけっか /算出結果/
さんしゅつずひょう /算出図表/
さんしゅつふくよう /３出複葉/
さんしゅつほう /算出法/
さんしゅつほうほう /算出方法/
さんしゅつりょう /産出量/
さんしゅるい /三種類/
さんしょ /山椒/
さんしょう /参照/三章/三唱/山椒/三賞/酸漿/
さんしょううお /鯢/山椒魚/
さんしょうかしょ /参照箇所/
さんしょうかんけい /参照関係/
さんしょうしんごう /参照信号/
さんしょうじ /参照時/
さんしょうすう /参照数/
さんしょうせん /参照線/
さんしょうち /参照値/
さんしょうてん /参照点/
さんしょうでんきょく /参照電極/
さんしょうとうめいせい /参照透明性/
さんしょうはんい /参照範囲/
さんしょうほう /参照法/
さんしょうみつど /参照密度/
さんしょうめん /参照面/
さんしょうもと /参照元/
さんしょうよう /参照用/
さんしょうよび /参照呼び/
さんしょうわく /参照枠/
さんしょく /三色/三食/蚕食/
さんしょくき /三色旗/
さんしろう /三四郎/三士郎/
さんしろういけ /三四郎池/
さんしん /三振/三信/三進/
さんしんき /三神器/
さんしんご /三振後/
さんしんすう /三振数/
さんしんだつしゅ /三振奪取/
さんしんとうない /三親等内/
さんしんびる /三信ビル/
さんじ /参事/三次/3時/産児/３次/惨事/賛辞/三時/3次/讃辞/
さんじかい /三次会/
さんじかん /3時間/参事官/
さんじく /三軸/
さんじげん /３次元/三次元/3次元/
さんじげんくうかん /三次元空間/
さんじげんぶったい /３次元物体/
さんじみゃく /三次脈/
さんじゃく /三尺/
さんじゃくだま /三尺玉/
さんじゅう /三十/三重/卅/
さんじゅういちじょう /三一条/
さんじゅうく /三重苦/
さんじゅうさつ /三重殺/
さんじゅうさんげんどう /三十三間堂/三十三間堂 /
さんじゅうし /三銃士/
さんじゅうしょう /三重唱/
さんじゅうじ /三重字/
さんじゅうすうねん /三十数年/
さんじゅうすうまい /三十数枚/
さんじゅうそう /三重奏/
さんじゅうそうきょく /三重奏曲/
さんじゅうたいかくか /三重対角化/
さんじゅうだい /三十代/
さんじゅうにん /三十人/
さんじゅうにんまち /三十人町/
さんじゅうのとう /三重塔/
さんじゅうまんえん /三十万円/
さんじゅうろう /三十郎/
さんじゅつ /算術/
さんじゅつえんざん /算術演算/
さんじゅつえんざんし /算術演算子/
さんじゅつか /算術化/
さんじゅつかいほう /算術解法/
さんじゅつかんすう /算術関数/
さんじゅつがた /算術型/
さんじゅつけいさん /算術計算/
さんじゅつしき /算術式/
さんじゅつしょ /算術書/
さんじゅつてき /算術的/
さんじゅん /相俊/
さんじょ /賛助/三女/
さんじょう /参上/三条/惨状/山上/三條/三乗/
さんじょうえき /三条駅/
さんじょうかいかん /山上会館/
さんじょうかん /三条間/
さんじょうき /三畳紀/
さんじょうけいはん /三条京阪/
さんじょうけいはんまえ /三条京阪前/
さんじょうしんまち /三条新町/
さんじょうちょう /三条町/
さんじょうほうめん /三条方面/
さんじょかいいん /賛助会員/
さんじょかいいんしゃ /賛助会員社/
さんじょきん /賛助金/
さんじょく /産褥/
さんすい /山水/散水/撤水/
さんすいでんき /山水電気/
さんすう /算数/
さんすうか /三数花/
さんすうかじゅぎょう /算数科授業/
さんすうけんてい /算数検定/
さんすくみ /三竦み/
さんすんだま /三寸玉/
さんず /三途/
さんずのかわ /三途の川/
さんずん /三寸/
さんせい /賛成/参政/酸性/三世/三精/三星/惨凄/惨悽/産生/
さんせいいけん /賛成意見/
さんせいう /酸性雨/
さんせいかはんすう /賛成過半数/
さんせいがわ /賛成側/
さんせいきじ /賛成記事/
さんせいぎろん /賛成議論/
さんせいけん /参政権/
さんせいこ /酸性湖/
さんせいし /酸性紙/
さんせいしゃ /賛成者/三世社/
さんせいしゃたすう /賛成者多数/
さんせいしょくひん /酸性食品/
さんせいすい /酸性水/
さんせいすいようえきちゅう /酸性水溶液中/
さんせいたすう /賛成多数/
さんせいとうひょう /賛成投票/
さんせいとうひょうすう /賛成投票数/
さんせいど /酸性度/
さんせいどう /三省堂/
さんせいどうしょてん /三省堂書店/
さんせいどうほんてん /三省堂本店/
さんせいは /賛成派/
さんせいはがわ /賛成派側/
さんせいはしゅさい /賛成派主催/
さんせいはんたい /賛成反対/
さんせいひょう /賛成票/
さんせいひょうめい /賛成表明/
さんせいようえきちゅう /酸性溶液中/
さんせいりゆう /賛成理由/
さんせいろん /賛成論/
さんせき /山積/
さんせつこん /三節棍/
さんせん /参戦/
さんせんくかん /三線区間/
さんせんべん /三尖弁/
さんぜん /燦然/
さんぜんいん /三千院/
さんぜんえん /三千円/
さんぜんり /三千里/
さんそ /酸素/
さんそう /三層/山荘/三索/三相/惨愴/酸愴/散層/
さんそうこうりゅう /三相交流/
さんそきょうきゅう /酸素供給/
さんそきょうきゅうのうりょく /酸素供給能力/
さんそきょうきゅうりょう /酸素供給量/
さんそぎょらい /酸素魚雷/
さんそけつぼうしょう /酸素欠乏症/
さんそこうぎょう /酸素工業/
さんそこきゅう /酸素呼吸/
さんそせっしゅのうりょく /酸素摂取能力/
さんそたいしゃ /酸素代謝/
さんそちゅうどく /酸素中毒/
さんそどういたいひ /酸素同位体比/
さんそのうど /酸素濃度/
さんそぶそく /酸素不足/
さんそぶんあつ /酸素分圧/
さんそん /山村/
さんぞう /三蔵/
さんぞうほうし /三蔵法師/
さんぞく /山賊/
さんぞくせい /三属性/
さんぞくなべ /山賊鍋/
さんぞくばん /山賊版/
さんぞくやき /山賊焼き/
さんたい /三体/算体/
さんたく /三択/
さんたま /三多摩/
さんたろう /三太郎/
さんたん /賛嘆/惨憺/惨澹/讃嘆/讃歎/
さんたんし /三端子/
さんだ /三田/
さんだい /三大/参内/三台/散大/三代/
さんだいきょうそ /三代教祖/
さんだいばなし /三題話/
さんだいめ /三代目/
さんだいりょうり /三大料理/
さんだつ /簒奪/
さんだや /三田屋/
さんだゆう /三太夫/
さんだん /三段/散弾/算段/
さんだんかい /三段階/
さんだんきょう /三段峡/
さんだんげり /三段蹴り/
さんだんじゅう /散弾銃/
さんだんとび /三段跳び/
さんだんめ /三段目/
さんだんろんぽう /三段論法/
さんち /産地/山地/三値/
さんちちょくそう /産地直送/
さんちゃく /三着/参着/
さんちゃほう /三家和/
さんちゅう /山中/
さんちゅうごえ /山中越/
さんちょう /山頂/
さんちょうきんぺん /山頂近辺/
さんちょうふきん /山頂付近/
さんちょうめ /三丁目/
さんちょうゆうえんち /山頂遊園地/
さんつう /三通/
さんてい /算定/算程/
さんていばん /三訂版/
さんていほう /算定法/
さんてつ /三鉄/
さんてん /…/3点/三点/
さんてんせいやく /参天製薬/
さんてんていい /三点定位/
さんてんとうし /三点透視/
さんと /三斗/三都/
さんとう /三東/三島/三等/山東/三頭/
さんとうか /山頭火/
さんとうはんとう /山東半島/
さんとうぶん /三等分/
さんとうへい /三等兵/
さんとおり /3通り/
さんとりーほーる /サントリーホール/
さんど /三度/
さんどう /賛同/参道/
さんどうしゃ /賛同者/
さんどうしょ /賛同書/
さんどがさ /三度笠/
さんどぬり /三度塗/
さんどめ /三度目/
さんない /山内/
さんなん /三男/山南/
さんにゅう /参入/算入/
さんにゅうじ /参入時/
さんにん /三人/3人/３人/
さんにんいじょう /三人以上/
さんにんぐみ /三人組/
さんにんさんよう /三人三様/
さんにんしまい /三人姉妹/
さんにんしょう /三人称/
さんにんたび /三人旅/
さんにんむすめ /三人娘/
さんにんめ /三人目/
さんねん /三年/３年/
さんねんいか /三年以下/
さんねんいじょう /三年以上/
さんねんご /三年後/
さんねんざか /三年坂/
さんねんじ /三年時/三年次/
さんねんせい /三年生/3年生/
さんねんまえ /三年前/
さんのう /山王/
さんのうびょういん /山王病院/
さんのへ /三戸/
さんのまる /三の丸/
さんのみや /三宮/三の宮/
さんのみやえき /三宮駅/
さんのみやかん /三宮間/
さんのみやきんぺん /三宮近辺/
さんのみやこうかした /三宮高架下/
さんはい /山廃/
さんはんきかん /三半器官/
さんば /産婆/三羽/
さんばい /三倍/三杯/
さんばいず /三杯酢/
さんばいぞうじょうしゅ /三倍増醸酒/
さんばかたいしょう /三馬鹿大将/
さんばがらす /三羽烏/
さんばし /桟橋/棧橋/
さんばそう /三番叟/
さんばば /三婆/
さんばりー /サンバリー/
さんばん /三番/
さんばんかん /三番館/
さんばんがい /三番街/
さんばんちょう /三番町/
さんばんめ /三番目/3番目/
さんぱ /三派/
さんぱい /参拝/惨敗/贊拜/
さんぱく /三拍/三泊/
さんぱつ /散髪/散発/三発/
さんぱつご /散髪後/
さんぱつてき /散発的/
さんぱつや /散髪屋/
さんぱつりょう /散髪料/
さんび /賛美/讃美/
さんびか /賛美歌/
さんびき /三匹/
さんびゃく /三百/
さんびゃくにんまち /三百人町/
さんびゃくねんかん /三百年間/
さんびょうし /三拍子/
さんぴ /賛否/
さんぴあざ /サンピアザ/
さんぴほりゅう /賛否保留/
さんぴりょうろん /賛否両論/
さんぴん /三一/
さんふくせん /三複線/
さんふじんか /産婦人科/
さんふらんしすこ /桑港/
さんぶ /三部/山武/三分/
さんぶぐん /山武郡/
さんぶさく /三部作/
さんぶつ /産物/
さんぶん /散文/三分/
さんぶんかつあん /三分割案/
さんぶんしてき /散文詩的/
さんぶんてき /散文的/
さんぶんるい /三分類/
さんぷ /算譜/散布/撒布/産婦/
さんぷく /山腹/
さんぷげんご /算譜言語/
さんぷげんごろん /算譜言語論/
さんぷず /散布図/
さんぷたい /撒布体/
さんぷらざ /サンプラザ/
さんぷりんぐ /サンプリング/
さんぷる /サンプル/
さんぷん /三分/
さんぷんかん /三分間/
さんへいほう /三平方/
さんべんしゅ /三鞭酒/
さんぺい /三平/散兵/
さんぺいじる /三平汁/
さんぺいせん /散兵線/
さんほうこう /三方向/
さんぼう /参謀/三方/
さんぼうほんぶ /参謀本部/
さんぼうほんぶない /参謀本部内/
さんぼく /山北/
さんぼだい /三菩提/
さんぼん /三本/≡/
さんぼんあし /三本足/
さんぼんがわ /三本川/
さんぼんぎ /三本木/
さんぼんじめ /三本締め/
さんぼんだて /三本建/
さんぼんばしら /三本柱/
さんぼんまつ /三本松/
さんぼんめ /三本目/
さんぼんゆび /三本指/
さんぽ /散歩/
さんぽう /算法/山砲/三宝/三方/纂法/
さんぽういん /三宝院/
さんぽうげんご /算法言語/
さんぽみち /散歩道/
さんま /秋刀魚/
さんまい /三枚/三昧/
さんまいめ /三枚目/
さんまきめ /三巻目/
さんまん /散漫/三万/
さんまんすうせん /三万数千/
さんみ /酸味/三位/
さんみいったい /三位一体/三身一体/
さんみゃく /山脈/三藐/
さんめい /三名/賛明/3名/山名/
さんめん /三面/
さんめんず /三面図/3面図/
さんめんちょうてん /三面頂点/
さんもく /三目/
さんもじ /3文字/三文字/
さんもん /三文/山門/
さんもんおぺら /三文オペラ/
さんもんばん /三文判/
さんや /山谷/山野/
さんやく /三役/
さんやくいじょう /三役以上/
さんやくけいけん /三役経験/
さんゆ /産油/
さんゆうかん /三遊間/
さんゆうてい /三遊亭/
さんゆこく /産油国/
さんよ /参与/贊譽/參與/
さんよう /三洋/山陽/算用/山容/
さんようかんこうでんしゃ /山陽緩行電車/
さんようぐんま /三洋群馬/
さんようしょうかい /三陽商会/
さんようしょうけん /三洋証券/
さんようしょうじ /三洋商事/
さんようしんかんせん /山陽新幹線/
さんようしんぶん /山陽新聞/
さんようじ /山陽路/
さんようじどうしゃどう /山陽自動車道/
さんようすうじ /算用数字/
さんようせん /山陽線/
さんようせんじゅんきゅう /山陽線準急/
さんようせんない /山陽線内/
さんようそ /三要素/
さんようちく /山陽地区/
さんようちゅう /三葉虫/
さんようてつどう /山陽鉄道/
さんようでんき /三洋電機/
さんようでんしゃ /山陽電車/
さんようでんてつ /山陽電鉄/
さんようとっきゅう /山陽特急/
さんようどう /山陽道/
さんようどうけいゆ /山陽道経由/
さんようひめじ /山陽姫路/
さんようほうそう /山陽放送/
さんようほうめん /山陽方面/
さんようほんせん /山陽本線/
さんらく /三楽/
さんらん /散乱/産卵/
さんらんかく /散乱角/
さんらんき /産卵期/
さんらんけい /産卵鶏/
さんらんげん /散乱源/
さんらんこう /散乱光/
さんらんしょう /産卵床/
さんらんじょう /産卵場/
さんらんせん /散乱線/
さんらんそう /産卵槽/
さんらんたい /散乱体/
さんらんてん /散乱点/
さんらんは /散乱波/
さんらんはんしゃ /散乱反射/
さんらんばこ /産卵箱/
さんらんばしょ /産卵場所/
さんらんほうほう /産卵方法/
さんらんほせい /散乱補正/
さんらんりろん /散乱理論/
さんりく /三陸/
さんりくかいがん /三陸海岸/
さんりづか /三里塚/
さんりゅう /三流/
さんりゅうしゅ /散粒種/
さんりゅうしゅっぱん /三流出版/
さんりゅうてつがくしゃ /二流哲学者/
さんりょう /算料/三稜/
さんりょうけい /三稜形/
さんりん /山林/
さんりんか /三輪花/
さんりんしゃ /三輪車/
さんりんじてんしゃ /三輪自転車/
さんりんじぬし /山林地主/
さんりんよう /三輪用/
さんるい /三塁/
さんるいがわ /三塁側/
さんるいしゅ /三塁手/
さんるいせん /三塁線/
さんるいそうしゃ /三塁走者/
さんるいだ /三塁打/
さんれつ /参列/3列/三裂/
さんれつしゃ /参列者/
さんれん /三連/
さんれんきゅう /三連休/
さんれんしょう /三連勝/
さんれんせい /三連星/
さんれんせん /三連戦/
さんれんぞく /三連続/
さんれんぱ /三連覇/
さんれんぱい /三連敗/
さんれんぷ /三連符/
さんろうた /三朗太/
さんろく /山麓/
さんわ /三和/三話/三羽/
さんわぎんこう /三和銀行/
さんわこうさん /三和興産/
さんわせいさくしょ /三和製作所/
ざ /座/挫/坐/蔵/左/藏/
ざい /在/財/材/剤/罪/済/才/西/斉/劑/濟/戝/
ざいあく /罪悪/
ざいあくかん /罪悪感/
ざいあくし /罪悪視/
ざいい /在位/
ざいいきかん /在位期間/
ざいえい /在英/
ざいおう /在欧/
ざいか /在荷/財貨/罪科/罰科/
ざいかい /財界/在会/
ざいかいじん /財界人/
ざいかん /在官/
ざいかんちゅう /在官中/
ざいがい /在外/
ざいがいけんきゅういん /在外研究員/
ざいがいこくにほんじん /在外国日本人/
ざいがいほうじん /在外邦人/
ざいがく /在学/
ざいがくしゃ /在学者/
ざいがくしょうめいしょ /在学証明書/
ざいがくせい /在学生/
ざいがくちゅう /在学中/
ざいきょう /在京/
ざいきん /在勤/
ざいぎょう /罪業/
ざいく /細工/
ざいけい /財形/財経/
ざいけいちょちく /財形貯蓄/
ざいけいほうていしゅぎ /罪刑法定主義/
ざいげん /財源/罪滅/
ざいげんかくほ /財源確保/
ざいこ /在庫/財庫/
ざいこう /在校/在広/
ざいこかんり /在庫管理/
ざいこくがい /在国外/
ざいこしょぶん /在庫処分/
ざいこじたい /在庫自体/
ざいこちょうせい /在庫調整/
ざいこひん /在庫品/
ざいこひんはんばい /在庫品販売/
ざいこぶそく /在庫不足/
ざいさん /財産/
ざいさんけん /財産権/
ざいさんぜい /財産税/
ざいさんてき /財産的/
ざいしつ /材質/在室/
ざいしつひょうじ /材質表示/
ざいしゃ /在社/
ざいしょ /在所/
ざいしょく /在職/
ざいしょくしょうめい /在職証明/
ざいしょくちゅう /在職中/
ざいじゅう /在住/
ざいじゅうしゃ /在住者/
ざいじょう /罪状/
ざいす /座椅子/
ざいせい /財政/
ざいせいししゅつ /財政支出/
ざいせいじじょう /財政事情/
ざいせいたんとう /財政担当/
ざいせいてき /財政的/
ざいせいてきこんなん /財政的困難/
ざいせいてきじょうきょう /財政的状況/
ざいせいなん /財政難/
ざいせき /在籍/在席/材積/
ざいせきしゃ /在籍者/
ざいせきじ /在籍時/
ざいせきちゅう /在籍中/
ざいせん /在仙/
ざいぜん /財前/
ざいたく /在宅/
ざいたくきんむ /在宅勤務/
ざいだん /財団/
ざいだんほうじん /財団法人/
ざいちゅう /在中/
ざいつ /財津/
ざいつかずお /財津和夫/
ざいとう /財投/
ざいに /在荷/
ざいにしかいがん /在西海岸/
ざいにち /在日/
ざいにちかんこく /在日韓国/
ざいにちかんこくじん /在日韓国人/
ざいにちちゅう /在日中/
ざいにちちゅうごくじん /在日中国人/
ざいにちちょうせんじん /在日朝鮮人/
ざいにちべいぐん /在日米軍/
ざいにっぽん /在日本/
ざいにん /在任/罪人/
ざいにんきかんちゅう /在任期間中/
ざいにんちゅう /在任中/
ざいはく /財帛/
ざいば /在場/
ざいばつ /財閥/
ざいぶつ /財物/
ざいべい /在米/
ざいほう /財宝/
ざいま /在間/
ざいむ /財務/
ざいむしょう /財務省;大蔵省が2001年1月の中央省庁再編で再編されたもの/
ざいむしょひょう /財務諸表;事業報告書、損益計算書、貸借対照表、キャシュフロー計算書、付属明細表、剰余金処分案の6つ/
ざいむじょうたい /財務状態/
ざいむないよう /財務内容/
ざいめい /罪名/
ざいもく /材木/
ざいもくざかいがん /材木座海岸/
ざいもくや /材木屋/材木谷/
ざいや /在野/
ざいらい /在来/
ざいらいえき /在来駅/
ざいらいがた /在来型/
ざいらいぎじゅつ /在来技術/
ざいらいしゃ /在来車/
ざいらいしゅ /在来種/
ざいらいせん /在来線/
ざいらいせんがたとっきゅう /在来線型特急/
ざいらいせんくかん /在来線区間/
ざいらいせんけいゆ /在来線経由/
ざいらいせんけいゆう /在来線経由/
ざいらいせんこうそくか /在来線高速化/
ざいらいせんのりつぎ /在来線乗継/
ざいらいせんりょこう /在来線旅行/
ざいらいてつどう /在来鉄道/
ざいらいとっきゅう /在来特急/
ざいらんようぼうし /剤乱用防止/
ざいりゅう /在留/
ざいりょう /材料/在寮/
ざいりょうかいはつ /材料開発/
ざいりょうかがく /材料科学/
ざいりょうがっか /材料学科/
ざいりょうきょうど /材料強度/
ざいりょうけい /材料系/
ざいりょうけんきゅうしつ /材料研究室/
ざいりょうこうがく /材料工学/
ざいりょうこうがくぶ /材料工学部/
ざいりょうこうがっか /材料工学科/
ざいりょうだい /材料代/
ざいりょうてき /材料的/
ざいりょうとくせい /材料特性/
ざいりょうひ /材料費/
ざいりょうぶ /材料部/
ざいりょく /財力/
ざう /座右/
ざえもん /左衛門/
ざお /竿/
ざおう /蔵王/
ざおうおんせん /蔵王温泉/
ざおうおんせんがい /蔵王温泉街/
ざおうかん /蔵王間/
ざおうちょう /蔵王町/
ざか /坂/
ざがく /座学/
ざがね /座金/
ざき /崎/嵜/
ざぎょう /ザ行/
ざくつ /座屈/
ざくろ /榴/柘榴/
ざけ /酒/
ざこ /座古/雑喉/雑魚/
ざこう /座高/
ざこうさ /座高差/
ざこうじ /座光寺/
ざこたらず /座高不足/
ざこつ /坐骨/
ざこね /雑寝/
ざこば /雑喉場/
ざし /座視/
ざしき /座敷/
ざしきでんしゃ /座敷電車/
ざしきれっしゃ /座敷列車/
ざしきろう /座敷牢/
ざしきわらし /座敷童/
ざしつ /座室/
ざしゅ /座種/
ざしょう /座礁/挫傷/坐礁/
ざせき /座席/
ざせきかくほ /座席確保/
ざせきかん /座席間/
ざせきけん /座席券/
ざせきした /座席下/
ざせきしてい /座席指定/
ざせきしていけん /座席指定券/
ざせきしていせい /座席指定制/
ざせきしゃ /座席車/
ざせきしゅうのうがた /座席収納型/
ざせきしよう /座席使用/
ざせきしようじ /座席使用時/
ざせきじたい /座席自体/
ざせきすう /座席数/
ざせきぜんご /座席前後/
ざせきていいん /座席定員/
ざせきはいち /座席配置/
ざせきばんごう /座席番号/
ざせきひょう /座席表/
ざせきよやく /座席予約/
ざせきりつ /座席率/
ざせきわく /座席枠/
ざせつ /挫折/
ざせつかん /挫折感/
ざせつしゃ /挫折者/
ざぜん /座禅/坐禅/
ざぞう /座像/
ざた /沙汰/
ざたく /座卓/
ざだん /座談/
ざだんかい /座談会/
ざちょう /座長/
ざっか /雑貨/
ざっかてん /雑貨店/
ざっかはんばい /雑貨販売/
ざっかや /雑貨屋/
ざっかん /雑感/
ざっき /雑記/
ざっきちょう /雑記帳/
ざっきょ /雑居/
ざっきん /雑菌/
ざっけん /雑件/
ざっこく /雑穀/
ざっし /雑誌/
ざっしかい /雑誌会/
ざっしきじ /雑誌記事/
ざっしきょうかい /雑誌協会/
ざっしけいさいじ /雑誌掲載時/
ざっしこうこく /雑誌広告/
ざっししゃ /雑誌社/
ざっししょもつ /雑誌書物/
ざっしじょう /雑誌上/
ざっしたんか /雑誌単価/
ざっしだい /雑誌代/
ざっしとう /雑誌等/
ざっしなど /雑誌等/
ざっしへんしゅうがいしゃ /雑誌編集会社/
ざっしへんしゅうしゃ /雑誌編集者/
ざっしべつ /雑誌別/
ざっしほんたい /雑誌本体/
ざっしめい /雑誌名/
ざっしゅ /雑種/
ざっしゅうにゅう /雑収入/
ざっしゅきょうせい /雑種強勢/
ざっしょく /雑食/雑色/
ざっしょくせい /雑食性/
ざっしょくどうぶつ /雑食動物/
ざっしよう /雑誌用/
ざっしるい /雑誌類/
ざっしれんさい /雑誌連載/
ざっしれんさいじ /雑誌連載時/
ざっしれんさいちゅう /雑誌連載中/
ざっそう /雑草/
ざっそく /雑則/
ざった /雑多/
ざっとう /雑踏/雑沓/
ざっぱ /雑破/雑把/
ざっぱく /雑駁/
ざっぴ /雑費/
ざっぽう /雑報/
ざつ /雑/襍/雜/
ざつえき /雑益/雑役/
ざつおん /雑音/
ざつおんか /雑音下/
ざつおんしんごう /雑音信号/
ざつおんじょきょ /雑音除去/
ざつおんじょきょほう /雑音除去法/
ざつおんぶぶん /雑音部分/
ざつおんよくあつ /雑音抑圧/
ざつおんよくあつこうか /雑音抑圧効果/
ざつおんよくあつしゅほう /雑音抑圧手法/
ざつおんよくあつしょり /雑音抑圧処理/
ざつおんよくせい /雑音抑制/
ざつおんよくせいこうか /雑音抑制効果/
ざつおんよくせいしゅほう /雑音抑制手法/
ざつがく /雑学/
ざつがくちしき /雑学知識/
ざつがくていど /雑学程度/
ざつがくぼん /雑学本/
ざつぎだん /雑技団/
ざつぎだんげきじょう /雑技団劇場/
ざつぎょ /雑魚/
ざつさぎょう /雑作業/
ざつじ /雑事/
ざつぜん /雑然/
ざつだん /雑談/
ざつだんはんぶん /雑談半分/
ざつだんふう /雑談風/
ざつねん /雑念/
ざつのう /雑嚢/
ざつはいすい /雑排水/
ざつぶつ /雑物/
ざつぶん /雑文/
ざつみんとう /雑民党/
ざつむ /雑務/
ざつよう /雑用/
ざつようがかり /雑用係/
ざとう /座頭/
ざとういち /座頭市/
ざね /実/
ざひょう /座標/
ざひょうけい /座標系/
ざひょうけいさん /座標計算/
ざひょうじく /座標軸/
ざひょうち /座標値/
ざひょうにゅうりょく /座標入力/
ざひょうひょうじ /座標表示/
ざひょうへんかん /座標変換/
ざぶとん /座布団/
ざぶろう /三郎/
ざま /座間/
ざまし /座間市/
ざまみ /座間見/
ざめん /座面/
ざやく /座薬/坐薬/
ざゆう /座右/
ざら /皿/
ざり /座利/
ざりがに /蜊蛄/
ざる /笊/
ざるご /笊碁/
ざるそば /笊蕎麦/
ざれごと /戯事/戯言/
ざわ /沢/澤/
ざん /残/暫/斬/慙/山/惨/算/塹/嶄/巉/慘/慚/懺/懴/殘/竄/讒/鏨/参/
ざんあつけい /残圧計/
ざんい /残遺/
ざんかん /斬奸/斬姦/
ざんがい /残骸/斬刈/
ざんがく /残額/
ざんき /残機/慙愧/慙悸/慚愧/残基/
ざんきゅう /斬級/
ざんきょう /残響/
ざんきょうおん /残響音/
ざんきょうおんじょう /残響音場/
ざんきょうかん /残響感/
ざんきょうしつ /残響室/
ざんきょうじかん /残響時間/
ざんきょうせい /残響性/
ざんきょうりろん /残響理論/
ざんきりょう /残気量/
ざんきん /残金/
ざんぎゃく /残虐/
ざんぎゃくこうい /残虐行為/
ざんぎゃくじけん /残虐事件/
ざんぎゃくひどう /残虐非道/
ざんぎょう /残業/
ざんぎょうしょく /残業食/
ざんぎょうしんこく /残業申告/
ざんぎょうじかん /残業時間/
ざんぎょうだい /残業代/
ざんぎょうてあて /残業手当/
ざんぎょうでい /残業デイ/
ざんくろう /斬九郎/
ざんけん /残件/
ざんげ /懺悔/慚悔/
ざんげん /讒言/
ざんこく /残酷/
ざんごう /塹壕/
ざんさ /残差/
ざんさい /斬衰/残滓/
ざんさぎょう /残作業/
ざんさけいれつ /残差系列/
ざんさつ /惨殺/
ざんさひょうかち /残差評価値/
ざんさぶんぷ /残差分布/
ざんさへいほうわ /残差平方和/
ざんさほうていしき /残差方程式/
ざんし /残滓/惨死/慙死/
ざんしゃ /讒者/
ざんしゅ /斬首/
ざんしょ /残暑/
ざんしょう /残照/
ざんしょみまい /残暑見舞い/残暑見舞/
ざんしん /斬新/嶄新/
ざんじ /暫時/
ざんじつろく /残日録/
ざんじんざんば /斬人斬馬/
ざんすう /残数/
ざんせき /残席/
ざんせつ /残雪/
ざんせつき /残雪期/
ざんぜつ /嶄絶/
ざんぜん /嶄然/
ざんそん /残存/
ざんぞう /残像/残象/
ざんぞうげんしょう /残像現象/
ざんぞん /残存/
ざんぞんちょうや /残存聴野/
ざんぞんぶんれつそしき /残存分裂組織/
ざんぞんりつ /残存率/
ざんぞんりょう /残存量/
ざんだか /残高/
ざんだかしょうかい /残高照会/
ざんだかぶそく /残高不足/
ざんだんすう /残弾数/
ざんち /残置/
ざんてい /暫定/
ざんていあん /暫定案/
ざんていいいん /暫定委員/
ざんていいいんかい /暫定委員会/
ざんていかい /暫定解/
ざんていかいぎょう /暫定開業/
ざんていかんりにん /暫定管理人/
ざんていしょち /暫定処置/
ざんていしょり /暫定処理/
ざんていじょうきょう /暫定状況/
ざんていそち /暫定措置/
ざんていてき /暫定的/
ざんていてきかいしゃく /暫定的解釈/
ざんていてきようそ /暫定的要素/
ざんていばん /暫定版/
ざんとう /残党/
ざんどすう /残度数/
ざんにっすう /残日数/
ざんにん /残忍/惨忍/
ざんねん /残念/
ざんねんかい /残念会/
ざんねんしごく /残念至極/
ざんねんしょう /残念賞/
ざんねんむねん /残念無念/
ざんばつ /斬伐/
ざんぱい /惨敗/
ざんぱん /残飯/
ざんぴん /残品/
ざんぶ /残部/
ざんぶん /残分/
ざんぺん /残片/
ざんぼう /讒謗/
ざんまい /三昧/三味/
ざんむ /残務/
ざんむしょり /残務処理/
ざんよ /残余/殘餘/
ざんよさん /残予算/
ざんりゅう /残留/
ざんりゅういりゅうみん /在留居留民/
ざんりゅうかく /残留核/
ざんりゅうかち /残留価値/
ざんりゅうこじ /残留孤児/
ざんりゅうしねん /残留思念/
ざんりゅうじば /残留磁場/
ざんりゅうせんざい /残留洗剤/
ざんりゅうぶつ /残留物/
ざんりゅうほうしゃのう /残留放射能/
ざんりゅうようせい /残留要請/
ざんりょう /残量/残料/
ざんりょうけいこく /残量警告/
ざんりょうけいこくとう /残量警告灯/
ざんりょうひょうじ /残量表示/
ざんるい /残塁/
し /氏/子/誌/死/詩/詞/私/指/市/紙/師/使/視/旨/試/伺/姉/姿/至/志/士/覗/支/資/始/止/四/史/飼/紫/司/施/枝/思/歯/糸/岐/知/肢/仕/斯/雌/賜/諮/孜/脂/祉/獅/示/刺/屍/嗣/仔/柿/時/次/之/巳/嗜/偲/漬/侈/俟/卮/厮/厶/呰/咨/咫/啻/嗤/嘴/址/尸/屎/妛/巵/帋/幟/廝/弑/徙/恣/揣/摯/沚/泗/滓/熾/痣/祀/祠/祗/竢/笶/篩/粢/絲/緇/翅/耆/耜/肆/舐/茲/蚩/謚/諡/豕/貲/齎/趾/輜/釶/錙/阯/駟/駛/鷙/齒/恃/衰/梔/祇/此/匙/自/柴/芝/笥/弛/砥/髭/矢/茨/只/
しーずん /シーズン/
しーた /θ/
しーたは /θ波/
しーと /シート/
しーど /シード/
しーるど /シールド/
しーん /シーン/
しあい /試合/仕合/
しあいいがい /試合以外/
しあいうん /試合運/
しあいかいさい /試合開催/
しあいかいし /試合開始/
しあいかいしご /試合開始後/
しあいかいしじかん /試合開始時間/
しあいかいしちょくご /試合開始直後/
しあいかいしちょくぜん /試合開始直前/
しあいかいしまえ /試合開始前/
しあいかんせん /試合観戦/
しあいきぼう /試合希望/
しあいけいか /試合経過/
しあいけいしき /試合形式/
しあいけっか /試合結果/
しあいけっかほうこく /試合結果報告/
しあいこうしゃ /試合巧者/
しあいご /試合後/
しあいしゅうりょう /試合終了/
しあいしゅうりょうご /試合終了後/
しあいしゅうりょうじかん /試合終了時間/
しあいしゅつじょう /試合出場/
しあいしょうかすう /試合消化数/
しあいじかん /試合時間/
しあいじたい /試合自体/
しあいじゅん /試合順/
しあいすう /試合数/
しあいぜんたい /試合全体/
しあいぜんはん /試合前半/
しあいぞっこう /試合続行/
しあいちゅう /試合中/
しあいちゅうけい /試合中継/
しあいちょくぜん /試合直前/
しあいてんかい /試合展開/
しあいとうじつ /試合当日/
しあいとちゅう /試合途中/
しあいないよう /試合内容/
しあいないようてき /試合内容的/
しあいにってい /試合日程/
しあいび /試合日/
しあいふうけい /試合風景/
しあいぶん /試合分/
しあいほうき /試合放棄/
しあいまえ /試合前/
しあいよう /試合用/
しあいよそう /試合予想/
しあいよてい /試合予定/
しあがり /仕上がり/
しあげ /仕上/仕上げ/
しあげこう /仕上工/
しあたー /シアター/
しあつ /指圧/
しあつき /指圧器/
しあつし /指圧師/
しあつほう /指圧法/
しあわせ /幸せ/仕合せ/幸福/
しあん /思案/試案/シアン/私案/
しあんちゅう /思案中/
しい /椎/恣意/私意/思惟/資意/示威/肆意/
しいえき /志井駅/
しいか /詩歌/
しいがもと /椎本/
しいき /椎木/市域/篩域/
しいく /飼育/
しいくいん /飼育員/
しいくがかり /飼育係/
しいくじょうきょう /飼育状況/
しいくすい /飼育水/
しいくほうほう /飼育方法/
しいこうい /示威行為/
しいこうどう /示威行動/
しいざかな /強肴/
しいじ /椎路/
しいせい /恣意性/
しいた /θ/Θ/
しいたけ /椎茸/
しいだ /志井田/椎田/
しいて /強いて/
しいてき /恣意的/資意的/
しいな /椎名/椎菜/秕/粃/
しいなひゃっかてん /椎名百貨店/
しいなまこと /椎名誠/
しいなまち /椎名町/
しいの /椎野/
しいば /椎葉/
しいる /罔/
しいれ /仕入/仕入れ/
しいれかかく /仕入価格/
しいれね /仕入値/
しいれぶ /仕入部/
しいん /子音/試飲/死因/
しいんぎょう /子音行/
しいんしつ /試飲室/
しいんじ /子音字/
しいんぶ /子音部/
しいんぶぶん /子音部分/
しう゛ぁ /湿婆/
しうち /仕打/仕打ち/
しうと /舅/
しうとめ /姑/
しうら /市浦/
しうん /紫雲/
しうんじ /紫雲寺/
しうんてん /試運転/
しうんてんけっか /試運転結果/
しうんてんちゅう /試運転中/
しうんてんていど /試運転程度/
しぇあ /シェア/
しぇぱーど /シェパード/
しぇるへんすう /シェル変数/
しえい /市営/私営/
しえいこうつう /市営交通/
しえいしゃ /市営車/
しえいちかてつ /市営地下鉄/
しえいちゅうしゃじょう /市営駐車場/私営駐車場/
しえき /使役/私益/
しえん /支援/紫煙/私怨/
しえんかたんそ /四塩化炭素/
しえんかのう /支援可能/
しえんかんきょう /支援環境/
しえんきかん /支援機関/
しえんきこう /支援機構/
しえんきのう /支援機能/
しえんけい /支援系/
しえんざいだん /支援財団/
しえんにん /支援人/
しえんぶ /支援部/
しお /塩/汐/潮/鹽/入/史生/志雄/潮田/
しおあじ /塩味/
しおいがい /塩以外/
しおいり /塩入/
しおうち /塩内/
しおかぜ /汐風/潮風/
しおから /塩辛/
しおかり /塩狩/
しおかわ /塩川/
しおがま /塩竃/塩釜/
しおがまえき /塩釜駅/
しおがまこう /塩竃港/塩釜港/
しおがまし /塩釜市/
しおがません /塩釜線/
しおがまふきん /塩釜付近/
しおき /仕置/仕置き/
しおきにん /仕置人/
しおくり /仕送り/
しおけ /塩気/
しおこさじ /塩小匙/
しおこしょう /塩胡椒/
しおこんぶ /塩昆布/
しおさい /潮騒/
しおさめ /仕納め/爲納め/
しおざき /塩崎/潮崎/
しおざけ /塩鮭/
しおざわ /塩沢/塩澤/
しおじ /汐路/塩路/
しおじり /塩尻/
しおじりえき /塩尻駅/
しおず /塩津/
しおずか /塩塚/
しおせ /塩瀬/
しおた /塩田/
しおたに /塩谷/
しおだ /塩田/
しおち /潮地/
しおつぐ /塩次/
しおづけ /塩漬け/
しおで /塩出/
しおどき /潮時/
しおどめ /汐留/
しおの /塩野/
しおのえ /塩江/
しおのぎ /塩野義/
しおのぎせいやく /塩野義製薬/
しおはま /塩浜/
しおはまゆき /塩浜行/
しおはら /塩原/
しおばら /塩原/
しおばらおんせん /塩原温泉/
しおひ /潮干/
しおひがり /潮干狩/
しおふき /潮吹き/
しおべつ /塩別/
しおまねき /潮招き/
しおみ /塩見/潮見/
しおみえき /潮見駅/
しおみず /塩水/
しおみだい /潮見台/汐見台/
しおむら /塩村/
しおもと /塩本/
しおや /塩屋/塩谷/
しおやき /塩焼/
しおゆ /塩湯/
しおり /栞/詩央里/
しおん /紫苑/子音/私怨/
しか /鹿/歯科/史家/市価/飾/紙価/餝/雌花/爾/然/翅果/志賀/私家/
しかい /司会/視界/市会/死海/歯科医/此界/斯界/
しかいいん /歯科医院/
しかいぎいん /市会議員/
しかいしゃ /司会者/
しかいしゃせき /司会者席/
しかいしんこう /司会進行/
しかいちょうていやく /司会調停役/
しかいない /視界内/
しかいふりょう /視界不良/
しかいや /司会屋/
しかいやく /司会役/
しかいりょう /司会料/
しかいりょうこう /視界良好/
しかえし /仕返し/
しかおい /鹿追/
しかかり /仕掛り/仕掛/
しかぎこうし /歯科技工士/
しかく /資格/視覚/■/四角/□/◇/刺客/死角/視角/◆/
しかくか /視覚化/
しかくかひょうじ /視覚化表示/
しかくかんけい /視覚関係/
しかくきゅう /資格給/
しかくけい /四角形/視覚系/
しかくこうか /視覚効果/
しかくこうざ /資格講座/
しかくごうま /四角号碼/
しかくしげき /視覚刺激/
しかくしめん /四角四面/
しかくしゅとく /資格取得/
しかくしゅとくご /資格取得後/
しかくしゅとくしゃ /資格取得者/
しかくしょうがい /視覚障害/
しかくしょうがいしゃ /視覚障害者/視覚障碍者/
しかくしょうがいしゃよう /視覚障害者用/
しかくしょり /視覚処理/
しかくしんごう /視覚信号/
しかくじょう /視覚上/
しかくじょうけん /資格条件/
しかくじょうほう /視覚情報/
しかくじょうほうしょり /視覚情報処理/
しかくせいげん /資格制限/
しかくてき /視覚的/
しかくてきげいじゅつ /視覚的芸術/
しかくてきこうか /視覚的効果/
しかくとうろく /資格登録/
しかくにんてい /資格認定/
しかくはんいない /資格範囲内/
しかくひしつ /視覚皮質/
しかくふよう /資格不要/
しかくぶ /視覚部/
しかくべつ /資格別/
しかくほゆう /資格保有/
しかくぼ /鹿窪/
しかけ /仕掛/仕掛け/
しかけにん /仕掛け人/仕掛人/
しかけんしん /歯科検診/
しかご /市俄古/
しかさわぐち /鹿沢口/
しかざわ /鹿沢/
しかし /然し/併し/
しかしながら /然し乍ら/
しかしょ /四ヶ所/
しかじか /云々/然々/然然/
しかず /如かず/若かず/
しかた /仕方/志方/
しかたに /鹿谷/
しかちりょう /歯科治療/
しかっけい /四角形/
しかつ /死活/師勝/
しかつもんだい /死活問題/
しかと /聢/
しかど /鹿戸/
しかの /鹿野/
しかのしま /志賀島/
しかばね /屍/
しかばん /私家版/
しかべ /鹿部/
しかま /飾磨/志鎌/色麻/
しかまえき /飾磨駅/
しかまた /鹿又/
しかまち /鹿町/
しかみ /鹿見/爾見/
しかめん /死仮面/
しかも /而も/然も/
しからば /然らば/
しかり /然り/尓/
しかりべつ /然別/
しかりべつこ /然別湖/
しかん /視姦/歯冠/仕官/士官/士関/弛緩/支間/視感/篩管/
しかんがっこう /士官学校/
しかんけん /資環研/
しかんほう /弛緩法/
しが /滋賀/志賀/齒牙/四賀/
しがい /市外/死骸/市街/屍骸/紫外/
しがいか /市街化/
しがいかきょり /市街化距離/
しがいきょくばん /市外局番/
しがいこう /紫外光/
しがいしょく /紫外色/
しがいせん /紫外線/市街戦/市外線/
しがいせんきゅうしゅうざい /紫外線吸収剤/
しがいせんぼうしざい /紫外線防止剤/
しがいせんりょうほう /紫外線療法/
しがいち /市街地/
しがいちそうこう /市街地走行/
しがいちちゅうしん /市街地中心/
しがいちゅうしん /市街中心/
しがいちろせん /市街地路線/
しがいちろせんしゃ /市街地路線車/
しがいつうわ /市外通話/
しがき /志垣/
しがきたろう /志垣太郎/
しがく /歯学/私学/史学/
しがくか /史学科/歯学科/
しがくさつどうろ /志賀草津道路/
しがくぶ /歯学部/
しがけん /滋賀県/
しがけんいぶきやま /滋賀県伊吹山/
しがけんおおつし /滋賀県大津市/
しがけんか /滋賀県下/
しがけんぎかい /滋賀県議会/
しがけんくさつし /滋賀県草津市/
しがけんみん /滋賀県民/
しがけんりつ /滋賀県立/
しがげんぱつ /志賀原発/
しがこうげん /志賀高原/
しがこうげんえき /志賀高原駅/
しがごえ /志賀越/
しがごえみち /志賀越道/
しがさと /滋賀里/
しがちょう /志賀町/
しがっか /歯学科/
しがつ /四月/４月/4月/卯月/
しがほうめん /志賀方面/
しがらき /信楽/紫香楽/
しがらきのみやあと /紫香楽宮跡/
しがらみ /柵/
しがりゅうおう /志賀竜王/
しがん /志願/此岸/
しがんしゃ /志願者/
しき /式/敷/色/指揮/識/四季/拭/死期/士気/始期/志木/志気/惻/織/鋪/磯城/志岐/史記;中国の歴史書。正史のひとつ。著者は司馬遷/
しきい /敷居/閾/
しきいき /識域/識閾/
しきいし /敷石/
しきいた /敷板/
しきいち /閾値/しきい値/
しきか /指揮下/
しきかいぞうど /色解像度/
しきかく /色覚/
しきかくいじょう /色覚異常/
しきかくいじょうしゃ /色覚異常者/
しきかくけんさ /色覚検査/
しきかくこうじょう /色覚恒常/
しきかくしけん /色覚試験/
しきかくせいじょうしゃ /色覚正常者/
しきかくべんべつのうりょく /色覚弁別能力/
しきかん /指揮官/
しきかんとく /指揮監督/
しきがみ /式神/
しきがわ /敷皮/
しききん /敷金/
しきぎょう /私企業/
しきけいとう /指揮系統/
しきけん /指揮権/識見/
しきこう /式項/
しきこうぞう /式構造/
しきさい /色彩/四季菜/
しきさいかんかく /色彩感覚/
しきさいこうがく /色彩工学/
しきさいしんりがく /色彩心理学/
しきさしんごう /色差信号/
しきし /色紙/
しきしだい /式次第/
しきしま /敷島/磯城島/
しきしゃ /指揮者/識者/
しきしゅ /色種/
しきしゅうさ /色収差/
しきしん /色神/
しきじ /式辞/式次/
しきじたい /式自体/
しきじつ /式日/
しきじゃく /色弱/
しきじゃくきょうせい /色弱矯正/
しきじょう /式場/色情/
しきじりつ /識字率/
しきすう /色数/
しきそ /色素/式素/
しきそう /色相/
しきそうかん /色相環/
しきそくぜくう /色即是空/
しきそせいかんぴしょう /色素性乾皮症/
しきそぶんし /色素分子/
しきた /敷田/
しきたま /敷玉/
しきたり /仕來り/爲來り/
しきだ /敷田/
しきだい /指揮台/
しきち /敷地/
しきちがい /敷地外/
しきちきょうかい /敷地境界/
しきちない /敷地内/
しきちめんせき /敷地面積/
しきちゅう /式中/
しきちょう /色調/
しきてい /式亭/
しきてき /式的/
しきてん /式典/
しきど /色度/
しきね /式根/
しきねじま /式根島/
しきのうりょく /指揮能力/
しきばん /色板/
しきばんごう /式番号/
しきひょう /色票/
しきふ /敷布/
しきふくはんそうは /色副搬送波/
しきふね /式船/
しきぶ /式部/
しきぶとん /敷布団/敷き布団/
しきぶん /式文/
しきへんけい /式変形/
しきべつ /識別/
しきべつかのう /識別可能/
しきべつき /識別器/
しきべつくうかん /識別空間/
しきべつし /識別子/
しきべつししゅうごう /識別子集合/
しきべつじっけん /識別実験/
しきべつてん /識別点/
しきべつばんごう /識別番号/
しきべつほう /識別法/
しきべつめい /識別名/
しきべつよう /識別用/
しきべつりつ /識別率/
しきべつりょく /識別力/
しきほう /四季報/
しきぼう /指揮棒/
しきみ /樒/櫁/
しきみか /シキミ科/Illiciaceae/
しきみもどきか /シキミモドキ科/Winteraceae/
しきめ /式女/
しきめい /色名/
しきもう /色盲/
しきもの /敷物/敷き物/
しきものがたり /四季物語/
しきやみ /頻闇/
しきゅう /至急/支給/子宮/四球/死球/
しきゅうかく /子宮角/
しきゅうがく /支給額/
しきゅうこう /子宮口/
しきゅうせん /子宮腺/
しきゅうび /支給日/
しきょ /死去/
しきょう /司教/市況/試供/
しきょういく /私教育/
しきょうばん /試供版/
しきょうひん /試供品/
しきょく /支局/詩曲/
しきり /仕切り/頻り/頻/
しきりしょ /仕切書/
しきりとびら /仕切扉/
しきりに /頻/
しきりや /仕切り屋/
しきろう /識浪/
しきん /資金/至近/試金/
しきんうんよう /資金運用/
しきんえんじょ /資金援助/
しきんか /資金化/
しきんかいしゅう /資金回収/
しきんきょうよ /資金供与/
しきんきょり /至近距離/
しきんぐり /資金繰り/
しきんぐりひょう /資金繰り表/
しきんげん /資金源/
しきんしと /資金使途/
しきんせき /試金石/
しきんたんとうやくいん /資金担当役員/
しきんだん /至近弾/至近彈/
しきんちょうたつ /資金調達/
しきんちょうたつこすと /資金調達コスト/
しきんていきょう /資金提供/
しきんてき /資金的/
しきんはいぶん /資金配分/
しきんまえわたし /資金前渡/
しきんめん /資金面/
しきんりょう /資金量/
しきんりょく /資金力/
しぎ /鴫/仕儀/市議/思議/私議/鷸/信貴/
しぎかい /市議会/
しぎこ /鴫子/
しぎの /鴫野/
しぎゃく /嗜虐/
しぎょう /始業/仕業/紙業/施業/
しぎょうしき /始業式/
しぎょうじ /始業時/
しぎょうじかん /始業時間/
しぎょうてんけん /始業点検/
しぎょく /紫玉/
しぎょくえん /紫玉苑/
しぎょはっせいすう /死魚発生数/
しぎん /詩吟/市銀/
しく /市区/詩句/珠玖/
しくうかん /視空間/
しくしく /(concat "(\073_\073)")/(concat "\073_\073")/
しくちょうそん /市区町村/
しくつ /試掘/
しくはっく /四苦八苦/
しくみ /仕組/仕組み/
しぐさ /仕草/仕種/
しぐま /Σ/σ/シグマ/
しぐれ /時雨/
しぐん /市郡/
しぐんくちょうそんあざ /市郡区町村字/
しけ /時化/
しけい /死刑/私刑/市警/紙型/司計/
しけいおん /歯茎音/
しけいしっこう /死刑執行/
しけいしゅう /死刑囚/
しけいせいど /死刑制度/
しけつ /止血/
しけん /試験/私見/私権/四間/
しけんうんよう /試験運用/
しけんうんようちゅう /試験運用中/
しけんおんせい /試験音声/
しけんかいじょう /試験会場/
しけんかいじょうまえ /試験会場前/
しけんかいはつひ /試験開発費/
しけんかもく /試験科目/
しけんかん /試験官/試験管/
しけんかんけい /試験関係/
しけんかんすう /試験関数/
しけんかんとく /試験監督/
しけんかんべいびー /試験管ベイビー/
しけんき /試験機/
しけんきかく /試験規格/
しけんきかん /試験期間/試験機関/
しけんきかんちゅう /試験期間中/
しけんけいたい /試験形態/
しけんけっか /試験結果/
しけんけんきゅう /試験研究/
しけんけんきゅうきかん /試験研究機関/
しけんけんきゅうひ /試験研究費/
しけんけんきゅうひこうじょ /試験研究費控除/
しけんこうかいちゅう /試験公開中/
しけんし /試験紙/
しけんしゃ /試験車/
しけんしゃりょう /試験車両/
しけんしゅうりょう /試験終了/
しけんしょ /試験所/
しけんじかん /試験時間/
しけんじょ /試験所/
しけんじょう /試験場/
しけんじょうきんぺん /試験場近辺/
しけんじょうけん /試験条件/
しけんじょうたいさく /試験場対策/
しけんせい /試験生/
しけんせいど /試験制度/
しけんせつび /試験設備/
しけんせん /試験線/
しけんそうこう /試験走行/
しけんだい /試験台/
しけんだんかい /試験段階/
しけんち /試験地/
しけんちゅう /試験中/
しけんちゅうし /試験中止/
しけんてき /試験的/
しけんとうじつ /試験当日/
しけんないよう /試験内容/
しけんひこうかのう /試験飛行可能/
しけんび /試験日/
しけんびしゃ /四間飛車/
しけんふごうかく /試験不合格/
しけんべんきょう /試験勉強/
しけんほうそう /試験放送/
しけんほうほう /試験方法/
しけんまえ /試験前/
しけんめんじょ /試験免除/
しけんもんだい /試験問題/
しけんよう /試験用/
しげ /滋/茂/重/繁/恵/成/楙/卯/
しげあき /成章/重昭/重明/繁明/
しげい /重井/
しげえだ /重枝/
しげお /重雄/茂雄/成夫/茂男/重男/重夫/繁男/繁夫/繁雄/茂夫/滋雄/滋夫/茂生/恵雄/滋男/繁生/惠雄/成雄/
しげかず /重一/繁一/茂和/
しげかつ /重勝/
しげがき /茂垣/
しげき /刺激/滋樹/茂樹/重樹/繁樹/茂喜/刺戟/枝隙/
しげきおん /刺激音/
しげきしゅう /刺激臭/
しげきてき /刺激的/
しげきでんたつそしき /刺激伝達組織/
しげきはけい /刺激波形/
しげきひょうげん /刺激表現/
しげきぶつ /刺激物/
しげく /繁く/
しげこ /茂子/滋子/シゲ子/
しげさだ /繁定/
しげさと /重里/
しげし /茂志/
しげじ /茂司/
しげぞう /茂三/
しげた /重田/
しげたか /重隆/重高/
しげたけ /重武/
しげつぐ /重継/
しげとし /恵俊/成俊/
しげとも /成伴/
しげなが /重永/
しげなり /重成/
しげのぶ /滋延/重信/茂伸/
しげのり /重則/重徳/茂典/繁則/卯典/繁徳/茂則/
しげはら /重原/
しげはる /重治/
しげひこ /重彦/茂彦/
しげひろ /重宏/重弘/重博/繁弘/
しげふみ /重文/
しげまさ /茂昌/
しげまつ /重松/
しげまつけん /重松研/
しげみ /茂美/茂見/成美/茂実/
しげみち /茂道/
しげみつ /重光/
しげみつがいしょう /重光外相/
しげむら /重村/
しげもり /繁盛/重森/
しげや /茂哉/
しげやす /成康/
しげゆき /重行/繁之/茂之/茂行/滋之/繁行/
しげよし /重義/誠良/
しげり /成里/
しげる /茂/滋/繁/楙/
しげん /資源/始原/至言/始源/死言/
しげんかん /始原環/
しげんかんり /資源管理/
しげんがく /資源学/
しげんこうがく /資源工学/
しげんさいぼう /始原細胞/
しげんさいりよう /資源再利用/
しげんしょうひ /資源消費/
しげんじょう /資源上/
しげんじょうきょう /資源状況/
しげんすう /四元数/
しげんせい /資源性/
しげんせつやく /資源節約/
しげんたんさくしゃ /資源探索車/
しげんはいぶん /資源配分/
しげんもんだい /資源問題/
しげんわりあて /資源割当て/
しげんわりあてようきゅう /資源割当て要求/
しこ /鬼/四股/醜/
しこう /指向/思考/試行/施行/嗜好/至高/志向/施工/私好/歯垢/市郊/私行/紙工/市交/伺候/篩孔/
しこうあん /試行案/
しこういらい /施行依頼/
しこうかいすう /試行回数/
しこうかいろ /思考回路/
しこうかてい /思考過程/思考仮定/
しこうがた /指向型/
しこうきかい /思考機械/
しこうきかん /試行期間/
しこうきかんちゅう /試行期間中/
しこうきそく /施行規則/
しこうきそくいはん /施行規則違反/
しこうきそくさいそく /施行規則細則/
しこうぎじゅつ /施工技術/
しこうくんれん /思考訓練/
しこうけいさん /指向計算/
しこうけいしき /思考形式/
しこうけいたい /思考形態/
しこうげんご /指向言語/
しこうご /施行後/
しこうさ /思考差/
しこうさくご /試行錯誤/
しこうさくごてき /試行錯誤的/
しこうして /而して/
しこうじき /施行時期/
しこうじっけん /思考実験/
しこうじっけんれい /思考実験例/
しこうせい /指向性/志向性/嗜好性/
しこうせんひたいおう /市交線非対応/
しこうだんかい /試行段階/
しこうちゅう /思考中/試行中/
しこうてい /始皇帝;中国史上初の皇帝/
しこうていし /思考停止/
しこうてき /試行的/指向的/
しこうとくせい /指向特性/
しこうないよう /思考内容/
しこうのうりょく /思考能力/
しこうひん /嗜好品/
しこうび /施行日/
しこうぶつ /嗜好物/
しこうほう /思考法/
しこうほうこう /指向方向/
しこうほうほう /思考方法/
しこうまえ /施行前/
しこうようしき /思考様式/
しこうりょく /思考力/
しこうれい /施行令/
しこく /四国/市國/
しこくいっしゅう /四国一周/
しこくおき /四国沖/
しこくかくけん /四国各県/
しこくかくせん /四国各線/
しこくこうぎょうしけん /四国工業試験/
しこくさんち /四国山地/
しこくしぶ /四国支部/
しこくしゅっしんしゃ /四国出身者/
しこくだいがく /四国大学/
しこくでんか /四国電化/
しこくでんきこうじ /四国電気工事/
しこくない /四国内/
しこくほうめん /四国方面/
しこたん /色丹/
しこたんとう /色丹島/
しこつ /死骨/肢骨/指骨/趾骨/歯骨/篩骨/
しこつおきな /醜つ翁/
しこつこ /支笏湖/
しこつとうやこくりつこうえん /支笏洞爺国立公園/
しこな /四股名/醜名/
しこめ /醜女/
しこり /凝/痼/
しころ /錏/錣/鍜/
しこん /紫紺/
しご /死後/死語/私語/
しごう /諡号/紫合/
しごく /至極/
しごくしぜん /至極自然/
しごくたんじゅん /至極単純/
しごくとうぜん /至極当然/
しごせん /子午線/
しごと /仕事/
しごとあいて /仕事相手/
しごとおさめ /仕事納め/
しごとがら /仕事柄/
しごとぎ /仕事着/
しごとさき /仕事先/
しごとし /仕事師/
しごとじたい /仕事自体/
しごとじょう /仕事上/
しごとじょうりよう /仕事上利用/
しごとちゅう /仕事中/
しごとづくえ /仕事机/
しごとないよう /仕事内容/
しごとにん /仕事人/
しごとはんぶん /仕事半分/
しごとば /仕事場/
しごとべや /仕事部屋/
しごとよう /仕事用/
しごとりょう /仕事量/
しごはっぴょう /死後発表/
しごめん /子午面/
しごめんじゅんかん /子午面循環/
しさ /示唆/視差/指唆/
しさい /子細/司祭/仔細/市債/
しさいぼう /篩細胞/
しさく /試作/施策/思索/
しさくがた /試作型/
しさくき /試作機/
しさくしゃ /試作車/
しさくだんかい /試作段階/
しさくちゅう /試作中/
しさくてき /試作的/
しさくばん /試作版/
しさくひん /試作品/詩作品/
しさくぶ /試作部/
しさつ /視察/刺殺/
しさつだん /視察団/
しさてき /示唆的/
しさん /資産/試算/四散/私産/
しさんか /資産家/
しさんかいきゅうか /資産階級化/
しさんかぜい /資産課税/
しさんかち /資産価値/
しさんかんり /資産管理/
しさんごうけい /資産合計/
しさんちくせき /資産蓄積/
しさんばんごう /資産番号/
しさんひょう /試算表/
しざ /視座/
しざい /資材/私財/死罪/
しざいおきば /資材置場/
しざいちょうたつ /資材調達/
しざわ /志沢/
しざん /死産/試算/
しし /獅子/宍/四肢/死屍/獅/肉/貎/祠祀/志士/
ししうち /猪内/
ししき /始式/司式/
ししきゅう /四死球/
ししくい /宍喰/
ししざ /獅子座/
ししざりゅうせいぐん /獅子座流星群/
ししつ /資質/紙質/支質/脂質/
ししづか /宍塚/
ししど /宍戸/
ししどじょう /宍戸錠/
ししゃ /支社/死者/試写/使者/四捨/試射/視射/
ししゃかい /試写会/
ししゃかいばん /試写会版/
ししゃく /子爵/
ししゃごにゅう /四捨五入/
ししゃすう /死者数/
ししゃちょう /支社長/
ししゃも /シシャモ/柳葉魚/
ししゅ /死守/
ししゅう /詩集/刺繍/刺しゅう/死臭/
ししゅういり /刺繍入り/
ししゅうき /思秋期/
ししゅうへん /市周辺/
ししゅく /私淑/
ししゅつ /支出/
ししゅつがく /支出額/
ししゅつきぼう /支出希望/
ししゅつきんがく /支出金額/
ししゅつごうけい /支出合計/
ししゅんき /思春期/
ししょ /支所/司書/支署/史書/私書/四書/
ししょう /支障/師匠/刺傷/死傷/視床/四生/
ししょうしゃ /死傷者/
ししょうすじ /師匠筋/
ししょうせつ /私小説/
ししょく /試食/
ししょくばん /試食版/
ししょばこ /私書箱/
ししよう /試使用/
ししるいるい /死屍累々/
ししん /私信/指針/私心/視診/
ししんけい /視神経/歯神経/
ししんもーど /私信モード/
しじ /指示/支持/私事/師事/榻/指事/指似/
しじいがい /指示以外/
しじいけん /支持意見/
しじかのう /指示可能/
しじこうぞう /支持構造/
しじご /指示語/
しじし /指示子/
しじしゃ /支持者/
しじしゃすう /支持者数/
しじしょ /指示書/
しじせいとう /支持政党/
しじそくど /指示速度/
しじそしき /支持組織/
しじたいしょう /指示対象/
しじだい /支持台/
しじつ /史実/
しじつごう /私事都合/
しじてき /指示的/
しじどうこう /支持動向/
しじひょう /指示票/
しじほうほう /指示方法/
しじま /静寂/黙/四十万/
しじみ /蜆/
しじゃく /枝雀/
しじやく /指示薬/
しじゅう /始終/四十/四重/
しじゅういっかん /始終一貫/
しじゅうから /四十雀/
しじゅうくにち /四十九日/
しじゅうしちし /四十七士/
しじゅうそう /四重奏/
しじゅうそうだん /四重奏団/
しじゅく /私塾/
しじゅほうしょう /紫綬褒章/
しじょ /子女/
しじょう /市場/史上/至上/市上/私情/四条/施錠/試乗/紙上/誌上/四條/矢状/糸状/
しじょういき /市場行/
しじょうかい /試乗会/
しじょうかかく /市場価格/
しじょうかち /市場価値/
しじょうからすま /四条烏丸/
しじょうかわらまち /四条河原町/
しじょうき /試乗記/
しじょうきぼ /市場規模/
しじょうきょう /私情協/
しじょうきょうそう /市場競争/
しじょうくうぜん /史上空前/
しじょうけいざい /市場経済/
しじょうけいせい /市場形成/
しじょうけんしゅう /市場研修/
しじょうげんり /市場原理/
しじょうこうへきいけいさいぼう /糸状厚壁異形細胞/
しじょうさいきょう /史上最強/
しじょうさいこう /史上最高/
しじょうさいだい /史上最大/
しじょうさいねんしょう /史上最年少/
しじょうさいやすね /史上最安値/
しじょうしゃ /試乗車/
しじょうしゅぎ /至上主義/
しじょうせい /市場性/
しじょうせいや /四条青夜/
しじょうせん /四条線/
しじょうちょうさ /市場調査/
しじょうてき /市場的/
しじょうとうにゅう /市場投入/
しじょうとうろん /誌上討論/
しじょうとりひき /市場取引/
しじょうないとりひき /市場内取引/
しじょうなわて /四條畷/四条畷/
しじょうにい /史上二位/
しじょうのあい /至上の愛/
しじょうはつ /史上初/
しじょうひがしやま /四条東山/
しじょうめいだい /至上命題/
しじょうりすく /市場リスク/
しじょうれい /市条例/
しじりつ /支持率/指示率/
しじりょく /支持力/
しじん /詩人/私人/
しすい /市水/止水/酒々井/泗水/
しすう /指数/紙数/
しすうかんすう /指数関数/
しすうかんすうてき /指数関数的/
しすうげんすい /指数減衰/
しすうげんすいがた /指数減衰型/
しすうげんすいは /指数減衰波/
しすうそく /指数則/
しすうてき /指数的/
しすうてきけいこう /指数的傾向/
しすうてきげんしょう /指数的減少/
しすうぶ /指数部/
しすうぶんぷ /指数分布/
しすうほうそく /指数法則/
しすてむ /システム/
しすてむこうがく /システム工学/
しすてむず /システムズ/
しず /静/志津/靜/
しずい /雌蕊/
しずえ /静江/静枝/志津恵/
しずお /静雄/静夫/静男/鎮雄/靜生/
しずおか /静岡/靜岡/
しずおかえき /静岡駅/
しずおかえきまえ /静岡駅前/
しずおかかん /静岡間/
しずおかがわ /静岡側/
しずおかぎんこう /静岡銀行/
しずおかけいゆ /静岡経由/
しずおかけん /静岡県/
しずおかけんがい /静岡県外/
しずおかけんすそのし /静岡県裾野市/
しずおかけんない /静岡県内/静岡圏内/
しずおかけんはままつし /静岡県浜松市/
しずおかけんみん /静岡県民/
しずおかけんりつだいがく /静岡県立大学/
しずおかこうこう /静岡高校/
しずおかし /静岡市/
しずおかしみん /静岡市民/
しずおかしゅっしん /静岡出身/
しずおかしりつしょう /静岡市立商/
しずおかしんぶん /静岡新聞/
しずおかせいぶ /静岡西部/
しずおかせんばつ /静岡選抜/
しずおかぜんけん /静岡全県/
しずおかだい /静岡大/
しずおかだいいち /静岡第一/
しずおかだいがく /静岡大学/
しずおかちく /静岡地区/
しずおかていしゃ /静岡停車/
しずおかてつどう /静岡鉄道/
しずおかでんしゃく /静岡電車区/
しずおかほうそう /静岡放送/
しずおかりこう /静岡理工/
しずおかりこうか /静岡理工科/
しずおかりこうかだい /静岡理工科大/
しずか /静香/閑か/静か/静/靜か/静佳/
しずかごぜん /静御前/
しずがわ /志津川/
しずぎん /静銀/
しずく /雫/滴/
しずくいし /雫石/
しずけさ /静けさ/
しずこ /静子/志津子/
しずごころ /静心/
しずたに /閑谷/
しずだい /静大/
しずだいこうがくぶ /静大工学部/
しずない /静内/
しずや /静谷/靜谷/
しずりだい /静理大/
しずる /静流/
しせい /姿勢/四声/至誠/市制/市政/施政/私製/市勢/市井/私生/刺青/志誠/雌性/
しせいか /施政下/
しせいかく /姿勢角/
しせいかつ /私生活/
しせいきょうりょくいいん /市政協力委員/
しせいけん /施政権/
しせいさつじんじけん /刺青殺人事件/
しせいし /市政史/
しせいしこう /市制施行/
しせいしゃ /施政者/
しせいじ /私生児/
しせいせいぎょ /姿勢制御/
しせいせいど /氏姓制度/
しせいせこう /市制施行/
しせいたい /四声体/
しせいどう /資生堂/
しせいはがき /私製葉書/
しせいへんか /姿勢変化/
しせかいこうきょうきょく /新世界交響曲/
しせき /史跡/歯石/枝跡/
しせきめいしょうてんねんきねんぶつ /史跡名勝天然記念物/
しせつ /施設/私設/使節/私説/
しせつおうえんだん /私設応援団/
しせつかいせん /私設回線/
しせつかん /施設間/
しせつぜんたい /施設全体/
しせつちょう /施設長/
しせつとう /施設等/
しせつとしょかん /私設図書館/
しせつぶ /施設部/
しせん /視線/支線/死線/四川/
しせんけい /支線系/
しせんついび /視線追尾/
しせんどう /詩仙堂/
しせんにゅうりょく /視線入力/
しせんふう /四川風/
しせんりょうり /四川料理/
しぜん /自然/
しぜんあいて /自然相手/
しぜんいくじほう /自然育児法/
しぜんえんえき /自然演繹/
しぜんえんえきたいけい /自然演繹体系/
しぜんえんえきほう /自然演繹法/
しぜんかい /自然界/
しぜんかがく /自然科学/
しぜんかがくいがい /自然科学以外/
しぜんかがくしゃたち /自然科学者達/
しぜんかがくてき /自然科学的/
しぜんかがくようそ /自然科学要素/
しぜんかん /自然観/
しぜんかんきょう /自然環境/
しぜんかんさつ /自然観察/
しぜんが /自然画/
しぜんがく /自然学/
しぜんきゅうかむら /自然休暇村/
しぜんきゅうき /自然吸気/
しぜんけい /自然系/
しぜんげんご /自然言語/
しぜんげんごしょり /自然言語処理/
しぜんげんごりかい /自然言語理解/
しぜんげんしょう /自然現象/
しぜんこう /自然光/
しぜんこうえん /自然公園/
しぜんこうさつえい /自然光撮影/
しぜんこうは /自然光派/
しぜんさいがい /自然災害/
しぜんし /自然死/自然史/
しぜんしはくぶつかん /自然史博物館/
しぜんしゅぎてき /自然主義的/
しぜんしょうめつ /自然消滅/
しぜんしょうもう /自然消耗/
しぜんじん /自然人/
しぜんすう /自然数/
しぜんすうこう /自然数項/
しぜんすうしき /自然数式/
しぜんすうぜんたい /自然数全体/
しぜんすうれつ /自然数列/
しぜんすうろん /自然数論/
しぜんせい /自然性/
しぜんぞう /自然増/
しぜんたい /自然体/
しぜんたいすう /自然対数/
しぜんたいりゅう /自然対流/
しぜんちゆ /自然治癒/
しぜんちゆのうりょく /自然治癒能力/
しぜんちょう /自然長/
しぜんちょうわ /自然調和/
しぜんてきかんきょう /自然的環境/
しぜんてつがく /自然哲学/
しぜんとうた /自然淘汰/
しぜんどうぶつえん /自然動物園/
しぜんにんしき /自然認識/
しぜんのうほう /自然農法/
しぜんはかい /自然破壊/
しぜんはくぶつかん /自然博物館/
しぜんはっか /自然発火/
しぜんはっせい /自然発生/
しぜんはっせいてき /自然発生的/
しぜんふりこ /自然振子/
しぜんぶつ /自然物/
しぜんぶんべん /自然分娩/
しぜんへんかん /自然変換/
しぜんほうしゃせん /自然放射線/
しぜんほうしゃのう /自然放射能/
しぜんほうそく /自然法則/
しぜんほご /自然保護/
しぜんほごだんたい /自然保護団体/
しぜんらっか /自然落下/
しそ /始祖/紫蘇/
しそう /思想/試奏/試走/視奏/宍粟/使嗾/志操/死相/祀竈/祀竃/私送/
しそうか /思想家/
しそうかい /思想界/
しそうがた /視奏型/
しそうきはん /思想規範/
しそうきょういく /思想教育/
しそうぎろん /思想議論/
しそうけんご /志操堅固/
しそうげんろん /思想言論/
しそうし /思想史/
しそうしつ /試奏室/
しそうしょ /思想書/
しそうしんじょう /思想信条/
しそうそうさ /思想操作/
しそうたいけい /思想体系/
しそうてき /思想的/
しそうてきはいけい /思想的背景/
しそうとうせい /思想統制/
しそうなど /思想等/
しそうのうろう /歯槽膿漏/
しそうはいけい /思想背景/
しそか /シソ科/Labiatae/
しそく /四則/子息/
しそくえんざん /四則演算/
しそちょう /始祖鳥/
しそもく /シソ目/Laminales/
しそん /子孫/
しぞう /死蔵/私蔵/
しぞうひん /死蔵品/
しぞく /士族/氏族/
した /下/舌/↓/舍/舐/舖/
したあご /下顎/
したあじ /下味/
したい /死体/姿態/肢体/屍体/死體/
したいいきじけん /死体遺棄事件/
したいおきば /死体置場/
したいしょうがい /肢体障害/
したいじんいしょく /死体腎移植/
したいふ /士大夫/
したうけ /下請け/下請/
したうち /舌打/舌打ち/
したえ /下絵/
したか /志鷹/
したがき /下書き/下書/
したがって /従って/
したがわ /下側/
したぎ /下着/
したぎすがた /下着姿/
したく /仕度/支度/私宅/
したくきん /支度金/仕度金/
したくさ /下草/
したくさかり /下草苅り/
したくちびる /下唇/
したくべや /支度部屋/
したぐつ /襪/
したけんぶん /下検分/
したごころ /下心/
したごしらえ /下拵え/
したさき /舌先/
したさんかく /下三角/
したざわり /舌触り/
したしい /親/
したしく /親しく/
したしょく /下職/
したしらべ /下調べ/下調/
したじ /下地/
したじき /下敷き/下敷/
したじゅんび /下準備/
したず /下図/
したそうだん /下相談/
したたか /強か/健か/
したたらず /舌足らず/
しただ /下田/
したっぱ /下端/下っぱ/下っ端/
したっぱら /下っ腹/
したつ /示達/
したつけ /下付/
したづつみ /舌鼓/
したづみ /下積み/
したて /仕立て/下手/仕立/
したてだしなげ /下手出し投げ/
したてなげ /下手投げ/
したてひねり /下手捻り/
したてや /仕立屋/
したてん /．/
したで /下手/
したどり /下取り/下取/
したどりがく /下取額/
したどりきんがく /下取金額/
したなめずり /舌舐めずり/
したぬり /下塗/
したね /下値/
したの /下野/
したはんぶん /下半分/
したばえ /下生/
したばたらき /下働き/
したばなし /下話/
したび /下火/
したまえば /下前歯/
したまち /下町/
したみ /下見/
したみち /下道/
したむき /下向き/
しため /下目/
したや /↓/
したやじるし /↓/
したら /設楽/
したん /始端/紫檀/枝端/
しだ /志太/志田/試打/信太/羊歯/羊齒/齒朶/
しだい /次第/私大/
しだいすう /始代数/
しだし /仕出し/
しだじょうしゅししょくぶつ /シダ状種子植物/
しだじょうしゅししょくぶつあこう /シダ状種子植物亜綱/Pteridospermidae/
しだじょうしゅししょくぶつもく /シダ状種子植物目/Pteridospermales/
しだよう /試打用/
しだら /設楽/
しだれざくら /枝垂れ桜/
しだれやなぎ /枝垂れ柳/
しだわら /志俵/
しだん /指弾/師団/指彈/
しだんきぼ /師団規模/
しだんしょ /示談書/
しだんほんぶ /師団本部/
しち /七/質/貭/叱/
しちいれ /質入れ/
しちうけ /質請け/
しちかく /視知覚/
しちかくさいぼう /視知覚細胞/
しちがしゅく /七ヶ宿/
しちがつ /七月/7月/７月/文月/
しちがはま /七ヶ浜/
しちく /紫竹/
しちけん /質権/
しちごさん /七五三/
しちごちょう /七五調/
しちしょう /七生/
しちじ /七時/
しちじゅう /七重/七十/
しちじゅうしち /七十七/
しちじょう /七丈/七城/
しちじょうかわらまち /七条河原町/
しちずんどけい /シチズン時計/
しちだん /七段/
しちてんばっとう /七転八倒/
しちなん /七難/
しちなんはっく /七難八苦/
しちにん /七人/
しちねん /七年/
しちねんめ /七年目/
しちのへ /七戸/
しちふくじん /七福神/
しちふくせい /七福星/
しちふだ /質札/
しちぶ /七分/
しちへんげ /七変化/
しちほのさい /七歩の才/
しちみ /七味/
しちめんちょう /七面鳥/
しちめんどう /七面倒/
しちゃく /試着/
しちゃくしつ /試着室/
しちや /質屋/
しちゅー /シチュー/
しちゅう /市中/支柱/
しちゅうかかく /市中価格/
しちゅうぎんこう /市中銀行/
しちゅうこん /支柱根/
しちゅうしんぶ /市中心部/
しちょう /市長/試聴/視聴/市庁/思潮/支庁/市町/輜重/
しちょうかい /試聴会/視聴会/
しちょうかく /視聴覚/
しちょうかくしつ /視聴覚室/
しちょうかくしりょう /視聴覚資料/
しちょうかくじょうほう /視聴覚情報/
しちょうかくてきこうか /視聴覚的効果/
しちょうかのう /視聴可能/
しちょうき /試聴記/
しちょうしつ /試聴室/
しちょうしゃ /視聴者/市庁舎/
しちょうしゃさんか /視聴者参加/
しちょうしゃそう /視聴者層/
しちょうしゃまどぐち /視聴者窓口/
しちょうせん /市長選/
しちょうせんきょ /市長選挙/
しちょうそん /市町村/
しちょうそんがっぺい /市町村合併/
しちょうそんぎょうせい /市町村行政/
しちょうそんちょう /市町村長/
しちょうそんやくしょ /市町村役所/
しちょうそんやくば /市町村役場/
しちょうゆそつ /輜重輸卒/
しちょうりつ /視聴率/
しちょうりつかくほ /視聴率確保/
しちょうりつちょうさ /視聴率調査/
しちょうりょう /視聴料/
しちょく /司直/
しちょっけい /視直径/
しちよう /七曜/
しちり /七里/
しちりん /七輪/
しちろう /七郎/
しちろうじ /七郎次/
しっか /失火/膝下/
しっかい /悉皆/
しっかく /失格/
しっかくしゃ /失格者/
しっかり /確り/聢り/
しっかん /疾患/
しっかんしゃ /疾患者/
しっかんじこう /疾患事項/
しっかんめい /疾患名/
しっき /漆器/湿気/
しっきゃく /失脚/
しっきん /失禁/
しっく /疾駆/
しっくい /漆喰/
しっけ /湿気/
しっけい /失敬/
しっけつ /失血/
しっけん /識見/失権/執権/
しっこう /執行/失効/
しっこうきかん /執行機関/
しっこうきそく /執行規則/
しっこうけん /執行権/
しっこうしょぶん /失効処分/
しっこうちゅう /執行中/
しっこうぶ /執行部/
しっこうやくいん /執行役員/
しっこうりつ /執行率/
しっこく /漆黒/桎梏/
しっこし /尻腰/
しっさく /失策/
しっしき /湿式/
しっしっ /叱叱/
しっしょう /失笑/
しっしょく /失職/
しっしん /失神/湿疹/
しっせい /失政/叱正/叱声/執政/
しっせき /叱責/失跡/叱斥/
しっせきちょう /叱責調/
しっそ /質素/
しっそう /失踪/疾走/
しっそうかん /疾走感/
しっそく /失速/
しっそくそくど /失速速度/
しった /叱咤/
しったい /失態/
しったげきれい /叱咤激励/
しったん /悉曇/
しっち /湿地/失地/
しっちたい /湿地帯/
しっちょう /失調/室長/
しっつい /失墜/
しって /知って/尻手/
しってん /失点/質点/
しっと /嫉妬/
しっとう /失投/執刀/
しっとしん /嫉妬心/
しっぱい /失敗/
しっぱいさく /失敗作/
しっぱいじ /失敗時/
しっぱいじれい /失敗事例/
しっぱいだん /失敗談/
しっぱいりつ /失敗率/
しっぱいれい /失敗例/
しっぴ /櫛比/失費/
しっぴつ /執筆/
しっぴつしゃ /執筆者/
しっぴつしゃめい /執筆者名/
しっぴつじたい /執筆自体/
しっぴつじゅん /執筆順/
しっぴつじん /執筆陣/
しっぴつちゅう /執筆中/
しっぴつようりょう /執筆要領/
しっぷ /湿布/
しっぷう /疾風/
しっぷうどとう /疾風怒涛/Sturm und Drang/
しっぺい /疾病/
しっぺがえし /しっぺ返し/
しっぽ /尻尾/
しっぽう /七宝/
しっぽうとう /七宝塔/
しっぽうやき /七宝焼/七宝焼き/
しっぽく /卓袱/
しつ /室/質/失/疾/漆/湿/嫉/悉/執/叱/出/濕/瑟/蟋/貭/隲/隰/膝/蛭/櫛/
しつい /視追/失意/
しついん /室員/
しつう /止痛/
しつおか /室岡/
しつおん /室温/
しつおんいか /室温以下/
しつおんかくゆうごう /室温核融合/
しつおんちょうせい /室温調整/
しつおんていど /室温程度/
しつかい /室会/
しつかん /質感/
しつがい /室外/膝蓋/
しつがいき /室外機/
しつがいこつ /膝蓋骨/
しつがいじんたい /膝蓋靭帯/
しつがいよう /室外用/
しつぎ /質疑/
しつぎおうとう /質疑応答/
しつぎょう /失業/
しつぎょうしゃ /失業者/
しつぎょうりつ /失業率/
しつけ /仕付/躾/
しつげい /漆芸/
しつげん /失言/湿原/
しつご /失語/
しつごしょう /失語症/
しつじ /執事/
しつじつ /質実/
しつじつごうけん /質実剛堅/質実剛健/
しつじゅん /湿潤/
しつちょう /室長/
しつてき /質的/
しつてきこうじょう /質的向上/
しつてきさ /質的差/
しつてきへんかん /質的変換/
しつてきもんだい /質的問題/
しつてん /質点/
しつでん /湿田/
しつど /湿度/
しつどう /室堂/
しつどおんど /湿度温度/
しつどくしょう /失読症/
しつどけい /湿度計/
しつない /室内/
しつないうんどうかい /室内運動会/
しつないおんきょう /室内音響/
しつないおんじょう /室内音場/
しつないかんきょう /室内環境/
しつないかんげんがくだん /室内管弦楽団/
しつないがく /室内楽/
しつないがくばん /室内楽版/
しつないがくろせん /室内楽路線/
しつないがわ /室内側/
しつないき /室内機/
しつないきょうぎ /室内競技/
しつないこう /室内光/
しつないさつえい /室内撮影/
しつないそうおん /室内騒音/
しつないちょう /室内長/
しつないとう /室内灯/
しつないはば /室内幅/
しつねん /失念/
しつば /叱罵/
しつばんごう /室番号/
しつぼう /失望/
しつぼうかん /失望感/
しつむ /執務/悉無/
しつむしつ /執務室/
しつむてき /悉無的/
しつめい /失明/室名/
しつめいしゃ /失明者/
しつめいじょうたい /失明状態/
しつもん /質問/
しつもんいと /質問意図/
しつもんかしょ /質問箇所/
しつもんきじ /質問記事/
しつもんきのう /質問機能/
しつもんけいしき /質問形式/
しつもんけん /質問権/
しつもんこうもく /質問項目/
しつもんしつ /質問室/
しつもんしゃ /質問者/
しつもんしゅう /質問集/
しつもんしょ /質問書/
しつもんじこう /質問事項/
しつもんじたい /質問自体/
しつもんじょう /質問状/
しつもんちゅう /質問中/
しつもんでんわ /質問電話/
しつもんないよう /質問内容/
しつもんなど /質問等/
しつもんばこ /質問箱/
しつもんほうこく /質問報告/
しつもんもと /質問元/
しつもんよう /質問用/
しつよう /執拗/
しつらく /失楽/
しつりょう /質量/室料/
しつりょうがいねん /質量概念/
しつりょうさ /質量差/
しつりょうすう /質量数/
しつりょうせいぶん /質量成分/
しつりょうそうとうせいぶん /質量相当成分/
しつりょうそく /質量則/
しつりょうそくど /質量速度/
しつりょうぞうだい /質量増大/
しつりょうたい /質量体/
しつりょうひ /質量比/
しつりょうふへんそく /質量不変則/
しつりょうぶんせきけい /質量分析計/
しつりょうぶんぷ /質量分布/
しつりょうほぞん /質量保存/
しつりょうほぞんそく /質量保存則/
しつれい /失礼/
しつれいごようしゃ /失礼御容赦/
しつれいせんばん /失礼千番/
しつれん /失恋/
しづえ /志津恵/
しづか /謐/
しづがわ /志津川/
しづく /雫/滴/
して /仕手/支手/爲手/
してぃ /シティ/
してい /指定/師弟/私邸/姉弟/子弟/
していえき /指定駅/
していえきいがい /指定駅以外/
していか /指定可/
していかのう /指定可能/
していき /指定機/
していきかん /指定機関/
していきつえんばしょ /指定喫煙場所/
していきょうしゅうじょ /指定教習所/
していぎょう /指定行/
していぎょうしゃ /指定業者/
していぎょうむ /指定業務/
していくうきあつ /指定空気圧/
していけん /指定券/
していけんけんばいき /指定券券売機/
していけんるい /指定券類/
していこうざ /指定口座/
していし /指定子/
していしゃ /指定車/
していしゅつりょくそうし /指定出力装置/
していしょく /指定職/
していしょしき /指定書式/
していじ /指定時/
していじかん /指定時間/
していすう /指定数/
していせいぶん /指定成分/
していせき /指定席/指定席券/
していせききんえんしゃ /指定席禁煙車/
していせきけん /指定席券/
していせきしゃ /指定席車/
していせきしゃりょう /指定席車両/
していせきしようしゃ /指定席仕様車/
していせきていき /指定席定期/
していせきとっきゅうけん /指定席特急券/
していせきよう /指定席用/
していせきりょうきん /指定席料金/
していせきれっしゃ /指定席列車/
していち /指定地/
していちいきない /指定地域内/
していちえき /指定地駅/
していてん /指定点/指定店/
していどおり /指定通り/
していばんごう /指定番号/
していひん /指定品/
していび /指定日/
していふく /指定服/
していぶ /指定部/
していへんこう /指定変更/
していほう /指定法/
していほうほう /指定方法/
していよう /指定用/
していらん /指定欄/
していれい /指定例/
していれっしゃ /指定列車/
してき /指摘/私的/詩的/史的/至適/
してきか /指摘下/
してきかいしゃ /私的会社/
してきかいぞうこうい /私的改造行為/
してきぎしき /私的儀式/
してきぎょうじ /私的行事/
してきしよう /私的使用/
してきしようもくてき /私的使用目的/
してきじこう /指摘事項/
してきじたい /指摘自体/
してきどくせん /私的独占/
してきふくせい /私的複製/
してきふくせいぶつ /私的複製物/
してきもくてき /私的目的/
してきもくてきいがい /私的目的以外/
してきりえき /私的利益/
してきりゆう /指摘理由/
してきりよう /私的利用/
してきりようもくてき /私的利用目的/
してせん /仕手戦/
してつ /私鉄/
してつけっそんほじょ /私鉄欠損補助/
してつしゃりょう /私鉄車両/
してつしょうわ /私鉄昭和/
してつじだい /私鉄時代/
してつせん /私鉄線/
してつでんしゃ /私鉄電車/
してん /視点/支店/始点/支点/祀天/祀典/
してんいぞん /視点依存/
してんざひょう /視点座標/
してんじょうほう /支店情報/
してんちょう /支店長/
してんちょうきんむ /支店長勤務/
してんちょうさま /支店長様/
してんとう /支店等/
してんどくりつ /視点独立/
してんのう /四天王/
してんのうじまえ /四天王寺前/
してんめい /支店名/
しで /椣/
しでむし /埋葬虫/
しでん /市電/紫電/
しでんえんちょう /市電延長/
しでんかい /紫電改/紫電海/
しでんはいし /市電廃止/
しと /使途/使徒/司徒/
しとう /死闘/至当/
しとど /鵐/
しとね /褥/
しとみ /蔀/
しとめにん /仕留人/
しとやか /淑やか/
しど /志度/
しどう /指導/始動/私道/市道/示導/
しどういん /指導員/
しどういんけんしゅうかい /指導員研修会/
しどういんけんてい /指導員検定/
しどういんしつ /指導員室/
しどうきかん /指導機関/
しどうきょういく /指導教育/
しどうきょうかん /指導教官/
しどうきょうじゅ /指導教授/
しどうこんなん /始動困難/
しどうご /始動後/
しどうしゃ /指導者/
しどうしゃたち /指導者達/
しどうしょ /指導書/
しどうじ /始動時/
しどうせい /始動性/指導性/
しどうせきにん /指導責任/
しどうそう /指導層/
しどうたいきょく /指導対局/
しどうだんたい /指導団体/
しどうちょくご /始動直後/
しどうてき /指導的/
しどうてきせいじか /指導的政治家/
しどうてきたちば /指導的立場/
しどうてびきしょ /指導手引書/
しどうどうき /示導動機/
しどうないよう /指導内容/
しどうぶ /指導部/
しどうほう /指導法/
しどうほうしん /指導方針/
しどうめん /指導面/
しどうようきょうかしょ /指導用教科書/
しどうようこう /指導要項/
しどうようりょう /指導要領/
しどうりねん /指導理念/
しどうりょく /指導力/
しどく /試読/
しどせん /志度線/
しどちょうせい /視度調整/
しな /品/支那/科/
しない /市内/竹刀/
しないいどう /市内移動/
しないえき /市内駅/
しないえきせいど /市内駅制度/
しないかんこう /市内観光/
しないきどう /市内軌道/
しないきょくばん /市内局番/
しないきんこう /市内近郊/
しないじゅんかん /市内循環/
しないず /市内図/
しないせん /市内線/
しないせんようしゃ /市内専用車/
しないたいかい /市内大会/
しないちゅうしんぶ /市内中心部/
しないつうわ /市内通話/
しないでんわ /市内電話/
しないでんわばんごう /市内電話番号/
しないでんわりょうきん /市内電話料金/
しないよう /市内用/
しなうす /品薄/
しなかず /品数/
しながわ /品川/
しながわえき /品川駅/
しながわえきひがしぐち /品川駅東口/
しながわえきまえ /品川駅前/
しながわえきみなとみなみぐち /品川駅港南口/
しながわかん /品川間/
しながわく /品川区/
しながわくひがししながわ /品川区東品川/
しながわじょしがくいん /品川女子学院/
しながわたんとう /品川担当/
しながわでんしゃく /品川電車区/
しながわどうぶつえん /品川動物園/
しながわひがしぐち /品川東口/
しながわゆき /品川行/
しなぎれ /品切れ/品切/
しなこ /信成子/
しなさだめ /品定め/
しなじな /品々/
しなじへん /支那事變/支那事変/
しなぞろえ /品揃え/
しなだ /品田/
しなだい /品代/
しなつるせん /品鶴線/
しなの /信濃/品濃/品野/
しなのおおまち /信濃大町/
しなのおおまちえき /信濃大町駅/
しなのがわ /信濃川/
しなのちょう /信濃町/
しなのまち /信濃町/
しなのまちえき /信濃町駅/
しなのまちがわ /信濃町側/
しなのまちちゃく /信濃町着/
しなのまちつうか /信濃町通過/
しなぷす /シナプス/
しなもの /品物/
しなりお /シナリオ/
しなん /至難/指南/
しにあ /シニア/
しにがみ /死神/
しにく /視肉/
しにざま /死に様/
しにせ /老舗/
しにせきゅうだん /老舗球団/
しにゅう /刺入/
しにょう /し尿/屎尿/
しにん /死人/視認/
しにんかのう /視認可能/
しにんせい /視認性/
しねま /シネマ/
しねん /思念/
しの /篠/紫乃/信乃/志野/詩乃/志乃/
しのかわ /篠河/篠川/
しのき /篠木/
しのぎ /凌/鎬/凌ぎ/
しのくりせん /篠栗線/
しのごの /四の五の/
しのざき /篠崎/
しのしま /篠島/
しのしょうにん /死の商人/
しのすけ /志の輔/
しのたけ /篠竹/
しのだ /篠田/信田/
しのづか /篠塚/
しののい /篠ノ井/
しののいせん /篠ノ井線/
しののめ /東雲/
しのはら /篠原/
しのばず /不忍/
しのばずぐち /不忍口/
しのばずのいけ /不忍池/
しのび /忍/忍び/
しのびのもの /忍ノ者/
しのびわらい /忍び笑い/
しのぶ /忍/紫伸/偲/信夫/
しのぶえ /篠笛/
しのぶぐさ /荵/
しのみや /篠宮/四ノ宮/四宮/
しのむら /篠村/
しのもと /篠本/
しのやま /篠山/
しのやまきしん /篠山紀信/
しのろ /篠路/
しはい /支配/賜杯/紙背/
しはいか /支配下/
しはいかいそう /支配階層/
しはいぎ /支配木/
しはいけん /支配権/
しはいこう /支配項/
しはいこうぞう /支配構造/
しはいし /支配子/
しはいしゃ /支配者/
しはいしゃそう /支配者層/
しはいせいぶつ /支配生物/
しはいせつ /支配節/
しはいそう /支配層/
しはいちいき /支配地域/
しはいてき /支配的/
しはいてきちい /支配的地位/
しはいにん /支配人/
しはいりつ /支配率/
しはいりょく /支配力/
しはく /糸帛/
しはす /師走/
しはつ /始発/
しはつえき /始発駅/
しはつぐみ /始発組/
しはつこくない /始発国内/
しはつち /始発地/
しはつちてん /始発地点/
しはつていりゅうじょ /始発停留所/
しはつてん /始発点/
しはつでんしゃ /始発電車/
しはつびん /始発便/
しはつれっしゃ /始発列車/
しはらい /支払/支払い/
しはらいがく /支払額/
しはらいき /支払機/
しはらいきんがく /支払金額/
しはらいずみ /支払済/
しはらいせきにんがく /支払責任額/
しはらいせきにんしゃ /支払責任者/
しはらいちょうしょ /支払調書/支払い調書/
しはらいてがた /支払手形/
しはらいにん /支払人/
しはらいび /支払日/
しはらいほうほう /支払方法/
しはらいまどぐち /支払窓口/
しはらいよゆうひりつ /支払余裕比率/
しはらいりつ /支払率/
しはん /市販/師範/四半/紫斑/
しはんか /市販化/
しはんかかく /市販価格/
しはんき /四半期/
しはんしゃ /市販車/
しはんしゃりょう /市販車両/
しはんせいき /四半世紀/
しはんせいひん /市販製品/
しはんだい /師範代/
しはんひん /市販品/
しはんやく /市販薬/
しはんよう /市販用/
しば /芝/柴/司馬/死馬/斯波/
しばい /芝居/
しばいけ /芝池/
しばいぢゃや /芝居茶屋/
しばうら /芝浦/
しばうらこうだい /芝浦工大/
しばかり /芝刈/柴刈/柴刈り/
しばかわ /芝川/
しばがき /柴垣/
しばくさ /芝草/
しばけいけん /芝経験/
しばこうえん /芝公園/
しばこうえんちゅうがく /芝公園中学/
しばこうだい /芝工大/
しばさき /柴崎/
しばざき /柴崎/
しばし /暫/暫し/
しばした /芝下/
しばしば /屡/屡々/
しばす /始バス/市バス/
しばせいねんかいかん /芝青年会館/
しばせん /司馬遷;漢の武帝の時代の人。史記の著者/
しばた /柴田/柴多/新発田/芝田/
しばたれんざぶろう /柴田錬三郎/
しばち /芝地/
しばの /柴野/芝野/
しばはま /芝浜/
しばはら /芝原/紫原/柴原/
しばふ /芝生/
しばふせき /芝生席/
しばふひろば /芝生広場/
しばふぶぶん /芝生部分/
しばまた /柴又/
しばまち /柴町/
しばみや /柴宮/
しばやま /柴山/芝山/
しばやまてつどう /芝山鉄道/
しばらく /暫く/
しばりょうたろう /司馬遼太郎/
しばれる /凍れる/
しばん /指板/篩板/
しひ /私費/市費/
しひょう /指標/私評/死票/
しひょうか /指標化/
しびれ /痺/
しびん /溲瓶/
しふく /私服/雌伏/至福/私腹/紙幅/
しふくいっちょう /至福一兆/
しふくせんねん /至福千年/
しふと /シフト/
しふん /私憤/
しぶ /支部/渋/４分/澁/市部/澀/篩部/
しぶあき /４分空/
しぶい /渋井/
しぶいち /四分一/
しぶおんぷ /４分音符/四分音符/
しぶかいひ /支部会費/
しぶかつどう /支部活動/
しぶかわ /渋川/渋皮/
しぶかわえき /渋川駅/
しぶかわおんせん /渋川温泉/
しぶがきたい /シブがき隊/
しぶき /飛沫/沫/
しぶこう /渋公/
しぶさわ /渋沢/澁澤/
しぶさわえき /渋沢駅/
しぶさわかん /渋沢間/
しぶし /志布志/
しぶしぶ /渋々/
しぶた /渋田/
しぶたいかい /支部大会/
しぶたに /渋谷/
しぶちょう /支部長/
しぶちょうせいど /支部長制度/
しぶつ /私物/
しぶつか /私物化/
しぶとうげ /渋峠/
しぶみ /渋み/
しぶみがわ /渋海川/
しぶや /渋谷/澁谷/
しぶやいえん /渋谷以遠/
しぶやえき /渋谷駅/
しぶやえきこうない /渋谷駅構内/
しぶやえきなんとう /渋谷駅南東/
しぶやえきまえ /渋谷駅前/
しぶやかいかん /渋谷会舘/渋谷会館/
しぶやかん /渋谷間/
しぶやく /渋谷区/澁谷區/
しぶやこうかいどう /渋谷公会堂/
しぶやじょし /渋谷女子/
しぶやせいぶ /渋谷西武/
しぶやてん /渋谷店/
しぶやほうこう /渋谷方向/
しぶやほうめん /渋谷方面/
しぶれいかい /支部例会/
しぶろく /四分六/
しぶん /詩文/
しぶんか /死文化/
しぶんしょ /私文書/
しぶんしょぎぞう /私文書偽造/
しへい /紙幣/子平/
しへいちょう /子平町/
しへいまち /子平町/
しへん /詩篇/紙片/四辺/
しへんけい /四辺形/
しべ /蕊/蘂/蕋/
しべちゃ /標茶/
しべつ /標別/士別/標津/死別/
しべつせん /標津線/
しべとろ /蕊取/
しべりあ /西伯利亞/シベリア/
しべん /思弁/支弁/至便/
しほ /志保/志穂/紫穂/汐/潮/鹽/志帆/
しほう /紫峰/四方/司法/至宝/市報/視法/
しほうかんけいしゃ /司法関係者/
しほうかんけん /司法官憲/
しほうかんりょう /司法官僚/
しほうきかん /司法機関/
しほうけん /司法権/
しほうしけん /司法試験/
しほうしょし /司法書士/
しほうせいど /司法制度/
しほうていど /四方程度/
しほうはっぽう /四方八方/
しほうはっぽうさい /四方八方祭/
しほうはんだん /司法判断/
しほこ /志保子/
しほさゐ /潮騒/
しほどき /潮時/
しほひ /潮干/
しほふき /潮吹き/
しほろ /士幌/
しほん /資本/
しほんうんようじょうきょう /資本運用状況/
しほんか /資本家/
しほんかんけい /資本関係/
しほんがわ /資本側/
しほんきん /資本金/
しほんごうけい /資本合計/
しほんさんか /資本参加/
しほんしゅぎ /資本主義/
しほんしゅぎけいざい /資本主義経済/
しほんしゅぎしゃ /資本主義者/
しほんしゅぎしゃかい /資本主義社会/
しほんしゅぎてき /資本主義的/
しほんしんしゅつ /資本進出/
しほんじゅんびきん /資本準備金;法定準備金の一種。新株発行時の額面オーバー分/
しほんせい /資本制/
しほんていけい /資本提携/
しほんりょく /資本力/
しほんろん /資本論/
しぼ /思慕/
しぼう /死亡/志望/脂肪/子房/
しぼうかい /子房下位/
しぼうきけんりつ /死亡危険率/
しぼうきじ /死亡記事/
しぼうげんいん /死亡原因/
しぼうこう /志望校/
しぼうさいぼう /脂肪細胞/
しぼうさん /脂肪酸/
しぼうしゃ /志望者/死亡者/
しぼうじ /死亡時/
しぼうじこ /死亡事故/
しぼうじほけんきん /死亡時保険金/
しぼうすう /死亡数/
しぼうた /柴生田/
しぼうどうき /志望動機/
しぼうはんてい /死亡判定/
しぼうほけん /死亡保険/
しぼうほけんきん /死亡保険金/
しぼうゆ /脂肪油/
しぼうりつ /死亡率/
しぼうりつひ /死亡率比/
しぼくのしん /徙木之信/
しぼつ /死没/死歿/
しぼり /絞り/
しま /島/縞/嶋/志摩/志真/嶌/揣摩/志麻/四万/
しまい /姉妹/仕舞/仕舞い/
しまいかんけい /姉妹関係/
しまいき /姉妹機/
しまいきしゅ /姉妹機種/
しまいこう /姉妹校/
しまいご /姉妹語/
しまいしゃ /姉妹車/
しまいてん /姉妹店/
しまいとし /姉妹都市/
しまいひん /姉妹品/
しまいへん /姉妹篇/姉妹編/
しまいやく /姉妹役/
しまうち /島内/
しまうま /シマウマ/
しまお /嶋尾/
しまおか /島岡/
しまおくそく /揣摩臆測/
しまかげ /島陰/島影/
しまがはら /島ヶ原/
しまきんぺん /島近辺/
しまぐに /島国/
しまこ /志麻子/
しまこうさく /島耕作/
しまこうぞう /縞構造/
しまさき /島崎/嶋崎/
しまざき /島崎/嶋崎/
しましま /縞々/
しまじょう /縞状/
しまじり /島尻/
しまず /島津/
しませ /島瀬/
しません /島線/志摩線/
しませんき /島戦記/
しまぜんぶ /島全部/
しまたに /島谷/嶋谷/
しまだ /島田/嶋田/
しまだかん /島田間/
しまだし /島田市/
しまだしえいきゅうじょう /島田市営球場/
しまだようこ /島田陽子/
しまつ /始末/嶋津/
しまつしょ /始末書/
しまつにん /始末人/
しまづ /島津/嶋津/
しまづけ /島津家/
しまづせいさくしょ /島津製作所/
しまてつ /島鉄/
しまてつかづさえき /島鉄加津佐駅/
しまとう /島藤/
しまなか /嶋中/島中/
しまね /島根/
しまねけん /島根県/
しまねげんぱつ /島根原発/
しまねだい /島根大/
しまねちょう /島根町/
しまの /島野/嶋野/
しまのせき /島ノ関/
しまばら /島原/
しまばらこう /島原港/
しまばらさん /島原山/
しまばらし /島原市/
しまばらしない /島原市内/
しまばらてつどう /島原鉄道/
しまばらはんとう /島原半島/
しまひ /仕舞ひ/
しまぶくろ /島袋/
しまほうめん /島方面/
しままき /島牧/
しままと /島本/
しまみや /嶋宮/
しまむら /島村/嶋村/
しまもと /島本/
しまもよう /縞模様/
しまもり /島森/
しまや /島谷/
しまり /締/
しまわき /嶋脇/
しまんとがわ /四万十川/
しみ /衣魚/汚点/紙魚/染み/
しみじみ /染々/沁々/
しみず /清水/志水/紫水/
しみずえき /清水駅/
しみずかわ /清水川/
しみずけんせつ /清水建設/
しみずさわ /清水沢/
しみずし /清水市/
しみずしみん /清水市民/
しみずしゅっしん /清水出身/
しみずしょう /清水商/
しみずだいら /清水平/
しみずだに /清水谷/
しみずちょう /清水町/
しみずとうげ /清水峠/
しみずぬま /清水沼/
しみずはら /清水原/
しみずひがし /清水東/
しみずひがしこうこう /清水東高校/
しみずや /清水屋/
しみずよしのり /清水義範/
しみぬき /染み抜き/
しみゃく /支脈/
しみゅれーしょん /シミュレーション/
しみゅれーたー /シミュレーター/
しみん /市民/嗜眠/
しみんうんどう /市民運動/
しみんうんどうだんたい /市民運動団体/
しみんおんせん /市民温泉/
しみんか /市民課/市民化/
しみんかいかん /市民会館/
しみんかいかんまえ /市民会館前/
しみんかいほうこうざ /市民開放講座/
しみんぎいん /市民議員/
しみんけん /市民権/
しみんげきじょう /市民劇場/
しみんしゃかい /市民社会/
しみんせいかつ /市民生活/
しみんぜい /市民税/
しみんたいかい /市民大会/
しみんだいがく /市民大学/
しみんだいがくこうざ /市民大学講座/
しみんだんたい /市民団体/
しみんてきじゆう /市民的自由/
しみんびょうどう /四民平等/
しみんむせん /市民無線/
しみんよう /市民用/
しむかっぷ /占冠/
しむけ /仕向/
しむけこく /仕向国/
しむけち /仕向地/
しむら /志村/
しめ /示/締め/〆/志免/締/
しめい /氏名/指名/使命/指命/誌名/死命/紙名/市名/
しめいかん /使命感/
しめいじ /指名時/
しめいじゅんい /指名順位/
しめいだしゃ /指名打者/
しめいつうわ /指名通話/
しめいてはい /指名手配/
しめいひょうじけん /氏名表示権/
しめいらん /使命欄/
しめいりょう /指名料/
しめきり /締切/〆切/締め切り/
しめきりご /締切後/
しめきりじこく /締切時刻/
しめきりちょくぜん /締切直前/
しめきりび /締切日/
しめきりほうほう /締切方法/
しめきりまえ /締切前/
しめきりまぎわ /締切間際/
しめぐ /締具/
しめつ /死滅/
しめなわ /注連縄/
しめの /示野/
しめび /締め日/締日/
しめむら /示村/
しめりゆき /湿り雪/
しめん /紙面/誌面/四面/
しめんそか /四面楚歌/
しも /下/霜/
しもあがた /下県/
しもあやし /下愛子/
しもい /下井/下位/
しもいぐさ /下井草/
しもいだ /下井田/
しもいち /下一/下市/
しもいな /下伊那/
しもいなば /下稲葉/
しもう /刺毛/
しもうさ /下総/
しもうま /下馬/
しもお /下尾/
しもおちあい /下落合/
しもかぬき /下香貫/
しもかまがり /下蒲刈/
しもかわ /下川/
しもかわべ /下河辺/
しもがも /下鴨/
しもがもおんせん /下賀茂温泉/
しもがもじんじゃ /下鴨神社/
しもがれ /霜枯れ/
しもき /下期/
しもきた /下北/
しもきたこうつう /下北交通/
しもきたざわ /下北沢/
しもきたざわえき /下北沢駅/
しもきたざわきたぐち /下北沢北口/
しもきたざわしょ /下北沢署/
しもきたはんとう /下北半島/
しもきたやま /下北山/
しもぎょう /下京/
しもくに /下國/
しもくろかわ /下黒川/
しもげ /下毛/
しもこしき /下甑/
しもごう /下郷/
しもごおり /下郡/
しもさくのべ /下作延/
しもざ /下座/
しもざと /下里/
しもざわ /下沢/
しもしき /下敷/
しもしきりょう /下敷領/
しもしん /下新/
しもじ /下地/
しもじま /下嶋/
しもじも /下々/下下/
しもじゅう /下重/
しもじょう /下條/下城/下条/
しもすわ /下諏訪/
しもすわえき /下諏訪駅/
しもせわ /下世話/
しもぞの /下園/下薗/
しもたかい /下高井/
しもたかいど /下高井戸/
しもたかの /下高野/
しもだ /下田/
しもだいら /下平/
しもだて /下館/
しもちしま /下地島/
しもちゃ /下家/
しもつ /下津/
しもつい /下津井/
しもついでんてつ /下津井電鉄/
しもつが /下都賀/
しもつき /霜月/
しもつけ /下野/
しもつじ /下辻/
しもつま /下妻/
しもづま /下妻/
しもて /下手/
しもとり /下鳥/霜取/霜鳥/
しもなり /下成/
しもにいかわ /下新川/
しもにた /下仁田/
しもにたねぎ /下仁田葱/
しもねた /下ネタ/
しもの /下野/
しものく /下の句/
しものせき /下関/
しものせきいえん /下関以遠/
しものせきえき /下関駅/
しものせきかん /下関間/
しものせきがわ /下関側/
しものせきし /下関市/
しものせきにしこうこう /下関西高校/
しものせきはつ /下関発/
しものせきみなみこう /下関南高/
しものだふきん /下野田付近/
しもはんき /下半期/
しもはんきしゅっぱんぶつ /下半期出版物/
しもばしら /霜柱/
しもばやし /下林/
しもひとけた /下一桁/
しもひろ /下廣/
しもふさ /下総/
しもふり /霜降り/
しもへい /下閉伊/
しもべ /下僕/下部/僕/
しもましき /下益城/
しもまるこ /下丸子/
しもまるこじぎょうしょ /下丸子事業所/
しもみち /下道/
しもみのち /下水内/
しもむ /下無/
しもむら /下村/
しもめぐろ /下目黒/
しもやけ /霜焼け/
しもやなぎ /下柳/
しもやま /下山/霜山/
しもやまて /下山手/
しもよし /下吉/
しもれんじゃく /下連雀/
しもん /諮問/指紋/試問/子門/
しもんいいんかい /諮問委員会/
しもんかい /試問会/
しもんきかん /諮問機関/
しもんしょうごう /指紋照合/
しゃ /者/社/車/写/斜/謝/煮/舎/射/捨/紗/赦/遮/砂/沙/這/冩/奢/娑/寫/洒/瀉/炙/舍/赭/鷓/蔗/西/卸/柘/
しゃーぷ /シャープ/
しゃあ /西/
しゃい /謝意/斜位/
しゃいん /社員/社印/
しゃいんかん /社員間/
しゃいんしょう /社員証/
しゃいんしょくどう /社員食堂/
しゃいんばんごう /社員番号/
しゃいんりょう /社員寮/
しゃいんりょこう /社員旅行/
しゃいんわり /社員割/
しゃうん /社運/
しゃえい /射影/写影/
しゃえいほう /射影法/
しゃおく /社屋/
しゃおん /謝恩/遮音/
しゃおんかい /謝恩会/
しゃおんこうか /遮音効果/
しゃおんせい /遮音性/
しゃおんせいのう /遮音性能/
しゃおんとうきゅう /遮音等級/
しゃおんとくせい /遮音特性/
しゃおんりょう /遮音量/
しゃか /釈迦/社歌/
しゃかい /社会/
しゃかいあく /社会悪/
しゃかいいしき /社会意識/
しゃかいいっぱん /社会一般/
しゃかいいりょう /社会医療/
しゃかいか /社会科/社会化/
しゃかいかがく /社会科学/
しゃかいかがくかんけい /社会科学関係/
しゃかいかがくけい /社会科学系/
しゃかいかがくてき /社会科学的/
しゃかいかがくぶんや /社会科学分野/
しゃかいかんきょう /社会環境/
しゃかいかんけい /社会関係/
しゃかいかんげん /社会還元/
しゃかいかんしゅう /社会慣習/
しゃかいがく /社会学/
しゃかいがくしゃ /社会学者/
しゃかいがくてき /社会学的/
しゃかいがくぶ /社会学部/
しゃかいきこう /社会機構/
しゃかいきはん /社会規範/
しゃかいきょういく /社会教育/
しゃかいきょういくがく /社会教育学/
しゃかいけん /社会権/
しゃかいけんきゅうじょ /社会研究所/
しゃかいげんしょう /社会現象/
しゃかいげんしょうか /社会現象化/
しゃかいこう /社会工/
しゃかいこうがく /社会工学/
しゃかいこうがくせんこう /社会工学専攻/
しゃかいこうがくるい /社会工学類/
しゃかいこうがっか /社会工学科/
しゃかいこうぞう /社会構造/
しゃかいこうどう /社会行動/
しゃかいさんか /社会参加/
しゃかいしそうしゃ /社会思想社/
しゃかいしほん /社会資本/
しゃかいしみん /社会市民/
しゃかいしゅうだん /社会集団/
しゃかいしゅぎ /社会主義/
しゃかいしゅぎてき /社会主義的/
しゃかいしんしゅつ /社会進出/
しゃかいしんしゅつりょう /社会進出量/
しゃかいしんとう /社会新党/
しゃかいしんり /社会心理/
しゃかいしんりがく /社会心理学/
しゃかいしんりがくてき /社会心理学的/
しゃかいじたい /社会自体/
しゃかいじょう /社会上/
しゃかいじょうきょう /社会状況/
しゃかいじょうしき /社会常識/
しゃかいじょうせい /社会情勢/
しゃかいじん /社会人/
しゃかいじんいんせい /社会人院生/
しゃかいじんきょういく /社会人教育/
しゃかいじんしゅっしん /社会人出身/
しゃかいじんじゅけんしゃ /社会人受験者/
しゃかいじんたいかい /社会人大会/
しゃかいじんちゅうしん /社会人中心/
しゃかいじんにゅうがく /社会人入学/
しゃかいじんにゅうし /社会人入試/
しゃかいじんやきゅう /社会人野球/
しゃかいじんよう /社会人用/
しゃかいじんよびぐん /社会人予備軍/
しゃかいせい /社会性/
しゃかいせいかつ /社会生活/
しゃかいせいかつてき /社会生活的/
しゃかいせいぎ /社会正義/
しゃかいせいど /社会制度/
しゃかいせいぶつがく /社会生物学/
しゃかいせいほうこう /社会性方向/
しゃかいぜんかんげん /社会全還元/
しゃかいぜんたい /社会全体/
しゃかいぜんぱん /社会全般/
しゃかいぞう /社会増/
しゃかいたいせい /社会体制/
しゃかいちつじょ /社会秩序/
しゃかいつうねん /社会通念/
しゃかいつうねんじょう /社会通念上/
しゃかいてき /社会的/
しゃかいてきいしき /社会的意識/
しゃかいてきいみ /社会的意味/
しゃかいてきえいきょう /社会的影響/
しゃかいてきおう /社会適応/
しゃかいてきおうせい /社会適応性/
しゃかいてきかんかく /社会的感覚/
しゃかいてきかんきょう /社会的環境/
しゃかいてきかんしゅう /社会的慣習/
しゃかいてききせい /社会的規制/
しゃかいてききやく /社会的規約/
しゃかいてきこうせい /社会的構成/社会的公正/
しゃかいてきこうどう /社会的行動/
しゃかいてきごうい /社会的合意/
しゃかいてきしえん /社会的支援/
しゃかいてきしめい /社会的使命/
しゃかいてきしんよう /社会的信用/
しゃかいてきじゃくしゃ /社会的弱者/
しゃかいてきじょうきょう /社会的状況/
しゃかいてきじょうしき /社会的常識/
しゃかいてきせいさい /社会的制裁/
しゃかいてきせいやく /社会的制約/
しゃかいてきせきにん /社会的責任/
しゃかいてきそくめん /社会的側面/
しゃかいてきそんしつ /社会的損失/
しゃかいてきたちば /社会的立場/
しゃかいてきちい /社会的地位/
しゃかいてきつうねん /社会的通念/
しゃかいてきどうぎせい /社会的道義性/
しゃかいてきはいたい /社会的敗退/
しゃかいてきひはん /社会的批判/
しゃかいてきひょうか /社会的評価/
しゃかいてきぶんみゃく /社会的文脈/
しゃかいてきみぶん /社会的身分/
しゃかいてきめいぶん /社会的名分/
しゃかいてきもんだい /社会的問題/
しゃかいてきよういん /社会的要因/
しゃかいてきようそ /社会的要素/
しゃかいてきりえき /社会的利益/
しゃかいてきわだい /社会的話題/
しゃかいとう /社会党/
しゃかいとうさは /社会党左派/
しゃかいとうせい /社会統制/
しゃかいとうたいかい /社会党大会/
しゃかいにんしき /社会認識/
しゃかいは /社会派/
しゃかいはいけい /社会背景/
しゃかいはさくひん /社会派作品/
しゃかいひはん /社会批判/
しゃかいふうきじょう /社会風紀上/
しゃかいふうちょう /社会風潮/
しゃかいふくし /社会福祉/
しゃかいふっき /社会復帰/
しゃかいふてきおうしゃ /社会不適応者/
しゃかいぶ /社会部/
しゃかいへんか /社会変化/
しゃかいほう /社会法/
しゃかいほうし /社会奉仕/
しゃかいほけん /社会保険/
しゃかいほしょう /社会保障/
しゃかいみんしゅしゅぎ /社会民主主義/
しゃかいみんしゅせいりょく /社会民主勢力/
しゃかいみんしゅとう /社会民主党/
しゃかいめん /社会面/
しゃかいもんだい /社会問題/
しゃかいもんだいか /社会問題化/
しゃかいりろん /社会理論/
しゃかく /車格/射角/斜格/
しゃかさま /釈迦様/
しゃかっこう /斜滑降/
しゃかん /舎監/車間/
しゃかんきょり /車間距離/
しゃがい /社外/車外/
しゃがいとりしまりやく /社外取締役/
しゃがいひ /社外秘/
しゃがいひじこう /社外秘事項/
しゃがいひん /社外品/
しゃがいべんきょうかい /社外勉強会/
しゃがく /写楽/
しゃき /社旗/社規/
しゃきゅう /社給/
しゃきゅうひん /社給品/
しゃきょう /写経/
しゃきん /謝金/
しゃぎょう /社業/
しゃく /釈/昔/借/錫/尺/酌/爵/灼/杓/勺/石/赤/笏/嚼/妁/斫/爍/癪/皙/綽/芍/釋/鑠/蹟/炸/蜥/
しゃくい /爵位/
しゃくざい /借財/
しゃくし /杓子/
しゃくしじょうぎ /杓子定規/
しゃくじ /借字/
しゃくじい /石神井/
しゃくじいこうえん /石神井公園/
しゃくじいだい /石神井台/
しゃくじょう /錫杖/
しゃくぜん /釈然/
しゃくそん /釈尊/
しゃくち /借地/
しゃくちけん /借地権/
しゃくちりょう /借地料/
しゃくとりむし /尺取虫/尺蠖/
しゃくど /尺度/赤土/
しゃくどう /赤銅/
しゃくどういろ /赤銅色/
しゃくどち /尺度値/
しゃくどほう /尺度法/
しゃくなが /尺長/
しゃくにゅう /借入/
しゃくにゅうきん /借入金/
しゃくねつ /灼熱/
しゃくねつじごく /灼熱地獄/
しゃくはち /尺八/
しゃくふ /酌婦/
しゃくぶく /折伏/
しゃくほう /釈放/
しゃくま /借間/
しゃくめい /釈明/綽名/
しゃくや /借家/
しゃくやく /芍薬/
しゃくやにん /借家人/
しゃくよう /借用/
しゃくようしょ /借用書/
しゃくようしょうしょ /借用証書/
しゃくようねがい /借用願/
しゃくりょう /酌量/
しゃくん /社訓/
しゃけ /鮭/
しゃけいよう /写経用/
しゃけつ /冩血/瀉血/
しゃけん /車検/写研/車券;競馬でいう馬券の競輪版。勝者投票券/
しゃけんぎれ /車検切/
しゃけんごうかくほう /車検合格法/
しゃけんしょう /車検証/
しゃけんしょうきさい /車検証記載/
しゃけんじ /車検時/
しゃけんじょう /車検場/
しゃけんせいど /車検制度/
しゃけんせいび /車検整備/
しゃけんたいおう /車検対応/
しゃけんたいおうひん /車検対応品/
しゃけんたんとう /車検担当/
しゃけんだい /車検代/
しゃけんだいこう /車検代行/
しゃけんてきおうがい /車検適応外/
しゃけんどり /車検取り/
しゃけんひよう /車検費用/
しゃけんまえ /車検前/
しゃげき /射撃/
しゃげきかん /射撃艦/
しゃげきじょう /射撃場/
しゃこ /車庫/蝦蛄/
しゃこう /車高/社交/斜行/遮光/
しゃこうかい /社交界/
しゃこうざひょう /斜交座標/
しゃこうし /斜行枝/
しゃこうしん /射幸心/射倖心/
しゃこうじれい /社交辞令/
しゃこうせい /遮光性/社交性/
しゃこうちょうせい /車高調整/
しゃこうてき /社交的/
しゃこうへんか /車高変化/
しゃこく /社告/
しゃこしょうめい /車庫証明/
しゃこしょうめいしんせい /車庫証明申請/
しゃこたん /積丹/
しゃこたんはんとう /積丹半島/
しゃこたんはんとうおき /積丹半島沖/
しゃこだい /車庫代/
しゃこつき /車庫付き/
しゃこない /車庫内/
しゃこないほかん /車庫内保管/
しゃこほう /車庫法/
しゃさい /社債/車載/
しゃさいかのう /車載可能/
しゃさいこうぐ /車載工具/
しゃさいしき /車載式/
しゃさいとりつけかなぐ /車載取付金具/
しゃさいよう /車載用/
しゃさいようかくせいき /車載用拡声器/
しゃさいれいぞうこ /車載冷蔵庫/
しゃさつ /射殺/
しゃざい /謝罪/
しゃざいこうこく /謝罪広告/
しゃざいぶん /謝罪文/
しゃざいようきゅう /謝罪要求/
しゃし /斜視/社史/奢侈/奢恣/奢肆/
しゃしつ /車室/
しゃしつない /車室内/
しゃしゃく /車借/
しゃしゅ /車種/射手/社主/
しゃしゅきせい /車種規制/
しゃしゅけいけん /車種経験/
しゃしゅごと /車種毎/
しゃしゅしてい /車種指定/
しゃしゅせんたく /車種選択/
しゃしゅせんてい /車種選定/
しゃしゅたいおうひょう /車種対応表/
しゃしゅつ /射出/
しゃしゅつご /射出後/
しゃしゅつせいけい /射出成型/
しゃしゅつせいけいき /射出成型機/
しゃしゅべつ /車種別/
しゃしょう /車掌/捨象/社章/蔗漿/
しゃしょうく /車掌区/
しゃしょうしつ /車掌室/
しゃしょうしゃ /車掌車/
しゃしょうちょう /車掌長/
しゃしょうべん /車掌弁/
しゃしょく /写植/社食/
しゃしょくいんさつき /写植印刷機/
しゃしょくき /写植機/
しゃしょくもじ /写植文字/
しゃしょくや /写植屋/
しゃしょくようげんこう /写植用原稿/
しゃしょゆう /社所有/
しゃしん /写真/
しゃしんいり /写真入り/写真入/
しゃしんうつり /写真写り/
しゃしんか /写真家/
しゃしんかん /写真館/
しゃしんがかり /写真係/
しゃしんき /写真機/
しゃしんきざいよう /写真機材用/
しゃしんこうぎょう /写真工業/
しゃしんごよう /写真誤用/
しゃしんさつえい /写真撮影/
しゃしんさつえいかい /写真撮影会/
しゃしんざっし /写真雑誌/
しゃしんしゅう /写真集/
しゃしんしゅうかんし /写真週刊誌/
しゃしんしょり /写真処理/
しゃしんじゅく /写真塾/
しゃしんだい /写真代/
しゃしんてん /写真展/
しゃしんてんぷ /写真添付/
しゃしんは /写真派/
しゃしんはんてい /写真判定/
しゃしんばん /写真版/
しゃしんひょうげん /写真表現/
しゃしんびじゅつかん /写真美術館/
しゃしんぶ /写真部/
しゃしんや /写真屋/
しゃしんよう /写真用/
しゃしんようでんきゅう /写真用電球/
しゃしんようひん /写真用品/
しゃじ /謝辞/斜字/社寺/
しゃじく /車軸/
しゃじくあつにゅうき /車軸圧入機/
しゃじくがわ /車軸側/
しゃじくはつでんき /車軸発電機/
しゃじたい /斜字体/
しゃじつ /写実/
しゃじつしゅぎ /写実主義/
しゃじつしゅぎてき /写実主義的/
しゃじつてき /写実的/
しゃじゅう /車重/
しゃじょう /謝状/車上/
しゃせい /射精/写生/社製/
しゃせつ /社説/
しゃせん /車線/斜線/
しゃせんかん /車線間/
しゃせんがわ /車線側/
しゃせんきせい /車線規制/
しゃせんごと /車線毎/
しゃせんすう /車線数/
しゃせんすうげんしょう /車線数減少/
しゃせんない /車線内/
しゃせんへんこう /車線変更/
しゃせんへんこうじ /車線変更時/
しゃせんへんこうまえ /車線変更前/
しゃぜ /社是/
しゃぜつ /謝絶/
しゃそう /社葬/車窓/斜走/
しゃそく /車速/社足/社則/
しゃそくちょうせつ /車速調節/
しゃぞう /写像/
しゃぞうほうほう /写像方法/
しゃたい /車体/斜体/
しゃたいうしろはし /車体後端/
しゃたいえんちょうこうじ /車体延長工事/
しゃたいがわ /車体側/
しゃたいきょうつう /車体共通/
しゃたいけいじょう /車体形状/
しゃたいこうしん /車体更新/
しゃたいこうぞう /車体構造/
しゃたいこうぶ /車体後部/
しゃたいしょく /車体色/
しゃたいせいのう /車体性能/
しゃたいちょう /車体長/
しゃたいはば /車体幅/
しゃたいばんごう /車体番号/
しゃたいひょうき /車体標記/
しゃたいへき /車体壁/
しゃたく /社宅/
しゃたくせいど /社宅制度/
しゃたんぶ /車端部/
しゃだい /社台/
しゃだつ /洒脱/
しゃだん /社団/遮断/射断/しゃ断/
しゃだんき /遮断機/遮断器/
しゃだんしゅうはすう /しゃ断周波数/
しゃだんぶつ /遮断物/
しゃだんほうじん /社団法人/
しゃだんぼう /遮断棒/
しゃち /鯱/
しゃちほこ /鯱鉾/鯱/
しゃちゅう /車中/社中/
しゃちゅうはく /車中泊/
しゃちょう /社長/車長/
しゃちょうこじん /社長個人/
しゃちょうしつ /社長室/
しゃちょうしゅうにん /社長就任/
しゃちょうじにん /社長辞任/
しゃっかん /借款/
しゃっかんほう /尺貫法/
しゃっきん /借金/
しゃっきんおとこ /借金男/
しゃっきんせいかつ /借金生活/
しゃっく /赤口/
しゃっけい /借景/
しゃっこう /笏康/灼光/赤光/
しゃっこつ /尺骨/
しゃったー /シャッター/
しゃっふりんぐ /シャッフリング/
しゃつ /シャツ/
しゃてい /射程/舎弟/
しゃていけんない /射程圏内/
しゃていない /射程内/
しゃてき /射的/
しゃとう /斜塔/車頭/
しゃど /斜度/
しゃどう /車道/
しゃな /紗那/
しゃない /社内/車内/
しゃないかいさつ /車内改札/
しゃないがい /社内外/
しゃないきそく /社内規則/
しゃないきてい /社内規定/
しゃないきんえん /社内禁煙/
しゃないけんがく /車内見学/
しゃないけんさつ /車内検札/
しゃないけんしゅう /社内研修/
しゃないさいそうしん /車内再送信/
しゃないし /社内誌/
しゃないしゃしん /車内写真/
しゃないしよう /車内仕様/
しゃないしんごうたいおう /車内信号対応/
しゃないじじょう /社内事情/
しゃないせいさん /車内精算/
しゃないせいど /社内制度/
しゃないせつび /車内設備/
しゃないせんよう /社内専用/
しゃないせんようせん /社内専用線/
しゃないぜんたい /社内全体/
しゃないてき /社内的/
しゃないでんわちょう /社内電話帳/
しゃないとう /車内灯/
しゃないはんばい /社内販売/車内販売/
しゃないはんばいよういん /車内販売要員/
しゃないひょうじゅん /社内標準/
しゃないびん /社内便/
しゃないふりん /社内不倫/
しゃないぶんしょ /社内文書/
しゃないほう /社内報/
しゃないほうそう /車内放送/
しゃないほじゅうけん /車内補充券/
しゃないむけ /社内向/
しゃないよきんよう /社内預金用/
しゃないりょこう /社内旅行/
しゃないりよう /社内利用/
しゃないれんあい /社内恋愛/
しゃないわりびき /社内割引/
しゃにくさい /謝肉祭/
しゃにむに /遮二無二/
しゃにゅう /西入/
しゃねつ /遮熱/
しゃはば /車幅/
しゃはん /車販/社販/
しゃば /娑婆/車馬/
しゃばくじょう /射爆場/
しゃばん /車番/社判/
しゃひ /社費/
しゃび /奢靡/
しゃふ /写譜/
しゃふう /社風/
しゃふく /車幅/
しゃふつ /煮沸/
しゃふつき /煮沸器/
しゃぶんれつ /斜分裂/
しゃへい /遮蔽/遮へい/
しゃへいざい /遮蔽材/
しゃへいじっけん /遮蔽実験/
しゃへいせっけい /遮蔽設計/
しゃへいたい /遮蔽体/
しゃへいばん /遮蔽板/
しゃへいぶつ /遮蔽物/
しゃへん /斜辺/
しゃほ /社保/
しゃほう /車砲/
しゃほたん /社保短/
しゃほん /写本/
しゃまく /紗幕/
しゃみせん /三味線/
しゃみせんかい /三味線界/
しゃみせんし /三味線師/
しゃみせんや /三味線屋/
しゃみんれん /社民連/
しゃむ /暹羅/
しゃむしょ /社務所/
しゃめい /社名/車名/社命/
しゃめいせんでん /社名宣伝/
しゃめいへんこう /社名変更/
しゃめん /斜面/赦免/
しゃめんじょう /斜面上/
しゃめんへんか /斜面変化/
しゃも /軍鶏/
しゃもん /沙門/
しゃゆう /社友/社有/
しゃゆうち /社有地/
しゃよう /社用/斜陽/
しゃようか /斜陽化/
しゃらく /写楽/酒楽/
しゃらそうじゅ /娑羅双樹/
しゃり /斜里/
しゃりえき /斜里駅/
しゃりき /車力/
しゃりょう /車両/車輛/車輌/
しゃりょういがい /車両以外/
しゃりょううんそうほう /車両運送法/
しゃりょううんよう /車両運用/
しゃりょうかかく /車両価格/
しゃりょうかさい /車両火災/
しゃりょうかん /車両間/
しゃりょうかんかく /車両感覚/
しゃりょうがいしゃ /車両会社/
しゃりょうがわ /車両側/
しゃりょうきち /車両基地/
しゃりょうきてい /車両規定/
しゃりょうく /車両区/
しゃりょうぐち /車両口/
しゃりょうけい /車両系/
しゃりょうけいしき /車両形式/
しゃりょうげんかい /車両限界/
しゃりょうこうかん /車両交換/
しゃりょうこうさく /車両工作/
しゃりょうこうしんちゅう /車両更新中/
しゃりょうこうにゅう /車両購入/
しゃりょうこしょう /車両故障/
しゃりょうさくせいぎじゅつ /車両作製技術/
しゃりょうじゅうしん /車両重心/
しゃりょうじゅうりょう /車両重量/
しゃりょうすう /車両数/
しゃりょうせいのう /車両性能/
しゃりょうせいのうこうじょう /車両性能向上/
しゃりょうぜんたい /車両全体/
しゃりょうぜんぶ /車両全部/
しゃりょうぞうけつ /車両増結/
しゃりょうだい /車両代/
しゃりょうちゅうしん /車両中心/
しゃりょうちゅうもん /車両注文/
しゃりょうてんけん /車両点検/
しゃりょうとうろく /車両登録/
しゃりょうとうろくひょう /車両登録票/
しゃりょうない /車両内/
しゃりょうないぶ /車両内部/
しゃりょうはいちひょう /車両配置表/
しゃりょうはば /車両幅/
しゃりょうばんごう /車両番号/
しゃりょうばんごうひょう /車両番号標/
しゃりょうぶそく /車両不足/
しゃりょうほう /車両法/
しゃりょうほけん /車両保険/
しゃりょうほんたい /車輌本体/
しゃりょうれいぼう /車両冷房/
しゃりん /車輪/
しゃりんおん /車輪音/
しゃりんせんばん /車輪旋盤/
しゃれ /シャレ/洒落/
しゃれい /謝礼/車齢/
しゃれき /社歴/車歴/
しゃれきじょう /車歴上/
しゃれつ /斜列/
しゃわー /シャワー/
しゃんたん /上湯/
しゃんはい /上海/
しゃんはいかぶ /上海株/
しゃんはいがに /上海蟹/
しゃんはいこうつうだいがく /上海交通大学/
しゃんはいご /上海語/
しゃんはいじへん /上海事變/
しゃんはいとっきゅう /上海特急/
しゃんぱん /三鞭酒/
しゃんぷー /シャンプー/
しや /視野/
しやかく /視野角/
しやく /試薬/試訳/
しやくかんり /試薬管理/
しやくしょ /市役所/
しやくしょふきん /市役所付近/
しやくしょまえ /市役所前/
しやくしょまえけいゆ /市役所前経由/
しやくしょまえけいゆう /市役所前経由/
しやくよう /試薬用/
しやけ /初宿/
しやぜんたい /視野全体/
しやりつ /視野率/
しやんかごうぶつ  /シヤン合物/
しゅ /主/種/手/取/首/酒/趣/修/守/狩/朱/腫/珠/殊/踵/侏/娵/娶/棕/椶/殳/洙/繻/蛛/銖/鬚/麈/撞/諏/株/衆/
しゅ> /主/
しゅーず /シューズ/
しゅーまい /シューマイ/焼売/
しゅい /首位/主意/趣意/種衣/
しゅいかんらく /首位陥落/
しゅいがため /首位固め/
しゅいけっせん /首位決戦/
しゅいこうぼう /首位攻防/
しゅいこうぼうせん /首位攻防戦/
しゅいしょ /趣意書/
しゅいだしゃ /首位打者/
しゅいだっかい /首位奪回/
しゅいち /主一/
しゅいどくそう /首位独走/
しゅいろ /朱色/
しゅいん /主因/手淫/
しゅう /週/集/修/収/秋/習/衆/拾/終/州/醜/周/秀/讐/襲/祝/臭/舟/愁/輯/蹴/就/酬/酋/蒐/洲/宗/囚/繍/嗅/執/朱/萩/售/啾/岫/愀/慫/慴/收/楸/楫/泅/湫/溲/甃/綉/緝/羞/脩/蓚/螽/褶/讎/踵/蹤/遒/逎/銹/鞦/駲/驟/摺/聚/鰍/鍬/袖/鷲/楢/穐/葺/
しゅうあく /醜悪/
しゅうあけ /週開け/週明け/
しゅうい /周囲/拾遺/衆意/周位/修理/
しゅういかんきょう /周囲環境/
しゅういきげんてき /周囲起源的/
しゅういち /週一/修一/秀一/周一/
しゅういちにち /週一日/
しゅういちょう /周囲長/
しゅういちろう /周一郎/修一郎/
しゅういっかい /週一回/
しゅういつ /秀逸/
しゅういん /衆院/執印/
しゅういんせん /衆院選/
しゅうう /驟雨/
しゅうえい /秀英/
しゅうえいしゃ /集英社/
しゅうえいしゃぶんこ /集英社文庫/
しゅうえき /収益/就役/
しゅうえききん /収益金/
しゅうえきせい /収益性/
しゅうえきりつ /収益率/
しゅうえきりょく /収益力/
しゅうえつ /収悦/
しゅうえん /終焉/終演/終宴/終鴛/周縁/
しゅうえんがた /周縁型/
しゅうえんご /終演後/
しゅうえんしげんさいぼう /周縁始原細胞/
しゅうえんじ /終演時/
しゅうえんせいちょう /周縁生長/
しゅうえんそうち /集煙装置/
しゅうえんぶ /周縁部/
しゅうえんぶんれつそしき /周縁分裂組織/
しゅうおん /収音/集音/
しゅうおんかのう /収音可能/
しゅうおんらい /周恩来/
しゅうおんらいしゅしょう /周恩来首相/
しゅうか /集荷/衆化/衆寡/
しゅうかい /集会/周回/集塊/聚會/醜怪/
しゅうかいきどう /周回起動/
しゅうかいしつ /集会室/
しゅうかいじょ /集会所/
しゅうかいすう /周回数/
しゅうかいせきぶん /周回積分/
しゅうかいせきぶんろ /周回積分路/
しゅうかいどうろ /周回道路/
しゅうかいめい /集会名/
しゅうかいろ /周回路/
しゅうかく /収穫/収獲/嗅覚/臭覚/
しゅうかくさい /収穫祭/
しゅうかくまえ /収穫前/
しゅうかくりょう /収穫量/
しゅうかさい /愁華祭/
しゅうかん /週間/習慣/週刊/収監/終刊/終巻/
しゅうかんあさひ /週刊朝日/
しゅうかんいじょう /週間以上/
しゅうかんか /習慣化/週刊化/
しゅうかんけいば /週刊競馬/週間競馬/
しゅうかんげんだい /週刊現代/
しゅうかんご /週間後/
しゅうかんごう /終刊号/
しゅうかんごと /週間毎/
しゅうかんざっし /週刊雑誌/
しゅうかんし /週刊誌/週刊紙/
しゅうかんしょうねん /週刊少年/週間少年/
しゅうかんせい /習慣性/
しゅうかんづけ /習慣付け/
しゅうかんてき /習慣的/
しゅうかんてんきよほう /週間天気予報/
しゅうかんぶんしゅん /週刊文春/
しゅうかんほうせき /週刊宝石/
しゅうかんまえ /週間前/
しゅうかんようはんたいじ /習慣用繁体字/
しゅうかんれんさい /週刊連載/
しゅうがく /修学/就学/
しゅうがくいん /修学院/
しゅうがくさき /就学先/
しゅうがくしょう /終楽章/
しゅうがくまえ /就学前/
しゅうがくりょこう /修学旅行/
しゅうがくりょこういがい /修学旅行以外/
しゅうがくりょこうせい /修学旅行生/
しゅうがくりょこうよう /修学旅行用/
しゅうがくりょこうれっしゃ /修学旅行列車/
しゅうき /秋季/周期/周忌/終期/臭気/秋期/秋気/終帰/
しゅうきうんどう /周期運動/
しゅうきおん /周期音/
しゅうきかい /周期解/
しゅうきかんすう /周期関数/
しゅうききょうかいじょうけん /周期境界条件/
しゅうきこうぞう /周期構造/
しゅうきしょり /周期処理/
しゅうきじ /集記事/
しゅうきすうれつ /周期数列/
しゅうきせい /周期性/
しゅうきせつ /周期説/
しゅうきたいかい /秋季大会/
しゅうきてき /周期的/
しゅうきてん /周期点/
しゅうきはけい /周期波形/
しゅうきへんどう /周期変動/
しゅうきほう /集気法/
しゅうきゃく /集客/
しゅうきゃくこうか /集客効果/
しゅうきゃくもくてき /集客目的/
しゅうきゃくりょく /集客力/
しゅうきゅう /週休/蹴球/週給/
しゅうきゅうふつか /週休二日/
しゅうきょう /宗教/
しゅうきょういっぱん /宗教一般/
しゅうきょうおんがく /宗教音楽/
しゅうきょうか /宗教家/
しゅうきょうかいかく /宗教改革/
しゅうきょうかん /宗教観/
しゅうきょうが /宗教画/
しゅうきょうがく /宗教学/
しゅうきょうがくしゃ /宗教学者/
しゅうきょうがっか /宗教学科/
しゅうきょうきょういく /宗教教育/
しゅうきょうきょく /宗教曲/
しゅうきょうげんしょう /宗教現象/
しゅうきょうさいばん /宗教裁判/
しゅうきょうさいばんかん /宗教裁判官/
しゅうきょうしゃかいがく /宗教社会学/
しゅうきょうしょく /宗教色/
しゅうきょうじょう /宗教上/
しゅうきょうせんそう /宗教戦争/
しゅうきょうだんたい /宗教団体/
しゅうきょうだんたいほう /宗教団体法/
しゅうきょうてき /宗教的/
しゅうきょうてきけんい /宗教的権威/
しゅうきょうてきじつざい /宗教的実在/
しゅうきょうほうじん /宗教法人/
しゅうきょうろんそう /宗教論争/
しゅうきょく /終曲/終局/褶曲/周極/
しゅうきょくいき /周極域/
しゅうきょくちょくご /終局直後/
しゅうきょくりゅう /周極流/
しゅうきりつ /周期律/
しゅうきりつひょう /周期律表/
しゅうきん /集金/
しゅうきんたんい /集金単位/
しゅうきんにん /集金人/
しゅうきんぶくろ /集金袋/
しゅうぎ /祝儀/衆議/
しゅうぎいん /衆議院/
しゅうぎいんかいさん /衆議院解散/
しゅうぎいんぎいん /衆議院議員/
しゅうぎいんせんきょ /衆議院選挙/衆議員選挙/
しゅうぎいんほうせいきょく /衆議院法制局/
しゅうぎく /秋菊/
しゅうぎょう /就業/終業/修業/
しゅうぎょうきそく /就業規則/
しゅうぎょうしき /終業式/
しゅうぎょうじかん /就業時間/
しゅうぎょうじかんちゅう /就業時間中/
しゅうぎょうせいげん /就業制限/
しゅうぎょうちゅう /修業中/就業中/
しゅうぎょうにっすう /就業日数/
しゅうぎょうひょう /就業票/
しゅうぎょうりつ /就業率/
しゅうぎょこうか /集魚効果/
しゅうぐ /衆愚/
しゅうぐじち /衆愚自治/
しゅうぐせいじ /衆愚政治/
しゅうぐん /州軍/
しゅうけい /集計/修景/
しゅうけいかいし /集計開始/
しゅうけいがかり /集計係/
しゅうけいきかん /集計期間/
しゅうけいきじ /集計記事/
しゅうけいけっか /集計結果/
しゅうけいけっかはっぴょう /集計結果発表/
しゅうけいさぎょう /集計作業/
しゅうけいしゃ /集計者/
しゅうけいしゃどくじ /集計者独自/
しゅうけいじ /集計時/
しゅうけいじょう /集計上/
しゅうけいじょうきょう /集計状況/
しゅうけいたんとう /集計担当/
しゅうけいちゅう /集計中/
しゅうけいとちゅうけいか /集計途中経過/
しゅうけいはっぴょう /集計発表/
しゅうけいほうほう /集計方法/
しゅうけいよう /集計用/
しゅうけつ /終結/集結/
しゅうけつがっしょう /終結合唱/
しゅうけつぶ /終結部/
しゅうけん /集権/舟券;競馬でいう馬券の競艇版/
しゅうけんてき /集圏的/
しゅうげき /襲撃/
しゅうげつ /秋月/
しゅうげん /祝言/
しゅうこ /修子/収子/
しゅうこう /周行/集光/周航/就航/修好/秋向/
しゅうこうぶ /集光部/
しゅうごう /集合/
しゅうごうえんざん /集合演算/
しゅうごうか /集合果/
しゅうごうかた /集合型/
しゅうごうがいねん /集合概念/
しゅうごうがた /集合型/
しゅうごうけい /集合系/
しゅうごうご /集合後/
しゅうごうざい /集合材/
しゅうごうしゃしん /集合写真/
しゅうごうじかん /集合時間/
しゅうごうぞく /集合族/
しゅうごうたい /集合体/
しゅうごうていこう /集合抵抗/
しゅうごうていすう /集合定数/
しゅうごうてき /集合的/
しゅうごうてきむいしき /集合的無意識/
しゅうごうばしょ /集合場所/
しゅうごうび /集合日/
しゅうごうへいきん /集合平均/
しゅうごうめいぎ /集合名義/
しゅうごうろん /集合論/
しゅうごうろんてきほうほう /集合論的方法/
しゅうごろう /周五郎/脩五郎/
しゅうさ /収差/
しゅうさい /秀才/収載/集載/
しゅうさきょくせん /収差曲線/
しゅうさく /秀作/秀策/習作/周作/
しゅうさず /収差図/
しゅうさつ /集札/
しゅうさつかかりいん /集札係員/
しゅうさん /集散/衆参/蓚酸/
しゅうさんかじょ /集散花序/
しゅうさんぎょうしゅぎ /集産業主義/
しゅうさんち /集散地/
しゅうざい /集材/秋材/
しゅうざかい /州境/
しゅうざん /周山/
しゅうし /修士/収支/終始/宗旨/終止/
しゅうしいちねん /修士壱年/修士一年/
しゅうしかてい /修士課程/
しゅうしかていじだい /修士課程時代/
しゅうしがくいろんぶん /修士学位論文/
しゅうしき /終式/
しゅうしけい /終止形/
しゅうしけいすう /収支係数/
しゅうしけっさん /収支決算/
しゅうしごう /修士号/
しゅうししゅうりょう /修士終了/
しゅうしにねん /修士二年/
しゅうしひょう /収支表/
しゅうしふ /終止符/
しゅうしぼ /収支簿/
しゅうしゃ /終車/
しゅうしゅう /収集/収拾/蒐集/拾集/集輯/啾啾/集収/
しゅうしゅうか /収集家/
しゅうしゅうかいひ /収拾回避/
しゅうしゅうかんり /収集管理/
しゅうしゅうさぎょう /収集作業/
しゅうしゅうし /収集子/
しゅうしゅうしゃ /収集車/収集者/
しゅうしゅうほうほう /収集方法/
しゅうしゅうりつ /集収率/
しゅうしゅく /収縮/
しゅうしゅくこん /収縮根/
しゅうしゅくりつ /収縮率/
しゅうしょう /愁傷/修証/終章/周章/就床/
しゅうしょうさま /愁傷様/
しゅうしょうろうばい /周章狼狽/
しゅうしょく /就職/修飾/
しゅうしょくかつどう /就職活動/
しゅうしょくかつどうよう /就職活動用/
しゅうしょくかんけい /就職関係/
しゅうしょくぐち /就職口/
しゅうしょくご /修飾語/
しゅうしょくごく /修飾語句/
しゅうしょくさき /就職先/
しゅうしょくさべつ /就職差別/
しゅうしょくざっし /就職雑誌/
しゅうしょくし /修飾子/
しゅうしょくしゃ /就職者/
しゅうしょくじ /就職時/
しゅうしょくじょうほう /就職情報/
しゅうしょくじょうほうし /就職情報誌/
しゅうしょくせつめいかい /就職説明会/
しゅうしょくせんせん /就職戦線/
しゅうしょくせんせんいじょう /就職戦線異状/
しゅうしょくなん /就職難/
しゅうしょくまえ /就職前/
しゅうしょくもんだい /就職問題/
しゅうしょくりつ /就職率/
しゅうしろんぶん /修士論文/
しゅうしん /就寝/執心/終身/修身/集信/
しゅうしんかいいん /終身会員/
しゅうしんかいひ /終身会費/
しゅうしんけい /終身刑/
しゅうしんこよう /終身雇用/
しゅうしんこようせい /終身雇用制/
しゅうしんしかく /終身資格/
しゅうしんまえ /就寝前/
しゅうしんよう /就寝用/
しゅうじ /修司/習字/修辞/周二/修治/修二/秀司/秀治/宗司/修次/秀次/
しゅうじがく /修辞学/
しゅうじぎもんぶん /修辞疑問文/
しゅうじつ /終日/週日/
しゅうじつかくてい /終日各停/
しゅうじつきんえん /終日禁煙/
しゅうじゅうろう /宗十郎/
しゅうじゅく /習熟/
しゅうじゅくてきほうほう /習熟的方法/
しゅうじゅくど /習熟度/
しゅうじょうたい /終状態/
しゅうじょし /終助詞/
しゅうじん /囚人/衆人/
しゅうじんかんし /衆人環視/
しゅうじんき /集塵器/
しゅうじんせん /囚人船/
しゅうじんふく /囚人服/
しゅうすけ /秀介/
しゅうせい /修正/習性/修整/集成/終世/終生/輯成/
しゅうせいあん /修正案/
しゅうせいいけん /修正意見/
しゅうせいいち /修正位置/
しゅうせいえき /修正液/
しゅうせいかしょ /修正個所/修正箇所/
しゅうせいかのう /修正可能/
しゅうせいきじ /修正記事/
しゅうせいきぼう /修正希望/
しゅうせいご /修正後/
しゅうせいし /修正子/
しゅうせいしんこく /修正申告/
しゅうせいじ /修正時/
しゅうせいじこう /修正事項/
しゅうせいじょうこう /修正条項/
しゅうせいじょうほう /修正情報/
しゅうせいずみ /修正済/
しゅうせいぜんご /修正前後/
しゅうせいち /修正値/
しゅうせいちゅう /修正中/
しゅうせいていあん /修正提案/
しゅうせいてん /修正点/
しゅうせいとうこう /修正投稿/
しゅうせいなし /修正無/
しゅうせいばん /修正版/
しゅうせいぶぶん /修正部分/
しゅうせいぶん /修正分/修正文/
しゅうせいへんしゅう /修正編集/
しゅうせいほう /修正法/
しゅうせいまえ /修正前/
しゅうせいよう /修正用/修正要/
しゅうせいりゆう /修正理由/
しゅうせいりょう /修正量/
しゅうせき /集積/
しゅうせきか /集積化/
しゅうせきかいろ /集積回路/
しゅうせきかいろこうざ /集積回路講座/
しゅうせきけいたい /集積形態/
しゅうせきそう /集積層/
しゅうせきたい /集積体/
しゅうせきていこう /集積抵抗/
しゅうせきてん /集積点/
しゅうせきど /集積度/
しゅうせん /周旋/終戦/終戰/集線/鞦韆/
しゅうせんご /終戦後/
しゅうせんちょくご /終戦直後/
しゅうぜい /州税/
しゅうぜん /修繕/
しゅうそ /臭素/愁訴/
しゅうそう /秋霜/愀愴/終相/
しゅうそうれつじつ /秋霜烈日/
しゅうそく /収束/集束/終息/終熄/周速/
しゅうそくかいせき /収束解析/
しゅうそくかてい /収束過程/
しゅうそくけい /収束形/
しゅうそくさき /収束先/
しゅうそくしょうめい /収束証明/
しゅうそくじょうけん /収束条件/
しゅうそくせい /収束性/
しゅうそくそくど /収束速度/
しゅうそくち /収束値/
しゅうそくていり /収束定理/
しゅうそくてん /収束点/
しゅうそくとくせい /収束特性/
しゅうそくはんけい /収束半径/
しゅうそくはんてい /収束判定/
しゅうそくほう /収束法/
しゅうそくりつ /収束率/
しゅうそさん /臭素酸/
しゅうぞう /修三/収三/秀三/収蔵/修造/脩三/
しゅうぞうひん /収蔵品/
しゅうぞうぶつ /収蔵物/
しゅうぞく /習俗/
しゅうたい /醜態/
しゅうたいしょう /終対象/
しゅうたいせい /集大成/
しゅうたろう /終太郎/
しゅうたん /終端/愁嘆/
しゅうたんい /週単位/
しゅうたんえき /終端駅/
しゅうたんがわ /終端側/
しゅうたんきごう /終端記号/
しゅうたんじょうけん /終端条件/
しゅうたんそくど /終端速度/
しゅうたんていこう /終端抵抗/
しゅうたんば /愁嘆場/
しゅうたんもじ /終端文字/
しゅうだいすう /終代数/
しゅうだん /集団/終段/
しゅうだんいしけってい /集団意思決定/
しゅうだんいでんがく /集団遺伝学/
しゅうだんかぜ /集団風邪/
しゅうだんかつどう /集団活動/
しゅうだんかん /集団間/
しゅうだんきはん /集団規範/
しゅうだんけいせい /集団形成/
しゅうだんけっこん /集団結婚/
しゅうだんこうどう /集団行動/
しゅうだんさいみん /集団催眠/
しゅうだんしゅうしょく /集団就職/
しゅうだんじえいけん /集団自衛権/
しゅうだんせいかつ /集団生活/
しゅうだんちゅう /集団中/
しゅうだんてき /集団的/
しゅうだんてきじえいけん /集団的自衛権/
しゅうだんどうし /集団同士/
しゅうだんない /集団内/
しゅうだんにゅうりょく /終段入力/
しゅうだんれんしゅう /集団練習/
しゅうち /周知/羞恥/周智/習知/衆知/周緻/
しゅうちく /修築/
しゅうちしん /羞恥心/
しゅうちてってい /周知徹底/
しゅうちど /周知度/
しゅうちゃく /執着/終着/
しゅうちゃくえき /終着駅/
しゅうちゃくしん /執着心/
しゅうちゃくてん /終着点/
しゅうちゃくれっしゃ /終着列車/
しゅうちゅう /集中/
しゅうちゅうか /集中化/
しゅうちゅうかんり /集中管理/
しゅうちゅうかんりほうしき /集中管理方式/
しゅうちゅうがた /集中型/
しゅうちゅうきょく /集中局/
しゅうちゅうけん /集中研/
しゅうちゅうげんしょう /集中現象/
しゅうちゅうこうぎ /集中講義/
しゅうちゅうこうげき /集中攻撃/
しゅうちゅうこうざ /集中講座/
しゅうちゅうこうじ /集中工事/
しゅうちゅうごうう /集中豪雨/
しゅうちゅうちりょうしつ /集中治療室/
しゅうちゅうてき /集中的/
しゅうちゅうてんかせん /集中点火線/
しゅうちゅうとうこう /集中投稿/
しゅうちゅうほうえい /集中放映/
しゅうちゅうほうか /集中砲火/
しゅうちゅうやく /集中役/
しゅうちゅうりょく /集中力/
しゅうちょう /周長/酋長/
しゅうづら /主面/
しゅうてい /舟艇/
しゅうていばん /修訂版/
しゅうてん /終点/秋天/
しゅうてんえん /周転円/
しゅうてんげしゃ /終点下車/
しゅうでん /終電/集電/
しゅうでんいがい /終電以外/
しゅうでんえんちょう /終電延長/
しゅうでんしゃ /終電車/
しゅうでんそうち /集電装置/
しゅうでんのうりょく /集電能力/
しゅうでんふりょう /集電不良/
しゅうと /姑/修斗/舅/州都/
しゅうとう /周到/秋冬/周東/
しゅうとく /修得/習得/収得/拾得/修徳/
しゅうとくかのう /習得可能/
しゅうとくげんごすう /習得言語数/
しゅうとくこうこう /修徳高校/
しゅうとくしょうきん /収得賞金/
しゅうとくそくど /習得速度/
しゅうとくぶつ /拾得物/
しゅうとくほう /修得法/
しゅうとめ /姑/
しゅうどう /修道/摺動/
しゅうどういん /修道院/
しゅうどうし /修道士/
しゅうどうじょ /修道女/
しゅうどうそう /修道僧/
しゅうにゅう /収入/
しゅうにゅういんし /収入印紙/
しゅうにゅうかくほ /収入確保/
しゅうにゅうきんがく /収入金額/
しゅうにゅうげん /収入源/
しゅうにゅうごうけい /収入合計/
しゅうにゅうせいさん /収入清算/
しゅうにゅうぞうか /収入増加/
しゅうにゅうばいぞう /収入倍増/
しゅうにん /就任/
しゅうにんえんぜつ /就任演説/
しゅうにんほうどう /就任報道/
しゅうねん /周年/執念/
しゅうのう /収納/
しゅうのうかのう /収納可能/
しゅうのうじ /収納時/
しゅうのうぶくろ /収納袋/
しゅうのうほう /収納法/
しゅうのうようぶくろ /収納用袋/
しゅうは /宗派/周波/秋波/
しゅうはい /集配/
しゅうはいきょく /集配局/
しゅうはいきょくかんない /集配局管内/
しゅうはいしん /集配信/
しゅうはいゆうびんきょく /集配郵便局/
しゅうはすう /周波数/
しゅうはすうおうとう /周波数応答/
しゅうはすうかいせき /周波数解析/
しゅうはすうかじゅう /周波数荷重/
しゅうはすうくうかん /周波数空間/
しゅうはすうくぶん /周波数区分/
しゅうはすうこうぞうかふぃるた /周波数構造化フィルタ/
しゅうはすうさんぷりんぐ /周波数サンプリング/
しゅうはすうしよう /周波数使用/
しゅうはすうじく /周波数軸/
しゅうはすうじくじょう /周波数軸上/
しゅうはすうじょうほう /周波数情報/
しゅうはすうせいぶん /周波数成分/
しゅうはすうせんたくせい /周波数選択性/
しゅうはすうたい /周波数帯/
しゅうはすうたいいき /周波数帯域/
しゅうはすうちょうせい /周波数調整/
しゅうはすうてき /周波数的/
しゅうはすうとくせい /周波数特性/
しゅうはすうとくてい /周波数特定/
しゅうはすうはんい /周波数範囲/
しゅうはすうひ /周波数比/
しゅうはすうひょうじ /周波数表示/
しゅうはすうひょうほんか /周波数標本化/
しゅうはすうひょうほんかこうぞう /周波数標本化構造/
しゅうはすうひょうほんかこうぞうふぃるた /周波数標本化構造フィルタ/
しゅうはすうぶぶん /周波数部分/
しゅうはすうぶんかいのう /周波数分解能/
しゅうはすうぶんかつ /周波数分割/
しゅうはすうぶんかつしょり /周波数分割処理/
しゅうはすうぶんせき /周波数分析/
しゅうはすうへんかん /周波数変換/
しゅうはすうへんさ /周波数偏差/
しゅうはすうへんどう /周波数変動/
しゅうはすうべつ /周波数別/
しゅうはすうほうこう /周波数方向/
しゅうはすうほせい /周波数補正/
しゅうはすうまど /周波数窓/
しゅうはすうりょういき /周波数領域/
しゅうはつ /終発/
しゅうばす /終バス/
しゅうばん /終盤/終板/
しゅうばんしゅ /終盤手/
しゅうばんせん /終盤戦/
しゅうひ /周皮/
しゅうび /愁眉/秀眉/秀美/
しゅうふ /呪符/
しゅうふく /修復/
しゅうふくかのう /修復可能/
しゅうふくさぎょう /修復作業/
しゅうふくちゅう /修復中/
しゅうふくほうほう /修復方法/
しゅうふつ /修祓/
しゅうふつか /週二日/
しゅうぶん /秋分/醜聞/
しゅうぶんび /秋分日/
しゅうへい /周平/修平/州兵/
しゅうへき /習癖/
しゅうへん /周辺/
しゅうへんいき /周辺域/
しゅうへんかいろ /周辺回路/
しゅうへんかくしょ /周辺各所/
しゅうへんかんきょう /周辺環境/
しゅうへんきき /周辺機器/
しゅうへんぎじゅつ /周辺技術/
しゅうへんくういき /周辺空域/
しゅうへんげんこう /周辺減光/
しゅうへんこうりょう /周辺光量/
しゅうへんこく /周辺国/
しゅうへんこっか /周辺国家/
しゅうへんし /周辺視/
しゅうへんしや /周辺視野/
しゅうへんしょこく /周辺諸国/
しゅうへんしょみんぞく /周辺諸民族/
しゅうへんじゅうみん /周辺住民/
しゅうへんそうち /周辺装置/
しゅうへんぞう /周辺像/
しゅうへんぶ /周辺部/
しゅうへんぶぶん /周辺部分/
しゅうへんぶんれつそしき /周辺分裂組織/
しゅうへんみんぞく /周辺民族/
しゅうへんもうまく /周辺網膜/
しゅうへんりょういき /周辺領域/
しゅうほう /週報/州法/秀芳/秋芳/
しゅうほうどう /秋芳洞/
しゅうぼう /衆望/
しゅうまく /終幕/
しゅうまつ /週末/終末/
しゅうまつきせい /週末帰省/
しゅうまつまえ /週末前/
しゅうまつろん /終末論/
しゅうみつ /周密/
しゅうみん /就眠/
しゅうめ /週目/周目/
しゅうめい /襲名/
しゅうもく /衆目/
しゅうや /終夜/秀哉/
しゅうやうんてん /終夜運転/
しゅうやく /集約/
しゅうやくてき /集約的/
しゅうゆう /周遊/
しゅうゆうかん /修猷館/
しゅうゆうくかん /周遊区間/
しゅうゆうくかんがい /周遊区間外/
しゅうゆうけん /周遊券/
しゅうゆうけんがいくかん /周遊券外区間/
しゅうゆうこうくうけん /周遊航空券/
しゅうゆうしていち /周遊指定地/
しゅうゆうしていちえき /周遊指定地駅/
しゅうよう /収容/収用/修養/数/
しゅうようじょ /収容所/
しゅうようじんいん /収容人員/
しゅうようすう /収容数/
しゅうようだいすう /収容台数/
しゅうようにんずう /収容人数/
しゅうようのうりょく /収容能力/
しゅうようほう /収用法/
しゅうようよていじんいん /収容予定人員/
しゅうようりょう /収容量/
しゅうようりょく /収容力/
しゅうら /修羅/
しゅうらい /襲来/
しゅうらく /集落/聚落/
しゅうらん /秀蘭/
しゅうり /修理/
しゅうりいらい /修理依頼/
しゅうりかのう /修理可能/
しゅうりきんし /修理禁止/
しゅうりぎじゅつ /修理技術/
しゅうりこうじょう /修理工場/
しゅうりこうちん /修理工賃/
しゅうりざい /修理剤/修理材/
しゅうりしょくにん /修理職人/
しゅうりたいせい /修理体制/
しゅうりだい /修理代/
しゅうりちゅう /修理中/
しゅうりつ /州立/収率/
しゅうりつだい /州立大/
しゅうりつだいがく /州立大学/
しゅうりていしゃ /修理停車/
しゅうりてんけん /修理点検/
しゅうりでんぴょう /修理伝票/
しゅうりないよう /修理内容/
しゅうりのうりょく /修理能力/
しゅうりひ /修理費/
しゅうりひよう /修理費用/
しゅうりひん /修理品/
しゅうりび /修理日/
しゅうりふのう /修理不能/
しゅうりぶひん /修理部品/
しゅうりぶもん /修理部門/
しゅうりほうほう /修理方法/
しゅうりまえ /修理前/
しゅうりもくてき /修理目的/
しゅうりや /修理屋/
しゅうりょう /終了/修了/収量/秋涼/
しゅうりょうおん /終了音/
しゅうりょうきねん /終了記念/
しゅうりょうけい /終了型/
しゅうりょうご /終了後/
しゅうりょうしき /終了式/
しゅうりょうしゃ /修了者/
しゅうりょうしょう /修了証/
しゅうりょうしょり /終了処理/
しゅうりょうじ /終了時/
しゅうりょうじかん /終了時間/
しゅうりょうじこく /終了時刻/
しゅうりょうじてん /終了時点/
しゅうりょうじょうけん /終了条件/
しゅうりょうせい /終了性/修了生/
しゅうりょうせんげん /終了宣言/
しゅうりょうち /終了値/
しゅうりょうちょくご /終了直後/
しゅうりょうちょくぜん /終了直前/
しゅうりょうてん /終了点/
しゅうりょうねんげん /修了年限/
しゅうりょうはんてい /終了判定/
しゅうりょうほうこく /終了報告/
しゅうりょうまえ /終了前/
しゅうりょうまぎわ /終了間際/
しゅうりょうまじか /終了間近/
しゅうりょうよてい /終了予定/
しゅうりよう /修理用/
しゅうりようひん /修理用品/
しゅうりようぶひん /修理用部品/
しゅうりわりびき /修理割引/
しゅうりん /秋林/
しゅうれい /秋冷/秀麗/週令/
しゅうれっしゃ /終列車/
しゅうれん /修練/収斂/收斂/
しゅうろう /周郎/就労/秀朗/
しゅうろうちゅう /就労中/
しゅうろく /収録/集録/
しゅうろくきょく /収録曲/
しゅうろくきょくすう /収録曲数/
しゅうろくけい /収録系/
しゅうろくご /収録後/
しゅうろくごすう /収録語数/
しゅうろくさく /収録作/
しゅうろくさくひん /収録作品/
しゅうろくじかん /収録時間/
しゅうろくじゅん /収録順/
しゅうろくち /収録地/
しゅうろくぶん /収録分/
しゅうろくぼん /収録本/
しゅうろん /修論/
しゅうろんしんさ /修論審査/
しゅうろんはっぴょうかい /修論発表会/
しゅうわ /秀和/
しゅうわい /収賄/
しゅうわいざい /収賄罪/
しゅえい /守衛/
しゅえいしつ /守衛室/
しゅえいじょ /守衛所/
しゅえいほんぶ /守衛本部/
しゅえん /主演/酒宴/主煙/
しゅえんえいが /主演映画/
しゅえんじょゆう /主演女優/
しゅえんだんゆうしょう /主演男優賞/
しゅおう /手応/
しゅおん /主音/
しゅおんせい /主音声/
しゅか /種化/酒家/
しゅかい /首魁/
しゅかいろ /主回路/
しゅかく /主格/主客/
しゅかん /主幹/主観/主管/首巻/
しゅかんけいしき /主観形式/
しゅかんこう /主幹校/
しゅかんじ /主幹事/
しゅかんせい /主観性/
しゅかんせいぎょき /主幹制御機/
しゅかんせんどうろ /主幹線道路/
しゅかんてき /主観的/
しゅかんてきけいぞくじかん /主観的継続時間/
しゅかんてきじぞくじかん /主観的持続時間/
しゅかんてきぞくせい /主観的属性/
しゅかんてきとうかかち /主観的等価価値/
しゅかんてきとうかてん /主観的等価点/
しゅかんてきはんだん /主観的判断/
しゅかんてきひょうげん /主観的表現/
しゅかんてきようそ /主観的要素/
しゅかんひょうか /主観評価/
しゅかんろん /主観論/
しゅが /主芽/
しゅがー /シュガー/
しゅがん /主眼/
しゅき /手記/酒気/首記/朱記/主機/
しゅきおく /主記憶/
しゅきおくそうち /主記憶装置/
しゅきおくようりょう /主記憶容量/
しゅきごう /主記号/
しゅきゃく /主客/主脚/
しゅきゅう /首級/
しゅきょう /主教/
しゅきん /手巾/
しゅぎ /主義/手技/
しゅぎしゃ /主義者/
しゅぎしゅちょう /主義主張/
しゅぎょう /修行/修業/
しゅぎょうしゃ /修行者/
しゅぎょうじだい /修行時代/
しゅぎょうじょう /修行場/
しゅぎょうちゅう /修行中/
しゅぎょうどう /修行堂/修行道/
しゅぎょく /珠玉/
しゅく /祝/宿/縮/淑/粛/夙/叔/蹙/珠久/粥/俶/槭/倏/肅/菽/蓿/
しゅくあ /宿痾/
しゅくい /祝意/
しゅくえん /祝宴/
しゅくが /祝賀/
しゅくがおんれつ /祝賀御列/
しゅくがかい /祝賀会/
しゅくがじょう /祝賀状/
しゅくがわ /夙川/
しゅくがわこうえん /夙川公園/
しゅくがわら /宿河原/
しゅくがん /宿願/
しゅくぎ /祝儀/
しゅくけいえん /縮景園/
しゅくげん /縮減/
しゅくこ /祝子/
しゅくごう /宿業/
しゅくさい /祝祭/
しゅくさいじつ /祝祭日/
しゅくさつ /縮刷/
しゅくさつばん /縮刷版/
しゅくしゃ /宿舎/縮写/
しゅくしゃく /縮尺/
しゅくしゃにゅうきょじ /宿舎入居時/
しゅくしゅ /宿主/
しゅくしゅく /粛々/粛粛/
しゅくしょう /縮小/縮少/
しゅくしょういんさつ /縮小印刷/
しゅくしょうかい /祝勝会/
しゅくしょうかくだい /縮小拡大/
しゅくしょうがぞう /縮小画像/
しゅくしょうがめんひょうじ /縮小画面表示/
しゅくしょうきのう /縮小機能/
しゅくしょうけいこう /縮小傾向/
しゅくしょうじ /縮小時/
しゅくしょうばん /縮小版/
しゅくしょうりつ /縮小率/
しゅくじ /祝辞/
しゅくじつ /祝日/
しゅくじょ /淑女/
しゅくず /縮図/
しゅくせい /粛正/粛清/
しゅくぜん /宿善/
しゅくそつぎょう /祝卒業/
しゅくたい /縮退/
しゅくたいど /縮退度/
しゅくだい /宿題/
しゅくだいじこう /宿題事項/
しゅくちょく /宿直/
しゅくてき /宿敵/
しゅくてん /祝典/
しゅくてんこうしんきょく /祝典行進曲/
しゅくてんじょきょく /祝典序曲/
しゅくでん /祝電/
しゅくとく /淑徳/
しゅくとくがくえん /淑徳学園/
しゅくとくこうこう /淑徳高校/
しゅくとくすがも /淑徳巣鴨/
しゅくにっちょく /宿日直/
しゅくはい /祝杯/
しゅくはく /宿泊/
しゅくはくあっせん /宿泊斡旋/
しゅくはくか /宿泊可/
しゅくはくきゃく /宿泊客/
しゅくはくきゃくせんよう /宿泊客専用/
しゅくはくけん /宿泊券/
しゅくはくさき /宿泊先/
しゅくはくしせつ /宿泊施設/
しゅくはくしゃ /宿泊者/
しゅくはくしゃいがい /宿泊者以外/
しゅくはくしょう /宿泊証/
しゅくはくじょ /宿泊所/
しゅくはくじょうほう /宿泊情報/
しゅくはくせつび /宿泊設備/
しゅくはくだい /宿泊代/
しゅくはくだいきん /宿泊代金/
しゅくはくち /宿泊地/
しゅくはくていいん /宿泊定員/
しゅくはくとう /宿泊棟/
しゅくはくばしょ /宿泊場所/
しゅくはくひ /宿泊費/
しゅくはくひよう /宿泊費用/
しゅくはくもうしこみしょ /宿泊申込書/
しゅくはくゆうたいけん /宿泊優待券/
しゅくはくよてい /宿泊予定/
しゅくはくよやく /宿泊予約/
しゅくはくりょう /宿泊料/
しゅくはくりょうきん /宿泊料金/
しゅくば /宿場/
しゅくふく /祝福/
しゅくほう /祝砲/
しゅくぼう /宿望/宿坊/
しゅくまる /宿丸/
しゅくみょう /宿命/
しゅくめい /宿命/
しゅくめいてき /宿命的/
しゅくもくひょうたっせい /祝目標達成/
しゅくやく /縮約/
しゅくん /主君/殊勲/
しゅくんしゃ /殊勲者/
しゅくんしょう /殊勲賞/
しゅけい /主系/主計/
しゅけいか /主計課/
しゅけいかん /主計監/
しゅけいきょく /主計局/
しゅけいさんき /主計算機/
しゅけいしかん /主計士官/
しゅけいせい /種形成/
しゅけいちょう /主計長/
しゅけいれつ /主系列/
しゅけん /主権/
しゅけんきゅういん /主研究員/
しゅけんこっかれんぽう /主権国家連邦/
しゅけんざいみん /主権在民/
しゅけんしゃ /主権者/
しゅけんしんがい /主権侵害/
しゅげい /手芸/
しゅげいざいりょう /手芸材料/
しゅげいざっし /手芸雑誌/
しゅげいしょ /手芸書/
しゅげた /主桁/
しゅげんいん /主原因/
しゅげんご /主言語/
しゅげんどう /修験道/
しゅげんりょう /主原料/
しゅこ /朱子/
しゅこう /趣向/酒肴/首肯/珠孔/
しゅこうか /主効果/
しゅこうぎょう /手工業/
しゅこうげい /手工芸/
しゅこうじく /主光軸/
しゅこうせん /主光線/
しゅこん /酒魂/主根/
しゅこんけい /主根系/
しゅご /主語/守護/
しゅごう /酒豪/
しゅごきし /守護騎士/
しゅごしゃ /守護者/
しゅごしん /守護神/
しゅごせい /守護星/
しゅごれい /守護霊/
しゅさ /主査/主鎖/
しゅさい /主催/主宰/主菜/
しゅさいしゃ /主催者/主宰者/
しゅさいしゃがわ /主催者側/
しゅさいしゃはっぴょう /主催者発表/
しゅさいじあい /主催試合/
しゅさいだんたい /主催団体/
しゅさんち /主産地/
しゅさんぶつ /主産物/
しゅざ /主座/
しゅざい /取材/
しゅざいかつどう /取材活動/
しゅざいきょひ /取材拒否/
しゅざいちゅう /取材中/
しゅざいはん /取材班/
しゅざいはんい /取材範囲/
しゅざいばんぐみ /取材番組/
しゅざいよう /取材用/
しゅざん /珠算/
しゅし /主旨/趣旨/種子/繻竢/
しゅしがく /朱子学/
しゅしさぎょう /手指作業/
しゅししょうどく /種子消毒/
しゅししょくぶつ /種子植物/
しゅししょくぶつもん /種子植物門/Spermatophyta/
しゅしせつめい /趣旨説明/
しゅしゃ /取捨/種車/
しゅしゃせんたく /取捨選択/
しゅしゃりん /主車輪/
しゅしゅ /種々/
しゅしゅざった /種々雑多/
しゅしゅつ /収出/
しゅしょ /朱書/
しゅしょう /首相/主将/主唱/殊勝/首唱/酒漿/
しゅしょうかんてい /首相官邸/
しゅしょうけいけんしゃ /首相経験者/
しゅしょく /主食/
しゅしょり /主処理/
しゅしん /主審/珠心/主神/
しゅしんか /種進化/
しゅしんしつ /主寝室/
しゅじ /主事/主辞/主餌/
しゅじい /主治医/
しゅじく /主軸/
しゅじくかんせい /主軸慣性/
しゅじゃく /朱雀/
しゅじゅ /種々/侏儒/
しゅじゅう /主従/
しゅじゅうかんけい /主従関係/
しゅじゅざった /種々雑多/
しゅじゅつ /手術/
しゅじゅつあと /手術跡/
しゅじゅつご /手術後/
しゅじゅつしつ /手術室/
しゅじょう /衆生/
しゅじん /主人/
しゅじんこう /主人公/
しゅじんこうたち /主人公達/
しゅじんこうほんにん /主人公本人/
しゅじんさま /主人様/
しゅす /繻子/
しゅすい /取水/
しゅすう /種数/
しゅせい /守勢/酒精/
しゅせいぎょき /主制御器/
しゅせいひん /主製品/
しゅせいぶん /主成分/
しゅせいぶんぶんせき /主成分分析/
しゅせき /主席/首席/酒席/酒石/
しゅせきえい /酒石英/
しゅせきけんきゅうかん /首席研究官/
しゅせきごうかく /首席合格/
しゅせきさん /酒石酸/
しゅせつ /取説/主節/
しゅせん /主戦/
しゅせんきしゅ /主戦騎手/
しゅせんじょう /主戦場/
しゅせんせん /主戦線/
しゅせんど /守銭奴/
しゅせんは /主戦派/
しゅせんりつ /主旋律/
しゅせんりょく /主戦力/
しゅぜい /酒税/
しゅぜいきょく /主税局/
しゅぜん /酒膳/
しゅぜんじ /修善寺/
しゅぜんじちょう /修善寺町/
しゅぜんじものがたり /修善寺物語/
しゅぜんたい /種全体/
しゅそ /主訴/
しゅそう /主相/
しゅそうさ /主走査/
しゅぞう /酒造/酒蔵/
しゅぞうけんがく /酒蔵見学/
しゅぞうけんきゅうじょ /酒造研究所/
しゅぞうし /酒造史/
しゅぞく /種族/
しゅぞくそんぞく /種族存続/
しゅぞくてき /種族的/
しゅぞくほぞん /種族保存/
しゅたい /主体/
しゅたいしゃ /主体者/
しゅたいせい /主体性/
しゅたいてき /主体的/
しゅたいふめい /主体不明/
しゅたんとう /主担当/
しゅだい /主題/主代/腫大/
しゅだいか /主題歌/主題化/
しゅだいかこうほ /主題歌候補/
しゅだいけいじ /主題提示/
しゅだいてき /主題的/
しゅだいへんよう /主題変容/
しゅだいわく /主台枠/
しゅだん /手段/
しゅち /主値/恤/
しゅちせつ /主知説/
しゅちていり /主値定理/
しゅちにくりん /酒池肉林/
しゅちゅう /手中/
しゅちょ /主著/
しゅちょう /主張/主潮/首長/主徴/腫脹/
しゅちょうこくれんぽう /首長国連邦/
しゅちょうじしん /主張自身/
しゅちょうじたい /主張自体/
しゅちょうぜんたい /主張全体/
しゅちょうちゅう /出張中/
しゅちょうてん /主張点/
しゅちょうどおり /主張通り/
しゅちょうないよう /主張内容/
しゅちょうほうほう /主張方法/
しゅっか /出荷/出火/
しゅっかかいし /出荷開始/
しゅっかがく /出荷額/
しゅっかき /出荷機/
しゅっかご /出荷後/
しゅっかじ /出荷時/
しゅっかじき /出荷時期/
しゅっかじっせき /出荷実績/
しゅっかじてん /出荷時点/
しゅっかすう /出荷数/
しゅっかだいすう /出荷台数/
しゅっかちょくぜん /出荷直前/
しゅっかにちじ /出荷日時/
しゅっかばん /出荷版/
しゅっかび /出荷日/
しゅっかぶん /出荷分/
しゅっかまち /出荷待ち/
しゅっかよてい /出荷予定/
しゅっかりょう /出荷量/
しゅっかん /出棺/
しゅっきん /出勤/出金/
しゅっきんじ /出勤時/
しゅっきんじかん /出勤時間/
しゅっきんび /出勤日/
しゅっきんぼ /出勤簿/
しゅっきんまえ /出勤前/
しゅっけ /出家/
しゅっけしゃ /出家者/
しゅっけつ /出欠/出血/
しゅっけつかかく /出血価格/
しゅっけつせい /出血性/
しゅっけつひょう /出欠表/
しゅっこ /出庫/
しゅっこう /出向/出航/出港/出稿/
しゅっこうさき /出向先/
しゅっこうちゅう /出向中/
しゅっこく /出国/
しゅっこくけんさ /出国検査/
しゅっこくしんさ /出国審査/
しゅっこくじ /出国時/
しゅっこくぜい /出国税/
しゅっこくてつづき /出国手続/出国手続き/
しゅっこくとうじつ /出国当日/
しゅっこくとし /出国都市/
しゅっこくびん /出国便/
しゅっこじ /出庫時/
しゅっさつがかり /出札係/
しゅっさつぐち /出札口/
しゅっさつほじゅうけん /出札補充券/
しゅっさん /出産/
しゅっさんいがい /出産以外/
しゅっさんしょうめいしょ /出産証明書/
しゅっさんじ /出産時/
しゅっさんたいしょく /出産退職/
しゅっし /出資/
しゅっしきん /出資金/
しゅっしさき /出資先/
しゅっししゃ /出資者/
しゅっしゃ /出社/出射/
しゅっしゃび /出社日/
しゅっしゃまえ /出社前/
しゅっしゃめん /出射面/
しゅっしょ /出所/出処/
しゅっしょう /出生/
しゅっしょく /出色/出食/
しゅっしょしんたい /出処進退/
しゅっしん /出身/
しゅっしんがくぶ /出身学部/
しゅっしんがっか /出身学科/
しゅっしんがっこう /出身学校/
しゅっしんけん /出身県/
しゅっしんこう /出身校/
しゅっしんこうこう /出身高校/
しゅっしんこく /出身国/
しゅっしんしゃ /出身者/
しゅっしんしゃどうし /出身者同士/
しゅっしんだいがく /出身大学/
しゅっしんち /出身地/
しゅっすい /出水/
しゅっせ /出世/出瀬/
しゅっせい /出生/出征/出精/
しゅっせいしょうめいしょ /出生証明書/
しゅっせいすう /出生数/
しゅっせいち /出生地/
しゅっせいとどけ /出生届/
しゅっせいりつ /出生率/
しゅっせうお /出世魚/
しゅっせき /出席/
しゅっせきかいすう /出席回数/
しゅっせききぼう /出席希望/
しゅっせきしゃ /出席者/
しゅっせきにっすう /出席日数/
しゅっせきばんごう /出席番号/
しゅっせきぼ /出席簿/
しゅっせきりつ /出席率/
しゅっせさく /出世作/
しゅっせばらい /出世払い/
しゅっそう /出走/出槽/
しゅっそういし /出走意思/
しゅっそうかいすう /出走回数/
しゅっそうかいひ /出走回避/
しゅっそうかのう /出走可能/
しゅっそうかのうとうすう /出走可能頭数/
しゅっそうきんし /出走禁止/
しゅっそうけん /出走権/
しゅっそうしかく /出走資格/
しゅっそうしゃめいぼ /出走者名簿/
しゅっそうじょうけん /出走条件/
しゅっそうせいげん /出走制限/
しゅっそうとうすう /出走頭数/
しゅっそうとうろく /出走登録/
しゅっそうとりけし /出走取消/
しゅっそうば /出走馬/
しゅっそうばかんれん /出走馬関連/
しゅっそうばじしん /出走馬自身/
しゅっそうふか /出走不可/
しゅっそうまえ /出走前/
しゅっそうよてい /出走予定/
しゅっそうよていば /出走予定馬/
しゅったい /出待/
しゅったいきん /出退勤/
しゅったつ /出立/
しゅったん /出炭/
しゅっちょう /出張/出超/
しゅっちょういらい /出張依頼/
しゅっちょういらいしょ /出張依頼書/
しゅっちょうさき /出張先/
しゅっちょうさつえい /出張撮影/
しゅっちょうしゃ /出張者/
しゅっちょうしゅうり /出張修理/
しゅっちょうしょ /出張所/
しゅっちょうじ /出張時/
しゅっちょうじょ /出張所/
しゅっちょうちく /出張地区/
しゅっちょうちゅう /出張中/
しゅっちょうてあて /出張手当/
しゅっちょうはんばい /出張販売/
しゅっちょうばぼう /出張馬房/
しゅっちょうひ /出張費/
しゅっちょうほうこく /出張報告/
しゅっちょうまえ /出張前/
しゅっちょうめいれいしょ /出張命令書/
しゅっちょうりょひ /出張旅費/
しゅっちょうりよう /出張利用/
しゅってい /出廷/出艇/
しゅってん /出典/出展/出店/
しゅってんさくひん /出展作品/
しゅってんしゃ /出展者/
しゅってんふめい /出典不明/
しゅっとう /出頭/
しゅっとうめいれい /出頭命令/
しゅっぱつ /出発/
しゅっぱつき /出発機/
しゅっぱつしんごう /出発信号/
しゅっぱつしんごうき /出発信号機/
しゅっぱつじ /出発時/
しゅっぱつじかん /出発時間/
しゅっぱつじこく /出発時刻/
しゅっぱつじたい /出発自体/
しゅっぱつち /出発地/
しゅっぱつちてん /出発地点/
しゅっぱつちょくぜん /出発直前/
しゅっぱつていこう /出発抵抗/
しゅっぱつてん /出発点/
しゅっぱつとうちゃくじ /出発到着時/
しゅっぱつび /出発日/
しゅっぱつびちょくぜん /出発日直前/
しゅっぱつびん /出発便/
しゅっぱつまえ /出発前/
しゅっぱつまぎわ /出発間際/
しゅっぱん /出版/出帆/
しゅっぱんかい /出版会/
しゅっぱんかんけい /出版関係/
しゅっぱんかんけいしゃ /出版関係者/
しゅっぱんがいしゃ /出版会社/
しゅっぱんきねん /出版記念/
しゅっぱんきょく /出版局/
しゅっぱんぎじゅつぶ /出版技術部/
しゅっぱんぎょうかい /出版業界/
しゅっぱんけん /出版権/
しゅっぱんけんしゃ /出版権者/
しゅっぱんしゃ /出版社/出版者/
しゅっぱんしゃがわ /出版社側/
しゅっぱんしゃじたい /出版社自体/
しゅっぱんしゃなど /出版社等/
しゅっぱんしゃふめい /出版社不明/
しゅっぱんしゃべつ /出版社別/
しゅっぱんしゃめい /出版社名/出版者名/
しゅっぱんじ /出版時/
しゅっぱんじぎょうほんぶ /出版事業本部/
しゅっぱんたんとういいん /出版担当委員/
しゅっぱんふ /出版譜/
しゅっぱんぶ /出版部/
しゅっぱんぶすう /出版部数/
しゅっぱんぶつ /出版物/
しゅっぱんぶつぶもん /出版物部門/
しゅっぱんまえ /出版前/
しゅっぱんもと /出版元/
しゅっぱんもとしゃちょう /出版元社長/
しゅっぱんよてい /出版予定/
しゅっぴ /出費/
しゅっぴつ /出筆/
しゅっぴみてい /出否未定/
しゅっぴん /出品/
しゅっぴんさっか /出品作家/
しゅっぴんだんたい /出品団体/
しゅっぴんぶつ /出品物/
しゅっぴんほうほう /出品方法/
しゅっぺい /出兵/
しゅっぽん /出奔/
しゅつ /出/蟀/恤/卆/
しゅつえき /出役/
しゅつえん /出演/
しゅつえんいちらん /出演一覧/
しゅつえんさく /出演作/
しゅつえんさくひん /出演作品/
しゅつえんしゃ /出演者/
しゅつえんしゃごと /出演者毎/
しゅつえんしゃぜんいん /出演者全員/
しゅつえんしゃたち /出演者達/
しゅつえんしゃめい /出演者名/
しゅつえんじょうほう /出演情報/
しゅつえんちゅう /出演中/
しゅつえんばんぐみ /出演番組/
しゅつえんよてい /出演予定/
しゅつえんりょう /出演料/
しゅつがん /出願/
しゅつがんしかく /出願資格/
しゅつがんしょ /出願書/
しゅつがんちゅう /出願中/
しゅつがんにん /出願人/
しゅつがんび /出願日/
しゅつげき /出撃/
しゅつげん /出現/
しゅつげんいち /出現位置/
しゅつげんかくりつ /出現確率/
しゅつげんかのうせい /出現可能性/
しゅつげんすう /出現数/
しゅつげんばしょ /出現場所/
しゅつげんひんど /出現頻度/
しゅつげんまえ /出現前/
しゅつげんよてい /出現予定/
しゅつげんりつ /出現率/
しゅつごく /出獄/
しゅつじ /出自/
しゅつじょう /出場/出状/
しゅつじょうかいすう /出場回数/
しゅつじょうかしゅ /出場歌手/
しゅつじょうかのう /出場可能/
しゅつじょうきかい /出場機会/
しゅつじょうきてい /出場規定/
しゅつじょうけん /出場権/
しゅつじょうけんかくとく /出場権獲得/
しゅつじょうこう /出場校/
しゅつじょうこうけってい /出場校決定/
しゅつじょうしかく /出場資格/
しゅつじょうしゃ /出場者/
しゅつじょうせんしゅ /出場選手/
しゅつじょうせんしゅとうろく /出場選手登録/
しゅつじょうちゅう /出場中/
しゅつじょうていし /出場停止/
しゅつじょうていしかいじょ /出場停止解除/
しゅつじょうば /出場馬/
しゅつじょうよてい /出場予定/
しゅつじょうよていしゃ /出場予定者/
しゅつじょうわく /出場枠/
しゅつじん /出陣/
しゅつだい /出題/
しゅつだいいいんかい /出題委員会/
しゅつだいがわ /出題側/
しゅつだいけいしき /出題形式/
しゅつだいしゃ /出題者/
しゅつだいじ /出題時/
しゅつだいもと /出題元/
しゅつど /出土/
しゅつどう /出動/
しゅつどひん /出土品/
しゅつにゅう /出入/
しゅつにゅうかんり /出入管理/
しゅつにゅうこく /出入国/
しゅつにゅうこくかんりきょく /出入国管理局/
しゅつにゅうこくぜい /出入国税/
しゅつにゅうこしゃ /出入庫車/
しゅつのう /出納/
しゅつば /出馬/
しゅつばとうひょう /出馬投票/
しゅつばとうひょうご /出馬投票後/
しゅつばひょう /出馬表/
しゅつぼつ /出没/
しゅつぼつきぎょう /出没企業/
しゅつぼつち /出没地/
しゅつもくよそう /出目予想/
しゅつらん /出藍/
しゅつり /出離/
しゅつりょう /出漁/出猟/
しゅつりょく /出力/
しゅつりょくいち /出力位置/
しゅつりょくか /出力可/
しゅつりょくかのう /出力可能/
しゅつりょくかんすう /出力関数/
しゅつりょくがわ /出力側/
しゅつりょくがわたんとう /出力側担当/
しゅつりょくくうかん /出力空間/
しゅつりょくくらす /出力クラス/
しゅつりょくけい /出力系/
しゅつりょくけいしき /出力形式/
しゅつりょくけっか /出力結果/
しゅつりょくこうじょう /出力向上/
しゅつりょくさいだい /出力最大/
しゅつりょくさいぼう /出力細胞/
しゅつりょくさき /出力先/
しゅつりょくし /出力紙/
しゅつりょくしてい /出力指定/
しゅつりょくしゅうごう /出力集合/
しゅつりょくしょり /出力処理/
しゅつりょくしんごう /出力信号/
しゅつりょくじ /出力時/
しゅつりょくじく /出力軸/
しゅつりょくせってん /出力節点/
しゅつりょくせん /出力線/
しゅつりょくそう /出力層/
しゅつりょくそうさ /出力操作/
しゅつりょくそうち /出力装置/
しゅつりょくたん /出力端/
しゅつりょくたんし /出力端子/
しゅつりょくだん /出力段/
しゅつりょくち /出力値/
しゅつりょくちゅう /出力中/
しゅつりょくちょうせい /出力調整/
しゅつりょくでんあつ /出力電圧/
しゅつりょくとくせい /出力特性/
しゅつりょくはけい /出力波形/
しゅつりょくばいたい /出力媒体/
しゅつりょくひんしつ /出力品質/
しゅつりょくひんど /出力頻度/
しゅつりょくふきん /出力付近/
しゅつりょくぶ /出力部/
しゅつりょくべくとるち /出力ベクトル値/
しゅつりょくほう /出力法/
しゅつりょくほうほう /出力方法/
しゅつりょくもじ /出力文字/
しゅつりょくよう /出力用/
しゅつりょくようきゅう /出力要求/
しゅつりょくようし /出力用紙/
しゅつりょくれい /出力例/
しゅつりょくれつ /出力列/
しゅつるい /出塁/
しゅてん /主点/
しゅてんどうじ /手天童子/酒呑童子/
しゅでんげん /主電源/
しゅでんどうき /主電動機/
しゅと /首都/
しゅとう /首藤/種痘/手刀/
しゅとく /取得/
しゅとくかのう /取得可能/
しゅとくご /取得後/
しゅとくしゃ /取得者/
しゅとくしんせいしょ /取得申請書/
しゅとくじ /取得時/
しゅとくだいこうぎょうしゃ /取得代行業者/
しゅとくほうほう /取得方法/
しゅとくみこみ /取得見込/
しゅとくりょう /取得料/
しゅとけん /首都圏/
しゅとけんきんこう /首都圏近郊/
しゅとけんしゅうへん /首都圏周辺/
しゅとけんしゅっしん /首都圏出身/
しゅとけんてつどう /首都圏鉄道/
しゅとけんない /首都圏内/
しゅとこう /首都高/
しゅとこうこうだん /首都高公団/
しゅとこうした /首都高下/
しゅとこうしんじゅくせん /首都高新宿線/
しゅとこうそく /首都高速/
しゅとこうそくけいゆ /首都高速経由/
しゅとこうそくけいゆう /首都高速経由/
しゅとこうそくどうろ /首都高速道路/
しゅとこうりよう /首都高利用/
しゅとして /主として/
しゅどう /手動/主導/主動/首藤/衆道/
しゅどうかいへいしき /手動開閉式/
しゅどうかんり /手動管理/
しゅどうがた /手動型/主導型/
しゅどうけいさんき /手動計算機/
しゅどうけん /主導権/
しゅどうしき /手動式/
しゅどうしゃだんき /手動遮断機/
しゅどうしゅうけい /手動集計/
しゅどうせってい /手動設定/
しゅどうそうさ /手動操作/
しゅどうそうしん /手動送信/
しゅどうそうじゅしん /手動送受信/
しゅどうだい /手動台/
しゅどうてき /主導的/
しゅどうとうろく /手動登録/
しゅどうは /手動派/
しゅどうへんそくき /手動変速機/
しゅどうりん /主動輪/
しゅにく /朱肉/
しゅにん /主任/
しゅにんいん /主任員/
しゅにんかい /主任会/
しゅにんきょうじゅ /主任教授/
しゅにんぎし /主任技師/
しゅにんけんきゅうかん /主任研究官/
しゅにんしゃ /主任者/
しゅにんしゃしけん /主任者試験/
しゅにんよほうかん /主任予報官/
しゅねんしょうしつ /主燃焼室/
しゅのう /首脳/
しゅのうかいだん /首脳会談/
しゅのうじん /首脳陣/
しゅのうぶ /首脳部/
しゅはく /手搏/
しゅはすうひょうほんか /周波数標本化/
しゅはん /主犯/
しゅばい /酒売/
しゅばんごう /主番号/
しゅひ /守秘/種皮/珠皮/
しゅひぎむ /守秘義務/
しゅひぎむいはん /守秘義務違反/
しゅひつ /主筆/朱筆/
しゅひん /主賓/
しゅび /守備/首尾/
しゅびいち /守備位置/
しゅびいっかん /首尾一貫/
しゅびがた /守備型/
しゅびがわ /守備側/
しゅびじん /守備陣/
しゅびたい /守備隊/
しゅびはんい /守備範囲/
しゅびはんいがい /守備範囲外/
しゅびぼうがい /守備妨害/
しゅびめん /守備面/
しゅびょうほう /種苗法/
しゅびよく /首尾よく/
しゅびりつ /守備率/
しゅびりょく /守備力/
しゅびりょくきょうか /守備力強化/
しゅふ /主婦/主夫/首府/
しゅふぎょう /主婦業/
しゅふく /首服/
しゅふやく /主婦役/
しゅふれん /主婦連/
しゅぶき /主武器/
しゅぶん /主文/
しゅぷーる /シュプール/
しゅへい /珠柄/
しゅへいかつ /主平滑/
しゅへんあつき /主変圧器/
しゅべつ /種別/
しゅべつごと /種別毎/
しゅべつじゅん /種別順/
しゅべつひょうじ /種別表示/
しゅべつへんこう /種別変更/
しゅほ /酒保/
しゅほう /手法/主峰/主砲/
しゅほうしゃ /首謀者/
しゅぼう /首謀/
しゅぼうしゃ /主謀者/首謀者/
しゅぼば /種牡馬/
しゅぼばこうこく /種牡馬広告/
しゅぼばじてん /種牡馬辞典/
しゅぼばせいせき /種牡馬成績/
しゅぼばせんてい /種牡馬選定/
しゅまい /酒米/
しゅみ /趣味/
しゅみきょうよう /趣味教養/
しゅみし /趣味誌/
しゅみじん /趣味人/
しゅみせい /趣味性/
しゅみせん /須弥山/
しゅみてき /趣味的/
しゅみひん /趣味品/
しゅみゃく /主脈/
しゅむ /主務/
しゅめもり /主メモリ/
しゅもーど /主モード/
しゅもく /種目/撞木/
しゅもくぞり /撞木反り/
しゅもくてき /主目的/
しゅもくべつ /種目別/
しゅやく /主役/
しゅやくかく /主役格/
しゅやくきゅう /主役級/
しゅゆ /須臾/
しゅよう /主要/腫瘍/
しゅよういん /主要因/
しゅようえき /主要駅/
しゅようかげきじょう /主要歌劇場/
しゅようかんせん /主要幹線/
しゅようがく /腫瘍学/
しゅようきき /主要機器/
しゅようきょてんかん /主要拠点間/
しゅようくうこう /主要空港/
しゅようさくひん /主要作品/
しゅようさんきしゅ /主要三機種/
しゅようさんぎょう /主要産業/
しゅようしゅだい /主要主題/
しゅようじかん /主要時間/
しゅようじんぶつ /主要人物/
しゅようそしき /主要組織/
しゅようたいいん /主要隊員/
しゅようだいがく /主要大学/
しゅようち /主要地/
しゅようちょさく /主要著作/
しゅようとうじょうじんぶつ /主要登場人物/
しゅようとっきゅう /主要特急/
しゅようどうろ /主要道路/
しゅようひしゃたい /主要被写体/
しゅようぶ /主要部/
しゅようぶひん /主要部品/
しゅようぶぶん /主要部分/
しゅようぶもん /主要部門/
しゅようへんこうてん /主要変更点/
しゅようようそ /主要要素/
しゅようようそじょう /主要要素上/
しゅようろんぶん /主要論文/
しゅよく /主翼/
しゅよくじょう /主翼上/
しゅら /修羅/
しゅらおう /修羅王/
しゅらせいさん /修羅凄惨/
しゅらば /修羅場/
しゅらん /酒乱/
しゅり /首里/
しゅりけん /手裏剣/
しゅりし /首里市/
しゅりゅう /主流/腫瘤/
しゅりゅうけっとう /主流血統/
しゅりゅうけつみゃく /主流血脈/
しゅりゅうだん /手榴弾/
しゅりゅうは /主流派/
しゅりょう /狩猟/首領/酒量/
しゅりょうけん /狩猟犬/
しゅりょうじゅう /狩猟銃/狩猟獣/
しゅりょうたいしょう /狩猟対象/
しゅりょうほういはん /狩猟法違反/
しゅりょうよう /狩猟用/
しゅりょく /主力/
しゅりょくかん /主力艦/
しゅりょくき /主力機/
しゅりょくきゅう /主力級/
しゅりょくせいひん /主力製品/
しゅりょくせんしゃ /主力戦車/
しゅりょくせんしゅ /主力選手/
しゅりょくだしゃ /主力打者/
しゅりょくとうしゅ /主力投手/
しゅりょくぶたい /主力部隊/
しゅるい /種類/酒類/
しゅるいごと /種類毎/
しゅるいすう /種類数/
しゅるいべつ /種類別/
しゅるいめい /種類名/
しゅろ /棕櫚/椶櫚/
しゅろんぶん /主論文/
しゅわ /手話/
しゅわおん /主和音/
しゅわくせい /主惑星/
しゅわこうしゅうかい /手話講習会/
しゅわひょうげん /手話表現/
しゅわん /手腕/
しゅん /春/瞬/俊/旬/舜/峻/竣/駿/儁/墫/悛/惷/浚/濬/皴/蕣/蠢/逡/雋/筍/
しゅんいち /俊一/峻一/
しゅんいちろう /俊一郎/俊一朗/
しゅんえい /俊英/
しゅんか /春夏/春歌/
しゅんかしゅうとう /春夏秋冬/
しゅんかどう /春華堂/
しゅんかん /瞬間/春寒/
しゅんかんいどう /瞬間移動/
しゅんかんげい /瞬間芸/
しゅんかんさいだい /瞬間最大/
しゅんかんさいだいふうそく /瞬間最大風速/
しゅんかんさいみん /瞬間催眠/
しゅんかんしょうげきは /瞬間衝撃波/
しゅんかんせっちゃく /瞬間接着/
しゅんかんせっちゃくざい /瞬間接着剤/
しゅんかんてき /瞬間的/
しゅんかんゆわかしき /瞬間湯沸かし機/
しゅんが /春画/
しゅんき /春期/春季/峻輝/
しゅんきたいかい /春期大会/春季大会/
しゅんきち /駿吉/
しゅんぎく /春菊/
しゅんぎょ /旬魚/
しゅんぎょう /春業/
しゅんけん /峻険/
しゅんげん /峻厳/
しゅんこう /竣工/
しゅんさい /俊才/
しゅんざい /春材/
しゅんしょう /春宵/
しゅんしん /舜臣/
しゅんじ /瞬時/俊二/俊次/俊司/俊治/
しゅんじち /瞬時値/
しゅんじていか /瞬時低下/
しゅんじゅう /春秋/
しゅんじゅうせんごくじだい /春秋戦国時代/
しゅんじゅん /逡巡/
しゅんすい /旬粋/
しゅんすけ /俊介/俊輔/俊亮/
しゅんせい /俊成/
しゅんせつ /春節/浚渫/
しゅんそく /駿足/俊足/瞬息;単位。10^-16/
しゅんぞう /俊三/
しゅんたろう /俊太郎/
しゅんだん /瞬断/春暖/
しゅんてい /瞬停/
しゅんてつ /俊哲/
しゅんでん /瞬電/
しゅんとう /春闘/
しゅんとうぐん /駿東郡/
しゅんどう /春藤/蠢動/
しゅんば /駿馬/
しゅんぱつりょく /瞬発力/
しゅんぱつりょくしょうぶ /瞬発力勝負/
しゅんびん /俊敏/
しゅんぶん /春分/
しゅんぶんてん /春分点/
しゅんぶんび /春分日/
しゅんぷう /春風/
しゅんぷうたいとう /春風駘蕩/
しゅんぷうてい /春風亭/
しゅんべつ /峻別/
しゅんみん /春眠/
しゅんめ /駿馬/
しゅんや /春夜/
しゅんようぶんこ /春陽文庫/
しゅんようぶんこばん /春陽文庫版/
しゅんらい /春雷/
しゅんれつ /峻烈/
しゅんろう /隼郎/隼朗/俊朗/春郎/
しゆう /私有/雌雄/市有/
しゆういしゅ /雌雄異株/
しゆうざいさん /私有財産/
しゆうち /私有地/市有地/
しゆうてつどうがいしゃ /私有鉄道会社/
しゆうどうしゅ /雌雄同株/
しゆうどうたい /雌雄同体/
しゆうぶつ /私有物/
しょ /書/所/初/諸/暑/緒/署/庶/処/藷/薯/曙/渚/狙/處/墅/嶼/砠/胥/苴/苜/蔗/蜍/雎/黍/岨/杵/且/
しょ> /諸/
しょー /ショー/
しょーと /ショート/
しょあく /諸悪/
しょい /所為/所謂/
しょいちねん /初一念/
しょいり /初入/
しょいん /所員/書院/署員/
しょいんぶんこ /書院文庫/
しょう /章/小/賞/証/笑/勝/少/称/焦/傷/照/松/尚/性/消/詳/障/正/焼/省/祥/昭/上/象/鐘/症/渉/姓/粧/昇/承/衝/昌/商/沼/晶/彰/将/硝/漿/床/奨/生/裳/紹/捷/璋/鞘/掌/鉦/鍾/醤/詔/庄/招/肖/菖/蒋/償/訟/唱/礁/召/抄/匠/湘/蕉/樟/樵/梢/升/廠/宵/娼/妾/嘗/哨/翔/相/政/星/精/青/牀/邵/ショウ/鬆/鯖/荘/倡/剿/劭/厰/燮/嘯/囁/墻/奬/妝/將/峭/嶂/庠/悚/悄/慯/憔/懾/敞/枩/椒/樅/橸/檣/殤/浹/淞/湫/瀟/炒/燒/爿/牆/猖/猩/獎/甞/瘴/稍/稱/竦/笙/筱/簫/聳/舂/艢/蕭/薔/觴/誦/誚/證/逍/鈔/銷/鏘/陞/霄/霎/韶/頌/顳/餉/鷦/聲/廂/愴/愀/鍬/錆/篠/装/蛸/憧/橡/(^_^)/(笑)/腫/摺/井/秤/咲/慴/声/
しょう# /小#0/
しょう> /小/症/
しょうあく /掌握/性悪/
しょうあくせつ /性悪説/
しょうあつ /昇圧/
しょうあつかいぞうこうじ /昇圧改造工事/
しょうあつこうじ /昇圧工事/
しょうあつたいおうしゃ /昇圧対応車/
しょうい /小異/少尉/小尉/傷痍/焼夷/
しょういいんかい /小委員会/
しょういぐんじん /傷痍軍人/
しょういだん /焼夷弾/燒夷彈/
しょういち /正一/庄一/彰一/昇一/昭一/章一/小一/昌一/省一/祥一/昭市/
しょういちろう /正一郎/昭一郎/
しょういん /勝因/松蔭/証印/
しょういんこうこう /松蔭高校/
しょういんしん /小陰唇/
しょうう /小雨/
しょううちゅう /小宇宙/
しょううん /昌運/勝運/
しょうえ /庄衛/
しょうえい /昌栄/庄栄/庄衛/昭栄/頌栄/
しょうえいじょがくいん /頌栄女学院/
しょうえいじょしがくいん /頌栄女子学院/
しょうえき /漿液/
しょうえね /省エネ/
しょうえん /鞘炎/小宴/招宴/硝煙/荘園/
しょうえんざい /消炎剤/
しょうえんちんつうさよう /消炎鎮痛作用/
しょうお /尚夫/
しょうおう /照応/勝央/
しょうおん /消音/昇温/
しょうおんき /消音器/
しょうおんりょう /小音量/
しょうか /消化/消火/昇華/唱歌/商家/商科/頌歌/漿果/銷夏/
しょうかい /紹介/照会/商会/哨戒/詳解/小海/
しょうかいいがい /紹介以外/
しょうかいかいいん /紹介会員/
しょうかいき /哨戒機/
しょうかいきじ /紹介記事/
しょうかいぎ /小会議/
しょうかいぎしつ /小会議室/
しょうかいけっか /照会結果/
しょうかいさき /照会先/紹介先/
しょうかいしゃ /照会者/紹介者/
しょうかいしゃめい /照会者名/
しょうかいしょ /紹介書/
しょうかいじょ /紹介所/
しょうかいじょう /紹介状/
しょうかいせき /蒋介石/
しょうかいそしき /紹介組織/
しょうかいぞう /小改造/
しょうかいちゅう /照会中/
しょうかいてい /哨戒艇/
しょうかいていど /紹介程度/
しょうかいは /小会派/
しょうかいばんぐみ /紹介番組/
しょうかいぶん /紹介文/紹介分/
しょうかいぼん /紹介本/
しょうかいらん /紹介欄/
しょうかいりょう /紹介料/
しょうかいわく /紹介枠/
しょうかがた /昇華型/
しょうかき /消火器/消化器/小火器/
しょうかきかん /消化器官/
しょうかく /昇格/翔鶴/
しょうかくご /昇格後/
しょうかくしゃ /昇格者/
しょうかくもんだい /昇格問題/
しょうかしあいすう /消化試合数/
しょうかじあい /消化試合/
しょうかせん /消火栓/
しょうかそんじゅく /松下村塾/
しょうかぞく /小家族/
しょうかどう /松花堂;松花堂弁当/
しょうかどうべんとう /松花堂弁当;松花堂弁当/
しょうかふりょう /消化不良/
しょうかへい /小花柄/
しょうかぼう /裳華房/
しょうかりょく /消化力/
しょうかわ /荘川/
しょうかん /償還/召喚/小寒/松幹/召還/商館/将官/招喚/
しょうかんしゃ /召喚者/
しょうかんしゅう /商慣習/
しょうかんじゅもん /召喚呪文/
しょうかんじょう /召喚状/
しょうかんねんすう /償還年数/
しょうが /生姜/
しょうがい /障害/生涯/渉外/傷害/障碍/
しょうがいがくしゅう /生涯学習/
しょうがいきょういく /生涯教育/
しょうがいげんえき /生涯現役/
しょうがいざい /傷害罪/
しょうがいしゃ /障害者/障碍者/
しょうがいしゃうんどう /障害者運動/
しょうがいしゃきょういく /障害者教育/
しょうがいしゃさべつ /障害者差別/
しょうがいしゃもんだい /障害者問題/
しょうがいしゅうひ /傷害周皮/
しょうがいじ /障害児/障害時/
しょうがいじきょういく /障害児教育/
しょうがいじしせつ /障害児施設/
しょうがいぜいふたんりつ /生涯税負担率/
しょうがいたいさく /障害対策/
しょうがいたんとう /渉外担当/
しょうがいだりつ /生涯打率/
しょうがいちし /障害致死/
しょうがいちょうきょう /障害調教/
しょうがいちょうさ /障害調査/
しょうがいとうかせい /障害透過性/
しょうがいどくしん /生涯独身/
しょうがいば /障害馬/
しょうがいぶい /障害部位/
しょうがいぶつ /障害物/
しょうがいぶつきょうそう /障害物競争/
しょうがいぶつなし /障害物無/
しょうがいほけん /傷害保険/障害保険/
しょうがく /小学/奨学/小額/少額/商学/
しょうがくかん /小学館/
しょうがくきふきん /奨学寄付金/
しょうがくきん /奨学金/
しょうがくせい /小学生/奨学生/
しょうがくせいいか /小学生以下/
しょうがくせいじだい /小学生時代/
しょうがくせいじぶん /小学生時分/
しょうがくせいだんし /小学生男子/
しょうがくせいていがくねん /小学生低学年/
しょうがくせいみまん /小学生未満/
しょうがくせいやく /小学生役/
しょうがくせいよう /小学生用/
しょうがくぶ /小学部/
しょうがくろくねんせい /小学六年生/
しょうがっかん /小学館/
しょうがっかんいがい /小学館以外/
しょうがっかんぎょうしょ /小学館業書/
しょうがっかんけい /小学館系/
しょうがっかんそうしょ /小学館叢書/
しょうがっかんはっこう /小学館発行/
しょうがっこう /小学校/
しょうがっこうきょうし /小学校教師/
しょうがっこうこうがくねん /小学校高学年/
しょうがっこうじだい /小学校時代/
しょうがっこうだんかい /小学校段階/
しょうがっこうていがくねん /小学校低学年/
しょうがつ /正月/
しょうがついらい /正月以来/
しょうがつきせい /正月帰省/
しょうがつきぶん /正月気分/
しょうがつこうかい /正月公開/
しょうがつそうそう /正月早々/
しょうがつちゅう /正月中/
しょうがつとくべつこうえん /正月特別公演/
しょうがつばん /正月版/
しょうがつばんぐみ /正月番組/
しょうがつまえ /正月前/
しょうがつやすみ /正月休み/
しょうがつよう /正月用/
しょうがつりょうり /正月料理/
しょうがみそ /生姜味噌/
しょうがもく /ショウガ目/Musales/Scitamineae/Zingiberales/
しょうがわ /庄川/
しょうき /正気/勝機/商機/鍾馗/瘴気/詳記/笑気/
しょうきぎょう /小企業/
しょうきち /昭吉/正吉/
しょうきぼ /小規模/
しょうきぼきょく /小規模局/
しょうきゃく /償却/焼却/消却/
しょうきゃくきかん /償却期間/
しょうきゃくきげん /償却期限/
しょうきゃくじょ /焼却所/
しょうきゃくじょう /焼却場/
しょうきゃくろ /焼却炉/
しょうきゅう /昇給/小球/昇級/
しょうきゅうし /小休止/小臼歯/
しょうきゅうしけん /昇級試験/
しょうきゅうしょうだん /昇級昇段/
しょうきょ /消去/
しょうきょう /商況/
しょうきょうと /小京都/
しょうきょうれんごう /勝共連合/
しょうきょく /消極/小曲/
しょうきょくさく /消極策/
しょうきょくしゅう /小曲集/
しょうきょくせい /消極性/
しょうきょくてき /消極的/
しょうきょくてきさんせい /消極的賛成/
しょうきょくてきたちば /消極的立場/
しょうきょくてきはんたい /消極的反対/
しょうきょくてきりゆう /消極的理由/
しょうきょちょくご /消去直後/
しょうきょほう /消去法/
しょうきん /賞金/償金/正金/
しょうきんおう /賞金王/
しょうきんかくさ /賞金格差/
しょうきんかくとくそうがく /賞金獲得総額/
しょうきんじょおう /賞金女王/
しょうきんそうがく /賞金総額/
しょうきんてき /賞金的/
しょうきんぶそく /賞金不足/
しょうきんもんだい /賞金問題/
しょうぎ /将棋/商議/娼妓/牀几/床几/象棋/
しょうぎいご /将棋囲碁/
しょうぎいっちょくせん /将棋一直線/
しょうぎかい /将棋界/
しょうぎかいかん /将棋会館/
しょうぎかんけい /将棋関係/
しょうぎきょうかい /将棋協会/
しょうぎし /将棋史/
しょうぎしなん /将棋指南/
しょうぎしょり /将棋処理/
しょうぎせかい /将棋世界/
しょうぎせんしゅけん /将棋選手権/
しょうぎたいきょく /将棋対局/
しょうぎどうじょう /将棋道場/
しょうぎばん /将棋板/将棋盤/
しょうぎぶ /将棋部/
しょうぎまつり /将棋祭/
しょうぎょう /商業/
しょうぎょうか /商業化/
しょうぎょうこうこう /商業高校/
しょうぎょうさくひん /商業作品/
しょうぎょうし /商業誌/
しょうぎょうしかつどう /商業誌活動/
しょうぎょうしせつ /商業施設/
しょうぎょうしゅぎてき /商業主義的/
しょうぎょうじょう /商業上/
しょうぎょうせいひん /商業製品/
しょうぎょうせん /商業船/
しょうぎょうたんこうぼん /商業単行本/
しょうぎょうち /商業地/商業値/
しょうぎょうてき /商業的/
しょうぎょうてきじょうほう /商業的情報/
しょうぎょうてきりえき /商業的利益/
しょうぎょうぶん /商業文/
しょうぎょうぶんや /商業分野/
しょうぎょうもくてき /商業目的/
しょうぎょうよう /商業用/
しょうぎょうりよう /商業利用/
しょうぎょうれつ /小行列/
しょうぎょうれつしき /小行列式/
しょうぎようご /将棋用語/
しょうぎれんめい /将棋連盟/
しょうぎんが /小銀河/
しょうくうかん /小空間/商空間/
しょうくかん /小区間/
しょうぐん /将軍/
しょうぐんけ /将軍家/
しょうぐんづか /将軍塚/
しょうけい /小計/小憩/象形/尚絅/上卿/小径/小逕/小経/小景/小慧/少頃/少憩/正慶/承継/昌慶/松径/祥啓/祥慶/商計/捷径/捷勁/紹継/勝景/晶系/憧憬/鐘形/
しょうけつ /燒結/猖獗/
しょうけん /証券/證券/商圏/
しょうけんかい /証券界/
しょうけんがいしゃ /証券会社/
しょうけんがいしゃきんむ /証券会社勤務/
しょうけんぎょうかい /証券業界/
しょうけんしゅうしつ /小研修室/
しょうけんとりひきいいんかい /証券取引委員会/
しょうけんとりひきほう /証券取引法/
しょうけんろう /笑犬楼/笑犬樓/
しょうげき /衝撃/
しょうげきおん /衝撃音/
しょうげききゅうしゅうざい /衝撃吸収材/
しょうげききゅうしゅうりつ /衝撃吸収率/
しょうげきじょう /小劇場/
しょうげきせい /衝撃性/
しょうげきそうおん /衝撃騒音/
しょうげきてき /衝撃的/
しょうげきは /衝撃波/
しょうげん /証言/将監/象限/
しょうげんしゃ /証言者/
しょうげんしゅう /証言集/
しょうげんじたい /証言自体/
しょうげんないよう /証言内容/
しょうげんりょく /証言力/
しょうこ /証拠/祥子/翔子/昌己/しょう子/晶子/聖子/章子/省子/商估/商賈/尚子/宵子/昌子/證拠/抄子/荘子/
しょうこあつめ /証拠集め/
しょうこいんめつ /証拠隠滅/
しょうこう /商工/小康/症候/将校/昇降/焼香/昭晃/商港/焼光/少考/消耗/銷耗/召公/
しょうこうい /商行為/
しょうこうかいぎしょ /商工会議所/
しょうこうき /昇降機/
しょうこうぎょう /商工業/
しょうこうぎょうしゃ /商工業者/
しょうこうぐち /昇降口/
しょうこうぐん /症候群/
しょうこうけい /小口径/
しょうこうざ /小講座/
しょうこうし /小公子/
しょうこうしき /昇降式/
しょうこうしゅ /紹興酒/
しょうこうじょ /小公女/
しょうこうじょうたい /小康状態/
しょうこうだ /昇降舵/
しょうこうだい /焼香台/
しょうこうつうしょう /昭光通商/
しょうこうてん /昇交点/
しょうこうどう /昭晃堂/
しょうこうねつ /猩紅熱/
しょうこうほ /賞候補/
しょうこうもく /小項目/
しょうこうろう /小紅楼/
しょうこかくほ /証拠確保/
しょうこきん /証拠金/
しょうこく /小国/
しょうこくみん /小国民/
しょうこしゃしん /証拠写真/
しょうこしゅうしゅう /証拠収集/
しょうこじょう /証拠上/
しょうこのうりょく /証拠能力/
しょうこふじゅうぶん /証拠不十分/
しょうこり /性懲り/性凝り/
しょうこん /商魂/傷痕/
しょうご /正午/昭吾/省吾/正吾/祥吾/尚五/昌吾/祥悟/小五/翔吾/
しょうごいん /聖護院/
しょうごう /照合/称号/商号/稱號/
しょうごういん /照合印/
しょうごうけっか /照合結果/
しょうごうさくせん /捷号作戰/
しょうごうしゃ /照合者/
しょうごうじ /照合時/
しょうごうじかん /照合時間/
しょうごうじっけん /照合実験/
しょうごうせいど /照合精度/
しょうごうぶ /照合部/
しょうごうぶん /照合文/
しょうごうほう /照合法/
しょうごうよう /照合用/
しょうごうりつ /照合率/
しょうごく /小国/
しょうごげんざい /正午現在/
しょうごはつ /正午発/
しょうごひっちゃく /正午必着/
しょうごまで /正午迄/
しょうさ /照査/小差/少佐/証左/
しょうさい /詳細/商才/省際/
しょうさいか /詳細化/
しょうさいけんとう /詳細検討/
しょうさいじょうほう /詳細情報/
しょうさいず /詳細図/
しょうさいずめん /詳細図面/
しょうさいせっけい /詳細設計/
しょうさいせってい /詳細設定/
しょうさいばん /詳細版/
しょうさいふめい /詳細不明/
しょうさいみてい /詳細未定/
しょうさかん /小属/
しょうさく /昇作/
しょうさっし /小冊子/
しょうさん /勝算/称賛/賞賛/消散/硝酸/賞讃/
しょうさんえん /硝酸塩/
しょうさんぎん /硝酸銀/
しょうざき /庄崎/
しょうざっし /小雑誌/
しょうざぶろう /正三郎/
しょうざんかん /勝山館/
しょうし /笑止/尚士/焼死/証紙/昇志/省資/尚志/
しょうしかん /尚志館/
しょうしげん /省資源/
しょうしせんばん /笑止千万/
しょうしたい /焼死体/
しょうしつ /消失/焼失/銷失/
しょうしつせん /消失線/
しょうしつてん /消失点/
しょうしみん /小市民/
しょうしみんてき /小市民的/
しょうしゃ /勝者/商社/照射/小社/瀟洒/
しょうしゃいん /商社員/
しょうしゃかく /照射角/
しょうしゃご /照射後/
しょうしゃごしけん /照射後試験/
しょうしゃしょくひん /照射食品/
しょうしゃせんりょう /照射線量/
しょうしゃはんい /照射範囲/
しょうしゃめん /照射面/
しょうしゃめんせき /照射面積/
しょうしゃよう /照射用/
しょうしゃりょう /照射量/
しょうしゅ /漿酒/
しょうしゅう /召集/招集/消臭/
しょうしゅうかん /商習慣/
しょうしゅうごう /商集合/
しょうしゅうざい /消臭剤/
しょうしゅうせい /小修正/
しょうしゅうだん /少集団/
しょうしゅうれい /召集令/
しょうしゅうれいじょう /召集令状/
しょうしゅつ /抄出/
しょうしゅん /頌春/
しょうしょ /証書/小暑/詔書/尚書/
しょうしょう /少々/少将/小将/詔召/小升/小哨/小祥/小照/少小/少少/小小/昌昌/昭昭/省掌/将相/悚悚/悄悄/商聖/章章/彰彰/晶晶/蕭牆/蕭蕭/鏘鏘/瀟湘/
しょうしょうひでんりょく /小消費電力/
しょうしょく /小食/小職/
しょうしょたい /小所帯/
しょうしょていき /証書定期/
しょうしん /昇進/傷心/焼身/正真/小心/焦心/
しょうしんさいん /賞審査員/
しょうしんしょうめい /正真正銘/
しょうしんじさつ /焼身自殺/
しょうしんちょくぜん /昇進直前/
しょうしんぷく /小振幅/
しょうしんまえ /昇進前/
しょうしんもの /小心者/
しょうしんもんだい /昇進問題/
しょうしんよく /昇進欲/
しょうじ /商事/尚司/庄司/障子/東海林/昭二/昭司/祥之/荘司/勝治/捷二/昭次/消磁/昇二/庄子/昭治/将司/小事/昇治/祥治/尚史/昇司/章二/少時/小路/昌二/章司/正次/正治/正二/小児/彰治/
しょうじき /正直/
しょうじきぎょうしゃ /正直業者/
しょうじきもの /正直者/
しょうじこ /精進湖/
しょうじてん /小事典/
しょうじま /生島/
しょうじゃ /精舎/
しょうじゃく /正雀/
しょうじゅう /小銃/
しょうじゅしょうしゃ /賞受賞者/
しょうじゅつ /詳述/
しょうじゅまんが /少女漫画/
しょうじゅん /昇順/照準/
しょうじゅんがんきょう /照準眼鏡/
しょうじゅんき /照準器/
しょうじゅんせんじょう /照準線上/
しょうじゅんてん /照準点/
しょうじょ /少女/翔女/
しょうじょう /症状/賞状/小乗/商状/猩猩/清浄/掌状/霄壌/
しょうじょうけいげん /症状軽減/
しょうじょうさいげん /症状再現/
しょうじょうひ /猩々緋/
しょうじょうふくよう /掌状複葉/
しょうじょうみゃく /掌状脈/
しょうじょかしゅ /少女歌手/
しょうじょざっし /少女雑誌/
しょうじょし /少女誌/
しょうじょしゅみ /少女趣味/
しょうじょしょうせつ /少女小説/
しょうじょしょうせつるい /少女小説類/
しょうじょたい /少女隊/
しょうじょたち /少女達/
しょうじょぶもん /少女部門/
しょうじょまんが /少女漫画/
しょうじょまんがか /少女漫画家/
しょうじょまんがざっし /少女漫画雑誌/
しょうじょまんがし /少女漫画誌/
しょうじろう /彰二郎/正次郎/章治郎/象二郎/
しょうじん /精進/焼尽/
しょうじんあげ /精進揚/
しょうじんりょうり /精進料理/
しょうすい /憔悴/消衰/将帥/小水/
しょうすう /小数/少数/勝数/
しょうすういけん /少数意見/小数意見/
しょうすうがわ /小数側/
しょうすうしい /小四喜/
しょうすうしゃ /少数者/小数者/
しょうすうじれい /小数事例/
しょうすうせいえい /少数精鋭/
しょうすうせいえいしゅぎ /少数精鋭主義/
しょうすうせいとう /小数政党/
しょうすうてん /小数点/
しょうすうてんいか /小数点以下/
しょうすうてんいじ /小数点維持/
しょうすうてんいじへんかんほう /小数点維持変換法/
しょうすうてんすう /小数点数/少数点数/
しょうすうにんずう /少数人数/
しょうすうは /少数派/小数派/
しょうすうひょうじ /小数表示/
しょうすうぶ /小数部/
しょうすうぶぶん /小数部分/
しょうすうみんぞく /小数民族/少数民族/
しょうすけ /正助/庄助/昭助/
しょうず /小豆/
しょうずい /祥瑞/
しょうせい /小生/招請/小成/焼成/
しょうせいりょく /小勢力/
しょうせき /鐘石/
しょうせつ /小説/小節/詳説/小雪/章節/
しょうせつか /小説家/小説化/
しょうせつげんだい /小説現代/
しょうせつざっし /小説雑誌/
しょうせつせん /小節線/
しょうせつちゅう /小説中/
しょうせつない /小説内/
しょうせつばん /小説版/
しょうせつぶん /小節分/
しょうせつぼん /小説本/
しょうせつめ /小節目/
しょうせん /商船/商戦/省線/
しょうせんがくけんきゅうか /商船学研究科/
しょうせんきょう /昇仙峡/
しょうせんきょく /小選挙区/
しょうせんきょくせい /小選挙区制/
しょうせんこうせん /商船高専/
しょうせんだい /商船大/
しょうせんだいがく /商船大学/
しょうせんでんしゃ /省線電車/
しょうぜつ /勝絶/
しょうぜん /小全/哨然/承前/性善/悄然/
しょうぜんてい /小前提/
しょうそ /勝訴/
しょうそう /尚早/焦燥/傷愴/悄愴/焦躁/
しょうそういん /正倉院/
しょうそうかん /焦燥感/
しょうそく /消息/
しょうそくすじ /消息筋/
しょうそくつう /消息通/
しょうそくふめい /消息不明/
しょうそん /焼損/
しょうぞう /省三/肖像/昭三/正三/勝三/捷三/省造/尚三/彰三/正蔵/
しょうぞういん /正倉院/
しょうぞうが /肖像画/
しょうぞうがしゅう /肖像画集/
しょうぞうがてん /肖像画展/
しょうぞうけん /肖像権/
しょうぞうしゅう /肖像集/
しょうぞうはんが /肖像版画/
しょうぞく /装束/
しょうた /正太/章太/翔太/
しょうたい /招待/正体/小体/小隊/商体/消退/
しょうたいきゃく /招待客/
しょうたいけん /招待券/
しょうたいこうえん /招待講演/
しょうたいこうえんしゃ /招待講演者/
しょうたいしゃ /招待者/
しょうたいじょう /招待状/
しょうたいせんしゅ /招待選手/
しょうたいちょう /小隊長/
しょうたいにゅうじょうけん /招待入場券/
しょうたいば /招待馬/
しょうたいび /招待日/
しょうたいふめい /正体不明/
しょうたいりょこう /招待旅行/
しょうたろう /昭太郎/正太郎/承太郎/章太郎/
しょうたん /賞嘆/
しょうたんい /章単位/
しょうだ /正田/庄田/掌打/
しょうだい /小代/正代/掌大/
しょうだく /承諾/
しょうだくいん /承諾印/
しょうだくけん /承諾権/
しょうだくしょ /承諾書/
しょうだくじょうけん /承諾条件/
しょうだて /章立て/
しょうだん /商談/昇段/
しょうだんせいりつ /商談成立/
しょうだんせいりつご /商談成立後/
しょうだんちゅう /商談中/
しょうち /承知/招致/
しょうちうんどう /招致運動/
しょうちく /松竹/
しょうちくばい /松竹梅/
しょうちゅう /掌中/焼酎/小中/
しょうちゅうがく /小中学/
しょうちゅうがくせい /小中学生/
しょうちゅうがくせいけん /小中学生券/
しょうちゅうがくせいじだい /小中学生時代/
しょうちゅうがくせいむけ /小中学生向け/
しょうちゅうがっこう /小中学校/
しょうちゅうこう /小中高/
しょうちょう /象徴/小腸/省庁/消長/
しょうちょういがい /象徴以外/
しょうちょうかんじ /象徴幹事/
しょうちょうじょうひ /小腸上皮/
しょうちょうせい /象徴性/
しょうちょうたいけいてき /象徴体系的/
しょうちょうてき /象徴的/
しょうちょうてんのう /象徴天皇/
しょうちょく /詔勅/
しょうちん /消沈/銷沈/
しょうてい /掌底/
しょうていぎょくはく /鐘鼎玉帛/
しょうていり /小定理/
しょうてきほう /小滴法/
しょうてん /焦点/商店/笑点/昇天/衝天/小篆/
しょうてんいどう /焦点移動/
しょうてんかい /商店会/
しょうてんがい /商店街/
しょうてんきょり /焦点距離/
しょうてんきょりふきん /焦点距離付近/
しょうてんしゅ /商店主/
しょうてんしんど /焦点深度/
しょうてんはんい /焦点範囲/
しょうでん /昭電/小伝/小電/
しょうでんしゃ /祥伝社/
しょうでんりょく /小電力/省電力/
しょうでんりょくがた /小電力型/
しょうでんりょくきのう /省電力機能/
しょうと /商都/
しょうとう /消灯/消燈/
しょうとうきょう /小東京/
しょうとうすう /小頭数/
しょうとく /聖徳/
しょうとくがくえん /聖徳学園/
しょうとくしゅう /小特集/
しょうとくたいし /聖徳太子/
しょうとくてき /生得的/
しょうとつ /衝突/
しょうとついち /衝突位置/
しょうとつおん /衝突音/
しょうとつかく /衝突核/
しょうとつかくりつほう /衝突確率法/
しょうとつこん /衝突痕/
しょうとつご /衝突後/
しょうとつじ /衝突時/
しょうとつじこ /衝突事故/
しょうとつじこく /衝突時刻/
しょうとつじっけん /衝突実験/
しょうとつてん /衝突点/
しょうとつはんてい /衝突判定/
しょうとつまえ /衝突前/
しょうとつみつど /衝突密度/
しょうとつりつ /衝突率/
しょうとりひき /商取引/
しょうとりほう /証取法/
しょうど /照度/焦土/
しょうどう /衝動/章動/
しょうどううり /衝動売り/
しょうどうがい /衝動買い/
しょうどうてき /衝動的/
しょうどうぶつ /小動物/
しょうどく /消毒/抄読会/
しょうどくかい /抄読会/
しょうどくき /消毒器/
しょうどくやく /消毒薬/
しょうどくよう /消毒用/
しょうどけい /照度計/
しょうどさ /照度差/
しょうどしま /小豆島/
しょうどじま /小豆島/
しょうどせんじゅつ /焦土戦術/焦土戰術/
しょうどちょうせい /照度調整/
しょうどぶんぷ /照度分布/
しょうない /庄内/荘内/省内/
しょうなり /≦/＜/
しょうなん /湘南/沼南/
しょうなんこうこう /湘南高校/
しょうなんしょく /湘南色/
しょうなんじぎょうしょ /湘南事業所/
しょうなんだい /湘南台/
しょうなんだいえき /湘南台駅/
しょうなんちく /湘南地区/
しょうなんちほう /湘南地方/
しょうなんでんきてつどう /湘南電気鉄道/
しょうなんでんし /湘南電子/
しょうなんでんしゃ /湘南電車/
しょうなんふじさわ /湘南藤沢/
しょうに /小児/
しょうにか /小児科/
しょうにかい /小児科医/
しょうにき /小児期/
しょうにげか /小児外科/
しょうにげかびょうとう /小児外科病棟/
しょうにゅう /鍾乳/
しょうにゅうたい /鍾乳体/
しょうにゅうどう /鍾乳洞/鐘乳洞/
しょうにん /承認/証人/商人/小人/昇任/上人/聖人/
しょうにんいぜん /承認以前/
しょうにんかんもん /証人喚問/
しょうにんご /承認後/
しょうにんじ /承認時/
しょうにんずう /少人数/小人数/
しょうにんとうひょう /承認投票/
しょうにんとうひょうじっし /承認投票実施/
しょうにんばんごう /承認番号/
しょうね /性根/
しょうねつ /焦熱/
しょうねん /少年/
しょうねんいん /少年院/
しょうねんがっしょうだん /少年合唱団/
しょうねんがほうしゃ /少年画報社/
しょうねんけいむしょ /少年刑務所/
しょうねんし /少年誌/
しょうねんしょうじょ /少年少女/
しょうねんじ /少年時/
しょうねんじだい /少年時代/
しょうねんたい /少年隊/
しょうねんたち /少年達/
しょうねんたんていだん /少年探偵団/
しょうねんだん /少年団/
しょうねんちょうやく /少年跳躍/
しょうねんはんざい /少年犯罪/
しょうねんば /正念場/
しょうねんばん /少年版/
しょうねんひこう /少年非行/
しょうねんぴ /少燃費/
しょうねんぴしゃ /省燃費車/
しょうねんぶもん /少年部門/
しょうねんまんが /少年漫画/
しょうねんまんがし /少年漫画誌/
しょうねんもの /少年物/
しょうねんやく /少年役/
しょうねんようじょ /少年幼女/
しょうの /庄野/笙野/
しょうのう /小脳/笑納/樟脳/
しょうのうじょうひ /小脳上皮/
しょうのうひしつ /小脳皮質/
しょうのすけ /庄之助/
しょうは /小破/消波/
しょうはい /勝敗/少牌/賞杯/
しょうはいきりょう /少排気量/小排気量/
しょうはいすう /勝敗数/
しょうはいひょう /勝敗表/
しょうはち /正八/
しょうばい /商売/
しょうばいがら /商売柄/
しょうばいぎ /商売気/
しょうばいじょう /商売上/
しょうばいじょうず /商売上手/
しょうばいにん /商売人/
しょうばいはんじょう /商売繁盛/
しょうばいひん /商売品/
しょうばいほうほう /商売方法/
しょうばいもの /商売物/
しょうばたけ /正畠/
しょうばつ /賞罰/
しょうばら /庄原/
しょうばらし /庄原市/
しょうばん /相伴/床版/
しょうばんごう /章番号/
しょうひ /消費/
しょうひかつどう /消費活動/
しょうひがく /消費額/
しょうひけいかく /消費計画/
しょうひけいたい /消費形態/
しょうひざい /消費財/
しょうひしゃ /消費者/
しょうひしゃうんどう /消費者運動/
しょうひしゃがた /消費者型/
しょうひしゃそうだん /消費者相談/
しょうひしゃだんたい /消費者団体/
しょうひしゃふたん /消費者負担/
しょうひしゃほご /消費者保護/
しょうひせいかつ /消費生活/
しょうひぜい /消費税/
しょうひぜいこみ /消費税込/
しょうひぜいじたい /消費税自体/
しょうひぜいどうにゅう /消費税導入/
しょうひぜいぬき /消費税抜き/
しょうひぜいぶん /消費税分/
しょうひぜいべつ /消費税別/
しょうひぜいほう /消費税法/
しょうひぜいりつ /消費税率/
しょうひぜんたい /消費全体/
しょうひたいしゃく /消費貸借/
しょうひち /消費地/
しょうひちょちくこうどう /消費貯蓄行動/
しょうひでんりゅう /消費電流/
しょうひでんりょく /消費電力/
しょうひでんりょくぶん /消費電力分/
しょうひほうほう /消費方法/
しょうひゃっか /小百科/
しょうひょう /商標/証票/証憑/
しょうひょうけん /商標権/
しょうひょうせいど /証票制度/
しょうひょうとうりょくきょく /商標登録局/
しょうひりつ /消費率/
しょうひりょう /消費量/消費料/
しょうひん /商品/賞品/小品/
しょうひんか /商品化/
しょうひんかいはつ /商品開発/
しょうひんかいはつか /商品開発課/
しょうひんかいはつご /商品開発後/
しょうひんかいはつしつ /商品開発室/
しょうひんかいはつぶ /商品開発部/
しょうひんかいはつほうほう /商品開発方法/
しょうひんかかく /商品価格/
しょうひんかけん /商品化権/
しょうひんかち /商品価値/
しょうひんきかく /商品企画/
しょうひんぐん /商品群/
しょうひんけいざい /商品経済/
しょうひんけいざいしゃかい /商品経済社会/
しょうひんけん /商品券/
しょうひんこうかんじょ /賞品交換所/
しょうひんこうせい /商品構成/
しょうひんさきものとりひき /商品先物取引/
しょうひんさくもつ /商品作物/
しょうひんしじょう /商品市場/
しょうひんしゅう /小品集/
しょうひんしゅどうがた /商品主導型/
しょうひんじぎょうぶ /商品事業部/
しょうひんじょうほう /商品情報/
しょうひんせっけい /商品設計/
しょうひんせつめい /商品説明/
しょうひんそうこ /商品倉庫/
しょうひんちしき /商品知識/
しょうひんていど /商品程度/
しょうひんはつばい /商品発売/
しょうひんはんばい /商品販売/
しょうひんばん /商品版/
しょうひんばんづけ /商品番付/
しょうひんめい /商品名/
しょうひんれい /商品例/
しょうび /焦眉/賞美/
しょうびょう /傷病/
しょうびょうへい /傷病兵/
しょうふ /娼婦/
しょうふく /承服/承伏/妾腹/
しょうふくてい /笑福亭/
しょうふくていつるこう /笑福亭鶴光/
しょうふだ /正札/
しょうぶ /勝負/菖蒲/
しょうぶけい /勝負型/
しょうぶこんじょう /勝負根性/
しょうぶごと /勝負事/
しょうぶし /勝負師/
しょうぶどころ /勝負所/
しょうぶふく /勝負服/
しょうぶもん /小部門/
しょうぶろん /勝負論/
しょうぶん /性分/昌文/小文/
しょうぶんかん /松文館/
しょうぶんしゃ /晶文社/昭文社/
しょうぶんせつ /小文節/
しょうぶんるい /小分類/
しょうへい /昇平/正平/笑瓶/招へい/招聘/小兵/昌平/章平/省平/昭平/
しょうへいこう /昌平黌/
しょうへいもと /招聘元/
しょうへき /障壁/
しょうへん /掌篇/掌編/小片/
しょうへんこう /小変更/
しょうへんせい /小編成/
しょうべん /小便/
しょうほーる /小ホール/
しょうほう /商法/詳報/勝報/小胞/捷報/唱法/
しょうほうじ /正法池/正法地/
しょうほうたい /小胞体/
しょうほく /勝北/
しょうほん /抄本/
しょうぼう /消防/
しょうぼうえんきょう /小望遠鏡/
しょうぼうし /消防士/
しょうぼうしせつ /消防施設/
しょうぼうしゃ /消防車/
しょうぼうしょ /消防署/
しょうぼうじょうれい /消防条例/
しょうぼうたい /消防隊/
しょうぼうたいいん /消防隊員/
しょうぼうちょう /消防庁/
しょうぼうほう /消防法/
しょうま /消磨/
しょうまく /漿膜/
しょうまつ /章末/
しょうまる /正丸/
しょうまん /小満/正満/
しょうみ /賞味/正味/
しょうみきげん /賞味期限/
しょうみじかん /正味時間/
しょうみつ /詳密/
しょうみゃく /小脈/
しょうみょう /声明/
しょうむ /商務/
しょうめい /証明/照明/正銘/證明/
しょうめいおわり /証明終/
しょうめいかのう /証明可能/
しょうめいかのうせい /証明可能性/
しょうめいかんきょう /証明環境/
しょうめいき /証明器/証明機/
しょうめいきぐ /照明器具/
しょうめいぎ /証明木/
しょうめいけい /証明系/
しょうめいけっか /証明結果/
しょうめいけんしょう /証明検証/
しょうめいけんしょうけい /証明検証系/
しょうめいこう /証明項/
しょうめいこうせいき /証明構成機/
しょうめいこうせいぶ /証明構成部/
しょうめいこうぞう /証明構造/
しょうめいこうちく /証明構築/
しょうめいさくせい /証明作成/
しょうめいしえん /証明支援/
しょうめいしえんき /証明支援器/
しょうめいしえんけい /証明支援系/
しょうめいしすてむ /証明システム/
しょうめいしゃ /証明者/
しょうめいしょ /証明書/
しょうめいしょう /証明証/
しょうめいしょはっこう /証明書発行/
しょうめいず /証明図/
しょうめいせつび /照明設備/
しょうめいせんりゃく /証明戦略/
しょうめいたいけい /証明体系/
しょうめいだん /照明弾/
しょうめいだんぺん /証明断片/
しょうめいちゅう /証明中/
しょうめいてじゅん /証明手順/
しょうめいてつづき /証明手続き/
しょうめいとう /照明燈/照明灯/
しょうめいふかのう /証明不可能/
しょうめいへんかん /証明変換/
しょうめいほう /証明法/
しょうめいほうしき /証明方式/
しょうめいほうしん /証明方針/
しょうめいほうほう /証明方法/
しょうめいもんだい /証明問題/
しょうめいよう /照明用/
しょうめいりろん /証明理論/
しょうめいれい /証明例/
しょうめいろん /証明論/
しょうめいろんてき /証明論的/
しょうめつ /消滅/生滅/
しょうめつご /消滅後/
しょうめつし /消滅子/
しょうめつしょり /消滅処理/
しょうめつせん /消滅線/
しょうめん /正面/生面/小面/
しょうめんきって /正面切って/
しょうめんぐち /正面口/
しょうめんしゃしん /正面写真/
しょうめんしょうとつ /正面衝突/
しょうめんぞう /正面像/
しょうめんちゅうしゃじょう /正面駐車場/
しょうめんとっぱ /正面突破/
しょうめんひじょうぐち /正面非常口/
しょうめんほうこう /正面方向/
しょうめんほうこうまく /正面方向幕/
しょうめんまど /正面窓/
しょうもう /消耗/
しょうもうせん /消耗戦/
しょうもうでんち /消耗電池/
しょうもうど /消耗度/
しょうもうひん /消耗品/
しょうもうひんかんけい /消耗品関係/
しょうもうひんだい /消耗品代/
しょうもうひんひ /消耗品費/
しょうもくひょう /小目標/
しょうもくろく /小目録/
しょうもん /証文/小問/
しょうもんだい /小問題/
しょうや /庄屋/
しょうやく /抄訳/小役/生薬/
しょうやま /正山/庄山/
しょうゆ /醤油/
しょうゆあじ /醤油味/
しょうゆう /少輔/
しょうゆがお /醤油顔/
しょうゆけいとう /醤油系統/
しょうよ /賞与/
しょうよう /商用/小用/従容/称揚/逍遥/縦容/小葉/
しょうようか /商用化/
しょうようき /商用機/
しょうようけいさんき /商用計算機/
しょうようこうりゅう /商用交流/
しょうようしゃ /商用車/
しょうようじゅ /照葉樹/
しょうようじゅたい /照葉樹帯/
しょうようじゅりん /照葉樹林/
しょうようせいひん /商用製品/
しょうようてき /商用的/
しょうようでんりょく /商用電力/
しょうようひんしつ /商用品質/
しょうようぶん /商用文/
しょうようぶんや /商用分野/
しょうようめい /商用名/
しょうようもくてき /商用目的/
しょうようゆそうしゃりょう /商用輸送車両/
しょうようりょう /小容量/
しょうよきん /賞与金/
しょうらい /将来/生来/招来/
しょうらいけいかく /将来計画/
しょうらいけいかくいいんかい /将来計画委員会/
しょうらいこうそう /将来構想/
しょうらいせい /将来性/
しょうらいぞう /将来像/
しょうらいてき /将来的/
しょうらいてんぼう /将来展望/
しょうらいよそく /将来予測/
しょうらん /照覧/笑覧/
しょうり /勝利/捷利/
しょうりき /正力/
しょうりしゃ /勝利者/
しょうりじょうけん /勝利条件/
しょうりすう /勝利数/
しょうりだてん /勝利打点/
しょうりつ /勝率/
しょうりとうしゅ /勝利投手/
しょうりゃく /省略/商略/
しょうりゃくか /省略可/
しょうりゃくかのう /省略可能/
しょうりゃくけい /省略形/
しょうりゃくじ /省略時/
しょうりゃくじかいしゃく /省略時解釈/
しょうりゃくち /省略値/
しょうりゃくめい /省略名/
しょうりゅう /昇竜/昇龍/
しょうりゅうけん /昇龍拳/昇竜拳/
しょうりょ /焦慮/
しょうりょう /少量/小量/松陵/精霊/聖霊/渉猟/
しょうりょういき /小領域/
しょうりょうえ /聖霊会/
しょうりょうか /少量化/
しょうりょうせいさん /小量生産/少量生産/
しょうりょく /省力/
しょうりょくか /省力化/
しょうりょこう /小旅行/
しょうりん /少林/
しょうりんじ /小林寺/少林寺/
しょうりんじけんぽう /少林寺拳法/
しょうれい /奨励/症例/省令/勝令/
しょうれいかい /奨励会/
しょうれいかいいん /奨励会員/
しょうれいきん /奨励金/
しょうれいけんきゅう /奨励研究/
しょうれいしょう /奨励賞/
しょうれいせいど /奨励制度/
しょうれいないよう /奨励内容/
しょうろう /精霊/
しょうろく /抄録/小六/
しょうろっぽう /小六法/
しょうろん /詳論/小論/
しょうろんぶん /小論文/
しょうろんぶんていしゅつ /小論文提出/
しょうわ /昭和/唱和/小話/笑話/庄和/倡和/
しょうわ#ねん /昭和#0年/昭和#1年/昭和#2年/昭和#3年/(skk-gengo-to-ad "" "年")/(skk-gengo-to-ad "西暦" "年")/
しょうわうまれ /昭和生れ/
しょうわかようし /昭和歌謡史/
しょうわき /昭和期/
しょうわきち /昭和基地/
しょうわきねんこうえん /昭和記念公園/
しょうわく /昭和区/
しょうわくせい /小惑星/
しょうわけんぽう /昭和憲法/
しょうわこうこう /昭和高校/
しょうわさんぎょう /昭和産業/
しょうわさんじゅうねんだい /昭和三十年代/
しょうわし /昭和史/
しょうわしぇるせきゆ /昭和シェル石油/
しょうわしょき /昭和初期/
しょうわしょねん /昭和初年/
しょうわしんざん /昭和新山/
しょうわじょし /昭和女子/
しょうわじょしだい /昭和女子大/
しょうわせきゆ /昭和石油/
しょうわちょう /昭和町/
しょうわてんのう /昭和天皇/
しょうわでんこう /昭和電工/
しょうわどう /昭和堂/
しょうわびょういん /昭和病院/
しょうわり /章割り/
しょうわる /性悪/
しょうわん /小彎/
しょえん /初演/
しょえんしゃ /初演者/
しょえんじ /初演時/
しょか /初夏/書架/
しょかい /初会/初回/所懷/
しょかいしゃけん /初回車検/
しょかいにゅうきん /初回入金/
しょかいひ /諸会費/
しょかいぶん /初回分/
しょかつ /所轄/諸葛/
しょかついん /所轄員/
しょかつこうめい /諸葛孔明;三国時代・蜀漢の丞相/
しょかつりょう /諸葛亮;三国時代・蜀漢の丞相/
しょかてい /諸過程/
しょかん /所感/書簡/所管/書館/初寒/
しょかんけい /諸関係/
しょかんけいしゃ /諸関係者/
しょかんしゅう /書簡集/
しょかんばこ /書簡箱/
しょが /書画/
しょがい /所外/
しょがいこく /諸外国/
しょがいこくみん /諸外国民/
しょがいねん /諸概念/
しょがかり /諸掛/
しょがくしゃ /初学者/
しょがこっとう /書画骨董/
しょき /初期/書記/所期/暑気/書紀/
しょきいち /初期位置/
しょきか /初期化/
しょきかかんすう /初期化関数/
しょきかご /初期化後/
しょきかしょり /初期化処理/
しょきかじ /初期化時/
しょきかぶ /初期化部/
しょきかようそ /初期化要素/
しょきかん /諸機関/
しょきかんきょう /初期環境/
しょきかんすう /初期関数/
しょきがくしゅうきかん /初期学習期間/
しょきがた /初期型/
しょきがめん /初期画面/
しょきけい /初期型/
しょきけいれつ /初期系列/
しょきこうてい /初期工程/
しょきさくひん /初期作品/
しょきしゃ /初期車/
しょきしゅっか /初期出荷/
しょきしゅっかすう /初期出荷数/
しょきしゅっかだいすう /初期出荷台数/
しょきしゅっかばん /初期出荷版/
しょきじゅうでん /初期充電/
しょきじょうけん /初期条件/
しょきじょうたい /初期状態/
しょきじょうほう /初期情報/
しょきじれい /初期事例/
しょきせいどうかん /初期制動感/
しょきせってい /初期設定/
しょきせっていち /初期設定値/
しょきせんかい /初期旋回/
しょきそ /書記素/
しょきそく /諸規則/
しょきたんぺんしゅう /初期短編集/
しょきだんかい /初期段階/
しょきち /初期値/
しょきちょう /書記長/
しょきちょうきょうぎじゅつ /初期調教技術/
しょきてい /諸規定/
しょきとうし /初期投資/
しょきとうしがく /初期投資額/
しょきとうろく /初期登録/
しょきのう /諸機能/
しょきはいち /初期配置/
しょきはんしゃ /初期反射/
しょきはんしゃおん /初期反射音/
しょきばらい /暑気赦い/
しょきふりょう /初期不良/
しょきぶんかつ /初期分割/
しょきゅう /初級/初給/
しょきゅううち /初球打ち/
しょきゅうき /初級機/
しょきゅうしゃ /初級者/
しょきゅうしゃよう /初級者用/
しょきゅうへん /初級編/
しょきろうりょく /初期労力/
しょぎ /所議/
しょぎしょ /枌所/
しょぎじゅつ /諸技術/
しょぎょう /諸行/所業/
しょぎょうむじょう /諸行無常/諸行無情/
しょく /食/職/色/触/燭/殖/拭/植/織/飾/蝕/嘱/埴/属/喰/囑/嗇/寔/屬/昃/矚/禝/稷/穡/蜀/觸/謖/贖/軾/餝/稙/
しょくあい /食鹽/
しょくあつ /触圧/
しょくあん /職安/
しょくあんどおり /職安通り/
しょくい /職位/
しょくいき /職域/
しょくいん /職員/
しょくいんさいよう /職員採用/
しょくいんしつ /職員室/
しょくいんしゅくしゃ /職員宿舎/
しょくいんぞう /職員増/
しょくいんようしょくどう /職員用食堂/
しょくいんろく /職員録/
しょくえん /食塩/
しょくえんすい /食塩水/
しょくかい /職階/
しょくがい /食害/
しょくぎょう /職業/
しょくぎょうえんそうか /職業演奏家/
しょくぎょうか /職業科/
しょくぎょうがら /職業柄/
しょくぎょうくんれん /職業訓練/
しょくぎょうくんれんたんだい /職業訓練短大/
しょくぎょうくんれんだいがく /職業訓練大学/
しょくぎょうせんたく /職業選択/
しょくぎょうてき /職業的/
しょくぎょうはんがか /職業版画家/
しょくぎょうひみつ /職業秘密/
しょくぎょうびょう /職業病/
しょくぎょうべつ /職業別/
しょくぎょうやきゅう /職業野球/
しょくぎょうらん /職業欄/
しょくぎれ /食切れ/
しょくぐん /職群/
しょくご /食後/
しょくごすうじかん /食後数時間/
しょくさつ /喰殺/
しょくさんこうぎょう /殖産興業/
しょくさんじゅうたく /殖産住宅/
しょくさんじん /蜀山人/
しょくざい /贖罪/食材/
しょくざいてん /食材店/
しょくし /食指/
しょくしゅ /職種/触手/蝕手/
しょくしょう /職掌/食傷/
しょくしょうがら /職掌柄/
しょくしょうぎみ /食傷気味/
しょくしん /触診/
しょくじ /食事/食餌/植字/
しょくじかい /食事会/
しょくじかいすう /食事回数/
しょくじきゅうけい /食事休憩/
しょくじけん /食事券/
しょくじご /食事後/
しょくじだい /食事代/
しょくじちゅう /食事中/
しょくじつき /食事付/
しょくじとうばん /食事当番/
しょくじどき /食事時/
しょくじひょう /食事表/
しょくじふうけい /食事風景/
しょくじゅ /植樹/
しょくじゅうせっきん /職住接近/
しょくじょせい /織女星/
しょくじよう /食事用/
しょくじりょうほう /食事療法/
しょくじんしゅ /食人種/
しょくせい /職制/植生/食性/
しょくせいかつ /食生活/
しょくせいかつかいぜん /食生活改善/
しょくせいがく /植生学/
しょくせいひょう /職制表/
しょくせいへんこう /職制変更/
しょくせき /職責/
しょくぜん /食前/食膳/
しょくぜんしゅ /食前酒/
しょくそ /職組/
しょくたい /飾帯/
しょくたく /食卓/嘱託/囑託/
しょくたん /職短/
しょくだい /燭台/燭臺/
しょくち /諸口/触知/
しょくちゅう /食虫/
しょくちゅうどく /食中毒/
しょくちゅうるい /食虫類/
しょくちょう /職長/
しょくつう /食通/
しょくどう /食堂/食道/
しょくどうえいぎょう /食堂営業/
しょくどうけんだんわしつ /食堂兼談話室/
しょくどうけんみんしゅく /食堂兼民宿/
しょくどうしゃ /食堂車/
しょくどうらくか /食道楽家/
しょくにく /食肉/
しょくにん /職人/
しょくにんいしき /職人意識/
しょくにんきしつ /職人気質/
しょくにんげい /職人芸/
しょくのう /職能/色濃/
しょくのうきゅう /職能給/
しょくのうだんたい /職能団体/
しょくはこうしゅうにあり /食在広州/
しょくはつ /触発/
しょくば /職場/
しょくばい /触媒/
しょくばいそうち /触媒装置/
しょくばいそうちゃく /触媒装着/
しょくばいっせいほうこくかい /職場一斉報告会/
しょくばかい /職場会/
しょくばかんきょう /職場環境/
しょくばない /職場内/
しょくばめい /職場名/
しょくぱん /食パン/
しょくひ /食費/植皮/
しょくひん /食品/
しょくひんうり /食品売/
しょくひんうりば /食品売場/
しょくひんかん /食品館/
しょくひんがい /食品害/
しょくひんぐん /食品群/
しょくひんこうぎょう /食品工業/
しょくひんてん /食品展/
しょくひんてんかぶつ /食品添加物/
しょくひんほぞんよう /食品保存用/
しょくひんや /食品屋/
しょくひんよう /食品用/
しょくひんるい /食品類/
しょくぶつ /植物/
しょくぶつえん /植物園/
しょくぶつかい /植物界/
しょくぶつがく /植物学/
しょくぶつけい /植物系/
しょくぶつし /植物誌/食物誌/
しょくぶつずかん /植物図鑑/
しょくぶつせい /植物性/
しょくぶつぜんたい /植物全体/
しょくぶつたい /植物体/
しょくぶつにんげん /植物人間/
しょくぶつめい /植物名/
しょくぶつゆ /植物油/
しょくぶん /職分/
しょくぶんか /食文化/
しょくほう /触法/織豊/
しょくぼう /嘱望/
しょくみ /食味/
しょくみん /植民/
しょくみんしゃ /植民者/
しょくみんせい /植民星/
しょくみんせん /植民船/
しょくみんち /植民地/
しょくみんちか /植民地化/
しょくみんちかいほう /植民地解放/
しょくみんちけいえい /植民地経営/
しょくみんちちゅうごくじん /植民地中国人/
しょくみんちてき /植民地的/
しょくみんちとうじ /植民地当時/
しょくみんちぶんかつ /植民地分割/
しょくみんわくせい /植民惑星/
しょくむ /職務/
しょくむきゅう /職務給/
しょくむけいぞく /職務継続/
しょくむけんげん /職務権限/
しょくむしつもん /職務質問/
しょくむじょう /職務上/
しょくむじょうさくせい /職務上作成/
しょくむすいこう /職務遂行/
しょくむたいまん /職務怠慢/
しょくむないよう /職務内容/
しょくめい /職名/
しょくもう /植毛/
しょくもく /属目/
しょくもつ /食物/
しょくもつちゅう /食物中/
しょくもつれんさ /食物連鎖/
しょくゆう /贖宥/
しょくゆうじょう /贖宥状/
しょくよう /食用/
しょくようあぶら /食用油/
しょくようか /食用可/
しょくようがえる /食用蛙/
しょくよく /食欲/
しょくよくおうせい /食欲旺盛/
しょくよくげんたい /食欲減退/
しょくりょう /食料/食糧/
しょくりょうかんりほう /食糧管理法/
しょくりょうちょう /食糧庁/
しょくりょうなん /食糧難/
しょくりょうひん /食糧品/食料品/
しょくりょうひんうり /食料品売/
しょくりょうひんうりば /食糧品売場/食料品売場/
しょくりょうひんや /食料品屋/
しょくりょうぶそく /食糧不足/
しょくりん /植林/
しょくるいご /触塁後/
しょくれき /職歴/
しょくん /諸君/
しょぐう /処遇/諸遇/
しょけい /諸兄/処刑/書経/
しょけいしょし /諸兄諸氏/
しょけいひ /諸経費/
しょけっか /諸結果/
しょけん /所見/初見/書見/諸賢/
しょけんきゅうきかん /諸研究機関/
しょけんじゃ /諸賢者/
しょけんだい /書見台/
しょげん /諸元/緒言/初元/
しょげんご /諸言語/
しょげんひょう /諸元表/
しょこ /書庫/書賈/
しょこう /初稿/諸侯/初校/曙光/初更/初項/
しょこうぎょう /諸工業/
しょこうじょ /諸控除/
しょこうばん /初稿版/
しょこく /諸国/
しょこくまんゆうき /諸国漫遊記/
しょこくみん /諸国民/
しょこん /初婚/
しょご /諸語/
しょごう /初号/
しょさ /所作/
しょさい /書斎/所載/書債/
しょさくひん /諸作品/
しょさん /所産/
しょさんべつ /初山別/
しょざ /初座/
しょざい /所在/
しょざいち /所在地/
しょざいひょう /所在表/
しょざん /初産/
しょし /諸氏/諸子/初志/書誌/書司/書肆/諸誌/書士/所司/
しょしかんてつ /初志貫徹/
しょしがく /書誌学/
しょしき /書式/諸式/
しょしきか /書式化/
しょしきしていし /書式指定子/
しょしきせいぎょ /書式制御/
しょしきせいぎょもじ /書式制御文字/
しょしきせってい /書式設定/
しょしきどおり /書式通り/
しょしきはんてい /書式判定/
しょしきもじれつ /書式文字列/
しょしじょうほう /書誌情報/
しょしひゃっか /諸子百家/
しょしゃ /書写/諸車/
しょしゃきん /諸謝金/
しょしゅ /諸種/
しょしゅう /初秋/所収/諸州/
しょしゅうさ /諸収差/
しょしゅつ /初出/
しょしゅつし /初出誌/
しょしゅん /初春/
しょしょ /諸処/処暑/所々/
しょしょう /書証/所掌/
しょしん /初心/初審/初診/所信/書信/
しょしんかい /初心会/
しょしんしゃ /初心者/
しょしんしゃあいて /初心者相手/
しょしんしゃかんげい /初心者歓迎/
しょしんしゃきょういく /初心者教育/
しょしんしゃこうざ /初心者講座/
しょしんしゃたいさく /初心者対策/
しょしんしゃてき /初心者的/
しょしんしゃふう /初心者風/
しょしんしゃへん /初心者編/
しょしんしゃよう /初心者用/
しょしんしゃようてびき /初心者用手引/初心者用手引き/
しょしんひょうめい /所信表明/
しょしんりょう /初診療/
しょしんわ /諸神話/
しょじ /所持/書字/諸事/
しょじきん /所持金/
しょじこう /諸事項/
しょじしゃ /所持者/
しょじしょうがい /書字障害/
しょじじょう /諸事情/
しょじひん /所持品/
しょじひんけんさ /所持品検査/
しょじゅん /初旬/
しょじょ /処女/
しょじょう /書状/諸嬢/
しょじょうけん /諸条件/
しょじょうやく /諸条約/
しょじょさく /処女作/
しょじょせい /処女性/
しょじょせん /処女戦/
しょじょたんこうぼん /処女単行本/
しょじょち /処女地/
しょじょちょうへん /処女長編/
しょじょまく /処女膜/
しょずみ /初炭/
しょせい /処世/書生/初生/
しょせいしつ /諸性質/
しょせいじゅつ /処世術/
しょせいど /諸制度/
しょせいへきこういき /初生壁孔域/
しょせいりょく /諸勢力/
しょせいろん /書生論/
しょせき /書籍/
しょせきうりば /書籍売場/
しょせきぐん /書籍群/
しょせきこづつみ /書籍小包/
しょせきだい /書籍代/
しょせきはんばい /書籍販売/
しょせきぶ /書籍部/
しょせきへんしゅうぶ /書籍編集部/
しょせきめい /書籍名/
しょせきるい /書籍類/
しょせってい /諸設定/
しょせつ /諸説/所説/
しょせつび /諸設備/
しょせん /所詮/書泉/諸戦/初戦/緒戦/
しょせんぐらんで /書泉グランデ/
しょせんしゅかん /所詮主観/
しょせんせい /諸先生/
しょせんせいがた /諸先生方/
しょせんたにん /所詮他人/
しょせんはいたい /初戦敗退/
しょせんぱい /諸先輩/
しょせんぱいがた /諸先輩方/
しょせんぶっくまーと /書泉ブックマート/
しょせんむり /所詮無理/
しょぜい /諸税/
しょそう /諸相/初相/
しょそく /初速/
しょそくど /初速度/
しょぞう /所蔵/
しょぞうしりょう /所蔵資料/
しょぞうびじゅつかん /所蔵美術館/
しょぞく /所属/
しょぞくがっかいめい /所属学会名/
しょぞくきかん /所属機関/
しょぞくきかんめい /所属機関名/
しょぞくきぎょう /所属企業/
しょぞくこうざ /所属講座/
しょぞくこく /所属国/
しょぞくさき /所属先/
しょぞくさきじゅうしょ /所属先住所/
しょぞくじむしょ /所属事務所/
しょぞくせい /所属性/
しょぞくせいとう /所属政党/
しょぞくそしき /所属組織/
しょぞくだんたい /所属団体/
しょぞくちょう /所属長/
しょぞくばしょ /所属場所/
しょぞくぶかめい /所属部課名/
しょぞくへんこう /所属変更/
しょぞくべつ /所属別/
しょぞくべや /所属部屋/
しょぞくめい /所属名/
しょぞくめいしょう /所属名称/
しょぞん /所存/
しょたい /書体/所帯/
しょたいくらぶ /書体倶楽部/
しょたいけん /初体験/
しょたいぬし /所帯主/
しょたいめん /初対面/
しょためん /初対面/
しょだい /初代/初台/書題/
しょだいおうじゃ /初代王者/
しょだいかいちょう /初代会長/
しょだいかんじ /初代幹事/
しょだいき /初代機/
しょだいそうとう /初代総統/
しょだいにほん /初代日本/
しょだな /書棚/
しょだん /初段/処断/
しょだんかい /諸段階/
しょだんけい /処断刑/
しょだんたい /諸団体/
しょち /処置/
しょちあん /処置案/
しょちほう /処置法/
しょちゅう /暑中/書中/
しょちゅうい /諸注意/
しょちゅうおみまい /暑中御見舞い/暑中お見舞い/
しょちゅうおみまいもうしあげます /暑中お見舞い申し上げます/
しょちゅうきゅう /初中級/
しょちゅうきゅうしゃ /初中級者/
しょちゅうとう /初・中等/初中等/
しょちゅうみまい /暑中見舞/
しょちょう /所長/署長/初潮/
しょちょうかいけん /所長会見/
しょちょうしつ /所長室/
しょちょうせん /所長選/
しょっかい /職階/
しょっかいきゅう /職階給/
しょっかいせい /職階制/
しょっかく /触角/触覚/食客/
しょっかくじょうほう /触覚情報/
しょっかくてき /触覚的/
しょっかん /触感/食管/食感/
しょっかんほう /食管法/
しょっき /食器/織機/
しょっきかんそうき /食器乾燥機/
しょっきすう /食器数/
しょっきせんじょうき /食器洗浄器/
しょっきだな /食器棚/
しょっきゅう /触球/
しょっきよう /食器用/
しょっきようせんざい /食器用洗剤/
しょっきるい /食器類/
しょっく /ショック/
しょっけん /食券/職権/
しょっけんらんよう /職権乱用/
しょっこう /職工/
しょっと /ショット/
しょっぱな /初っ端/初端/
しょっぴんぐ /ショッピング/
しょっぷ /ショップ/
しょて /初手/
しょてあて /諸手当/
しょてい /所定/
しょていじこう /所定事項/
しょていたんい /所定単位/
しょていようし /所定用紙/
しょていり /諸定理/
しょてん /書店/諸点/
しょてんがい /書店街/
しょてんくみあい /書店組合/
しょてんめい /書店名/
しょとう /諸島/初等/初頭/初冬/蔗糖/
しょとうか /初等科/
しょとうかんすう /初等関数/
しょとうきか /初等幾何/
しょとうきょういく /初等教育/
しょとうすうがく /初等数学/
しょとうてき /初等的/
しょとうてきろんりしき /初等的論理式/
しょとうぶ /初等部/
しょとく /所得/
しょとくきんがく /所得金額/
しょとくこうじょ /所得控除/
しょとくしょうめい /所得証明/
しょとくしょうめいしょ /所得証明書/
しょとくせい /諸特性/
しょとくぜい /所得税/
しょとくぜいげんぜい /所得税減税/
しょとくぜいほう /所得税法/
しょとくぜいりつ /所得税率/
しょとくそう /所得層/
しょとくほそくりつ /所得捕捉率/所得補足率/
しょどう /書道/初動/
しょどうか /書道家/
しょどうぐ /諸道具/
しょない /所内/
しょなのか /初七日/
しょにち /初日/
しょにちかんばい /初日完売/
しょにちよう /初日用/
しょにゅう /初乳/
しょにん /初任/
しょにんきゅう /初任給/
しょにんしゃ /初任者/
しょねん /初年/
しょねんど /初年度/
しょねんどさんく /初年度産駒/
しょねんどとうろく /初年度登録/
しょのうりょく /諸能力/
しょは /諸派/
しょはつ /初発/
しょはん /初版/諸般/初犯/
しょはんはっこう /初版発行/
しょはんぼん /初版本/
しょばつ /処罰/
しょばん /初盤/初版/
しょひ /諸費/
しょひょう /書評/諸表/
しょひょうむじょう /書評無情/
しょひょうらん /書評欄/
しょひよう /諸費用/
しょふう /書風/
しょぶっか /諸物価/
しょぶつ /諸仏/
しょぶん /処分/
しょぶんたいしょう /処分対象/
しょぶんひん /処分品/
しょぶんほうほう /処分方法/
しょぶんめい /諸文明/
しょぶんや /諸分野/
しょぶんりょう /処分量/処分料/
しょへん /初編/
しょほ /初歩/
しょほう /処方/書法/諸方/
しょほうげん /諸方言/
しょほうせん /処方せん/処方箋/
しょほうそく /諸法則/
しょほうりょう /処方料/
しょほてき /初歩的/
しょほてきかいしゃく /初歩的解釈/
しょほてききょういく /初歩的教育/
しょほてきぎもん /初歩的疑問/
しょほてきしつもん /初歩的質問/
しょぼう /書房/
しょみん /庶民/
しょみんぞく /諸民族/
しょみんてき /庶民的/
しょむ /庶務/
しょむか /庶務課/
しょむかかり /庶務掛/
しょむがかり /庶務掛/
しょむぶ /庶務部/
しょめい /署名/書名/
しょめいあつめ /署名集め/
しょめいうんどう /署名運動/
しょめいかつどう /署名活動/
しょめいきじ /署名記事/
しょめいだい /諸命題/
しょめいよう /署名用/
しょめいようし /署名用紙/
しょめん /書面/
しょめんじょう /書面上/
しょもう /所望/
しょもつ /書物/
しょもんだい /諸問題/
しょや /初夜/
しょゆう /所有/
しょゆうかのう /所有可能/
しょゆうけん /所有権/
しょゆうけんいてん /所有権移転/
しょゆうしゃ /所有者/所有車/
しょゆうち /所有地/
しょゆうぶつ /所有物/
しょゆうりつ /所有率/
しょよ /所与/
しょよう /所要/所用/
しょようじかん /所要時間/所用時間/
しょようじかんさ /所要時間差/
しょようじかんたんしゅく /所要時間短縮/
しょようそくど /所要速度/
しょようにっすう /所用日数/
しょようへんせいすう /所要編成数/
しょり /処理/
しょりえき /処理液/
しょりかいろ /処理回路/
しょりかのう /処理可能/
しょりがく /処理学/
しょりきじゅつよう /処理記述用/
しょりきょか /処理許可/
しょりぎじゅつ /処理技術/
しょりけい /処理系/
しょりけいごと /処理系毎/
しょりけいたい /処理形態/
しょりけっか /処理結果/
しょりけんきゅうぶ /処理研究部/
しょりこうがく /処理工学/
しょりこうりつ /処理効率/
しょりご /処理後/
しょりしこう /処理指向/
しょりしつ /処理室/
しょりしゃ /処理者/
しょりしゅうりょうご /処理終了後/
しょりしゅほう /処理手法/
しょりしんごう /処理信号/
しょりじ /処理時/
しょりじかん /処理時間/
しょりじゅん /処理順/
しょりじょう /処理上/処理場/
しょりすう /処理数/
しょりせいのう /処理性能/
しょりそうち /処理装置/
しょりそくど /処理速度/
しょりたいしょう /処理対象/
しょりちゅう /処理中/
しょりてじゅん /処理手順/
しょりないよう /処理内容/
しょりのうりょく /処理能力/
しょりひよう /処理費用/
しょりぶ /処理部/
しょりぶぶん /処理部分/
しょりほう /処理法/
しょりほうしき /処理方式/
しょりほうほう /処理方法/
しょりまえ /処理前/
しょりょう /所領/諸量/緒量/
しょりよう /処理用/
しょりりつ /処理率/
しょりりょう /処理量/
しょりろん /諸理論/
しょりん /書林/
しょるい /書類/
しょるいいっしき /書類一式/
しょるいじょう /書類上/
しょるいそうけん /書類送検/
しょるいていしゅつ /書類提出/
しょるいてつづき /書類手続/書類手続き/
しょるいめい /書類名/
しょるいよう /書類用/
しょろう /初老/
しょろん /所論/緒論/諸論/
しょわけ /諸訳/
しよ /賜与/
しよう /使用/仕様/私用/試用/枝葉/飼葉/飼養/子葉/脂溶/止揚/
しよういじょう /仕様以上/
しようか /仕様化/使用可/
しようかいし /使用開始/
しようかいしご /使用開始後/
しようかいしび /使用開始日/
しようかいしまえ /使用開始前/
しようかいすう /使用回数/
しようかくとく /仕様獲得/
しようかていしゃ /使用過程車/
しようかのう /使用可能/
しようかのうかいいき /使用可能海域/
しようかのうじかん /使用可能時間/
しようかん /使用感/使用艦/
しようかんきょう /使用環境/
しようがっき /使用楽器/
しようき /使用記/
しようきかく /仕様規格/
しようきかん /使用期間/使用機関/試用期間/
しようきき /使用機器/
しようきげん /使用期限/
しようきしゅ /使用機種/
しようきじゅつ /仕様記述/
しようきじゅつげんご /仕様記述言語/
しようきじゅん /使用基準/
しようきせい /使用規制/
しようきぼうきざい /使用希望機材/
しようきょか /使用許可/
しようきょだく /使用許諾/
しようきょだくけいやく /使用許諾契約/
しようきょだくりょう /使用許諾料/
しようきんし /使用禁止/
しようくぶん /使用区分/
しようくべつ /使用区別/
しようけいけん /使用経験/
しようけいけんしゃ /使用経験者/
しようけいぞく /使用継続/
しようけいたい /使用形態/
しようけってい /仕様決定/
しようけん /使用権/
しようげんご /使用言語/
しようこうりつ /使用効率/
しようご /使用後/
しようさくせい /仕様作成/
しようさくてい /仕様策定/
しようざいりょう /使用材料/
しようしつ /使用室/
しようしゃ /使用者/仕様車/
しようしゃきょういく /使用者教育/
しようしゃしゅ /使用車種/
しようしゃじしん /使用者自身/
しようしゃめい /使用者名/
しようしゃりょう /使用車両/
しようしゅうはすう /使用周波数/
しようしゅうはすうたい /使用周波数帯/
しようしょ /仕様書/
しようしょう /子葉鞘/
しようじ /使用時/
しようじかん /使用時間/
しようじしゅく /使用自粛/
しようじっせき /使用実績/
しようじょう /使用上/仕様上/
しようじょうきょう /使用状況/
しようじょうけん /使用条件/止揚条件/
しようすいりょう /使用水量/
しようずみ /使用済み/使用済/
しようせいげん /使用制限/
しようせっけい /仕様設計/
しようせつめいしょ /使用説明書/
しようせんく /使用線区/
しようぜんご /使用前後/
しようそ /篩要素/
しようちゅう /使用中/試用中/
しようついか /仕様追加/
しようていし /使用停止/
しようてびきしょ /使用手引書/
しようでんあつ /使用電圧/
しようでんげん /使用電源/
しようでんりょく /使用電力/
しようとどけ /使用届/
しようど /使用度/
しようどあい /使用度合/
しようにん /使用人/
しようねんげつ /使用年月/
しようねんすう /使用年数/
しようのうど /使用濃度/
しようはんい /使用範囲/
しようばん /試用版/仕様盤/
しようひんど /使用頻度/
しようふか /使用不可/
しようふかのう /使用不可能/
しようふのう /使用不能/
しようぶひん /使用部品/
しようへんこう /仕様変更/使用変更/
しようへんこうじ /仕様変更時/
しようほう /使用法/
しようほうこく /試用報告/
しようほうほう /使用方法/
しようぼ /使用簿/
しようまいすう /使用枚数/
しようまえ /使用前/
しようまっせつ /枝葉末節/
しようめん /使用面/
しようもくてき /使用目的/
しようようと /使用用途/
しようようりょう /使用容量/
しようよてい /使用予定/
しようりつ /使用率/
しようりょう /使用料/使用量/
しようりょうきん /使用料金/
しようれい /使用例/
しよく /私欲/
しら /調/白/
しらい /白井/
しらいし /白石/
しらいち /白市/
しらいちょう /白井町/
しらいと /白糸/
しらうお /白魚/
しらうめ /白梅/
しらうめがくえん /白梅学園/
しらえ /白江/
しらおい /白老/
しらおか /白岡/
しらかた /白方/白潟;姓/
しらかば /白樺/
しらかばこ /白樺湖/
しらかばばやし /白樺林/
しらかべ /白壁/
しらかみ /白神/
しらかわ /白川/白河/
しらかわどおり /白川通り/
しらが /白髪/
しらがあたま /白髪頭/
しらがた /白潟;姓/
しらがみ /白神/
しらき /白木/
しらきばる /白木原/
しらきや /白木屋/
しらぎ /新羅/
しらぎく /白菊/
しらくら /白倉/
しらこ /白子/
しらさか /白坂/
しらさき /白崎/
しらさぎ /白鷺/
しらさや /白鞘/
しらさわ /白沢/
しらじら /白々/
しらす /白州/白須/
しらず /知らず/不知/
しらせ /知らせ/
しらたか /白鷹/
しらたき /白滝/
しらたま /白珠/
しらたまこ /白玉粉/
しらと /白戸/白都/白土/
しらとり /白鳥/白取/
しらとりけん /白鳥研/
しらなみ /白波/白浪/
しらぬい /不知火/
しらぬいまい /不知火舞/
しらぬか /白糠/
しらぬひ /不知火/
しらね /白根/
しらねくかん /白根区間/
しらは /白羽/白刃/
しらはし /白橋/
しらはた /白幡/
しらはま /白濱/白浜/
しらはまちょう /白浜町/
しらふ /素面/
しらふじ /白藤/
しらぶる /シラブル/
しらべ /調べ/調/
しらべかた /調べ方/
しらべる /調べる/
しらほ /白保/
しらほねおんせん /白骨温泉/
しらみ /虱/蝨/
しらみね /白峰/
しらやき /白焼/
しらゆき /白雪/
しらゆきひめ /白雪姫/
しらゆり /白百合/
しらゆりがくえん /白百合学園/
しらゆりじょしたんだい /白百合女子短大/
しり /尻/私利/臀/
しりーず /シリーズ/
しりあい /知り合い/知合い/知合/
しりある /シリアル/
しりあるばんごう /シリアル番号/
しりうち /知内/
しりうま /尻馬/
しりお /尻尾/
しりきしない /尻岸内/
しりきれ /尻切れ/
しりこん /シリコン/
しりごみ /後込み/尻込み/しり込み/
しりしよく /私利私欲/
しりつ /私立/市立/
しりつがっこう /私立学校/
しりつこう /私立校/
しりつこうこう /私立高校/
しりつたんてい /私立探偵/
しりつたんていしょうせつ /私立探偵小説/
しりつだい /市立大/私立大/
しりつだいがく /私立大学/
しりつちゅうがく /私立中学/
しりつとしょかん /市立図書館/
しりてえき /尻手駅/
しりびと /知り人/
しりべ /後志/
しりべし /後志/
しりべつがわ /尻別川/
しりめ /後目/尻目/
しりめつれつ /支離滅裂/
しりもち /尻餅/
しりゃく /史略/
しりやき /尻焼/
しりゅう /支流/
しりょ /思慮/
しりょう /資料/試料/史料/思量/死霊/飼料/
しりょうえつらん /資料閲覧/
しりょうおきば /資料置場/
しりょうか /資料課/
しりょうかいざん /資料改竄/
しりょうかん /資料館/
しりょうさくせい /資料作成/
しりょうしつ /資料室/
しりょうしゃしん /資料写真/
しりょうしゅう /資料集/
しりょうず /指了図/
しりょうせい /資料性/
しりょうせいきゅう /資料請求/
しりょうせいり /資料整理/
しりょうだい /資料代/
しりょうだいきん /資料代金/
しりょうだいぜんしゅう /資料大全集/
しりょうちゅう /資料中/
しりょうてきかち /資料的価値/
しりょうばんごう /資料番号/
しりょうめい /資料名/
しりょうるい /資料類/
しりょく /視力/死力/資力/
しりょくかいふく /視力回復/
しりょくけんさ /視力検査/
しりょくさ /視力差/
しりょくしょうがいしゃ /視力障害者/
しりょくしょうがいしゃよう /視力障害者用/
しりょくていか /視力低下/
しりょぶそく /思慮不足/
しる /汁/什/知/
しるえっと /シルエット/
しるく /シルク/
しるけ /汁気/
しるこ /汁粉/
しるし /印/標/
しるばー /シルバー/
しるばーせいこう /シルバー精工/
しるひと /知る人/
しるびあ /シルビア/
しるべ /標/導/
しれい /指令/司令/
しれいかん /司令官/指令官/
しれいき /指令器/
しれいけいとう /指令系統/
しれいち /指令値/
しれいちょうかん /司令長官/
しれいぶ /司令部/
しれいほうしき /指令方式/
しれつ /熾烈/歯列/
しれつきょうせい /歯列矯正/
しれとこ /知床/
しれとこごこ /知床五湖/
しれとことうげ /知床峠/
しれん /試練/試錬/試煉/
しろ /白/城/代/
しろあと /城跡/
しろあり /白アリ/
しろあん /白餡/
しろい /白井/
しろいし /白石/
しろいと /白糸/
しろいめ /白い目/
しろいわ /白岩/
しろう /司朗/史朗/士郎/四郎/史郎/司郎/四朗/支朗/士朗/志郎/梔蝋/詩郎/死狼/
しろうず /白水/
しろうと /素人/
しろうとしつもん /素人質問/
しろうとしばい /素人芝居/
しろうとしゅう /素人衆/
しろうとしゅうだん /素人集団/
しろうとすじ /素人筋/
しろうとたんてい /素人探偵/
しろうとてきしつもん /素人的質問/
しろうとどうぜん /素人同然/
しろうとはんだん /素人判断/
しろうとみ /素人見/
しろうとむき /素人向/
しろうとめ /素人目/
しろうとりょうり /素人料理/
しろうま /白馬/
しろうまおおいけ /白馬大池/
しろうまだけ /白馬岳/
しろおび /白帯/
しろかぜ /城風/
しろかっこ /『/
しろかね /白金/
しろかねそうあか /シロカネソウ亜科/Isopyroideae/
しろかねだい /白金台/
しろかわ /城川/
しろかん /白缶/
しろがそ /白画素/
しろがね /白金/白銀/銀/
しろがねいろ /白銀色/
しろがねだい /白金台/
しろき /白木/
しろきや /白木屋/
しろくじちゅう /四六時中/
しろくばん /四六判/
しろくま /シロクマ/
しろくら /白倉/
しろくろ /白黒/
しろくろえきしょう /白黒液晶/
しろくろしゃしん /白黒写真/
しろくろはんてん /白黒反転/
しろぐみ /白組/
しろけいとう /白系統/
しろこっか /』/
しろさき /白崎/
しろさわ /代沢/白沢/
しろさんかく /白三角/
しろざけ /白酒/
しろざとう /白砂糖/
しろしか /白鹿/
しろした /城下/
しろしょうぞく /白装束/
しろじ /白地/白字/
しろすな /白砂/
しろた /城田/白田/
しろたえ /白妙/
しろたけ /白武/
しろたなせん /白棚線/
しろたなてつどう /白棚鉄道/
しろたに /城谷/
しろたま /白珠/
しろだ /白田/
しろだま /白玉/
しろぢ /白地/
しろとり /白鳥/
しろなまず /白癜/
しろぬかちょう /白糠町/
しろぬき /白抜/白抜き/
しろね /白根/
しろの /城野/
しろはた /白旗/
しろばい /白バイ/
しろばかま /白袴/
しろふだや /白札屋/
しろぶち /白縁/
しろへび /白蛇/
しろぼし /白星/○/
しろま /城間/
しろまく /白幕/
しろまだら /白斑/
しろまる /白丸/〇/○/
しろみ /白身/城見/
しろみざかな /白身魚/
しろみそ /白味噌/
しろむく /白無垢/
しろめ /白目/白眼/
しろもの /代物/
しろもん /白門/
しろや /城谷/
しろやなぎ /白柳/
しろやま /城山/白山/
しろやまえき /白山駅/
しろれんが /白煉瓦/
しろん /史論/私論/試論/詩論/
しわ /皺/皴/襞/紫波/私話/
しわく /思惑/
しわけ /仕訳/仕分け/
しわけちょう /仕訳帳/
しわざ /仕業/爲業/
しわす /師走/
しわひめ /志波姫/
しわよせ /しわ寄せ/皴寄せ/皺寄せ/
しをさめ /仕納め/爲納め/
しをり /栞/
しん /新/真/心/親/進/身/信/伸/寝/辛/眞/神/森/診/深/臣/針/晋/申/振/紳/辰/薪/震/慎/疹/芯/審/浸/清/侵/榛/秦/娠/唇/岑/愼/滲/賑/呻/哂/嗔/宸/寢/忱/怎/斟/晉/晨/沁/瀋/畛/瞋/箴/簪/縉/脣/臻/蓁/蔘/蜃/袗/襯/譖/譛/讖/軫/鍼/駸/鷆/鷏/齔/甄/津/矧/槙/請/シン/
しん< /新/
しん> /新/真/
しん? /新/
しんあい /親愛/信愛/
しんあいなる /親愛なる/
しんあおもりえき /新青森駅/
しんあおやま /新青山/
しんあさひ /新旭/
しんあん /新案/
しんい /真意/深意/襯衣/瞋恚/
しんいいづかえき /新飯塚駅/
しんいしかわ /新石川/
しんいそご /新磯子/
しんいたばし /新板橋/
しんいち /新一/進一/伸一/真一/慎一/晋一/信一/震一/眞一/申一/眞市/紳一/真市/信市/新市/
しんいちろう /信一郎/慎一郎/新一郎/真一郎/振一朗/伸一郎/進一郎/辰一郎/眞一郎/
しんいまみや /新今宮/
しんいり /新入り/
しんいん /心因/神韻/
しんいんせい /心因性/
しんいんひょうびょう /神韻縹渺/神韻縹眇/神韻縹緲/
しんうおのめ /新魚目/
しんうすい /新碓氷/
しんうち /真打ち/真打/
しんうらやす /新浦安/
しんうんちん /新運賃/
しんうんちんがく /新運賃額/
しんえい /新鋭/親衛/新栄/神栄/親英/信栄/
しんえいき /新鋭機/
しんえいたい /親衛隊/
しんえいわちゅうじてん /新英和中辞典/
しんえき /新駅/
しんえきかいぎょう /新駅開業/
しんえつ /信越/
しんえつせん /信越線/
しんえつほうそう /信越放送/
しんえつほんせん /信越本線/
しんえん /深遠/深淵/真円/
しんえんけい /真円形/
しんおう /震央/
しんおうきょり /震央距離/
しんおうじ /新王子/
しんおうめかいどう /新青梅街道/
しんおおくぼ /新大久保/
しんおおくぼえき /新大久保駅/
しんおおさか /新大阪/
しんおおさかいえん /新大阪以遠/
しんおおさかいき /新大阪行/
しんおおさかえき /新大阪駅/
しんおおさかかん /新大阪間/
しんおおさかしはつ /新大阪始発/
しんおおつか /新大塚/
しんおおつかえき /新大塚駅/
しんおおひらした /新大平下/
しんおおみや /新大宮/
しんおかやまくうこう /新岡山空港/
しんおがわまち /新小川町/
しんおくさわ /新奥沢/
しんおちゃのみず /新御茶の水/
しんおのみち /新尾道/
しんおん /唇音/心音/
しんおんがくじん /新音楽人/
しんか /進化/真価/深化/臣下/真果/
しんかい /新海/新開/深海/深回/新貝/神界/
しんかいいん /新会員/
しんかいいんしょうかい /新会員紹介/
しんかいぎょ /深海魚/
しんかいさぎょうよう /深海作業用/
しんかいじゅう /新怪獣/
しんかいそく /新快速/
しんかいそくでんしゃ /新快速電車/
しんかいたく /新開拓/
しんかいち /新開地/
しんかいてん /新開店/
しんかいはつ /新開発/
しんかいろ /新回路/
しんかいろず /新回路図/
しんかかてい /進化過程/
しんかがく /新科学/
しんかく /神格/真核/
しんかくとう /新格闘/
しんかしゃ /新華社/
しんかしょてん /新華書店/
しんかていりょうり /新家庭料理/
しんかてき /進化的/
しんかてん /進化点/
しんかな /新仮名/
しんかにゅう /新加入/
しんかぶ /新株/心窩部/
しんかまはらえき /新蒲原駅/
しんかりょく /進化力/
しんかろん /進化論/
しんかろんてき /進化論的/
しんかわ /新川/
しんかわさき /新川崎/
しんかわさきえき /新川崎駅/
しんかわさきじぎょうしょ /新川崎事業所/
しんかわさきみつい /新川崎三井/
しんかん /新歓/新館/新刊/神官/森閑/深閑/震撼/信管/深感/
しんかんあんない /新刊案内/
しんかんえいじてん /新漢英字典/
しんかんしょ /新刊書/
しんかんしょうかい /新刊紹介/
しんかんしょてん /新刊書店/
しんかんじ /新幹事/
しんかんじょうほう /新刊情報/
しんかんせん /新幹線/
しんかんせんえき /新幹線駅/
しんかんせんかいぎょうじ /新幹線開業時/
しんかんせんかいぎょうまえ /新幹線開業前/
しんかんせんかいさつ /新幹線改札/
しんかんせんかいつう /新幹線開通/
しんかんせんかいつうまえ /新幹線開通前/
しんかんせんかくれっしゃ /新幹線各列車/
しんかんせんがわ /新幹線側/
しんかんせんくかん /新幹線区間/
しんかんせんけいゆ /新幹線経由/
しんかんせんけいゆう /新幹線経由/
しんかんせんこうあんかん /新幹線公安官/
しんかんせんこうかきょう /新幹線高架橋/
しんかんせんこうない /新幹線構内/
しんかんせんこくらえき /新幹線小倉駅/
しんかんせんしゃない /新幹線車内/
しんかんせんしんえき /新幹線新駅/
しんかんせんじゆうせき /新幹線自由席/
しんかんせんせいび /新幹線整備/
しんかんせんせつぞく /新幹線接続/
しんかんせんたんどく /新幹線単独/
しんかんせんていしゃえき /新幹線停車駅/
しんかんせんでんしゃ /新幹線電車/
しんかんせんとうきょうえき /新幹線東京駅/
しんかんせんとっきゅうけん /新幹線特急券/
しんかんせんどうよう /新幹線同様/
しんかんせんながおかえき /新幹線長岡駅/
しんかんせんのりつぎ /新幹線乗継/
しんかんせんへんせい /新幹線編成/
しんかんせんものがたり /新幹線物語/
しんかんせんよう /新幹線用/
しんかんせんりょうきん /新幹線料金/
しんかんとく /新監督/
しんかんぼん /新刊本/
しんかんりにん /新管理人/
しんがー /シンガー/
しんがい /侵害/心外/震駭/新谷/
しんがいかくめい /辛劾革命/辛亥革命/
しんがいこくじん /新外国人/
しんがいしゃ /新会社/
しんがいじじつ /侵害事実/
しんがいじん /新外人/
しんがいねん /真概念/新概念/
しんがお /新顔/
しんがく /進学/信学/神学/新学/
しんがくか /神学科/
しんがくかい /信学会/
しんがくぎほう /信学技報/
しんがくこう /進学校/
しんがくご /進学後/
しんがくさき /進学先/
しんがくし /信学誌/
しんがくしゃ /進学者/神学者/
しんがくじ /進学時/
しんがくじゅく /進学塾/
しんがくだいがく /神学大学/
しんがくてき /神学的/
しんがくぶ /神学部/
しんがくよてい /進学予定/
しんがくりつ /進学率/
しんがくろん /信学論/
しんがくろんそう /神学論争/
しんがた /新型/
しんがたかりょく /新型火力/
しんがたき /新型機/
しんがたしゃ /新型車/
しんがたしゃりょう /新型車両/
しんがたでんしゃ /新型電車/
しんがたとっきゅう /新型特急/
しんがたとっきゅうしゃ /新型特急車/
しんがたとっきゅうしゃりょう /新型特急車両/
しんがたばくだん /新型爆弾/
しんがたばん /新型番/
しんがたよう /新型用/
しんがっかい /信学会/
しんがっき /新学期/
しんがっこう /進学校/
しんがぽーる /新嘉坡/
しんがら /新柄/
しんがり /殿/
しんがん /心眼/真贋/
しんき /新規/新奇/心機/蜃気/神器/心気/神姫/辛気/新期/新機/
しんきいってん /心機一転/
しんきかいいん /新規会員/
しんきかいきょく /新規開局/
しんきかいてん /新規開店/
しんきかいはつ /新規開発/
しんきかく /新企画/新規格/
しんきかごうぶつ /新規化合物/
しんきかにゅう /新規加入/
しんきげんしゃ /新紀元社/
しんきこう /新機構/
しんきこうそうちゅう /新規構想中/
しんきさくせい /新規作成/
しんきさんか /新規参加/
しんきさんかきぼう /新規参加希望/
しんきさんかしゃ /新規参加者/
しんきさんかそしき /新規参加組織/
しんきさんにゅう /新規参入/
しんきさんにゅうしゃ /新規参入者/
しんきしゅ /新機種/
しんきしゅしょうかい /新機種紹介/
しんきしゅっかきんし /新規出荷禁止/
しんきしゅとくしゃ /新規取得者/
しんきしゅはっぴょう /新機種発表/
しんきしょうひん /新規商品/
しんきじ /新記事/
しんきじぎょうすいしん /新規事業推進/
しんきじく /新基軸/新機軸/
しんきじゅうたく /新規住宅/
しんきせい /新奇性/新規性/
しんきせってい /新規設定/
しんきた /新喜多/
しんきち /信吉/新吉/真吉/進吉/
しんきてい /新規定/
しんきていあん /新規提案/
しんきとうろく /新規登録/
しんきにゅうかいしゃ /新規入会者/
しんきのう /新機能/
しんきはいび /新規配備/
しんきば /新木場/
しんきぶっしつ /新規物質/
しんきゅう /新旧/進級/
しんきゅうがた /新旧型/
しんきゅうこうたい /新旧交替/
しんきゅうだん /新球団/
しんきゅうめん /真球面/
しんきゅうりょうほう /新旧両方/
しんきょ /新居/
しんきょう /心境/新彊/新疆/信教/新京/
しんきょうごく /新京極/
しんきょうせん /神京戦/
しんきょうち /新境地/
しんきょうと /新教徒/
しんきょうどうやく /新共同訳/
しんきょうふくざつ /心境複雑/
しんきょく /新曲/神曲/
しんきょくとうひょう /新曲投票/
しんきょくはっぴょう /新曲発表/
しんきょくはっぴょうかい /新曲発表会/
しんきりゅうえき /新桐生駅/
しんきろう /蜃気楼/
しんきろく /新記録/
しんきろくたっせい /新記録達成/
しんきろせん /新規路線/
しんきん /心筋/伸筋/信金/親近/真菌/
しんきんかん /親近感/
しんきんこうそく /心筋梗塞/
しんぎ /審議/真偽/進木/信義/新技/
しんぎかい /審議会/
しんぎかん /審議官/
しんぎじゅつ /新技術/
しんぎじゅつかいはつ /新技術開発/
しんぎじゅつじぎょうだん /新技術事業団/
しんぎたいしょう /審議対象/
しんぎち /真偽値/
しんぎちゅう /審議中/
しんぎふ /新岐阜/
しんぎふめい /真偽不明/
しんぎん /呻吟/
しんく /辛苦/深紅/真紅/
しんくう /真空/
しんくうかん /真空管/
しんくうかんかいろ /真空管回路/
しんくうかんしき /真空管式/
しんくうかんじだい /真空管時代/
しんくうきゅういんほうしき /真空吸引方式/
しんくうけい /真空計/
しんくうこう /新空港/
しんくうこうかん /新空港間/
しんくうこうがく /真空工学/
しんくうこうけいかく /新空港計画/
しんくうだんねつ /真空断熱/
しんくうちゅう /真空中/
しんくうでんし /真空電子/
しんくうはどう /真空波動/
しんくうば /真空場/
しんくうぼ /新空母/
しんぐ /寝具/
しんぐう /信宮/新宮/
しんぐうえん /新宮宛/
しんぐる /シングル/
しんぐん /進軍/
しんけい /神経/唇形/針形/
しんけいいがく /神経医学/
しんけいか /神経科/
しんけいかいぼう /神経解剖/
しんけいかいろ /神経回路/
しんけいかいろがっかい /神経回路学会/
しんけいかいろもう /神経回路網/
しんけいかがく /神経科学/
しんけいかがくしゃ /神経科学者/
しんけいかく /神経核/
しんけいかつどう /神経活動/
しんけいかん /神経間/
しんけいかんけい /神経関係/
しんけいかんれん /神経関連/
しんけいがく /神経学/
しんけいがくてき /神経学的/
しんけいがくてきかいぼう /神経学的解剖/
しんけいきこう /神経機構/
しんけいけい /神経系/
しんけいけいさん /神経計算/
しんけいけつごう /神経結合/
しんけいげか /神経外科/
しんけいこん /神経根/
しんけいさいぼう /神経細胞/
しんけいしき /新形式/
しんけいしげき /神経刺激/
しんけいしつ /神経質/
しんけいしょう /神経症/
しんけいしんどうし /神経振動子/
しんけいしんり /神経心理/
しんけいしんりがく /神経心理学/
しんけいじゅようたい /神経受容体/
しんけいじょうほうしょり /神経情報処理/
しんけいじょうほうしょりけい /神経情報処理系/
しんけいじょうほうしょりけいかいぎ /神経情報処理系会議/
しんけいすいじゃく /神経衰弱/
しんけいせい /新京成/神経性/
しんけいせいでんてつ /新京成電鉄/
しんけいせいぶつがく /神経生物学/
しんけいせいまえはら /新京成前原/
しんけいせいりがく /神経生理学/
しんけいせいりがくしゃ /神経生理学者/
しんけいせつ /神経節/
しんけいせん /神経戦/
しんけいせんい /神経繊維/
しんけいそう /神経叢/
しんけいだん /神経弾/
しんけいつう /神経痛/
しんけいでんたつぶっしつ /神経伝達物質/
しんけいはん /新京阪/
しんけいぱるす /神経パルス/
しんけいぶつり /神経物理/
しんけいぶつりがくてき /神経物理学的/
しんけいまひ /神経麻痺/
しんけいやく /新契約/
しんけいれつとうにゅう /新系列投入/
しんけつ /心血/
しんけん /真剣/進研/親権/神拳/震研/
しんけんざい /新建材/
しんけんし /真剣師/
しんけんしょうぶ /真剣勝負/
しんけんせいじ /神権政治/
しんけんぜみ /進研ゼミ/
しんけんぽう /新憲法/
しんげき /進撃/新劇/
しんげつ /新月/心月/
しんげん /進言/信玄/震源/箴言/
しんげんいき /震源域/
しんげんこう /信玄公/
しんげんじょうほう /震源情報/
しんげんち /震源地/
しんこ /新香/
しんこいわ /新小岩/
しんこいわえき /新小岩駅/
しんこう /進行/振興/信仰/親交/新興/真興/侵攻/親好/真光/新光/新晃/神鋼/辰功/深厚/深更/進攻/侵寇/侵行/進講/
しんこういぜん /侵攻以前/
しんこうかい /振興会/親交会/
しんこうがかり /進行係/
しんこうき /神皇記/
しんこうけい /進行形/
しんこうこう /新興校/
しんこうこく /新興国/
しんこうこっか /新興国家/
しんこうざいだん /振興財団/
しんこうざっし /信仰雑誌/
しんこうしゃ /進講者/新光社/信仰者/
しんこうしゅうきょう /新興宗教/
しんこうしゅうきょうだんたい /新興宗教団体/
しんこうしん /信仰心/
しんこうじゅうたくち /新興住宅地/
しんこうじょう /進行上/信仰上/
しんこうじょうきょう /進行状況/
しんこうじょうたい /進行状態/
しんこうそう /新構想/
しんこうそくど /進行速度/
しんこうちゅう /進行中/侵攻中/
しんこうつう /新交通/
しんこうど /進行度/
しんこうどくりつこく /新興独立国/
しんこうは /進行波/
しんこうはかい /進行波解/
しんこうひょう /進行表/
しんこうべ /新神戸/
しんこうべえき /新神戸駅/
しんこうべていしゃ /新神戸停車/
しんこうほうこう /進行方向/
しんこうほうこうまえ /進行方向前/
しんこうほうこうみぎがわ /進行方向右側/
しんこうぼうがい /進行妨害/
しんこうやく /進行役/
しんこきゅう /深呼吸/
しんこきんわかしゅう /新古今和歌集/
しんこく /深刻/申告/親告/
しんこくか /深刻化/
しんこくげき /新国劇/
しんこくざい /親告罪;強姦罪などのように、公訴の提起に告訴を必要条件とする犯罪/
しんこくしょ /申告書/
しんこくせい /申告制/
しんこくほうほう /申告方法/
しんこくようし /申告用紙/
しんこしゃ /新古車/
しんこだ /新小田/
しんこっちょう /真骨頂/
しんこてんしゅぎ /新古典主義/
しんこてんてき /新古典的/
しんことに /新琴似/
しんこひん /新古品/
しんこやす /新子安/
しんこん /新婚/
しんこんかてい /新婚家庭/
しんこんしょや /新婚初夜/
しんこんせいかつ /新婚生活/
しんこんりょこう /新婚旅行/
しんご /伸吾/新吾/伸悟/信吾/新語/真悟/晋吾/信悟/慎吾/晋午/真吾/進悟/紳悟/
しんごう /信号/新郷/神郷/
しんごうおん /信号音/
しんごうか /信号化/
しんごうかいせき /信号解析/
しんごうかいせきしゅほう /信号解析手法/
しんごうかいせきほう /信号解析法/
しんごうかんかく /信号間隔/
しんごうき /信号機/信号器/
しんごうきょうど /信号強度/
しんごうきょくせい /信号極性/
しんごうきろく /信号記録/
しんごうぎじゅつ /信号技術/
しんごうけい /信号系/
しんごうけいとう /信号系統/
しんごうげん /信号源/
しんごうこうさてん /信号交差点/
しんごうしょ /信号所/
しんごうしょり /信号処理/
しんごうしょりかんけい /信号処理関係/
しんごうしょりきょうかい /信号処理協会/
しんごうしょりしゅほう /信号処理手法/
しんごうしょりよう /信号処理用/
しんごうしょりりろん /信号処理理論/
しんごうじどうか /信号自動化/
しんごうじょう /信号場/
しんごうせいせいかいろ /信号生成回路/
しんごうせいぶん /信号成分/
しんごうせつび /信号設備/
しんごうせん /信号線/
しんごうぜんたい /信号全体/
しんごうち /信号値/
しんごうちゅうしゅつ /信号抽出/
しんごうちょう /信号長/
しんごうつうしん /信号通信/
しんごうでんたつ /信号伝達/
しんごうとりあつかいじょ /信号取扱所/
しんごうにゅうりょくじょうたい /記号入力状態/
しんごうはいち /信号配置/
しんごうはけい /信号波形/
しんごうひょう /信号表/
しんごうぶんせき /信号分析/
しんごうほうしき /信号方式/
しんごうむし /信号無視/
しんごうめい /信号名/
しんごうめん /信号面/
しんごうれつ /信号列/
しんごうろ /信号路/
しんごごうめ /新五合目/
しんごさんけ /新御三家/
しんごん /真言/
しんごんしゅう /真言宗/
しんごんみっきょう /真言密教/
しんさ /審査/
しんさい /震災/
しんさいいん /審査委員/
しんさいたいさく /震災対策/
しんさいばし /心斎橋/
しんさいん /審査員/
しんさかい /審査会/
しんさかん /審査官/
しんさき /審査器/
しんさきじゅん /審査基準/
しんさく /新作/進作/晋作/
しんさくじょうほう /新作情報/
しんさくせいさくちゅう /新作制作中/
しんさくたんぺん /新作短編/
しんさくひん /新作品/
しんさくもんだい /新作問題/
しんさけっか /審査結果/
しんさけっかつうち /審査結果通知/
しんさけんとう /審査検討/
しんさしゃ /審査者/
しんさじてん /審査時点/
しんさたいしょう /審査対象/
しんさっぽろ /新札幌/
しんさつ /診察/新札/
しんさつしつ /診察室/
しんさつび /診察日/
しんさび /審査日/
しんさほうこく /審査報告/
しんさよく /新左翼/
しんさん /新参/辛酸/
しんさんだ /新三田/
しんざい /芯材/心材/
しんざいこ /新在庫/
しんざき /新崎/
しんざっし /新雑誌/
しんざわ /新沢/新澤/
しんざん /新参/深山/
しんざんしゅ /新参種/
しんざんもの /新参者/
しんざんゆうこく /深山幽谷/
しんし /真摯/紳士/神士/振子/新史/進士/
しんしき /新式/神式/
しんしきょうてい /紳士協定/
しんしこう /新試行/
しんしさ /真摯さ/
しんししゅくじょ /紳士淑女/
しんしちょう /振子長/
しんしっかん /心疾患/
しんしっこうぶ /新執行部/
しんしつ /寝室/心室/進出/
しんしてい /新指定/
しんしてき /紳士的/
しんしどうめい /紳士同盟/
しんしどうようりょう /新指導要領/
しんしのつ /新篠津/
しんしふう /紳士風/
しんしふく /紳士服/
しんしものせき /新下関/
しんしゃ /新車/深謝/新社/親炙/
しんしゃかいじん /新社会人/
しんしゃかいはつ /新車開発/
しんしゃかかく /新車価格/
しんしゃく /斟酌/
しんしゃこうにゅう /新車購入/
しんしゃこうにゅうじ /新車購入時/
しんしゃしゅ /新車種/
しんしゃしょう /新社章/
しんしゃじ /新車時/
しんしゃじょうほう /新車情報/
しんしゃそうちゃく /新車装着/
しんしゃちょう /新社長/
しんしゃどうにゅう /新車導入/
しんしゃめい /新社名/
しんしゃりょう /新車輛/新車両/新車輌/
しんしゅ /新種/新酒/進取/新手/
しんしゅう /信州/真宗/新秋/侵襲/神州/
しんしゅうきょう /新宗教/
しんしゅうじん /信州人/
しんしゅうそば /信州蕎麦/
しんしゅうだい /信州大/
しんしゅうだいがく /信州大学/
しんしゅうてき /侵襲的/
しんしゅうでんほうしき /新集電方式/
しんしゅうなまみそ /信州生味噌/
しんしゅうほうめん /信州方面/
しんしゅく /伸縮/
しんしゅくけい /伸縮計/
しんしゅくじ /伸縮時/
しんしゅくじざい /伸縮自在/
しんしゅくせい /伸縮性/
しんしゅくりつ /伸縮率/
しんしゅだん /新手段/
しんしゅつ /新出/進出/神出/侵出/浸出/滲出/
しんしゅつえき /滲出液/
しんしゅつきぼつ /神出鬼没/
しんしゅと /新首都/
しんしゅどき /新酒時/
しんしゅひんば /新種牝馬/
しんしゅほう /新手法/
しんしゅぼば /新種牡馬/
しんしゅん /新春/
しんしゅんこうぎょう /新春興行/
しんしゅんとくべつきかく /新春特別企画/
しんしゅんばん /新春版/
しんしゅんほうだん /新春放談/
しんしょ /新書/信書/親書/
しんしょう /辛勝/心証/心象/身上/財産/志ん生/
しんしょうしゃ /身障者/
しんしょうしゃさべつ /身障者差別/
しんしょうちくほうしき /新松竹方式/
しんしょうなん /新湘南/
しんしょうひつばつ /信賞必罰/
しんしょうひん /新商品/
しんしょうふうけい /心象風景/
しんしょうぼうだい /針小棒大/
しんしょかん /新書館/
しんしょく /侵食/寝食/侵蝕/浸食/浸蝕/新色/
しんしょちょう /新所長/
しんしょばん /新書版/新書判/
しんしょぼん /新書本/
しんしよう /紳士用/新仕様/
しんしろ /新城/
しんしろく /紳士録/
しんしん /信心/心身/津々/新進/新々/
しんしんかいそく /新新快速/
しんしんきえい /新進気鋭/
しんしんさっか /新進作家/
しんしんじゅくえき /新新宿駅/
しんしんそうしつ /心身喪失/
しんしんとう /新進党/
しんしんどう /駸々堂/
しんしんにげんろん /心身二元論/
しんしんにげんろんてき /心身二元論的/
しんじ /信司/伸治/新司/慎二/真司/真二/真治/眞治/信治/進士/神事/伸司/信次/信二/新治/伸二/慎治/伸自/伸次/慎司/新字/晋司/愼二/神餌/宍道/晋二/
しんじぎょう /新事業/
しんじけーと /シンジケート/
しんじこ /宍道湖/
しんじじつ /新事実/
しんじたい /新字体/
しんじだい /新時代/
しんじっけん /新実験/
しんじつ /真実/
しんじつせい /真実性/
しんじつど /真実度/
しんじつみ /真実味/
しんじゃ /信者/心者/
しんじゃたち /信者達/
しんじゅ /真珠/
しんじゅいり /真珠入り/
しんじゅう /心中/臣従/
しんじゅうぐんだん /臣従軍団/
しんじゅうしょ /新住所/
しんじゅうしょち /新住所地/
しんじゅうだいみょう /臣従大名/
しんじゅうみん /新住民/
しんじゅうろう /真十郎/
しんじゅく /新宿/
しんじゅくいき /新宿行/
しんじゅくえき /新宿駅/
しんじゅくえきにしぐち /新宿駅西口/
しんじゅくえきひがしぐち /新宿駅東口/
しんじゅくえきほうこう /新宿駅方向/
しんじゅくえきみなみぐち /新宿駅南口/
しんじゅくおだきゅう /新宿小田急/
しんじゅくおんがくさい /新宿音楽祭/
しんじゅくかぶきちょう /新宿歌舞伎町/
しんじゅくがわ /新宿側/
しんじゅくきんぺん /新宿近辺/
しんじゅくぎょえん /新宿御苑/
しんじゅくく /新宿区/
しんじゅくこうせいねんきん /新宿厚生年金/
しんじゅくさんちょうめ /新宿三丁目/
しんじゅくさんちょうめかん /新宿三丁目間/
しんじゅくしょぼう /新宿書房/
しんじゅくせん /新宿線/
しんじゅくせんおがわちょう /新宿線小川町/
しんじゅくちゅうおうこうえん /新宿中央公園/
しんじゅくてん /新宿店/
しんじゅくてんしょうどう /新宿天賞堂/
しんじゅくどおり /新宿通り/
しんじゅくにしぐち /新宿西口/
しんじゅくにしぐちえき /新宿西口駅/
しんじゅくにしぐちこうえん /新宿西口公園/
しんじゅくにしぐちしてん /新宿西口支店/
しんじゅくにししてん /新宿西支店/
しんじゅくのりかえ /新宿乗換/
しんじゅくはつ /新宿発/
しんじゅくひがしぐち /新宿東口/
しんじゅくふきん /新宿付近/
しんじゅくほうめん /新宿方面/
しんじゅくまるい /新宿丸井/
しんじゅくみつこし /新宿三越/
しんじゅくみつこししんかん /新宿三越新館/
しんじゅくみなみぐち /新宿南口/
しんじゅくむていしゃ /新宿無停車/
しんじゅくゆき /新宿行/
しんじゅわん /真珠湾/
しんじゅわんこうげき /真珠湾攻撃/
しんじゅん /浸潤/
しんじょ /神助/
しんじょう /信条/新城/心情/新庄/新條/身上/進上/真情/
しんじょうかん /新庄間/
しんじょうしょ /身上書/
しんじょうしんり /心情心理/
しんじょうせき /新定跡/
しんじょうてき /心情的/
しんじょうてきこうか /心情的効果/
しんじょうばし /新城橋/
しんじょうほう /新情報/
しんじょはら /新所原/
しんじろう /新次郎/慎次郎/
しんじん /新人/信心/深甚/審尋/
しんじんえんげいたいしょう /新人演芸大賞/
しんじんかしゅ /新人歌手/
しんじんきしゅ /新人騎手/
しんじんきょういく /新人教育/
しんじんけんしゅう /新人研修/
しんじんけんしゅうちゅう /新人研修中/
しんじんこうえん /新人公演/
しんじんしょう /新人賞/
しんじんせん /新人戦/
しんじんせんしゅ /新人選手/
しんじんたち /新人達/
しんじんまんがか /新人漫画家/
しんじんよう /新人用/
しんじんるい /新人類/
しんすい /浸水/心酔/進水/侵水/
しんすいじこ /浸水事故/
しんすいせい /新彗星/
しんすう /進数/芯数/
しんすけ /紳助/紳介/信介/信輔/慎介/伸介/
しんずい /真髄/心髄/神髄/
しんずし /新逗子/
しんずしえき /新逗子駅/
しんせい /申請/新星/真性/神聖/新生/新制/真正/新製/神性/新姓/新政/
しんせいうけつけ /申請受付/
しんせいか /神聖化/
しんせいかつ /新生活/
しんせいがく /申請額/
しんせいき /新世紀/
しんせいきどうしゃ /新製気動車/
しんせいきへん /新世紀編/
しんせいけい /神聖系/
しんせいけん /新政権/
しんせいけんじゅりつ /新政権樹立/
しんせいご /申請後/
しんせいさき /申請先/
しんせいしゃ /申請者/新声社/新製車/
しんせいしゃりょう /新製車両/
しんせいしょ /申請書/
しんせいしょう /申請証/
しんせいしょよう /申請書用/
しんせいしょるい /申請書類/
しんせいじ /新生児/申請時/
しんせいじよう /新生児用/
しんせいじん /新成人/
しんせいせきにんしゃ /申請責任者/
しんせいそしき /申請組織/
しんせいたんとうしゃ /申請担当者/
しんせいちゅう /申請中/
しんせいちゅうしんちゅう /真正中心柱/
しんせいでん /神制電/
しんせいでんしゃ /新製電車/
しんせいとう /新生党/
しんせいど /新制度/
しんせいどう /新星堂/
しんせいないよう /申請内容/
しんせいねん /新青年/
しんせいねんどくほん /新青年読本/
しんせいのう /新性能/
しんせいのうか /新性能化/
しんせいのうしゃ /新性能車/
しんせいのうしゃとうにゅう /新性能車投入/
しんせいばんごう /申請番号/
しんせいひん /新製品/
しんせいひんいちらん /新製品一覧/
しんせいひんかいはつ /新製品開発/
しんせいひんしょうかい /新製品紹介/
しんせいひんじょうほう /新製品情報/
しんせいひんてんじかい /新製品展示会/
しんせいひんはっぴょうかい /新製品発表会/
しんせいひんはつばい /新製品発売/
しんせいふかしん /神聖不可侵/
しんせいほうけい /真性包茎/
しんせいめん /新生面/
しんせいよう /申請用/
しんせいようし /申請用紙/
しんせいりょう /申請料/
しんせかい /新世界/真世界/
しんせかいきこう /新世界紀行/
しんせかいせんたい /新世界戦隊/
しんせかいちつじょ /新世界秩序/
しんせき /親戚/
しんせきいちどう /親戚一同/
しんせきかんけい /親戚関係/
しんせだい /新世代/
しんせだいぐん /新世代軍/
しんせっきじだい /新石器時代/
しんせっきじだいじん /新石器時代人/
しんせっけい /新設計/
しんせつ /親切/新設/新説/新雪/真説/
しんせつえき /新設駅/
しんせつかいはい /新設改廃/
しんせつがっか /新設学科/
しんせつぎ /親切気/
しんせつこう /新設校/
しんせつしん /親切心/
しんせつじょうたい /新雪状態/
しんせつせっけい /親切設計/
しんせつぞく /新接続/
しんせつひ /新設費/
しんせつほうほう /新設方法/
しんせん /新鮮/芯線/振戦/新線/深浅/神仙/神泉/震顫/神饌/新選/
しんせんか /新鮮化/芯線化/
しんせんくかん /新線区間/
しんせんくかんよう /新線区間用/
しんせんぐみ /新撰組/新選組/
しんせんし /新戦士/
しんせんしんじゅく /新線新宿/
しんせんみ /新鮮味/
しんせんりょく /新戦力/
しんぜん /神前/親善/
しんぜんしき /神前式/
しんぜんしゅう /新全集/
しんぜんじあい /親善試合/
しんそう /真相/新装/深層/眞相/深窓/
しんそうかいてん /新装開店/
しんそうかん /新創刊/
しんそうきゅうめい /真相究明/
しんそうしんり /深層心理/
しんそうしんりがく /深層心理学/
しんそうしんりてき /深層心理的/
しんそうじゅんかん /深層循環/
しんそうすい /深層水/
しんそうばん /新装版/
しんそこ /心底/真底/
しんそざい /新素材/
しんそしき /新組織/
しんそつ /新卒/
しんそつさいようじょうけん /新卒採用条件/
しんそつしゃ /新卒者/
しんぞう /心臓/新造/新三/心像/
しんぞういしょく /心臓移植/
しんぞうき /新造機/
しんぞうし /心臓死/
しんぞうしっかん /心臓疾患/
しんぞうしゃ /新造車/
しんぞうしゃりょう /新造車両/
しんぞうじ /新造時/
しんぞうせん /新造船/
しんぞうにんげん /新造人間/
しんぞうびょう /心臓病/
しんぞうぶ /心臓部/
しんぞうへき /心臓壁/
しんぞうほっさ /心臓発作/
しんぞうやぶり /心臓破り/
しんぞく /親族/
しんぞくいちどう /親族一同/
しんぞくかんけい /親族関係/
しんた /心太/新太/
しんたい /身体/進退/神体/
しんたいいぞん /身体依存/
しんたいかんかく /身体感覚/
しんたいきかん /身体器官/
しんたいけい /新体系/
しんたいけんさ /身体検査/
しんたいげんしょう /身体現象/
しんたいしょうがいしゃ /身体障害者/
しんたいじたい /身体自体/
しんたいすいじゃくしゃ /身体衰弱者/
しんたいせい /新体制/
しんたいせっしょく /身体接触/
しんたいぜんたい /身体全体/
しんたいそう /新体操/
しんたいそくてい /身体測定/
しんたいちゅう /身体中/
しんたいてき /身体的/
しんたいてきえいきょう /身体的影響/
しんたいてきせいしつ /身体的性質/
しんたいてきみりょく /身体的魅力/
しんたいないぶ /身体内部/
しんたいめん /身体面/
しんたいりく /新大陸/
しんたかなわ /新高輪/
しんたかね /新高値/
しんたく /信託/神託/新宅/
しんたくぎんこう /信託銀行/
しんたくりゅうほきん /信託留保金/
しんたちかわ /新立川/
しんたっくす /シンタックス/
しんたつまき /新竜巻/
しんたなべ /新田辺/
しんたに /新谷/
しんたまがわせん /新玉川線/
しんたまがわせんしぶや /新玉川線渋谷/
しんたまけいゆう /新玉経由/
しんたるい /新垂井/
しんたるいえき /新垂井駅/
しんたろう /慎太郎/信太郎/新太郎/辰太郎/
しんたん /薪炭/心胆/
しんだい /信大/新台/神大/寝台/神代/
しんだいきゃくしゃ /寝台客車/
しんだいきんえんしつ /寝台禁煙室/
しんだいけいふ /神代系譜/
しんだいけん /寝台券/
しんだいこしつ /寝台個室/
しんだいしゃ /寝台車/
しんだいしゃりょう /寝台車両/
しんだいでんき /神大電気/
しんだいでんしゃ /寝台電車/
しんだいとっきゅう /寝台特急/
しんだいはいち /寝台配置/
しんだいはば /寝台幅/
しんだいもじ /神代文字/
しんだいりょうきん /寝台料金/
しんだいれっしゃ /寝台列車/
しんだん /診断/
しんだんがく /診断学/
しんだんがた /診断型/
しんだんぎじゅつか /診断技術課/
しんだんけっか /診断結果/
しんだんしょ /診断書/
しんだんじょうほう /診断情報/
しんだんたい /新団体/
しんだんび /診断日/
しんだんほう /診断法/
しんだんほうほう /診断方法/
しんだんめい /診断名/
しんち /新治/新地/深智/深知/真値/心地/
しんちく /新築/
しんちくいっこだて /新築一戸建/
しんちくちゅう /新築中/
しんちしき /新知識/
しんちとせ /新千歳/
しんちとせくうこう /新千歳空港/
しんちとせくうこうえき /新千歳空港駅/
しんちへい /新地平/
しんちゃく /新着/
しんちゃくとしょ /新着図書/
しんちゃくとしょあんない /新着図書案内/
しんちゅう /心中/進駐/真鍮/鉐/
しんちゅういた /真鍮板/
しんちゅうぐん /進駐軍/
しんちゅうごく /新中国/
しんちゅうせい /真鍮製/
しんちゅうせん /真鍮線/
しんちゅうぼう /真鍮棒/
しんちょ /新著/
しんちょう /身長/慎重/新潮/新調/伸長/伸張/深長/清朝/志ん朝/
しんちょうげんしょう /伸長現象/
しんちょうさ /身長差/
しんちょうしゃ /新潮社/新庁舎/
しんちょうたいじゅう /身長体重/
しんちょうは /慎重派/
しんちょうぶんこ /新潮文庫/
しんちょうぶんこばん /新潮文庫版/
しんちょうろん /慎重論/
しんちょうろんしゃ /慎重論者/
しんちょく /進捗/
しんちょくじょうきょう /進捗状況/
しんちょくど /進捗度/
しんちょくほうこく /進捗報告/
しんちょくりつ /進捗率/
しんちん /新陳/
しんちんたいしゃ /新陳代謝/
しんつう /心痛/
しんつだぬま /新津田沼/
しんつるみ /新鶴見/
しんづ /新津/
しんて /新手/
しんてい /進呈/新訂/新艇/心底/
しんていあん /新提案/
しんてき /心的/
しんてきげんしょう /心的現象/
しんてつ /神鉄/
しんてら /新寺/
しんてん /進展/親展/伸展/秦篆/
しんてんかい /新展開/
しんてんじょうきょう /進展状況/
しんてんたいはっけん /新天体発見/
しんてんち /新天地/
しんてんちょう /新天町/
しんてんぽ /新店舗/
しんでし /新弟子/
しんでれら /シンデレラ/
しんでん /神殿/新田/心電/
しんでんず /心電図/
しんと /信徒/
しんとう /新棟/浸透/心頭/新党/親等/神東/滲透/神道/榛東/真藤/
しんとうあつ /浸透圧/
しんとうき /神統記/
しんとうきょう /新東京/
しんとうさい /新搭載/
しんとうじょう /新登場/
しんとうせい /浸透性/
しんとうど /浸透度/
しんとうめっきゃく /心頭滅却/
しんとうりょく /浸透力/
しんとく /新得/
しんところざわ /新所沢/
しんとしょく /新塗色/
しんとしん /新都心/
しんとそう /新塗装/
しんとちぎ /新栃木/
しんとちょう /新都庁/
しんとっきゅう /新特急/
しんとっきゅうくさつ /新特急草津/
しんとつかわ /新十津川/
しんとね /新利根/
しんとみ /新富/
しんど /震度/進度/深度/
しんどう /振動/新道/神童/進藤/震動/新藤/伸銅/神道/新堂/真藤/
しんどうかい /振動解/
しんどうかんちしき /振動感知式/
しんどうきゅうしゅう /振動吸収/
しんどうきゅうしゅうざい /振動吸収材/
しんどうけい /振動系/振動計/神道系/
しんどうし /振動子/
しんどうしきょうど /振動子強度/
しんどうしゅうはすう /振動周波数/
しんどうすう /振動数/
しんどうそくど /振動速度/
しんどうてき /振動的/
しんどうでんぱ /振動伝播/
しんどうば /振動場/
しんどうばいしつ /振動媒質/
しんどうばん /振動板/
しんどうまく /振動膜/
しんどうめん /振動面/
しんなー /シンナー/
しんないがいめん /新内外綿/
しんなおえつ /新直江津/
しんなかの /新中野/
しんながた /新長田/
しんなごやえき /新名古屋駅/
しんならしの /新習志野/
しんならしのえき /新習志野駅/
しんなんよう /新南陽/
しんにち /親日/新日/
しんにちか /親日家/
しんにちこく /親日国/
しんにちてき /親日的/
しんにちは /親日派/
しんにっこう /新日鉱/
しんにってつ /新日鉄/新日本製鉄株式会社/新日鐵/
しんにってつかまいし /新日鉄釜石/
しんにっぽん /新日本/
しんにっぽんせいてつ /新日本製鐵/
しんにほん /新日本/
しんにほんきかく /新日本企画/
しんにほんきこう /新日本紀行/
しんにほんしょうけん /新日本証券/
しんにほんせいてつ /新日本製鉄/新日本製鐵/
しんにゅう /新入/侵入/浸入/進入/
しんにゅうか /進入可/新入荷/
しんにゅうかい /新入会/
しんにゅうかいいん /新入会員/
しんにゅうがく /新入学/
しんにゅうがくせい /新入学生/
しんにゅうきんし /進入禁止/
しんにゅうきんしいはん /進入禁止違反/
しんにゅうけいろ /進入経路/
しんにゅうしゃ /侵入者/
しんにゅうしゃいん /新入社員/
しんにゅうしゃいんきょういく /新入社員教育/
しんにゅうしゃりょう /進入車両/
しんにゅうじ /進入時/侵入時/
しんにゅうじょうけん /進入条件/
しんにゅうせい /新入生/
しんにゅうせいかんげい /新入生歓迎/
しんにゅうせいかんゆう /新入生勧誘/
しんにゅうそくど /進入速度/
しんにゅうふか /進入不可/
しんにゅうぶいん /新入部員/
しんにゅうほうこう /進入方向/
しんにゅうほうほう /侵入方法/
しんにゅうまく /新入幕/
しんにゅうよう /進入用/
しんにゅうろ /侵入路/
しんにょ /真如/
しんにょう /遞/
しんにん /信任/新任/信認/
しんにんきじゅん /信任基準/
しんにんきょうかん /新任教官/
しんにんじょう /信任状/
しんにんじょうけん /信任条件/
しんにんじょしゅ /新任助手/
しんにんすう /信任数/
しんにんせいりつ /信任成立/
しんにんてつづき /信任手続/信任手続き/
しんにんとうひょう /信任投票/
しんにんとうひょうあん /信任投票案/
しんにんとうひょうすう /信任投票数/
しんにんとうひょうてき /信任投票的/
しんにんとうひょうほうしき /信任投票方式/
しんにんはんたいひょう /信任反対票/
しんにんひょう /信任票/
しんにんひょうぶそく /信任票不足/
しんにんほうほう /信任方法/
しんぬり /真塗/
しんね /新値/心根/
しんねん /信念/新年/
しんねんかい /新年会/
しんねんごう /新年号/
しんねんちょうせい /信念調整/
しんねんど /新年度/
しんねんどよさんあん /新年度予算案/
しんの /神野/新野/
しんのう /親王/心嚢/
しんのすけ /新之助/信之介/進之助/慎之介/
しんのとうげ /新野峠/
しんのむらこうぎょう /新野村工業/
しんはっけん /新発見/
しんはっけんでん /新八犬伝/
しんはつばい /新発売/
しんはつばいよてい /新発売予定/
しんはままつかん /新浜松間/
しんはらまちだ /新原町田/
しんはんにん /真犯人/
しんば /新馬/
しんばし /新橋/
しんばしえき /新橋駅/
しんばしえきまえ /新橋駅前/
しんばしえんぶじょう /新橋演舞場/
しんばしふきん /新橋付近/
しんばしょう /新馬勝/
しんばせん /新馬戦/
しんばば /新馬場/
しんばばえき /新馬場駅/
しんばら /新原/
しんばん /新版/新盤/
しんばんぐみ /新番組/
しんばんぐみしょうかい /新番組紹介/
しんばんぐみじょうほう /新番組情報/
しんぱ /新派/
しんぱい /心配/心肺/
しんぱいきのう /心肺機能/
しんぱいこうふん /心配興奮/
しんぱいごと /心配事/
しんぱいしょう /心配症/
しんぱいてん /心配点/
しんぱいむよう /心配無用/
しんぱく /心拍/心搏/
しんぱくすう /心拍数/
しんぱち /新八/
しんぱつ /進発/深発/
しんぱん /信販/侵犯/審判/新版/
しんぱんいん /審判員/
しんぱんがいしゃ /信販会社/
しんぱんぎじゅつ /審判技術/
しんぱんけい /信販系/
しんぱんこうしゅうかい /審判講習会/
しんぱんしかく /審判資格/
しんぱんだん /審判団/
しんぱんちょう /審判長/
しんぱんぶ /審判部/
しんひきた /新疋田/
しんひっさつわざ /新必殺技/
しんひろしまくうこう /新広島空港/
しんひろしまし /新広島市/
しんび /審美/
しんびがん /審美眼/
しんびてき /審美的/
しんぴ /神秘/真否/心皮/真皮/
しんぴか /神秘化/
しんぴしゅぎ /神秘主義/
しんぴしゅぎてき /神秘主義的/
しんぴせい /神秘性/
しんぴつ /真筆/
しんぴてき /神秘的/
しんぴょう /信憑/
しんぴょうせい /信憑性/
しんぴょうせいかいむ /信憑性皆無/
しんぴょうろん /新評論/
しんぴわおん /神秘和音/
しんぴん /新品/
しんぴんかかく /新品価格/
しんぴんじ /新品時/
しんぴんじょうたい /新品状態/
しんぴんどうよう /新品同様/
しんぴんぼん /新品本/
しんふくおかほうそう /新福岡放送/
しんふじ /新富士/
しんふじえき /新冨士駅/新富士駅/
しんふじがわばし /新富士川橋/
しんふぜん /心不全/
しんふらの /新富良野/
しんふり /進振り/進振/
しんぶ /深部/
しんぶきげん /神武紀元/
しんぶっしつ /新物質/
しんぶつ /神仏/
しんぶつしゅうごう /神仏習合/
しんぶぶんこう /真部分項/
しんぶぶんしゅうごう /真部分集合/
しんぶぶんろんりしき /真部分論理式/
しんぶん /新聞/
しんぶんかい /新聞会/
しんぶんかくし /新聞各紙/
しんぶんかんゆう /新聞勧誘/
しんぶんかんゆういん /新聞勧誘員/
しんぶんき /新聞記/
しんぶんきしゃ /新聞記者/
しんぶんきじ /新聞記事/
しんぶんきゅうかんび /新聞休刊日/
しんぶんきょく /新聞局/
しんぶんぐん /新聞群/
しんぶんこうこく /新聞広告/
しんぶんざっし /新聞雑誌/
しんぶんし /新聞紙/
しんぶんしじょう /新聞紙上/
しんぶんしゃ /新聞社/
しんぶんしゃがわ /新聞社側/
しんぶんしゃまえ /新聞社前/
しんぶんじょう /新聞上/
しんぶんじょうほう /新聞情報/
しんぶんじん /新聞人/
しんぶんすう /真分数/
しんぶんだね /新聞種/
しんぶんてき /新聞的/
しんぶんとう /新聞等/
しんぶんはいたつ /新聞配達/
しんぶんはいたつじょ /新聞配達所/
しんぶんはっぴょう /新聞発表/
しんぶんはんばいてん /新聞販売店/
しんぶんへんしゅう /新聞編輯/
しんぶんほうどう /新聞報道/
しんぶんめい /新聞名/
しんぶんもじ /新聞文字/
しんぶんや /新聞屋/
しんぶんようご /新聞用語/
しんぷ /新譜/新婦/神父/
しんぷう /新風/
しんぷがわ /新婦側/
しんぷく /振幅/信服/心服/
しんぷくあっしゅく /振幅圧縮/
しんぷくおうとう /振幅応答/
しんぷくさぶん /振幅差分/
しんぷくせいぎょ /振幅制御/
しんぷくち /振幅値/
しんぷくてん /振幅点/
しんぷくとくせい /振幅特性/
しんぷくひ /振幅比/
しんぷくぶんぷ /振幅分布/
しんぷじょうほう /新譜情報/
しんぷじょうほうし /新譜情報誌/
しんぷはつばい /新譜発売/
しんぷる /シンプル/
しんへいき /新兵器/
しんべい /親米/
しんべんてん /新弁天/
しんぺい /新平/晋平/慎平/神兵/
しんぺん /身辺/
しんぺんざっきろく /身辺雑記録/
しんぺんせいり /身辺整理/
しんほう /進法/
しんほうしき /新方式/
しんほうほう /新方法/
しんほく /真北/
しんほだか /新穂高/
しんほどがや /新保土ヶ谷/
しんほんかくは /新本格派/
しんほんてん /新本店/
しんほんや /新本屋/
しんぼ /新保/真保/
しんぼう /辛抱/辛棒/信望/心房/心棒/深謀/伸坊/
しんぼうさいどう /心房細動/
しんぼうしゃ /信奉者/
しんぼく /親睦/
しんぼくかい /親睦会/
しんぼくかいいん /親睦会員/
しんぼくかいひ /親睦会費/
しんぼる /シンボル/
しんぽ /進歩/
しんぽう /信奉/新法/新報/
しんぽうしゃ /信奉者/
しんぽじうむ /シンポジウム/
しんぽてき /進歩的/
しんぽん /新本/
しんまい /新米/
しんまいせんせい /新米先生/
しんまえばし /新前橋/
しんまおう /新魔王/
しんまきゅう /新魔球/
しんまく /心膜/
しんまち /新町/
しんまちだ /新町田/
しんまつ /新松/
しんまつけいしき /新松形式/
しんまつだ /新松田/
しんまつだえき /新松田駅/
しんまつだかん /新松田間/
しんまつど /新松戸/
しんまるこ /新丸子/
しんまるこえきまえ /新丸子駅前/
しんまるこふきん /新丸子付近/
しんみ /親身/新味/
しんみた /新三田/
しんみつ /親密/
しんみどうすじ /新御堂筋/
しんみなと /新湊/
しんみなとし /新湊市/
しんみなみぐち /新南口/
しんみょう /神妙/新名/
しんみん /臣民/
しんみんちょうたい /新明朝体/
しんみんぽう /新民法/
しんめ /新芽/
しんめい /身命/深名/神明/
しんめいかい /新明解/
しんめいしょう /新名称/
しんめいだい /真命題/
しんめいぶつ /新名物/
しんめいわこうぎょう /新明和工業/
しんめん /新免/
しんもつ /進物/
しんもり /新森/
しんもん /審問/
しんや /深夜/真也/信哉/信也/進也/信矢/伸弥/伸也/新也/晋哉/晋也/眞哉/真哉/真家/
しんやえいが /深夜映画/
しんやきゅうこう /深夜急行/
しんやく /新薬/新訳/
しんやくいん /新役員/
しんやくしじ /新薬師寺/
しんやくせいしょ /新約聖書/
しんやざんぎょうたいせい /深夜残業体制/
しんやじかんたい /深夜時間帯/
しんやでんりょく /深夜電力/
しんやとっきゅう /深夜特急/
しんやばんぐみ /深夜番組/
しんやほうそう /深夜放送/
しんやま /新山/
しんやまぐち /新山口/
しんやゆうぎ /深夜遊戯/
しんやわく /深夜枠/
しんやわりびき /深夜割引/
しんやわりまし /深夜割増/深夜割増し/
しんゆう /親友/
しんゆうばり /新夕張/
しんゆうやく /親友役/
しんゆり /新百合/
しんよう /信用/
しんようかいふく /信用回復/
しんようがし /信用貸し/
しんようきんこ /信用金庫/
しんようくみあい /信用組合/
しんようしっつい /信用失墜/
しんようしょうかい /信用照会/
しんようじゅ /針葉樹/
しんようじゅこう /針葉樹綱/
しんようじょう /信用状/
しんようじょうほう /信用情報/
しんようせい /信用性/
しんようちょうさ /信用調査/
しんようちょうさがいしゃ /信用調査会社/
しんようど /信用度/
しんようほうしき /信用方式/
しんよこはま /新横浜/
しんよこはまえき /新横浜駅/
しんよこはまげしゃ /新横浜下車/
しんよこはまていしゃ /新横浜停車/
しんよこはまどおり /新横浜通り/
しんよこはまはつ /新横浜発/
しんら /森羅/
しんらい /信頼/
しんらいかん /信頼感/
しんらいかんけい /信頼関係/
しんらいくかん /信頼区間/
しんらいけいすう /信頼係数/
しんらいせい /信頼性/
しんらいちょう /新雷鳥/
しんらいど /信頼度/
しんらつ /辛辣/
しんらばんしょう /森羅万象/
しんらん /親鸞/
しんり /真理/心理/審理/
しんりいでん /心理遺伝/
しんりいでんげんしょう /心理遺伝現象/
しんりおんきょう /心理音響/
しんりおんきょうてき /心理音響的/
しんりかんすう /真理関数/
しんりがく /心理学/
しんりがくしゃ /心理学者/
しんりがくてき /心理学的/
しんりがくてきけんきゅう /心理学的研究/
しんりがくようご /心理学用語/
しんりがっか /心理学科/
しんりきょう /真理教/
しんりくうかん /心理空間/
しんりけん /心理研/
しんりけんさ /心理検査/
しんりさくせん /心理作戦/
しんりし /心理士/
しんりじっけん /心理実験/
しんりじょう /心理上/
しんりじょうたい /心理状態/
しんりせい /真理性/
しんりせん /心理戦/
しんりそくていかんすう /心理測定関数/
しんりち /真理値/
しんりちひょう /真理値表/
しんりてき /心理的/
しんりてきえいきょう /心理的影響/
しんりてききょり /心理的距離/
しんりてきこうか /心理的効果/
しんりてきしょうげき /心理的衝撃/
しんりてきそんしつ /心理的損失/
しんりてきぞくせい /心理的属性/
しんりてきちりょう /心理的治療/
しんりひょう /真理表/
しんりびょうしゃ /心理描写/
しんりぶつりがく /心理物理学/
しんりぶつりがくてき /心理物理学的/
しんりぶつりじっけん /心理物理実験/
しんりぶつりてき /心理物理的/
しんりぶんせき /心理分析/
しんりゃく /侵略/侵掠/
しんりゃくこうい /侵略行為/
しんりゃくこく /侵略国/
しんりゃくざい /侵略罪/
しんりゃくしゃ /侵略者/
しんりゃくしゅうだん /侵略集団/
しんりゃくせい /侵略性/
しんりゃくせんそう /侵略戦争/
しんりゃくち /侵略地/
しんりゃくちゅう /侵略中/
しんりゃくてき /侵略的/
しんりゃくてきこうい /侵略的行為/
しんりゃくてきようそ /侵略的要素/
しんりゃくろん /侵略論/
しんりや /心理屋/
しんりゅう /神龍/神竜/
しんりょ /深慮/
しんりょう /診療/新涼/
しんりょうか /診療科/
しんりょうかもく /診療科目/
しんりょうきん /新料金/
しんりょうしつ /診療室/
しんりょうしょ /診療所/
しんりょうじょ /診療所/
しんりょうたいせい /診療体制/
しんりょうだいきん /診療代金/
しんりょうちゅう /診療中/
しんりょうほうしゅう /診療報酬/
しんりょく /新緑/深緑/真緑/
しんりりょうほう /心理療法/
しんりろん /新理論/
しんりん /森林/
しんりんくみあい /森林組合/
しんりんげんかい /森林限界/
しんりんこうえん /森林公園/
しんりんしげん /森林資源/
しんりんしょくぶつがく /森林植物学/
しんりんせいび /森林整備/
しんりんそうけん /森林総研/
しんりんちたい /森林地帯/
しんりんてつどう /森林鉄道/
しんりんばっさい /森林伐採/
しんりんよく /森林浴/
しんるい /親類/
しんるいえんじゃ /親類縁者/
しんるいぶん /進塁分/
しんれい /心霊/
しんれいしゃしん /心霊写真/
しんれいてき /心霊的/
しんれいばい /新冷媒/
しんれき /新暦/
しんれつ /進列/
しんれんさい /新連載/
しんろ /進路/針路/
しんろう /新郎/心労/
しんろうがわ /新郎側/
しんろうしんぷ /新郎新婦/
しんろかいつう /進路開通/
しんろくおん /新録音/
しんろしどう /進路指導/
しんろじょう /進路上/
しんろせん /新路線/
しんろへんこう /進路変更/
しんろへんこうきんし /進路変更禁止/
しんろへんこうご /進路変更後/
しんろぼうがい /進路妨害/
しんろめい /進路名/
しんわ /神話/親和/新和/
しんわかいうん /新和海運/
しんわかんけい /神話関係/
しんわぎんこう /親和銀行/
しんわじてん /神話辞典/
しんわじょう /神話上/
しんわせい /親和性/
しんわせかい /神話世界/
しんわたいけい /神話体系/
しんわだ /新和田/
しんわてき /神話的/
じ /時/字/次/自/事/辞/治/持/二/地/耳/痔/磁/示/児/滋/蒔/寺/而/爾/子/除/璽/似/路/慈/侍/以/司/至/仁/茲/史/嗣/士/寿/只/知/爺/亊/弍/兒/塒/孳/尓/岻/峙/怩/恃/珥/瓷/畤/粫/膩/轜/辭/邇/祀/餌/迩/冶/
じ> /次/
じーんず /ジーンズ/
じあい /自愛/慈愛/地合い/
じあえんそさん /次亜塩素酸/
じあえんそさんえん /次亜塩素酸塩/
じあげ /地上/
じあまり /字余り/
じい /自慰/爺/示威/辞意/侍医/磁位/
じいがたけ /爺ヶ岳/
じいこう /時以降/
じいこうい /自慰行為/
じいさま /爺様/
じいさん /爺さん/
じいしき /自意識/
じいしきかじょう /自意識過剰/
じいぱん /Ｇパン/
じいろ /地色/
じいん /寺院/
じうん /時運/
じぇいあーるひがしにほん /JR東日本/
じぇっと /ジェット/
じぇっとき /ジェット機/
じぇらしー /ジェラシー/
じえい /自衛/自営/
じえいかん /自衛官/
じえいぎょう /自営業/
じえいぎょうしゃ /自営業者/
じえいけん /自衛権/
じえいさく /自衛策/
じえいしゅだん /自衛手段/
じえいしょうぼうたい /自衛消防隊/
じえいせんそう /自衛戦争/
じえいそしき /自衛組織/
じえいたい /自衛隊/
じえいたいいん /自衛隊員/
じえいたいさんか /自衛隊参加/
じえいたいしょぞく /自衛隊所属/
じえん /自演/
じおう /地黄/
じおん /字音/
じか /時下/時価/自家/磁化/字化/耳科/直/磁荷/
じかい /次回/次会/磁界/自戒/耳介/
じかいいこう /次回以降/
じかいかいぎ /次回会議/
じかいかんじ /次回幹事/
じかいけい /磁界系/
じかいこうえん /次回公演/
じかいこうぎょう /次回興業/
じかいさく /次回作/
じかいしゃけん /次回車検/
じかいとうこう /次回投稿/
じかいにってい /次回日程/
じかいもんだい /次回問題/
じかいよこく /次回予告/
じかく /自覚/痔核/字画/時隔/
じかくしだい /自覚次第/
じかくしょうじょう /自覚症状/
じかくすう /字画数/
じかくそんしつ /時隔損失/
じかくてき /自覚的/
じかげんぞう /自家現像/
じかさいばい /自家栽培/
じかしゅっぱん /自家出版/
じかしょうひ /自家消費/
じかしょり /自家処理/
じかず /字数/
じかせい /自家製/
じかせいさん /自家製産/
じかせいみそ /自家製味噌/
じかせん /耳下腺/
じかそうがく /時価総額/
じかだん /直談/
じかだんぱん /直談判/
じかちゅうどく /自家中毒/
じかつ /自活/
じかづみ /直積/
じかどうちゃく /自家撞着/
じかに /直に/
じかはつでん /自家発電/
じかびしき /直火式/
じかよう /自家用/
じかようしゃ /自家用車/
じかろ /地火炉/
じかん /時間/字間/次官/耳間/
じかんあっしゅくこうか /時間圧縮効果/
じかんいがい /時間以外/
じかんいぞん /時間依存/
じかんいってい /時間一定/
じかんいない /時間以内/
じかんうんてん /時間運転/
じかんえいぎょう /時間営業/
じかんおくれ /時間遅れ/
じかんか /時間化/
じかんかじゅう /時間荷重/
じかんかへん /時間可変/
じかんかんかく /時間間隔/時間感覚/
じかんかんけい /時間関係/
じかんがい /時間外/
じかんがいかさん /時間外加算/
じかんがいせかい /時間外世界/
じかんがいねん /時間概念/
じかんきゅう /時間給/時間休/
じかんきれ /時間切れ/
じかんきろく /時間記録/
じかんぎれ /時間切れ/
じかんくうかんじょう /時間空間上/
じかんくかん /時間区間/
じかんけいか /時間経過/
じかんけいやく /時間契約/
じかんけいれつ /時間系列/
じかんげんしゅ /時間厳守/
じかんこうか /時間効果/
じかんこうぞう /時間構造/
じかんご /時間後/
じかんごと /時間毎/
じかんさ /時間差/
じかんさぶん /時間差分/
じかんざひょう /時間座標/
じかんしてい /時間指定/
じかんしょうとつ /時間衝突/
じかんしょり /時間処理/
じかんしんごう /時間信号/
じかんじく /時間軸/
じかんじくじょう /時間軸上/
じかんじくほうこう /時間軸方向/
じかんじっけん /時間実験/
じかんじょうほう /時間情報/
じかんじょうほうしょり /時間情報処理/
じかんすう /時間数/
じかんせい /時間制/
じかんせいきか /時間正規化/
じかんせいげん /時間制限/
じかんせいぶん /時間成分/
じかんせきぶん /時間積分/
じかんせってい /時間設定/
じかんせつ /時間説/
じかんせん /時間線/
じかんそう /時間走/
じかんそくてい /時間測定/
じかんそんしつ /時間損失/
じかんたい /時間帯/
じかんたいきゅう /時間耐久/
じかんたんしゅく /時間短縮/
じかんたんしゅくこうか /時間短縮効果/
じかんちえん /時間遅延/
じかんちえんこうか /時間遅延効果/
じかんちかく /時間知覚/
じかんちかくきこう /時間知覚機構/
じかんちゅう /時間中/
じかんちょう /時間長/
じかんちょうせい /時間調整/
じかんちょうちかく /時間長知覚/
じかんちょうちかくきこう /時間長知覚機構/
じかんていし /時間停止/
じかんていど /時間程度/
じかんてき /時間的/
じかんてきけいか /時間的経過/
じかんてきぞくせい /時間的属性/
じかんてきぶんさん /時間的分散/
じかんてきよういん /時間的要因/
じかんてきよゆう /時間的余裕/
じかんとくせい /時間特性/
じかんない /時間内/
じかんはいぶん /時間配分/
じかんはけい /時間波形/
じかんはってん /時間発展/
じかんはん /時間半/
じかんはんざい /時間犯罪/
じかんひ /時間比/
じかんひょう /時間表/
じかんひょうじ /時間表示/
じかんびぶん /時間微分/
じかんぶそく /時間不足/
じかんぶん /時間分/
じかんぶんかいのう /時間分解能/
じかんへいきん /時間平均/
じかんへいきんち /時間平均値/
じかんへんか /時間変化/
じかんへんこう /時間変更/
じかんへんどう /時間変動/
じかんべつ /時間別/
じかんほうこう /時間方向/
じかんまえ /時間前/
じかんまち /時間待/
じかんまど /時間窓/
じかんまどちょう /時間窓長/
じかんむせいげん /時間無制限/
じかんめ /時間目/
じかんようそ /時間要素/
じかんりつ /時間率/
じかんりょういき /時間領域/
じかんりょこう /時間旅行/
じかんれつ /時間列/
じかんろん /時間論/
じかんろんり /時間論理/
じかんわく /時間枠/
じかんわり /時間割/
じかんわりひょう /時間割表/
じかんわりもんだい /時間割問題/
じが /自我/自画/
じがい /自害/
じがいしき /自我意識/
じがく /自学/
じがじさん /自画自賛/自画自讃/
じがぞう /自画像/
じがため /地固め/
じがね /地金/
じがめん /自画面/
じき /時期/次期/直/磁気/自棄/時機/喰/食/磁器/時季/自機/自記/時宜/
じきあらし /磁気嵐/
じきか /磁気化/
じきかいてい /次期改訂/
じきかいろ /磁気回路/
じきかこうくうけん /磁気化航空券/
じききろく /磁気記録/
じききろくばいたい /磁気記録媒体/
じきけん /磁気圏/
じきこうほ /次期候補/
じきこっかい /次期国会/
じきごと /時期毎/
じきさ /時期差/
じきさくひん /次期作品/
じきしげき /磁気刺激/
じきしゃへい /磁気遮蔽/
じきしゅ /次機種/
じきしょうそう /時期尚早/
じきしょうそうろん /時期尚早論/
じきしんがたしゃりょう /次期新型車両/
じきしんきしゅ /次期新機種/
じきじき /直々/
じきじきに /直々に/
じきじょうほう /磁気情報/
じきすう /時期数/
じきそ /直訴/
じきたんい /時期単位/
じきだんぱん /直談判/
じきちゅう /時期中/
じきちりょうき /磁気治療器/
じきてき /自棄的/時期的/
じきてきへんどう /時期的変動/
じきでん /直伝/
じきばいたい /磁気媒体/
じきひつ /直筆/
じきふじょうてつどう /磁気浮上鉄道/
じきふめい /時期不明/
じきぶん /時期分/
じきほうそう /次期放送/
じきぼう /次期防/
じきゅう /自給/時給/持久/
じきゅうじそく /自給自足/
じきゅうせん /持久戦/
じきゅうそう /持久走/
じきゅうりつ /自給率/
じきゅうりょく /持久力/
じきょ /辞去/
じきょう /自供/
じきょく /自局/磁極/時局/
じぎ /字義/辞儀/児戯/
じぎどおり /字義通り/
じぎゃく /自虐/
じぎゃくてき /自虐的/
じぎょう /事業/事行/次行/
じぎょうか /事業家/
じぎょうかい /事業会/
じぎょうかいはつしつ /事業開発室/
じぎょうかいはつぶ /事業開発部/
じぎょうかすいしんしつ /事業化推進室/
じぎょうかすいしんぶ /事業化推進部/
じぎょうかつどう /事業活動/
じぎょうけいかく /事業計画/
じぎょうしつ /事業室/
じぎょうしゃ /事業者/
じぎょうしゃがわ /事業者側/
じぎょうしゅ /事業主/
じぎょうしょ /事業所/
じぎょうしょかん /事業所間/
じぎょうしょつうしん /事業所通信/
じぎょうしょない /事業所内/
じぎょうじゅんびしつ /事業準備室/
じぎょうじょう /事業場/
じぎょうすいしん /事業推進/
じぎょうすいしんしつ /事業推進室/
じぎょうすいしんぶ /事業推進部/
じぎょうすいしんほんぶ /事業推進本部/
じぎょうぜい /事業税/
じぎょうたい /事業体/
じぎょうだん /事業団/
じぎょうとうかつぶ /事業統轄部/
じぎょうないよう /事業内容/
じぎょうぬし /事業主/
じぎょうぶ /事業部/
じぎょうぶかいはつ /事業部開発/
じぎょうぶかいはつぶ /事業部開発部/
じぎょうぶせい /事業部制/
じぎょうぶちょう /事業部長/
じぎょうぶない /事業部内/
じぎょうぶもん /事業部門/
じぎょうぶんや /事業分野/
じぎょうほうこくしょ /事業報告書;財務諸表の1つ/
じぎょうほんぶ /事業本部/
じぎょうよう /事業用/
じぎょうようしゃ /事業用車/
じぎょうりょういき /事業領域/
じく /軸/宍/竺/字句/忸/衄/衂/
じくあし /軸足/
じくう /時空/
じくうい /時空意/
じくういち /時空位置/
じくうかん /時空間/
じくうかんけい /時空関係/
じくうけ /軸受/軸受け/
じくかいせき /字句解析/
じくかいせきき /字句解析器/
じくかいせきぶ /字句解析部/
じくかん /軸間/次区間/時区間/
じくがい /軸外/
じくこてい /軸固定/
じくさく /軸索/
じくしゅつりょくきょくせん /軸出力曲線/
じくじ /忸怩/
じくじゅう /軸重/
じくじゅうけいげん /軸重軽減/
じくじゅうけいげんそち /軸重軽減措置/
じくじょう /軸上/
じくじょうほう /軸情報/
じくすう /軸数/
じくずれ /地崩れ/
じくせいぶん /軸成分/
じくせん /軸線/
じくせんきんぼう /軸線近傍/
じくそうかん /軸相関/
じくたいしょう /軸対称/
じくない /軸内/
じくばこ /軸箱/
じくばり /字配り/
じくほうこう /軸方向/
じくほうこうじゅうさいぼう /軸方向柔細胞/
じくまわり /軸回/
じくや /軸屋/
じぐ /治具/
じぐざぐ /ジグザグ/
じぐそー /ジグソー/
じぐん /自軍/
じけい /自警/慈恵/字形/次兄/字型/
じけいいだいびょういん /慈恵医大病院/
じけいだん /自警団/
じけいれつ /時系列/
じけいれつかいせき /時系列解析/
じけいれつしょり /時系列処理/
じけいれつじゅん /時系列順/
じけいれつはってん /時系列発展/
じけいれつようそ /時系列要素/
じけつ /自決/
じけん /事件/
じけんいらい /事件以来/
じけんかんれん /事件関連/
じけんご /事件後/
じけんちょう /事件帳/
じけんはっかくご /事件発覚後/
じけんばんごう /事件番号/
じけんぼ /事件簿/
じげん /次元/時限/字源/示現/事言/
じげんいいんかい /時限委員会/
じげんか /次元化/
じげんかいせき /次元解析/
じげんがぞうしょり /次元画像処理/
じげんくうかん /次元空間/
じげんけんきゅうかい /時限研究会/
じげんじょう /次元上/
じげんすう /次元数/
じげんそう /次元窓/
じげんそうち /時限装置/
じげんてき /次元的/
じげんばくだん /時限爆弾/
じげんめ /時限目/
じげんりゅう /示現流;剣術の一派/
じこ /自己/事故/
じこあい /自己愛/
じこあんじ /自己暗示/
じこいちすいてい /自己位置推定/
じこいらい /事故以来/
じこう /事項/時効/自校/次項/時候/時侯/時好/
じこうさくいん /事項索引/
じこうしき /字光式/
じこうだいにごう /次項第二号/
じこうほ /次候補/
じこうほぐん /次候補群/
じこうほせんたく /次候補選択/
じこかいかく /自己改革/
じこかいき /自己回帰/
じこかいけつ /自己解決/
じこかいぜんせい /自己改善性/
じこかいぞう /自己改造/
じこかいとう /自己解凍/
じこかくちょう /自己拡張/
じこかんけつ /自己完結/
じこかんけつがた /自己完結型/
じこかんけつてき /自己完結的/
じこかんしょう /自己干渉/
じこかんり /自己管理/
じこがくしゅうがた /自己学習型/
じこきじゅん /自己基準/
じこきせい /自己規制/
じこきゅうしゅう /自己吸収/
じこきょうぶんさん /自己共分散/
じこきろく /自己記録/
じこく /時刻/自国/
じこくいこう /時刻以降/
じこくこっか /自国国家/
じこくご /自国語/
じこくせい /自国製/
じこくてん /持国天/
じこくない /自国内/
じこくひょう /時刻表/
じこくひょうじ /時刻表示/
じこくひょうふっこくばん /時刻表復刻版/
じこくひょうみきさい /時刻表未記載/
じこくぶんか /自国文化/
じこくみん /自国民/
じこくらん /時刻欄/
じこくりょう /自国領/
じこくんれん /自己訓練/
じこけいせい /自己形成/
じこけいたい /事故形態/
じこけいはつ /自己啓発/
じこけんお /自己嫌悪/
じこけんじよく /自己顕示欲/
じこげんきゅう /自己言及/
じこげんきゅうぶん /自己言及文/
じこげんば /事故現場/
じここうたい /自己抗体/
じこご /事故後/
じこさいこう /自己最高/
じこさいてん /自己採点/
じこさいみん /自己催眠/
じこさんしょう /自己参照/
じこし /事故死/
じこしほん /自己資本;資本金、法定準備金、剰余金の3つ/
じこしぼうりつ /事故死亡率/
じこしゃ /事故車/
じこしゃへい /自己遮蔽/
じこしゅうせいてき /自己修正的/
じこしゅうふく /自己修復/
じこしゅうふくきのう /自己修復機能/
じこしゅちょう /自己主張/
じこしょうかい /自己紹介/
じこしょうかいぶん /自己紹介文/
じこしょうめい /事故証明/
じこしんこう /自己進行/
じこしんこく /自己申告/
じこしんこくかあど /自己申告カード/
じこしんこくひょう /自己申告表/
じこしんせい /自己申請/
じこしんだん /自己診断/
じこじ /事故時/
じこじつげん /自己実現/
じこじゅうたい /事故渋滞/
じこじゅようかんかく /自己受容感覚/
じこじょうけん /自己条件/
じこじょうほう /自己情報/
じこすう /事故数/
じこせいとうか /自己正当化/自己正統化/
じこせきにん /自己責任/事故責任/
じこぜんご /事故前後/
じこそうかん /自己相関/
じこそうかんかんすう /自己相関関数/
じこそうかんぎょうれつ /自己相関行列/
じこそうかんけいすう /自己相関係数/
じこそうじ /自己相似/
じこそうじせい /自己相似性/
じこそうぞう /自己創造/
じこそきしか /自己組織化/
じこそしき /自己組織/
じこそしきか /自己組織化/
じこそしきかいろ /自己組織回路/
じこそしきかこうぞう /自己組織化構造/
じこそしきかほう /自己組織化法/
じこそしきけい /自己組織系/
じこそしきてき /自己組織的/
じこぞうしょく /自己増殖/
じこぞうしょくがた /自己増殖型/
じこちゅう /事故中/
じこちゅうしん /自己中心/
じこちゅうしんてき /自己中心的/
じこちゅうしんは /自己中心派/
じこちょうさ /自己調査/
じこちょうせつ /自己調節/
じこちょうせつへいこう /自己調節平衡/
じこちょくご /事故直後/
じこちりょうこうい /自己治療行為/
じこつごう /自己都合/
じこていせい /自己訂正/
じこてきよう /自己適用/
じこてきようてき /自己適用的/
じこてんかいせい /自己展開性/
じこてんめつがた /自己点滅型/
じことうえい /自己投影/
じことうじ /事故当時/
じことうすいてき /自己陶酔的/
じこどうけい /自己同型/
じこどうけいぐん /自己同型群/
じこないよう /事故内容/
じこはあく /自己把握/
じこはかい /自己破壊/
じこはさん /自己破産/
じこはさんしんせい /自己破産申請/
じこはっせい /事故発生/
じこはっせいりつ /事故発生率/
じこはんえい /自己反映/
じこはんえいけいさん /自己反映計算/
じこはんえいてき /自己反映的/
じこはんせい /自己反省/
じこひげ /自己卑下/
じこひてい /自己否定/
じこひはん /自己批判/
じこひょうか /自己評価/
じこひょうげん /自己表現/
じこふくせいし /自己複製子/
じこふたん /自己負担/
じこぶんせき /自己分析/
じこべんかい /自己弁解/
じこべんご /自己弁護/
じこほうこく /事故報告/
じこほぞん /自己保存/
じこほぞんほんのう /自己保存本能/
じこほんい /自己本位/
じこぼうえい /自己防衛/
じこぼうえいさく /自己防衛策/
じこぼうえいほんのう /自己防衛本能/
じこぼうぎょ /自己防御/
じこぼうぎょしんり /自己防御心理/
じこぼうし /事故防止/
じこぼうしこうか /事故防止効果/
じこまんぞく /自己満足/
じこむじゅん /自己矛盾/
じこむどうちゃく /自己無撞着/
じこめんえきけい /自己免疫系/
じこもくてきせい /自己目的性/
じこよくせい /自己抑制/
じこりつ /事故率/
じこりつぞうか /事故率増加/
じこりゅう /自己流/
じこりゅうかいしゃく /自己流解釈/
じこれい /事故例/
じこれき /事故歴/
じころ /時頃/
じご /事後/爾後/
じごう /次号/自業/
じごうじとく /自業自得/
じごうよこく /次号予告/
じごえ /地声/
じごく /地獄/
じごくだに /地獄谷/
じごくへん /地獄変/
じごくみみ /地獄耳/
じごしょうだく /事後承諾/
じごしょり /事後処理/
じごてき /事後的/
じごほうこく /事後報告/
じごろ /時頃/
じごろう /滋悟郎/
じさ /時差/橲/
じさいてき /次最適/
じさいと /自サイト/
じさく /自作/次作/治作/
じさくきじ /自作記事/
じさくきょく /自作曲/
じさくしゃりょう /自作車両/
じさくじえん /自作自演/
じさくじゅつ /自作術/
じさくちゅうしん /自作中心/
じさくのう /自作農/
じさくは /自作派/
じさくひん /自作品/
じさくよう /自作用/
じさげ /字下げ/
じさしゅっきん /時差出勤/
じさつ /自殺/
じさつこうい /自殺行為/
じさつしゃ /自殺者/
じさつてん /自殺点/
じさつみすい /自殺未遂/
じさつよう /自殺用/
じさばら /橲原/
じさぶろう /治三朗/
じさぼけ /時差ボケ/
じさん /持参/自参/自賛/自讃/
じさんきん /持参金/
じざい /自在/
じざけ /地酒/
じし /次子/
じしき /次式/
じしつ /自室/自失/
じしゃ /自社/自車/侍者/
じしゃかいはつ /自社開発/
じしゃかぶ /自社株/
じしゃかんぶ /自社幹部/
じしゃく /磁石/
じしゃくか /磁石化/
じしゃくかん /自社区間/
じしゃせい /自社製/
じしゃせいさん /自社生産/
じしゃせいひん /自社製品/
じしゃせん /自車線/
じしゃせんない /自社線内/
じしゃない /自社内/
じしゃはっちゅうしゃ /自社発注車/
じしゃはんばいけん /自社販売権/
じしゃびん /自社便/
じしゃわく /自社枠/
じしゅ /自主/字種/自首/
じしゅう /自習/次週/
じしゅういこう /次週以降/
じしゅうえんがた /次周縁型/
じしゅうえんしげんさいぼう /次周縁始原細胞/
じしゅうしつ /自習室/
じしゅうようきょうざい /自習用教材/
じしゅうよこく /次週予告/
じしゅかいはつ /自主開発/
じしゅきせい /自主規制/
じしゅく /自粛/
じしゅくきかん /自粛期間/
じしゅくちゅう /自粛中/
じしゅけん /自主権/
じしゅけんぽうせいてい /自主憲法制定/
じしゅこうぎょう /自主興行/
じしゅじょうえい /自主上映/
じしゅじょうえいかい /自主上映会/
じしゅせい /自主性/
じしゅせいさく /自主制作/自主製作/
じしゅせいさくえいが /自主製作映画/
じしゅせいさくばん /自主製作盤/自主制作版/
じしゅせんたくせいど /自主選択制度/
じしゅてき /自主的/
じしゅはっこう /自主発行/
じしゅはんだん /自主判断/
じしゅばん /自主盤/
じしゅへんかん /字種変換/
じしょ /辞書/自署/地所/字書/璽書/
じしょいっかつとうろく /辞書一括登録/
じしょう /事象/次章/自称/自象/時称/
じしょうぎ /持将棋/
じしょうくどう /事象駆動/
じしょうさけつう /自称酒通/
じしょうさんそうえん /次硝酸蒼鉛/
じしょかんり /辞書管理/
じしょがくしゅう /辞書学習/
じしょく /辞職/
じしょけいしき /辞書形式/
じしょけんさく /辞書検索/
じしょさいへんせい /辞書再編成/
じしょしき /辞書式/
じしょしきじゅんじょ /辞書式順序/
じしょしっぴつ /辞書執筆/
じしょじゅん /辞書順/
じしょじゅんはいち /辞書順配置/
じしょじゅんひかく /辞書順比較/
じしょじょうほう /辞書情報/
じしょとうろく /辞書登録/
じしょとうろくきのう /辞書登録機能/
じしょとうろくないよう /辞書登録内容/
じしょないよう /辞書内容/
じしょばんごう /辞書番号/
じしょぶん /辞書分/
じしょめい /辞書名/
じしょもの /辞書物/
じしん /自身/自信/地震/磁心/磁針/時針/
じしんか /自信家/
じしんかじょう /自信過剰/
じしんかんそく /地震観測/
じしんがく /地震学/
じしんがくし /地震学史/
じしんがっかい /地震学会/
じしんけい /地震計/
じしんけいそくぶもん /地震計測部門/
じしんけん /地震研/
じしんけんきゅうしょ /地震研究所/
じしんけんきゅうじょ /地震研究所/
じしんげん /地震源/
じしんさく /自信作/
じしんじょうほう /地震情報/
じしんぜんちょうげんしょう /地震前兆現象/
じしんそうしつ /自身喪失/自信喪失/
じしんちたい /地震地帯/
じしんどう /地震動/
じしんなし /自信無/
じしんは /地震波/
じしんはっせい /地震発生/
じしんや /地震屋/
じしんよち /地震予知/
じしんよちけんきゅう /地震予知研究/
じしんよちじょうほう /地震予知情報/
じじ /爺/時事/時々/
じじかい /次次回/次々回/
じじく /耳軸/
じじこくこく /時々刻々/
じじこっこく /時々刻々/
じじつ /事実/
じじつかくにん /事実確認/
じじつかんけい /事実関係/
じじつこん /事実婚/
じじつごにん /事実誤認/
じじつじょう /事実上/
じじつじょうかいさん /事実上解散/
じじつじょうだったい /事実上脱退/
じじつじょうふかけつ /事実上不可欠/
じじつじょうふかのう /事実上不可能/
じじつじょうむほしょう /事実上無保証/
じじつじょうめんじょ /事実上免除/
じじつてき /事実的/
じじつにんしき /事実認識/
じじつにんてい /事実認定/
じじつほうこく /事実報告/
じじつむこん /事実無根/
じじもんだい /時事問題/
じじゃく /自若/
じじゅう /侍従/自重/
じじゅうぞうか /自重増加/
じじゅん /次順/
じじょ /次女/侍女/自助/
じじょう /事情/自乗/２乗/二乗/2乗/磁場/
じじょうきょり /２乗距離/
じじょうけんてい /二乗検定/
じじょうごさ /二乗誤差/2乗誤差/
じじょうごさほう /二乗誤差法/
じじょうさよう /自浄作用/
じじょうじばく /自縄自縛/
じじょうせつめい /事情説明/
じじょうたい /次状態/
じじょうだいいっこう /次条第一項/
じじょうつう /事情通/
じじょうのうりょく /自浄能力/
じじょうふあんない /事情不案内/
じじょうへいきん /二乗平均/
じじょうほう /二乗法/
じじょうわ /二乗和/２乗和/2乗和/自乗和/
じじょでん /自叙伝/
じじょどりょく /自助努力/
じじん /自陣/自刃/
じすい /自炊/
じすう /字数/次数/時数/
じすうかん /次数間/
じすうしてい /字数指定/
じすうせいげん /字数制限/
じすべり /地滑り/
じず /次図/
じずめ /字詰め/
じずら /字面/
じずらどおり /字面通り、/
じせい /時制/自制/時世/磁性/自製/時勢/自生/自省/辞世/
じせいけん /自制研/
じせいしん /自制心/
じせいたい /磁性体/
じせいふん /磁性粉/
じせき /自席/次席/自責/事跡/
じせきてん /自責点/
じせきのねん /自責の念/
じせだい /次世代/
じせだいいこう /次世代以降/
じせだいき /次世代機/
じせつ /次節/時節/自説/
じせつがら /時節柄/
じせん /自薦/自選/次戦/
じせんき /自戦記/
じせんしょ /自薦書/
じせんたせん /自薦他薦/
じせんよう /耳栓用/
じぜん /事前/次善/慈善/
じぜんうんどう /事前運動/
じぜんかくりつ /事前確率/
じぜんかつどう /慈善活動/
じぜんがくしゅう /事前学習/
じぜんこうにゅう /事前購入/
じぜんこうにゅうきそく /事前購入規則/
じぜんしてい /事前指定/
じぜんしんさ /事前審査/
じぜんじぎょう /慈善事業/
じぜんじゅんび /事前準備/
じぜんじょうけん /事前条件/
じぜんだんたい /慈善団体/
じぜんち /事前値/
じぜんちょうさ /事前調査/
じぜんとうぎ /事前討議/
じぜんとうろく /事前登録/
じぜんとうろくふよう /事前登録不要/
じぜんはいふ /事前配布/
じぜんはっぴょう /事前発表/
じぜんひょうか /事前評価/
じぜんぶんぷ /事前分布/
じぜんよやく /事前予約/
じぜんよやくよう /事前予約要/
じそう /時相/自走/次走/自掃/
じそうかのう /自走可能/
じそうよてい /次走予定/
じそうろんり /時相論理/
じそく /自足/時速/磁束/
じそくき /自速機/
じそくみつど /磁束密度/
じそん /自損/自存/自尊/
じそんしん /自尊心/
じそんじえい /自存自衛/
じぞう /地蔵/
じぞうとうげ /地蔵峠/
じぞく /持続/
じぞくおん /持続音/
じぞくかん /持続感/
じぞくかんせんしゃ /持続感染者/
じぞくじかん /持続時間/
じぞくせい /持続性/
じぞくてき /持続的/
じぞくりょく /持続力/
じた /自他/
じたい /自体/事態/辞退/字体/字體/
じたいじょう /辞退状/
じたく /自宅/
じたくけいゆ /自宅経由/
じたくけんじむしょ /自宅兼事務所/
じたくせい /自宅生/
じたくたいき /自宅待機/
じたくとうちゃく /自宅到着/
じたくりょうよう /自宅療養/
じたくろくおん /自宅録音/
じたすく /自タスク/
じたつ /示達/
じたとも /自他共/
じたん /時短/
じだ /耳朶/次打/
じだい /時代/地代/次代/事大/
じだいおくれ /時代遅れ/時代後れ/
じだいげき /時代劇/
じだいこうしょう /時代考証/
じだいさくご /時代錯誤/
じだいさくごてき /時代錯誤的/
じだいしょく /時代色/
じだいじゅん /時代順/
じだいせいしん /時代精神/
じだいせってい /時代設定/
じだいそう /時代相/
じだいてき /時代的/
じだいはいけい /時代背景/
じだいもの /時代物/
じだらく /自堕落/
じだん /次段/示談/
じだんこうしょう /示談交渉/
じだんだ /地団駄/地団太/
じち /自治/
じちかい /自治会/
じちかいしつ /自治会室/
じちく /自治区/
じちけん /自治権/
じちさよう /自治作用/
じちしょう /自治省;2001年1月の中央省庁再編で総務省に再編された/
じちせい /自治性/自治制/
じちたい /自治体/
じちだいじん /自治大臣/
じちょ /自著/
じちょう /次長/自重/自嘲/
じちょうたん /次頂端/
じちょうたんしげんさいぼう /次頂端始原細胞/
じちょうてき /自嘲的/
じちりょう /自治領/
じちろう /自治労/
じちろうこくさいきょく /自治労国際局/
じちん /自沈/
じっ /十/
じっか /実家/
じっかい /実解/十戒/十階/十誡/
じっかいせきせい /実解析性/
じっかはく /実家泊/
じっかん /実感/甲乙丙丁戊己庚辛壬癸/十干/
じっかんじゅうにし /十干十二支/
じっき /実機/
じっきょう /実況/
じっきょうけんぶん /実況見分/
じっきょうしゃ /実況者/
じっきょうしゅっぱん /実教出版/
じっきょうじん /実況陣/
じっきょうせき /実況席/
じっきょうたんとう /実況担当/
じっきょうたんとうしゃ /実況担当者/
じっきょうちゅうけい /実況中継/
じっきょうほうそう /実況放送/
じっけい /実刑/実兄/
じっけん /実験/実権/実検/實驗/
じっけんいいんかい /実験委員会/
じっけんえいが /実験映画/
じっけんおんがくてき /実験音楽的/
じっけんか /実験可/
じっけんかいし /実験開始/
じっけんかいしご /実験開始後/
じっけんかいせき /実験解析/
じっけんかがくしゃ /実験科学者/
じっけんかのう /実験可能/
じっけんき /実験機/
じっけんきぐ /実験器具/
じっけんきざい /実験器材/実験機材/
じっけんきょく /実験局/
じっけんぎじゅつ /実験技術/
じっけんけい /実験系/
じっけんけいかく /実験計画/
じっけんけっか /実験結果/
じっけんげんば /実験現場/
じっけんげんり /実験原理/
じっけんごさ /実験誤差/
じっけんごさない /実験誤差内/
じっけんさんか /実験参加/
じっけんざいりょう /実験材料/
じっけんし /実験誌/
じっけんしき /実験式/
じっけんしせつ /実験施設/
じっけんしつ /実験室/
じっけんしつけい /実験室系/
じっけんしゃ /実験者/
じっけんしゅたい /実験主体/
じっけんしゅほう /実験手法/
じっけんしょうせつぐん /実験小説群/
じっけんしんりがく /実験心理学/
じっけんしんりがくしゃ /実験心理学者/
じっけんじかん /実験時間/
じっけんじじつ /実験事実/
じっけんじたい /実験自体/
じっけんじゅんび /実験準備/
じっけんじょう /実験場/実験上/
じっけんじょうけん /実験条件/
じっけんすい /実験水/
じっけんすうがく /実験数学/
じっけんずみ /実験済/
じっけんせい /実験星/
じっけんせつぞく /実験接続/
じっけんせつび /実験設備/
じっけんそうち /実験装置/
じっけんだい /実験台/
じっけんだんかい /実験段階/
じっけんち /実験値/
じっけんちゅう /実験中/
じっけんづくえ /実験机/
じっけんてき /実験的/
じっけんてきけんしょう /実験的検証/
じっけんてきこうさつ /実験的考察/
じっけんてきさくひん /実験的作品/
じっけんてきしょうこ /実験的証拠/
じっけんてきじょうほう /実験的情報/
じっけんてんたいぶつり /実験天体物理/
じっけんとう /実験棟/
じっけんどうぶつ /実験動物/
じっけんないよう /実験内容/
じっけんばしょ /実験場所/
じっけんばんぐみ /実験番組/
じっけんひけんしゃ /実験被験者/
じっけんぶ /実験部/
じっけんぶつりがく /実験物理学/
じっけんほうこく /実験報告/
じっけんほうそう /実験放送/
じっけんほうほう /実験方法/
じっけんもくてき /実験目的/
じっけんや /実験屋/
じっけんよう /実験用/
じっけんれい /実験例/
じっけんろ /実験炉/
じっけんろんぶん /実験論文/
じっこう /実行/実効/
じっこうい /実行委/
じっこういいん /実行委員/
じっこういいんかい /実行委員会/
じっこういいんちょう /実行委員長/
じっこういらい /実行依頼/
じっこうかいすう /実行回数/
じっこうかのう /実行可能/
じっこうかのうけいしき /実行可能形式/
じっこうかのうじょうたい /実行可能状態/
じっこうかんきょう /実行環境/
じっこうかんきょうじょう /実行環境上/
じっこうかんきょうよう /実行環境用/
じっこうかんし /実行監視/
じっこうかんど /実効感度/
じっこうがた /実行型/
じっこうがめん /実行画面/
じっこうきょか /実行許可/
じっこうけいしき /実行形式/
じっこうけっか /実行結果/
じっこうけん /実行権/
じっこうけんげん /実行権限/
じっこうこうりつ /実行効率/
じっこうこんざつど /実効混雑度/
じっこうご /実行後/
じっこうしゃ /実行者/
じっこうしゅたい /実行主体/
じっこうじ /実行時/
じっこうじかいけつ /実行時解決/
じっこうじかん /実行時間/
じっこうじっせき /実行実績/
じっこうじゅんじょ /実行順序/
じっこうじょうきょう /実行状況/
じっこうじょうたい /実行状態/
じっこうせい /実効性/
じっこうせいのう /実行性能/
じっこうせんりょう /実効線量/
じっこうせんりょうとうりょう /実効線量当量/
じっこうそくど /実行速度/実効速度/
じっこうぞうばいりつ /k$_{eff}$/実効増倍率/
じっこうぞくせい /実行属性/
じっこうたい /実行体/
じっこうだんかい /実行段階/
じっこうち /実効値/
じっこうちゅう /実行中/
じっこうてき /実効的/
じっこうてきいみ /実効的意味/
じっこうてじゅん /実行手順/
じっこうてんそうそくど /実効転送速度/
じっこうとちゅう /実行途中/
じっこうはん /実行犯/
じっこうび /実行日/
じっこうふかのう /実行不可能/
じっこうふのう /実行不能/
じっこうぶ /実行部/
じっこうぶん /実行文/
じっこうへんかん /実行変換/
じっこうほう /実行法/
じっこうほうしき /実行方式/
じっこうほうほう /実行方法/
じっこうまえ /実行前/
じっこうりょく /実行力/実効力/
じっこうれい /実行例/
じっこん /実根/入魂/昵懇/
じっさい /実際/
じっさいえいぞう /実際映像/
じっさいじょう /実際上/
じっさいせい /実際性/
じっさいてき /実際的/
じっさいてきな /実際的な/
じっさいに /実際に/
じっさいもんだい /実際問題/
じっさぎょう /実作業/
じっし /実施/実子/実視/実姉/十指/
じっしご /実施後/
じっししゃ /実施者/
じっしじき /実施時期/
じっしじたい /実施自体/
じっしちゅう /実施中/
じっしつ /実質/
じっしつじぎょうしゃ /実質事業者/
じっしつじょう /実質上/
じっしつぞうぜい /実質増税/
じっしつちゅう /実質中/
じっしつてき /実質的/
じっしつてきかかく /実質的価格/
じっしつてきこうか /実質的効果/
じっしつふくいん /実質幅員/
じっしつやく /実質役/
じっしび /実施日/
じっしほうほう /実施方法/
じっしゃ /実写/実車/
じっしゃえいが /実写映画/
じっしゃかい /実社会/
じっしゃがめん /実写画面/
じっしゃばん /実写版/
じっしゃふう /実写風/
じっしゃほうしき /実写方式/
じっしゃもの /実写物/
じっしゅ /十種/
じっしゅう /実習/実収/
じっしゅうかいぼう /実習解剖/
じっしゅうさき /実習先/
じっしゅうしつ /実習室/
じっしゅうせい /実習生/
じっしゅうそうち /実習装置/
じっしゅうねん /十周年/
じっしゅうよう /実習用/
じっしょう /実証/十漿/
じっしょうしゅぎ /実証主義/
じっしょうずみ /実証済/
じっしょうせい /実証性/
じっしょうてき /実証的/
じっしようこう /実施要綱/実施要項/
じっしようりょう /実施要領/
じっしれい /実施例/
じっしん /実身;BTRON のファイルシステム上の概念/１０進/十進/
じっしんすう /十進数/
じっしんすうひょうき /十進数表記/
じっしんぶんるいほう /十進分類法/
じっしんほう /十進法/
じっすう /実数/
じっすうかい /実数解/
じっすうがた /実数型/
じっすうぜんたい /実数全体/
じっすうたい /実数体/
じっすうたいじょう /実数体上/
じっすうち /実数値/
じっすうちょくせん /実数直線/
じっすうていすう /実数定数/
じっすうはっぴょう /実数発表/
じっすうぶ /実数部/
じっすうろん /実数論/
じっすん /実寸/
じっせい /実勢/
じっせいかかく /実勢価格/
じっせいかつ /実生活/實生活/
じっせいかつじょう /実生活上/
じっせかい /実世界/
じっせき /実績/
じっせきあり /実績有/
じっせきさく /実績作/
じっせきしゅぎ /実績主義/
じっせきじゅうし /実績重視/
じっせきぜったいは /実績絶対派/
じっせきち /実績値/
じっせきちょうさ /実績調査/
じっせきば /実績馬/
じっせきぶそく /実績不足/
じっせん /実践/実線/実戦/
じっせんからて /実戦空手/
じっせんけい /実戦形/
じっせんけいけん /実戦経験/
じっせんけっか /実践結果/
じっせんさんか /実戦参加/
じっせんしょうぎょう /実践商業/
じっせんしょうぎょうこうこう /実践商業高校/
じっせんじょがくえん /実践女学園/
じっせんじょしがくえん /実践女子学園/
じっせんじょしこう /実践女子高/
じっせんてき /実戦的/実践的/
じっせんてきぎじゅつ /実践的技術/
じっせんとうにゅう /実戦投入/
じっせんはいび /実戦配備/
じっせんへん /実践編/
じっせんりせいひはん /実践理性批判/
じっそう /実装/実相/十層/
じっそうかんきょう /実装環境/
じっそうき /実装機/
じっそうぎじゅつ /実装技術/
じっそうげんご /実装言語/
じっそうしゃていぎ /実装者定義/
じっそうしよう /実装仕様/
じっそうじ /実相寺/実装時/
じっそうじょう /実装上/
じっそうせいど /実装精度/
じっそうひょうげん /実装表現/
じっそうほう /実装法/実装方/
じっそうほうしき /実装方式/
じっそうほうほう /実装方法/
じっそうめんせき /実装面積/
じっそく /実測/
じっそくけっか /実測結果/
じっそくず /実測図/
じっそくち /実測値/
じっそくれい /実測例/
じったい /実体/実態/
じったいか /実体化/
じったいがいねん /実体概念/
じったいきょう /実体鏡/
じったいけん /実体験/
じったいけんしゃ /実体験者/
じったいけんびきょう /実体顕微鏡/
じったいちょうさ /実態調査/
じったいてき /実態的/実体的/
じったいは /実体波/
じっち /実地/
じっちえんしゅう /実地演習/
じっちきょうしゅう /実地教習/
じっちけいけん /実地経験/
じっちけんしゅう /実地研修/
じっちけんしょう /実地検証/
じっちしけんめんじょ /実地試験免除/
じっちゅう /十中/
じっちゅうはっく /十中八九/
じっちょうりょく /実張力/
じっちょく /実直/
じっつう /十通/
じって /十手/
じってい /実弟/
じっていほう /実定法/
じっていほうじょう /実定法上/
じっとく /十徳/
じっぱ /十羽/十把/
じっぱひとからげ /十把一絡/
じっぴ /実費/
じっぴき /十匹/
じっぴふたん /実費負担/
じっぴぶん /実費分/
じっぷ /実父/
じっぷん /十分/
じっぷんかん /十分間/
じっぽ /十歩/
じっぽう /実包/
じつ /実/日/實/昵/
じつあっしゅくひ /実圧縮比/
じつい /実委/
じついん /実印/
じつうんよう /実運用/
じつえき /実益/
じつえん /実演/
じつえんか /実演家/
じつえんじょう /実演場/
じつえんはんばい /実演販売/
じつおん /実音/
じつおんげん /実音源/
じつおんじょう /実音場/
じつおんせい /実音声/
じつおんぞう /実音像/
じつかそくど /実加速度/
じつかどう /実稼働/
じつかんきょう /実環境/
じつかんすう /実関数/
じつがい /実害/
じつがく /実学/
じつがめん /実画面/
じつきおく /実記憶/
じつぎ /実技/
じつぎこうしゅう /実技講習/
じつぎしけん /実技試験/
じつぎしけんふよう /実技試験不要/
じつぎょう /実業/
じつぎょうか /実業家/
じつぎょうかい /実業界/
じつぎょうだん /実業団/
じつぎょうのにほんしゃ /実業之日本社/
じつくうかん /実空間/
じつくうかんじょう /実空間上/
じつけいさんき /実計算機/
じつけいすう /実係数/
じつけいそく /実計測/
じつげつ /日月/
じつげん /実現/
じつげんか /実現化/
じつげんかてい /実現過程/
じつげんかのう /実現可能/
じつげんかのうせい /実現可能性/
じつげんかのうせいかいしゃく /実現可能性解釈/
じつげんきこう /実現機構/
じつげんきぼう /実現希望/
じつげんぎじゅつ /実現技術/
じつげんけいたい /実現形態/
じつげんし /実現子/
じつげんしゅほう /実現手法/
じつげんじょう /実現上/
じつげんせい /実現性/
じつげんど /実現度/
じつげんふかのう /実現不可能/
じつげんふのう /実現不能/
じつげんほう /実現法/
じつげんほうほう /実現方法/
じつげんみ /実現味/
じつげんようきゅう /実現要求/
じつこうりつ /実効率/
じつさぎょう /実作業/
じつざい /実在/
じつざいかん /実在感/
じつざいせい /実在性/
じつざいてき /実在的/
じつざいろん /実在論/
じつしよう /実使用/
じつじ /実耳/
じつじかん /実時間/
じつじかんか /実時間化/
じつじかんしょり /実時間処理/
じつじかんせい /実時間性/
じつじく /実軸/
じつじゅ /実需/
じつじょう /実状/実情/
じつせかい /実世界/
じつぞう /実像/
じつぞん /実存/
じつぞんしゅぎ /実存主義/
じつたいけん /実体験/
じつたいしょう /実対称/
じつだん /実弾/
じつちえん /実遅延/
じつづき /地続き/
じつていすう /実定数/
じつとうじょうじっせき /実搭乗実績/
じつどう /実働/実動/
じつどうさ /実動作/
じつどうさじょう /実動作上/
じつどうじかん /実働時間/
じつに /実に/
じつねんぴ /実燃費/
じつねんれい /実年齢/
じつねんろん /実念論/
じつは /実は/
じつばい /実売/
じつばいかかく /実売価格/
じつばりき /実馬力/
じつひきすう /実引数/
じつぶ /実部/
じつぶつ /実物/
じつぶつこうしょうてき /実物考証的/
じつぶつだい /実物大/
じつぶつだいもけい /実物大模型/
じつぼ /実母/地坪/
じつまい /実妹/
じつむ /実務/
じつむか /実務家/
じつむけいけん /実務経験/
じつむしゃ /実務者/
じつむてき /実務的/
じつめい /実名/
じつも /自模/
じつもふ /自模符/
じつやく /実役/
じつよう /実用/
じつようか /実用化/
じつようかいてんいき /実用回転域/
じつようかいろ /実用回路/
じつようかいわ /実用会話/
じつようかじだい /実用化時代/
じつようかどうむき /実用化動向/
じつようき /実用機/実用期/
じつようしゃ /実用車/
じつようしゅぎ /実用主義/
じつようしんあん /実用新案/
じつようじょう /実用上/
じつようじょうげん /実用上限/
じつようじょうもんだい /実用上問題/
じつようせい /実用性/
じつようてき /実用的/
じつようてきけいさんき /実用的計算機/
じつようてきばめん /実用的場面/
じつようでんしかいろ /実用電子回路/
じつようど /実用度/
じつようねんぴ /実用燃費/
じつようひん /実用品/
じつようほんい /実用本位/
じつようめん /実用面/
じつようれい /実用例/
じつり /実利/
じつりゆうせん /実利優先/
じつりょく /実力/
じつりょくいじょう /実力以上/
じつりょくこうし /実力行使/
じつりょくさ /実力差/
じつりょくしゃ /実力者/
じつりょくてき /実力的/
じつりょくどおり /実力通り/
じつりょくは /実力派/
じつりょくはくちゅう /実力伯仲/
じつりょくはんていしけん /実力判定試験/
じつりょくば /実力馬/
じつりょくひかく /実力比較/
じつりょくぶそく /実力不足/
じつりょくぼうがい /実力妨害/
じつれい /実例/
じつれいじたい /実例自体/
じつれん /実連/
じつろう /実労/
じつろうじかん /実労時間/
じつろく /実録/
じつわ /実話/
じづめ /字詰め/
じづら /字面/
じづらじょう /字面上/
じてい /時程/
じていすう /時定数/次定数/
じてき /自適/
じてん /時点/辞典/字典/事典/次点/自転/辭典/
じてんしゃ /自転車/自轉車/
じてんしゃいどう /自転車移動/
じてんしゃおうだんたい /自転車横断帯/
じてんしゃおきば /自転車置場/
じてんしゃぎょうかい /自転車業界/
じてんしゃくかん /自転車区間/
じてんしゃざっし /自転車雑誌/
じてんしゃせいさんしゃ /自転車生産者/
じてんしゃせんようどう /自転車専用道/
じてんしゃつうがく /自転車通学/
じてんしゃつうきん /自転車通勤/
じてんしゃどう /自転車道/
じてんしゃどうよう /自転車同様/
じてんしゃぶひん /自転車部品/
じてんしゃほんたい /自転車本体/
じてんしゃや /自転車屋/
じてんしゃよう /自転車用/
じてんしゃようくつ /自転車用靴/
じてんしゃりょこう /自転車旅行/
じてんしゃれき /自転車歴/
じてんしゅうき /自転周期/
じてんじく /自転軸/
じてんせつ /自転説/
じてんそくど /自転速度/
じてんひょうじ /時点表示/
じでん /自伝/
じでんてきさくひん /自伝的作品/
じとう /地頭/字統/
じとく /自得/
じどう /自動/児童/耳道/
じどううんてん /自動運転/
じどうえんそう /自動演奏/
じどうえんそうきかい /自動演奏機械/
じどうえんちょう /自動延長/
じどうおうとう /自動応答/
じどうおうとうでんわ /自動応答電話/
じどうおうふく /自動往復/
じどうか /自動化/
じどうかいぎょう /自動改行/
じどうかいけつ /自動解結/
じどうかいさつ /自動改札/
じどうかいさつか /自動改札化/
じどうかいさつき /自動改札機/
じどうかいせつ /自動解説/
じどうかいちょう /児童会長/
じどうかいとう /自動解凍/
じどうかいひょう /自動開票/
じどうかいふく /自動回復/
じどうかくてい /自動確定/
じどうかんそうき /自動乾燥機/
じどうかんり /自動管理/
じどうがくえん /児童学園/
じどうがくしゅうしすてむ /自動学習システム/
じどうがた /自動型/
じどうがっき /自動楽器/
じどうがっしょうだん /児童合唱団/
じどうがほう /児童画報/
じどうきかんにんしき /自動器官認識/
じどうきどう /自動起動/
じどうきどうじ /自動起動時/
じどうきゅうし /自動給紙/
じどうきりかえ /自動切換/自動切替/
じどうぎれ /自動切/
じどうけいさん /自動計算/
じどうけいそく /自動計測/
じどうけいそくよう /自動計測用/
じどうけんさ /自動検査/
じどうけんしゅつ /自動検出/
じどうけんしょう /自動検証/
じどうけんばいき /自動券売機/
じどうこうえん /児童公園/
じどうごうせい /自動合成/
じどうさいはっしん /自動再発信/
じどうさくじょ /自動削除/
じどうさくせい /自動作成/
じどうさくせいきのう /自動作成機能/
じどうさっきょく /自動作曲/
じどうざっし /児童雑誌/
じどうし /自動詞/
じどうしきべつ /自動識別/
じどうしはらいき /自動支払機/
じどうしゃ /自動車/
じどうしゃあいこうしゃ /自動車愛好者/
じどうしゃいがい /自動車以外/
じどうしゃかいたいや /自動車解体屋/
じどうしゃかさい /自動車火災/
じどうしゃかんけい /自動車関係/
じどうしゃかんれん /自動車関連/
じどうしゃがいしゃ /自動車会社/
じどうしゃがっこう /自動車学校/
じどうしゃきぎょう /自動車企業/
じどうしゃきょうかい /自動車協会/
じどうしゃきょうしゅうじょ /自動車教習所/
じどうしゃぎょうかい /自動車業界/
じどうしゃけんさひょう /自動車検査票/
じどうしゃこうがく /自動車工学/
じどうしゃこうじょう /自動車工場/
じどうしゃこうつう /自動車交通/
じどうしゃざっし /自動車雑誌/
じどうしゃしけんじょう /自動車試験場/
じどうしゃしゃかい /自動車社会/
じどうしゃしゅとくぜい /自動車取得税/
じどうしゃしんこうかい /自動車振興会/
じどうしゃじこ /自動車事故/
じどうしゃせいさくしょ /自動車製作所/
じどうしゃせんしゅ /自動車選手/
じどうしゃせんしんこく /自動車先進国/
じどうしゃせんよう /自動車専用/
じどうしゃせんようどう /自動車専用道/
じどうしゃぜい /自動車税/
じどうしゃつうきんしゃ /自動車通勤者/
じどうしゃでんわ /自動車電話/自動者電話/
じどうしゃとうろく /自動車登録/
じどうしゃどう /自動車道/
じどうしゃどうろ /自動車道路/
じどうしゃはいしゅつ /自動車排出/
じどうしゃばんぐみ /自動車番組/
じどうしゃひょうろんか /自動車評論家/
じどうしゃぶ /自動車部/
じどうしゃぶんか /自動車文化/
じどうしゃほゆうりつ /自動車保有率/
じどうしゃや /自動車屋/
じどうしゃゆうせん /自動車優先/
じどうしゃゆそう /自動車輸送/
じどうしゃよう /自動車用/
じどうしゃようご /自動車用語/
じどうしゃようとりょう /自動車用塗料/
じどうしゃりようしゃ /自動車利用者/
じどうしゅうけい /自動集計/
じどうしゅうせい /自動修正/
じどうしゅうりょう /自動終了/
じどうしょ /児童書/
じどうしょうこうき /自動昇降機/
じどうしょうめい /自動証明/
じどうしょうめいき /自動証明機/
じどうしょうめつ /自動消滅/
じどうしょり /自動処理/
じどうじっこう /自動実行/
じどうじゅしん /自動受信/
じどうせいぎょ /自動制御/
じどうせいぎょこうがく /自動制御工学/
じどうせいさんき /自動清算機/自動精算機/
じどうせいせい /自動生成/
じどうせいせいほう /自動生成法/
じどうせってい /自動設定/
じどうせんしゃき /自動洗車機/
じどうせんたく /自動選択/
じどうせんたくき /自動洗濯機/
じどうそうきん /自動送金/
じどうそうさ /自動操作/
じどうそうしん /自動送信/
じどうそうじゅう /自動操縦/
じどうそうちゃく /自動装着/
じどうそうちゃくがた /自動装着型/
じどうそうふ /自動送付/
じどうたいおう /自動対応/
じどうちゃっか /自動着火/
じどうちゅうしゅつ /自動抽出/
じどうちょうせい /自動調整/
じどうちょうせいはんい /自動調整範囲/
じどうついじゅう /自動追従/
じどうてあて /児童手当/
じどうていぎ /自動定義/
じどうていせい /自動訂正/
じどうてき /自動的/
じどうてきよう /自動適用/
じどうてんそう /自動転送/
じどうてんぷ /自動添付/
じどうてんめつ /自動点滅/
じどうてんやく /自動点訳/
じどうとうこう /自動投稿/
じどうとうひょう /自動投票/
じどうとうろく /自動登録/
じどうにゅうりょく /自動入力/
じどうにりん /自動二輪/
じどうにりんしゃ /自動二輪車/
じどうにりんめんきょ /自動二輪免許/
じどうにんぎょう /自動人形/
じどうにんしき /自動認識/
じどうはっしん /自動発信/
じどうはつばい /自動発売/
じどうはんてい /自動判定/
じどうはんていほうしき /自動判定方式/
じどうはんばいき /自動販売機/
じどうはんべつ /自動判別/
じどうばんそう /自動伴奏/
じどうびょうが /自動描画/
じどうふか /自動付加/
じどうふくしほう /児童福祉法/
じどうふくせいきき /自動複製機器/
じどうぶんかつ /自動分割/
じどうぶんかつきのう /自動分割機能/
じどうぶんがく /児童文学/
じどうへいれつか /自動並列化/
じどうへんかん /自動変換/
じどうへんこう /自動変更/
じどうへんすう /自動変数/
じどうへんそう /自動返送/
じどうへんそく /自動変速/
じどうへんそくき /自動変速機/
じどうへんそくしゃ /自動変速車/
じどうへんとう /自動返答/
じどうへんばい /自動変倍/
じどうほせい /自動補正/
じどうほんやく /自動翻訳/
じどうほんやくき /自動翻訳機/
じどうほんやくでんわ /自動翻訳電話/
じどうまきもどし /自動巻き戻し/
じどうまど /自動窓/
じどうまんが /児童漫画/
じどうみぎそろえ /自動右揃え/
じどうよやく /自動予約/
じどうりょうがえき /自動両替機/
じどうれんけつ /自動連結/
じどうれんけつき /自動連結器/
じどうろくが /自動録画/
じどうろこう /自動露光/
じどうろしゅつ /自動露出/
じどうろしゅつちょうせい /自動露出調整/
じどり /地鶏/
じない /耳内/
じなり /地鳴り/
じなん /次男/二男/
じなんぼう /次男坊/
じにん /辞任/自任/自認/
じにんご /辞任後/
じにんせつ /辞任説/
じぬし /地主/
じねつ /地熱/
じねん /自然/
じねんど /次年度/
じねんどいこう /次年度以降/
じはい /字牌/
じはく /自白/
じはくざい /自白剤/
じはだ /地肌/
じはつ /自発/次発/
じはついし /自発意思/
じはつこうい /自発行為/
じはつせい /自発性/
じはつてき /自発的/
じはつてきいし /自発的意志/
じはつてきうんよう /自発的運用/
じはつてきこうどう /自発的行動/
じはつてきさんか /自発的参加/
じはつてきせいしん /自発的精神/
じはつほうでん /自発放電/
じはん /時半/次版/
じはんき /自販機/
じはんきかかく /自販機価格/
じはんころ /時半頃/
じば /磁場/地場/
じばいせき /自賠責/
じばいせきほけん /自賠責保険/
じばく /自爆/自縛/地縛/
じばくそうち /自爆装置/
じばくれい /自縛霊/
じばさんぎょう /地場産業/
じばちゅう /磁場中/
じばら /自腹/
じばん /地盤/次版/
じばんちんか /地盤沈下/
じぱい /字牌/
じひ /自費/慈悲/
じひさんか /自費参加/
じひしゅっぱん /自費出版/
じひつ /自筆/
じひつしょうしょ /自筆証書/
じひつふ /自筆譜/
じひびき /地響き/
じひょう /辞表/時評/次表/恃憑/
じひょうじ /字表記/
じび /耳鼻/
じびいんこう /耳鼻咽喉/
じびいんこうか /耳鼻咽喉科/
じびか /耳鼻科/
じびき /字引/辞引/
じびょう /持病/
じびょうたいじ /持病退治/
じふ /自負/慈父/
じふく /自腹/地覆/地幅/
じふぶき /地吹雪/
じふへん /時不変/
じふん /時分/
じぶ /治部/
じぶく /地覆/地幅/
じぶつ /事物/
じぶもん /自部門/
じぶん /自分/時分/
じぶんあて /自分宛/
じぶんいがい /自分以外/
じぶんかって /自分勝手/
じぶんかつ /時分割/
じぶんかつしょり /時分割処理/
じぶんこじん /自分個人/
じぶんごのみ /自分好み/
じぶんしだい /自分次第/
じぶんじしん /自分自身/
じぶんじしんいがい /自分自身以外/
じぶんせんよう /自分専用/
じぶんたち /自分たち/自分達/
じぶんちゅうしん /自分中心/
じぶんひとり /自分一人/
じぶんほんい /自分本位/
じぶんめいぎ /自分名義/
じぶんよう /自分用/
じぶんりゅう /自分流/
じへいしょう /自閉症/
じへいしょうじ /自閉症児/
じへん /事変/時変/事變/
じへんしんごう /時変信号/
じへんまえ /事変前/
じべた /地べた/
じべん /自弁/
じぺーじ /次頁/次ページ/
じほう /時報/
じほうばんぐみ /時報番組/
じほく /磁北/
じほくせん /磁北線/
じぼ /字母/慈母/
じぼう /自暴/
じぼうじき /自暴自棄/
じぼひょう /字母表/
じま /島/嶋/縞/嶌/
じまい /仕舞い/仕舞/
じまえ /自前/時前/
じまく /字幕/
じまくいり /字幕入り/
じまくばん /字幕版/
じまくほうそう /字幕放送/
じまひ /仕舞い/
じまん /自慢/自漫/
じまんげ /自慢気/
じまんばなし /自慢話/
じみ /地味/滋味/
じみち /地道/
じみめ /地味目/
じみん /自民/
じみんとう /自民党/
じみんとうせいけん /自民党政権/
じみんとうぶんきょうぞく /自民党文教族/
じみんどくせん /自民独占/
じむ /事務/ジム/
じむいす /事務椅子/
じむいん /事務員/
じむかた /事務方/
じむかちょう /事務課長/
じむかん /事務官/
じむかんきょう /事務環境/
じむかんそか /事務簡素化/
じむき /事務機/事務器/
じむききてん /事務機器展/
じむきょく /事務局/
じむきょくけいゆ /事務局経由/
じむきょくけいゆう /事務局経由/
じむきょくしようらん /事務局使用覧/
じむきょくだいり /事務局代理/
じむきょくちょう /事務局長/
じむけい /事務系/
じむけいさん /事務計算/
じむさぎょう /事務作業/
じむしつ /事務室/
じむしょ /事務所/
じむしょいてん /事務所移転/
じむしょうもうひん /事務消耗品/
じむしょかんけい /事務所関係/
じむしょがわ /事務所側/
じむしょく /事務職/
じむしょり /事務処理/
じむしょりひよう /事務処理費用/
じむしょるい /事務書類/
じむじょう /事務上/
じむじょし /事務女子/
じむそうちょう /事務総長/
じむたんとうしゃ /事務担当者/
じむちょう /事務長/
じむていいん /事務定員/
じむてき /事務的/
じむてきれんらく /事務的連絡/
じむてつづき /事務手続き/
じむとう /事務棟/
じむひ /事務費/
じむぶ /事務部/
じむぶちょう /事務部長/
じむぶちょうしつ /事務部長室/
じむぶもん /事務部門/
じむほさいん /事務補佐員/
じむや /事務屋/
じむよう /事務用/
じむようひん /事務用品/
じむれんらく /事務連絡/
じむれんらくよう /事務連絡用/
じめい /自明/字名/
じめいかい /自明解/
じめつ /自滅/
じめつこうい /自滅行為/
じめん /地面/字面/
じめんてんかい /字面展開/
じもく /耳目/
じもくじ /甚目寺/
じもと /地元/
じもといがい /地元以外/
じもといしき /地元意識/
じもとがくせい /地元学生/
じもとけいさつ /地元警察/
じもとこうこうせい /地元高校生/
じもとさいしゅうせん /地元最終戦/
じもとし /地元紙/
じもとしこう /地元指向/
じもとしこうせい /地元指向性/
じもとしほん /地元資本/
じもとしゃ /地元車/
じもとしゅっしん /地元出身/
じもとしょうてんがい /地元商店街/
じもとしょうぼう /地元消防/
じもとしんぶん /地元新聞/
じもとじちかい /地元自治会/
じもとせつめいかい /地元説明会/
じもとせんしゅつ /地元選出/
じもとぜい /地元勢/
じもとちょうみん /地元町民/
じもとみっちゃく /地元密着/
じもとみっちゃくがた /地元密着型/
じもとみん /地元民/
じもとゆうり /地元有利/
じもよう /地模様/
じもん /次問/自問/字紋/
じもんじとう /自問自答/
じゃ /邪/蛇/者/闍/麝/
じゃーなりすと /ジャーナリスト/
じゃーなりずむ /ジャーナリズム/
じゃーなる /ジャーナル/
じゃあく /邪悪/
じゃき /邪気/邪鬼/
じゃきょう /邪教/
じゃく /弱/寂/惹/若/雀/搦/鉐/
じゃくえんさん /弱塩酸/
じゃくおん /弱音/
じゃくかりょく /弱火力/
じゃくきょうちゅう /弱強中/
じゃくけいしき /弱形式/
じゃくさん /弱酸/
じゃくさんせい /弱酸性/
じゃくし /弱視/杓子/
じゃくししゃ /弱視者/
じゃくししゃよう /弱視者用/
じゃくしゃ /弱者/
じゃくしゃほご /弱者保護/
じゃくしょう /弱小/
じゃくしょうぎんこう /弱小銀行/
じゃくしょうこく /弱小国/
じゃくしょうさんぎょう /弱小産業/
じゃくしょうせいりょく /弱小勢力/
じゃくしん /弱震/
じゃくたい /弱体/
じゃくたいか /弱体化/
じゃくたいさんぎょう /弱体産業/
じゃくたいとうしゅじん /弱体投手陣/
じゃくちゅうきょう /弱中強/
じゃくちょう /寂聴/
じゃくちょうぼいん /弱長母音/
じゃくてん /弱点/
じゃくでん /弱電/
じゃくでんかい /弱電界/
じゃくどくすいとう /弱毒水痘/
じゃくにくきょうしょく /弱肉強食/
じゃくねん /若年/
じゃくねんしゃいん /若年社員/
じゃくねんせいろうじんびょう /若年性老人病/
じゃくねんそう /若年層/
じゃくねんれい /若年齢/
じゃくねんれいしゃ /若年齢者/
じゃくはい /若輩/弱輩/
じゃくはいもの /若輩者/
じゃくはく /弱拍/
じゃくやく /雀躍/
じゃくれいしゃ /弱冷車/
じゃくれいぼうしゃ /弱冷房車/
じゃぐち /蛇口/
じゃけっと /ジャケット/
じゃけん /邪険/邪剣/邪慳/
じゃこう /麝香/
じゃこういん /寂光院/
じゃし /邪視/
じゃしん /邪神/邪心/
じゃじゃうま /じゃじゃ馬/
じゃすい /邪推/
じゃすこ /ジャスコ/
じゃすと /ジャスト/
じゃすみん /ジャスミン/
じゃず /ジャズ/
じゃせい /邪正/
じゃそく /蛇足/
じゃっか /弱化/
じゃっかん /若干/弱冠/
じゃっかんえいきょう /若干影響/
じゃっかんき /若干気/
じゃっかんふあん /若干不安/
じゃっかんふあんてい /若干不安定/
じゃっかんへいさてき /若干閉鎖的/
じゃっかんむり /若干無理/
じゃっかんめい /若干名/
じゃっかんもんだい /若干問題/
じゃっかんゆうり /若干有利/
じゃっかんりょう /若干量/
じゃっかんわりだか /若干割高/
じゃっき /惹起/
じゃっく /惹句/
じゃどう /邪道/
じゃねん /邪念/
じゃばら /蛇腹/
じゃま /邪魔/
じゃまもの /邪魔物/
じゃむ /ジャム/
じゃり /砂利/
じゃりうんぱん /砂利運搬/
じゃりみち /砂利路/
じゃりゅう /邪龍/
じゃわ /爪哇/
じゃん /雀/
じゃんぐる /ジャングル/
じゃんごう /雀豪/
じゃんし /雀師/
じゃんそう /雀荘/
じゃんたく /雀卓/
じゃんぱー /ジャンパー/
じゃんぷ /ジャンプ/
じゃんぼ /ジャンボ/
じゃんる /ジャンル/
じゅ /受/樹/寿/需/授/綬/呪/儒/珠/嬬/壽/濡/咒/孺/懦/戍/聚/襦/豎/讎/讐/愀/鷲/竪/就/
じゅーくぼっくす /ジュークボックス/
じゅーす /ジュース/
じゅあつ /受圧/
じゅあん /寿庵/
じゅいち /寿一/
じゅう /十/従/重/住/銃/柔/獣/渋/縦/中/充/汁/什/戎/拾/10/从/從/揉/澁/澀/狃/獸/糅/絨/縱/蹂/鞣/廿/
じゅう> /重/
じゅうあつ /重圧/
じゅうあつかん /重圧感/重厚感/
じゅうい /十位/獣医/
じゅういおん /重イオン/
じゅういがくぶ /獣医学部/
じゅういがっか /獣医学科/
じゅういがっこう /獣医学校/
じゅういし /獣医師/
じゅういせん /順位戦/
じゅういち /十一/
じゅういちおく /十一億/
じゅういちがつ /１１月/十一月/霜月/
じゅういっぴき /十一匹/
じゅうえいそう /重営倉/
じゅうえん /十円/
じゅうえんだま /十円玉/
じゅうおう /十王/縦横/
じゅうおうか /縦横家/
じゅうおうまち /十王町/
じゅうおうむじん /縦横無尽/
じゅうおく /十億/
じゅうおん /重音/
じゅうか /住家/従価/銃火/
じゅうかい /重解/
じゅうかいき /重回帰/
じゅうかがく /重化学/
じゅうかく /縦隔/
じゅうかくしばくだん /重核子爆弾/
じゅうかしつ /重過失/
じゅうかぜい /従価税/
じゅうかん /縦貫/
じゅうかんきょう /住環境/
じゅうかんせん /縦貫線/
じゅうかんどう /縦貫道/
じゅうがつ /１０月/十月/十筑/神無月/
じゅうき /什器/銃器/重機/
じゅうきかい /重機械/
じゅうきこうへい /重機甲兵/
じゅうきざい /重機材/
じゅうきせい /銃規制/
じゅうきち /重吉/
じゅうきゅう /十九/
じゅうきゅうさい /十九歳/
じゅうきょ /住居/
じゅうきょあと /住居跡/
じゅうきょかんきょう /住居環境/
じゅうきょち /住居地/
じゅうきょひょうじ /住居表示/
じゅうきょひょうじばんごう /住居表示番号/
じゅうきょふほうしんにゅう /住居不法侵入/
じゅうきょようせんざい /住居用洗剤/
じゅうきんぞく /重金属/
じゅうぎょう /従業/
じゅうぎょういん /従業員/
じゅうぎょういんすう /従業員数/
じゅうぎょういんはんばい /従業員販売/
じゅうぐん /従軍/
じゅうぐんいあんふ /従軍慰安婦/
じゅうぐんきしゃ /従軍記者/
じゅうぐんしさい /従軍司祭/
じゅうけい /従兄/従系/重刑/
じゅうけいこう /重慶港/
じゅうけいしょう /重軽傷/
じゅうけいはんてん /重慶飯店/
じゅうけつ /充血/
じゅうけん /銃剣/住建/重検/
じゅうげき /銃撃/
じゅうげん /重言/
じゅうげんそこうせき /重元素鉱石/
じゅうこう /重工/重厚/銃口/重項/
じゅうこうぎょう /重工業/
じゅうこうげき /銃攻撃/
じゅうこつ /獸骨/
じゅうこん /重根/重婚/
じゅうご /十五/銃後/
じゅうごう /重合/
じゅうごうしょくばい /重合触媒/
じゅうごおく /十五億/
じゅうごひき /十五匹/
じゅうごや /十五夜/
じゅうさいぼう /柔細胞/
じゅうさつ /銃殺/
じゅうさつけい /銃殺刑/
じゅうさん /十三/
じゅうさんおく /十三億/
じゅうさんじょう /十三条/
じゅうさんびき /十三匹/
じゅうざい /重罪/
じゅうし /重視/従姉/従祀/獣脂/
じゅうしちにち /十七日/
じゅうしてい /従姉弟/
じゅうしまつ /十姉妹/
じゅうしゃ /従者/
じゅうしやま /十四山/
じゅうしょ /住所/
じゅうしょあて /住所宛/
じゅうしょう /重症/重傷/重賞/
じゅうしょうがい /重障害/
じゅうしょうきょうそう /重賞競争/重賞競走/
じゅうしょうせいは /重賞制覇/
じゅうしょく /住職/重職/
じゅうしょしめい /住所氏名/
じゅうしょしめいねんれい /住所氏名年齢/
じゅうしょち /住所地/
じゅうしょてき /住所的/
じゅうしょとうろくきのう /住所録機能/
じゅうしょなど /住所等/
じゅうしょひょうき /住所表記/
じゅうしょふめい /住所不明/
じゅうしょへんこう /住所変更/
じゅうしょらん /住所欄/
じゅうしょろく /住所録/
じゅうしん /重心/銃身/獣身/住心/重臣/
じゅうしんいち /重心位置/
じゅうしんいどう /重心移動/
じゅうしんけい /重心系/
じゅうしんてん /重心点/
じゅうじ /従事/十字/10時/十時/
じゅうじか /十字架/
じゅうじがた /十字形/
じゅうじぐん /十字軍/
じゅうじけい /十字形/
じゅうじしゃ /従事者/
じゅうじしゃめんきょ /従事者免許/
じゅうじしゃめんきょしょう /従事者免許証/
じゅうじじょう /十字状/
じゅうじじょうにさぶんし /十字状二叉分枝/
じゅうじじょうふたまたぶんし /十字状二又分枝/
じゅうじたいせい /十字対生/
じゅうじつ /充実/
じゅうじつかん /充実感/
じゅうじつき /充実期/
じゅうじつど /充実度/
じゅうじつひ /充実費/
じゅうじにさぶんし /十字二叉分枝/
じゅうじふたまたぶんし /十字二又分枝/
じゅうじや /十字屋/
じゅうじゅう /重々/
じゅうじゅん /従順/重巡/
じゅうじょう /重畳/十条/
じゅうじょうえき /十条駅/
じゅうじょうせいし /十條製紙/
じゅうじょうどおり /十条通り/
じゅうじろ /十字路/
じゅうじろふきん /十字路付近/
じゅうじん /獣神/獣人/
じゅうすい /重水/
じゅうすいそ /重水素/
じゅうすいそこうせき /重水素鉱石/
じゅうすう /十数/
じゅうすうかい /十数回/
じゅうすうきょく /十数局/
じゅうすうこ /十数戸/
じゅうすうつう /十数通/
じゅうすうにん /十数人/
じゅうすうねん /十数年/
じゅうすうねんまえ /十数年前/
じゅうすうばい /十数倍/
じゅうすうびょう /十数秒/
じゅうすうふん /十数分/
じゅうすうほん /十数本/
じゅうすうまん /十数万/
じゅうすうまんえん /十数万円/
じゅうせい /獣性/銃声/
じゅうせき /重責/
じゅうせきぶん /重積分/
じゅうせんし /重戦士/
じゅうぜい /重税/
じゅうぜん /従前/
じゅうそう /縦走/重奏/重層/重曹/十三/重装/銃創/重秦/
じゅうそうかん /十三間/
じゅうそうきへい /重装機兵/
じゅうそうきょく /重奏曲/
じゅうそうこう /重装甲/
じゅうそうとちゅう /縦走途中/
じゅうそうび /重装備/
じゅうそく /充足/
じゅうそくかのう /充足可能/
じゅうそくかのうせい /充足可能性/
じゅうそくふのう /充足不能/
じゅうそしき /柔組織/
じゅうそしきさいぼう /柔組織細胞/
じゅうそつ /従卒/
じゅうぞう /十三/重像/
じゅうぞく /従属/
じゅうぞくこく /従属国/
じゅうぞくし /従属子/
じゅうぞくせい /従属性/
じゅうぞくせつ /従属節/
じゅうたい /渋滞/重体/縦隊/
じゅうたいかくご /渋滞覚悟/
じゅうたいかんわ /渋滞緩和/
じゅうたいこうさてん /渋滞交差点/
じゅうたいさいこうび /渋滞最後尾/
じゅうたいじ /渋滞時/
じゅうたいじょうきょう /渋滞状況/
じゅうたいちゅう /渋滞中/
じゅうたいほうていしき /状態方程式/
じゅうたいろ /渋滞路/
じゅうたく /住宅/
じゅうたくか /住宅化/
じゅうたくかいはつ /住宅開発/
じゅうたくがい /住宅街/
じゅうたくきんゆうこうこ /住宅金融公庫/
じゅうたくけんせつひ /住宅建設費/
じゅうたくこうにゅうじ /住宅購入時/
じゅうたくさんぎょう /住宅産業/
じゅうたくしんぽうしゃ /住宅新報社/
じゅうたくじじょう /住宅事情/
じゅうたくじょうほう /住宅情報/
じゅうたくせいさく /住宅政策/
じゅうたくせつび /住宅設備/
じゅうたくだんち /住宅団地/
じゅうたくち /住宅地/
じゅうたくちず /住宅地図/
じゅうたくてあて /住宅手当/
じゅうたくひ /住宅費/
じゅうたくひほじょ /住宅費補助/
じゅうたくひよう /住宅費用/
じゅうたくほじょ /住宅補助/
じゅうたくほじょてあて /住宅補助手当/
じゅうたくまえ /住宅前/
じゅうたくもんだい /住宅問題/
じゅうたくよう /住宅用/
じゅうたん /絨毯/絨緞/
じゅうたんさん /重炭酸/
じゅうたんばくげき /絨毯爆撃/
じゅうだい /重大/十代/十大/
じゅうだいしゃ /従台車/
じゅうだいせい /重大性/
じゅうだいはっぴょう /重大発表/
じゅうだいもんだい /重大問題/
じゅうだん /縦断/銃弾/銃彈/十段/
じゅうだんきこう /縦断紀行/
じゅうだんせん /十段戦/
じゅうだんめん /縦断面/
じゅうちん /重鎮/
じゅうていおん /重低音/
じゅうてん /重点/充填/
じゅうてんか /重点化/
じゅうてんけんきゅう /重点研究/
じゅうてんこうりつ /充填効率/
じゅうてんてき /重点的/
じゅうてんりょういき /重点領域/
じゅうてんりょういきけんきゅう /重点領域研究/
じゅうてんりょういきちょうしょ /重点領域調書/
じゅうでん /充電/
じゅうでんかのう /充電可能/
じゅうでんかんりょう /充電完了/
じゅうでんかんりょうご /充電完了後/
じゅうでんき /充電器/充電機/
じゅうでんきかん /充電期間/
じゅうでんこうりつ /充電効率/
じゅうでんご /充電後/
じゅうでんしき /充電式/
じゅうでんじ /充電時/
じゅうでんじかん /充電時間/
じゅうでんじょうたい /充電状態/
じゅうでんち /充電池/
じゅうでんちゅう /充電中/
じゅうでんでんりゅう /充電電流/
じゅうでんふかのう /充電不可能/
じゅうでんふりょう /充電不良/
じゅうでんよう /充電用/
じゅうでんりょう /充電量/
じゅうとう /充当/
じゅうとうろく /重登録/
じゅうとく /重篤/
じゅうとこうだん /住都公団/
じゅうとざんぐつ /重登山靴/
じゅうど /重度/
じゅうどう /柔道/
じゅうどうか /柔道家/
じゅうどうぎ /柔道着/
じゅうどうしょうねん /柔道少年/
じゅうどうぶ /柔道部/
じゅうどしょうがい /重度障害/
じゅうななにち /十七日/
じゅうなん /柔軟/
じゅうなんか /柔軟化/
じゅうなんかい /十何回/
じゅうなんぎょう /十何行/
じゅうなんざい /柔軟剤/
じゅうなんせい /柔軟性/
じゅうなんたいそう /柔軟体操/
じゅうなんにち /十何日/
じゅうなんねん /十何年/
じゅうなんまい /十何枚/
じゅうなんれんしょう /十何連勝/
じゅうに /１２/十二/
じゅうにおく /十二億/
じゅうにかげつ /十二ヶ月/十二カ月/
じゅうにがつ /１２月/極月/師走/十二月/
じゅうにく /獣肉/
じゅうにし /十二支/子丑寅卯辰巳午未申酉戌亥/
じゅうにしちょう /十二指腸/
じゅうにしと /十二使徒/
じゅうにひき /十二匹/
じゅうにひとえ /十二単/
じゅうにぶん /十二分/
じゅうにほうい /十二方位/
じゅうにん /住人/十人/重任/
じゅうにんたち /住人達/
じゅうにんといろ /十人十色/
じゅうねん /十年/
じゅうねんいじょう /十年以上/
じゅうねんいじょうあと /十年以上後/
じゅうねんいじょうまえ /十年以上前/
じゅうねんご /十年後/
じゅうねんまえ /十年前/
じゅうねんめ /十年目/
じゅうはち /十八/
じゅうはちぎんこう /十八銀行/
じゅうはちばん /十八番/
じゅうはん /従犯/重版/
じゅうばい /十倍/
じゅうばいいじょう /十倍以上/
じゅうばこ /重箱/
じゅうばこよみ /重箱読み/
じゅうばつ /重罰/
じゅうばん /十番/重版/
じゅうばんしょうてんがい /十番商店街/
じゅうばんみてい /重版未定/
じゅうびょう /重病/
じゅうびょうたんい /十秒単位/
じゅうびょうにん /重病人/
じゅうふか /重負荷/
じゅうふく /重複/
じゅうふくぎみ /重複気味/
じゅうぶ /十分/
じゅうぶん /十分/充分/重文/
じゅうぶんあんてい /十分安定/
じゅうぶんかくほ /十分確保/
じゅうぶんかっそうかのう /十分滑走可能/
じゅうぶんかのう /十分可能/
じゅうぶんしょうち /十分承知/
じゅうぶんしようかのう /十分使用可能/
じゅうぶんじつげんかのう /十分実現可能/
じゅうぶんじょうけん /十分条件/
じゅうぶんせい /十分性/充分性/
じゅうぶんたいおう /充分対応/
じゅうぶんちゅうい /十分注意/
じゅうぶんつうよう /充分通用/
じゅうぶんはいりょ /十分配慮/
じゅうぶんまんぞく /十分満足/
じゅうぶんゆうこう /十分有効/
じゅうべえ /十兵衛/十平衛/
じゅうほう /銃砲/重砲/
じゅうほうでん /充放電/
じゅうほうでんがた /充放電型/
じゅうぼく /従僕/
じゅうまい /十枚/
じゅうまん /十万/充満/
じゅうまんえん /十万円/
じゅうまんにん /十万人/
じゅうまんばい /十万倍/
じゅうまんぶ /十万部/
じゅうまんほう /充満法/
じゅうみん /住民/
じゅうみんうんどう /住民運動/
じゅうみんか /住民課/
じゅうみんがわ /住民側/
じゅうみんきほんだいちょう /住民基本台帳/
じゅうみんしゅたい /住民主体/
じゅうみんぜい /住民税/
じゅうみんぜいがく /住民税額/
じゅうみんとうろく /住民登録/
じゅうみんとうろくしょう /住民登録証/
じゅうみんひょう /住民票/住民表/
じゅうめい /十名/
じゅうめん /渋面/従免/
じゅうもう /絨毛/
じゅうもうまく /絨毛膜/
じゅうもんじ /十文字/
じゅうもんじこうこう /十文字高校/
じゅうもんじばし /十文字橋/
じゅうやく /重役/
じゅうゆ /重油/
じゅうよう /重要/充用/
じゅうようかだい /重要課題/
じゅうようきみつ /重要機密/
じゅうようぎだい /重要議題/
じゅうようけっていじこう /重要決定事項/
じゅうようこうもく /重要項目/
じゅうようご /重要語/
じゅうようさく /重要作/
じゅうようさくひん /重要作品/
じゅうようさんこうにん /重要参考人/
じゅうようし /重要視/重陽子/
じゅうようしりょう /重要資料/
じゅうようじこう /重要事項/
じゅうようじんぶつ /重要人物/
じゅうようせい /重要性/
じゅうようてん /重要点/
じゅうようど /重要度/
じゅうようどひょうてい /重要度評定/
じゅうような /重要な/
じゅうようほあんぶひん /重要保安部品/
じゅうようもんだい /重要問題/
じゅうようるいだい /重要類題/
じゅうよん /十四/
じゅうよんおく /十四億/
じゅうよんさい /十四歳/
じゅうよんひき /十四匹/
じゅうらい /従来/
じゅうらいがた /従来型/
じゅうらいき /従来機/
じゅうらいきかく /従来規格/
じゅうらいきしゅ /従来機種/
じゅうらいぎじゅつ /従来技術/
じゅうらいしゅほう /従来手法/
じゅうらいてき /従来的/
じゅうらいひ /従来比/
じゅうらいほう /従来法/
じゅうらいほうしき /従来方式/
じゅうらん /縦覧/
じゅうりゅうし /重粒子/
じゅうりょう /重量/従量/十両/
じゅうりょうかん /重量感/
じゅうりょうきゅう /重量級/
じゅうりょうけい /重量計/
じゅうりょうさ /重量差/
じゅうりょうしゃ /重量車/
じゅうりょうせい /従量制/
じゅうりょうぜい /従量税/重量税/
じゅうりょうぜいかんぷ /重量税還付/
じゅうりょうそくてい /重量測定/
じゅうりょうてき /重量的/
じゅうりょうはいぶん /重量配分/
じゅうりょうひ /重量比/
じゅうりょうぶつ /重量物/
じゅうりょうへんか /重量変化/
じゅうりょく /重力/
じゅうりょくいがい /重力以外/
じゅうりょくいど /重力井戸/
じゅうりょくかそく /重力加速/
じゅうりょくかそくど /重力加速度/
じゅうりょくけい /重力系/重力計/
じゅうりょくけんきゅうじょ /重力研究所/
じゅうりょくけんない /重力圏内/
じゅうりょくげん /重力源/
じゅうりょくこうばい /重力勾配/
じゅうりょくしき /重力式/
じゅうりょくじば /重力磁場/
じゅうりょくじょう /重力場/
じゅうりょくじょういち /重力場位置/
じゅうりょくせいぎょ /重力制御/
じゅうりょくそうごさよう /重力相互作用/
じゅうりょくていすう /重力定数/
じゅうりょくは /重力波/
じゅうりょくはけんしゅつ /重力波検出/
じゅうりょくはほう /重力波砲/
じゅうりょくはぼうえんきょう /重力波望遠鏡/
じゅうりょくふほうかい /重力負崩壊/
じゅうりょくぶっしつ /重力物質/
じゅうりょくほうかい /重力崩壊/
じゅうりょくほうこう /重力方向/
じゅうりょくほうていしき /重力方程式/
じゅうりょくりだつ /重力離脱/
じゅうりん /蹂躙/蹂躪/
じゅうれつ /縦列/
じゅうれつちゅうしゃ /縦列駐車/
じゅうれん /重連/
じゅうろう /十郎/
じゅうろうた /十郎太/
じゅうろうどう /重労働/
じゅうろく /十六/
じゅうろくぎんこう /十六銀行/
じゅうろくさい /十六歳/
じゅうろくしん /十六進/１６進/
じゅうろくちゃ /十六茶/
じゅうろくや /十六夜/
じゅえき /受益/樹液/
じゅえきしゃ /受益者/
じゅえきしゃふたん /受益者負担/
じゅおん /受音/
じゅおんいち /受音位置/
じゅおんがわ /受音側/
じゅおんけい /受音系/
じゅおんてん /受音点/
じゅか /樹香/儒家/樹下/
じゅかい /樹海/
じゅかん /樹幹/
じゅがく /儒学/
じゅきゅう /受給/需給/
じゅきょう /儒教/受教/授亨/
じゅぎょう /授業/
じゅぎょういがい /授業以外/
じゅぎょうかもく /授業科目/
じゅぎょうしゅっせき /授業出席/
じゅぎょうじかん /授業時間/
じゅぎょうちゅう /授業中/
じゅぎょうてんかい /授業展開/
じゅぎょうとうろく /授業登録/
じゅぎょうないよう /授業内容/
じゅぎょうは /授業/
じゅぎょうまえ /授業前/
じゅぎょうよう /授業用/
じゅぎょうりょう /授業料/
じゅぎょうりょうめんじょ /授業料免除/
じゅく /熟/塾/宿/孰/
じゅくいん /塾員/
じゅくこう /熟考/塾高/塾講/
じゅくこうし /塾講師/
じゅくご /熟語/
じゅくし /熟視/
じゅくじくん /熟字訓/
じゅくじょ /熟女/
じゅくすい /熟睡/
じゅくせい /熟成/塾生/
じゅくせいど /熟成度/
じゅくたつ /熟達/
じゅくたつか /熟達化/
じゅくたつかかてい /熟達化過程/
じゅくたつしゃ /熟達者/
じゅくち /熟知/
じゅくどく /熟読/
じゅくない /塾内/
じゅくねん /熟年/
じゅくりょ /熟慮/
じゅくれん /熟練/
じゅくれんこう /熟練工/
じゅくれんしゃ /熟練者/
じゅくれんち /熟練値/
じゅくれんど /熟練度/
じゅけい /受刑/
じゅけいしゃ /受刑者/
じゅけつしゃ /受血者/
じゅけん /受験/受検/授権/
じゅけんえいご /受験英語/
じゅけんかいじょう /受験会場/
じゅけんかいすう /受験回数/
じゅけんかもく /受験科目/
じゅけんきかい /受験機会/
じゅけんきぼうしゃ /受験希望者/
じゅけんきょかしょ /受験許可書/
じゅけんげんご /受験言語/
じゅけんこう /受験校/
じゅけんさんぎょう /受験産業/
じゅけんさんこうしょ /受験参考書/
じゅけんざっし /受験雑誌/
じゅけんしかく /受験資格/
じゅけんしつ /受験室/
じゅけんしゃ /受験者/受検者/
じゅけんしゃすう /受験者数/
じゅけんじゅんび /受験準備/
じゅけんすうがく /受験数学/
じゅけんせい /受験生/
じゅけんせんそう /受験戦争/
じゅけんち /受験地/
じゅけんばんごう /受験番号/
じゅけんひ /受験費/
じゅけんひょう /受験票/
じゅけんべんきょう /受験勉強/
じゅけんまえ /受験前/
じゅけんよう /受験用/
じゅけんりょう /受験料/
じゅこう /受講/受光/
じゅこうきげん /受講期限/
じゅこうきのう /受光機能/
じゅこうさいぼう /受光細胞/
じゅこうしゃ /受講者/
じゅこうしゃていいん /受講者定員/
じゅこうしょうがい /受光障害/
じゅこうせい /受講生/
じゅこうそし /受光素子/
じゅこうとうろくしゃ /受講登録者/
じゅこうひょう /受講票/
じゅこうぶ /受光部/
じゅこうぶぶん /受光部分/
じゅこうへいめん /受光平面/
じゅこうめん /受光面/
じゅこうめんせき /受光面積/
じゅこうよていしゃ /受講予定者/
じゅこうりょう /受講料/
じゅこん /樹根/
じゅさつ /呪殺/
じゅし /樹脂/儒子/孺子/
じゅしせい /樹脂製/樹脂性/
じゅしどう /樹脂道/
じゅしゃ /儒者/
じゅしゅ /樹種/
じゅしょう /受賞/授賞/受章/
じゅしょうけいけん /授賞経験/
じゅしょうこうえん /受賞講演/授賞講演/
じゅしょうさく /受賞作/
じゅしょうしき /授賞式/受賞式/
じゅしょうしゃ /受賞者/授賞者/
じゅしょうたいしょう /授賞対象/
じゅしん /受信/受身/受診/
じゅしんかいすう /受信回数/
じゅしんかいろ /受信回路/
じゅしんかんど /受信感度/
じゅしんがわ /受信側/
じゅしんき /受信機/受信器/
じゅしんけいしき /受信形式/
じゅしんけいやくりょう /受信契約料/
じゅしんけっか /受信結果/
じゅしんさき /受信先/
じゅしんしけん /受信試験/
じゅしんしゃ /受信者/
じゅしんしゅうはすう /受信周波数/
じゅしんしゅうはすうたい /受信周波数帯/
じゅしんじ /受信時/
じゅしんじっけん /受信実験/
じゅしんじょうきょう /受信状況/
じゅしんじょうたい /受信状態/
じゅしんせつび /受信設備/
じゅしんそうち /受信装置/
じゅしんそし /受信素子/
じゅしんたん /受信端/
じゅしんちてん /受信地点/
じゅしんつうち /受信通知/
じゅしんてん /受信点/
じゅしんとも /受信共/
じゅしんにん /受信人/
じゅしんび /受診日/
じゅしんふかのう /受信不可能/
じゅしんぶ /受信部/
じゅしんよう /受信用/
じゅしんりょう /受信料/
じゅしんりょうせいど /受信料制度/
じゅじゅ /授受/受授/
じゅじゅつ /呪術/
じゅじょう /樹状/
じゅじょうかいろ /樹状回路/
じゅじょうこうぞう /樹状構造/
じゅじょうとっき /樹状突起/
じゅすい /入水/
じゅず /数珠/
じゅせい /受精/授精/樹勢/
じゅせいらん /受精卵/
じゅせいりつ /授精率/
じゅそ /呪詛/呪咀/受訴/
じゅそうしんかんど /受送信感度/
じゅぞう /受像/受贈/
じゅぞうき /受像機/
じゅたい /受胎/
じゅたいりつ /受胎率/
じゅたく /受託/
じゅたくしゅうわいようぎ /受託収賄容疑/
じゅだい /入内/
じゅだく /受諾/
じゅだくしょ /受諾書/
じゅちゅう /受注/
じゅちゅうざん /受注残/
じゅちゅうせいさん /受注生産/
じゅちゅうび /受注日/
じゅちょう /受聴/
じゅちょういち /受聴位置/
じゅちょうかんきょう /受聴環境/
じゅちょうしゃ /受聴者/
じゅちょうめいりょうど /受聴明瞭度/
じゅっかい /十戒/述懐/十階/十誡/
じゅっかいき /十回忌/
じゅっかいてん /十回転/
じゅっかんじゅうにし /十干十二支/
じゅっこ /十個/
じゅっこう /熟考/
じゅっさく /術策/
じゅっしゅうねん /十周年/
じゅっしん /十進/１０進/10進/
じゅっしんすう /十進数/10進数/
じゅっしんすうひょうき /十進数表記/
じゅっしんぶんるいほう /十進分類法/
じゅっしんほう /十進法/
じゅっちゅう /十中/術中/
じゅっちゅうはっく /十中八九/
じゅっつう /十通/
じゅっつういじょう /十通以上/
じゅって /十手/
じゅっとく /拾得/
じゅっぱ /十羽/十把/
じゅっぱひとからげ /十把一絡/
じゅっぴき /十匹/
じゅっぷん /十分/
じゅっぷんかん /十分間/
じゅっぽ /十歩/
じゅつ /術/述/朮/恤/戌/
じゅつかい /述懐/
じゅつご /述語/術後/術語/
じゅつごきごう /述語記号/
じゅつごけいさん /述語計算/
じゅつごけいさんけい /述語計算系/
じゅつごそうき /術後早期/
じゅつごていぎ /術語定義/
じゅつごていすう /述語定数/
じゅつごぶ /述語部/
じゅつごろん /述語論/
じゅつごろんり /述語論理/
じゅつごろんりしき /述語論理式/
じゅつし /術師/
じゅつしき /術式/
じゅつしゃ /術者/
じゅつぜん /術前/
じゅつちゅう /術中/
じゅつてき /術的/
じゅつぶ /述部/
じゅつほう /術法/
じゅどう /受動/
じゅどうきつえん /受動喫煙/
じゅどうたい /受動態/
じゅどうてき /受動的/
じゅどうてききつえん /受動的喫煙/
じゅなん /受難/
じゅなんきょく /受難曲/
じゅにあ /ジュニア/
じゅにゅう /授乳/
じゅにゅうかんかく /授乳間隔/
じゅねーぶ /壽府/
じゅのう /受納/
じゅはい /受配/
じゅばく /呪縛/
じゅばん /襦袢/
じゅひ /樹皮/
じゅひょう /樹氷/
じゅひょうげん /樹氷原/
じゅふ /呪符/授付/
じゅふん /受粉/
じゅぶん /十分/
じゅへい /寿平/
じゅほう /呪法/
じゅみょう /寿命/
じゅもく /樹木/
じゅもん /呪文/
じゅもんこうげき /呪文攻撃/
じゅよ /授与/
じゅよう /需要/受容/
じゅようか /需要家/
じゅようき /受容器/
じゅようこうぞう /需要構造/
じゅようしゃ /需要者/
じゅようたい /受容体/
じゅようたいきっこうざい /受容体拮抗剤/
じゅようちょうせつ /需要調節/
じゅようとっしゅつ /需要突出/
じゅようぶ /受容部/
じゅようや /受容野/
じゅようよそく /需要予測/
じゅよしき /授与式/
じゅらい /入来/
じゅらいほう /従来法/
じゅらく /聚楽/
じゅらくだい /聚楽第/
じゅり /受理/ジュリ/朱里/珠理/樹里/樹理/寿理/
じゅりき /受理機/
じゅりすう /受理数/
じゅりつ /樹立/
じゅりつうち /受理通知/
じゅりみち /砂利道/
じゅりょう /受領/授領/
じゅりょういん /受領印/
じゅりょうしょ /受領書/
じゅりょうしょう /受領証/
じゅりりつ /受理率/
じゅりん /樹林/
じゅりんたい /樹林帯/
じゅれい /樹齢/樹苓/
じゅわ /受話/
じゅわき /受話器/
じゅわしゃ /受話者/
じゅん /順/純/準/潤/淳/巡/盾/旬/醇/遵/殉/循/楯/准/篤/馴/凖/徇/恂/洵/筍/笋/荀/蓴/詢/諄/惇/閏/隼/
じゅん> /準/
じゅんあい /純愛/
じゅんあつ /順圧/
じゅんあつせいぶん /順圧成分/
じゅんあつたいき /順圧大気/
じゅんあんくうこう /順安空港/
じゅんい /順位/准尉/準位/準尉/遵依/
じゅんいがい /順位外/
じゅんいけってい /順位決定/
じゅんいじゅん /順位順/
じゅんいせん /順位戦/
じゅんいち /淳一/純一/潤一/順一/准一/遵一/
じゅんいちろう /淳一郎/潤一郎/純一郎/順一郎/
じゅんいてん /順位点/
じゅんいにん /準委任/
じゅんいはっぴょう /順位発表/
じゅんいひょう /順位表/
じゅんいよそう /順位予想/
じゅんいん /準員/
じゅんうりあげ /純売上/
じゅんえいぎょうじょうたい /準営業状態/
じゅんえき /純益/準駅/
じゅんえん /順延/巡演/
じゅんおう /順応/
じゅんおうせい /順応性/
じゅんおおて /準大手/
じゅんおくり /順送り/
じゅんおん /純音/
じゅんか /純化/順化/馴化/
じゅんかい /巡回/
じゅんかいいん /準会員/
じゅんかいいんしょうにん /準会員承認/
じゅんかいいんとうろく /準会員登録/
じゅんかいぐん /巡回群/
じゅんかいし /巡回子/
じゅんかいしょうにん /巡回商人/
じゅんかいちゅう /巡回中/
じゅんかいむりょう /巡回無料/
じゅんかがくてき /純科学的/
じゅんかつ /潤滑/
じゅんかつざい /潤滑材/潤滑剤/
じゅんかつせいのう /潤滑性能/
じゅんかつゆ /潤滑油/
じゅんかめい /準加盟/
じゅんかん /循環/准看/旬刊/
じゅんかんき /循環器/
じゅんかんきかん /循環器官/
じゅんかんきけい /循環器系/
じゅんかんきのう /循環機能/
じゅんかんきゅうこう /循環急行/
じゅんかんけいとう /循環系統/
じゅんかんごし /准看護師;保健婦助産婦看護婦法一部改正による呼称変更/
じゅんかんしょうすう /循環小数/
じゅんかんせん /循環線/
じゅんかんぜんじあい /準完全試合/
じゅんかんていり /循環定理/
じゅんかんてき /循環的/
じゅんかんよう /循環用/
じゅんかんろんぽう /循環論法/
じゅんがくし /準学士/
じゅんきし /準棋士/
じゅんきゅう /準急/
じゅんきゅうこう /準急行/
じゅんきゅうしんじゅくいき /準急新宿行/
じゅんきゅうしんじゅくゆき /準急新宿行/
じゅんきゅうていしゃえき /準急停車駅/
じゅんきゅうへんせい /準急編成/
じゅんきゅうほんあつぎいき /準急本厚木行/
じゅんきゅうほんあつぎゆき /準急本厚木行/
じゅんきゅうよう /準急用/
じゅんきょ /準拠/
じゅんきょう /殉教/
じゅんきょうじゅ /準教授/准教授/
じゅんきょうち /殉教地/
じゅんきょきやく /準拠規約/
じゅんきょすう /純虚数/
じゅんきん /純金/
じゅんぎゃく /順逆/
じゅんぎょう /巡業/巡行/
じゅんぎょうきょり /巡行距離/
じゅんぎょうさき /巡業先/
じゅんぎん /純銀/
じゅんぐん /準群/
じゅんけい /順慶/
じゅんけいしきてき /準形式的/
じゅんけっしょう /準決勝/準結晶/
じゅんけつ /純潔/純血/準決/
じゅんけつしゅ /純血種/
じゅんけつしゅぎ /純血主義/
じゅんけん /巡検/
じゅんこ /絢子/順子/純子/ＪＵＮＫＯ/淳子/潤子/惇子/準子/
じゅんこう /巡航/純項/巡行/順光/巡幸/
じゅんこうかん /巡航艦/
じゅんこうしき /準公式/
じゅんこうじ /巡行時/
じゅんこうそく /準光速/
じゅんこうそくど /巡航速度/巡行速度/
じゅんこうちゅう /巡航中/巡行中/
じゅんこうむいん /準公務員/
じゅんこくさん /純国産/
じゅんさ /巡査/
じゅんさい /蓴菜/
じゅんさいあか /ジュンサイ亜科/Cabomboideae/
じゅんさつ /巡察/
じゅんさぶちょう /巡査部長/
じゅんさんそ /純酸素/
じゅんし /巡視/殉死/潤史/
じゅんしかん /准士官/
じゅんしすうじかん /準指数時間/
じゅんしてい /準指定/
じゅんしていちえき /準指定地駅/
じゅんしどういん /準指導員/
じゅんしゅ /遵守/順守/
じゅんしゅじこう /遵守事項/
じゅんしゅつりょく /準出力/
じゅんしゅふかのう /遵守不可能/
じゅんしゅやく /準主役/
じゅんしょう /准将/順昭/
じゅんしょく /殉職/潤色/
じゅんしょくしゃ /殉職者/
じゅんしょくどうしゃ /準食堂車/
じゅんしん /純真/純心/順心/
じゅんしんこうこう /純心高校/
じゅんしんじょがくえん /順心女学園/
じゅんしんじょし /純心女子/順心女子/
じゅんしんじょしがくえん /順心女子学園/
じゅんしんじょしこうこう /純心女子高校/
じゅんしんむく /純真無垢/
じゅんじ /順次/純次/淳二/淳司/順治/淳嗣/純司/純治/洵二/純二/順司/順二/
じゅんじかくてい /順次確定/
じゅんじけんさく /順次検索/
じゅんじしゅっか /順次出荷/
じゅんじしんこう /順次進行/
じゅんじじっこう /順次実行/
じゅんじつ /閏日/旬日/
じゅんじどくりつ /順次独立/
じゅんじゅん /順々/恂恂/循循/順順/諄諄/
じゅんじゅんけっしょう /凖凖決勝/準々決勝/準準決勝/
じゅんじょ /順序/
じゅんじょいそうくうかん /順序位相空間/
じゅんじょう /純情/
じゅんじょうかれん /純情可憐/
じゅんじょうは /純情派/
じゅんじょかいろ /順序回路/
じゅんじょかいろりろん /順序回路理論/
じゅんじょかんけい /順序関係/
じゅんじょきかい /順序機械/
じゅんじょすう /順序数/
じゅんじょせい /順序性/
じゅんじょちかく /順序知覚/
じゅんじょつい /順序対/
じゅんじょづけ /順序付/順序付け/
じゅんじょてき /順序的/
じゅんじょどうけい /順序同型/
じゅんじょひょうげん /順序表現/
じゅんすい /純粋/純水/
じゅんすいすうがく /純粋数学/
じゅんすいせん /準推薦/
じゅんすいだんじょこうゆう /純粋男女交遊/
じゅんすいぶつり /純粋物理/
じゅんすいりせいひはん /純粋理性批判/
じゅんすいろんり /純粋論理/
じゅんせい /純正/順清/
じゅんせいいがい /純正以外/
じゅんせいがいぶ /純正外部/
じゅんせいげんぞうしょ /純正現像所/
じゅんせいじょう /準正常/
じゅんせいじょういごかん /純正上位互換/
じゅんせいじょうけい /準正常系/
じゅんせいちょう /純正調/
じゅんせいちょうりつ /純正調律/
じゅんせいてきへんか /準静的変化/
じゅんせいないぞう /純正内蔵/
じゅんせいひん /純正品/純製品/
じゅんせいひんいがい /純製品以外/
じゅんせいぶひん /純正部品/
じゅんせいようひん /純正用品/
じゅんせいりつ /純正律/純正率/
じゅんせん /準線/
じゅんせんけい /準線形/
じゅんせんもん /準専門/
じゅんせんりゃく /純戦略/
じゅんぜいきん /準税金/
じゅんぜん /純然/
じゅんぜんこくはつばい /準全国発売/
じゅんそう /順走/
じゅんそくたつか /準速達化/
じゅんぞう /淳三/純増/
じゅんたいいん /準隊員/
じゅんたく /潤沢/
じゅんたんしょく /準単色/
じゅんだいすうてき /純代数的/
じゅんだんせいこうさんらん /準弾性光散乱/
じゅんちょう /順調/
じゅんていこう /純抵抗/
じゅんていじょう /準定常/
じゅんていじょうしょうげきおん /準定常衝撃音/
じゅんていれい /準定例/
じゅんてん /順天/
じゅんてんこうこう /順天高校/
じゅんてんどう /順天堂/
じゅんてんどうだいがく /順天堂大学/
じゅんとう /順当/
じゅんとうしょう /順当勝/
じゅんとく /潤徳/
じゅんとくじょし /潤徳女子/
じゅんとくじょしこうこう /潤徳女子高校/
じゅんど /純度/
じゅんどうけい /準同形/準同型/
じゅんどうけいしゃぞう /準同形写像/
じゅんな /純名/
じゅんなま /純生/
じゅんにゅうりょく /準入力/
じゅんのう /順応/
じゅんのうせい /順応性/
じゅんのすけ /純之介/順之介/淳之介/
じゅんばん /順番/
じゅんばんいがい /順番以外/
じゅんばんひょう /順番表/
じゅんばんまち /順番待ち/
じゅんぱい /潤肺/
じゅんぱく /純白/
じゅんひぶ /順日歩/
じゅんひょうじゅん /準標準/
じゅんび /準備/順備/
じゅんびい /準備委/
じゅんびいいん /準備委員/
じゅんびいいんかい /準備委員会/
じゅんびいいんかいあん /準備委員会案/
じゅんびいいんかいせい /準備委員会制/
じゅんびいいんせんしゅつ /準備委員選出/
じゅんびうんどう /準備運動/
じゅんびかい /準備会/
じゅんびかいかんけいしゃ /準備会関係者/
じゅんびかつどう /準備活動/
じゅんびかてい /準備過程/
じゅんびかんりょう /準備完了/
じゅんびがかり /準備係/
じゅんびきかん /準備期間/
じゅんびきん /準備金/
じゅんびこう /準備稿/
じゅんびこうじ /準備工事/
じゅんびごう /準備号/
じゅんびさぎょう /準備作業/
じゅんびしつ /準備室/
じゅんびしほんきん /準備資本金/
じゅんびだんかい /準備段階/
じゅんびちゅう /準備中/
じゅんびぶそく /準備不足/
じゅんびょう /閏秒/
じゅんふどう /順不同/
じゅんぶんがく /純文学/
じゅんぷう /順風/
じゅんぷうまんぱん /順風満帆/
じゅんへんせい /順編成/
じゅんぺい /順平/
じゅんほうこう /順方向/
じゅんぼく /純朴/
じゅんぽう /遵法/順法/旬報/
じゅんぽうそうこうかい /遵法走行会/
じゅんまい /純米/
じゅんまいぎんじょう /純米吟醸/
じゅんまいぎんじょうしゅ /純米吟醸酒/
じゅんまいしゅ /純米酒/
じゅんまいだいぎんじょう /純米大吟醸/
じゅんめ /巡目/順目/
じゅんもう /純毛/
じゅんや /純也/潤也/潤哉/順彌/
じゅんゆうしょう /準優勝/
じゅんよう /準用/巡洋/
じゅんようかん /巡洋艦/
じゅんようきてい /準用規定/
じゅんようせんかん /巡洋戦艦/巡洋戰艦/
じゅんら /巡邏/
じゅんり /純利/
じゅんりえき /純利益/
じゅんりゅうさん /純硫酸/
じゅんりょう /純量/
じゅんりろんてき /純理論的/
じゅんれい /巡礼/
じゅんれいきゃく /巡礼客/
じゅんれつ /順列/
じゅんろ /順路/
じゅんろちょう /順路帳/
じゅんろへんこう /順路変更/
じゅんろんりてき /純論理的/
じゆう /自由/事由/
じゆうあぐん /自由亜群/
じゆういし /自由意志/自由意思/
じゆういしろん /自由意志論/
じゆういぜん /自由以前/
じゆういっぱん /自由一般/
じゆううんだい /自由雲台/
じゆうおうぼ /自由応募/
じゆうおんじょう /自由音場/
じゆうか /自由化/
じゆうかいとう /自由回答/
じゆうかいほうせい /自由開放性/
じゆうがおか /自由ヶ丘/自由が丘/
じゆうがくえん /自由学園/
じゆうきどう /自由軌道/
じゆうきょうそう /自由競争/
じゆうきょうそうしじょう /自由競争市場/
じゆうきょく /自由曲/
じゆうきょくめん /自由曲面/
じゆうぎょう /自由業/
じゆうくうかん /自由空間/
じゆうぐん /自由群/
じゆうけいざい /自由経済/
じゆうけいやく /自由契約/
じゆうけいやくせんしゅ /自由契約選手/
じゆうけん /自由権/
じゆうけんきゅう /自由研究/
じゆうけんり /自由権利/
じゆうげんり /自由原理/
じゆうこうえん /自由公演/
じゆうこうてい /自由行程/
じゆうこうどう /自由行動/
じゆうこくみんしゃ /自由国民社/
じゆうさいりょう /自由裁量/
じゆうさいりょうけん /自由裁量権/
じゆうさんか /自由参加/
じゆうしげん /自由資源/
じゆうしじょう /自由市場/
じゆうしゃかい /自由社会/
じゆうしゅうゆうくかん /自由周遊区間/
じゆうしゅぎ /自由主義/
じゆうしゅぎけいざい /自由主義経済/
じゆうしゅぎしゃ /自由主義者/
じゆうしゅぎしゃかい /自由主義社会/
じゆうしゅぎじんえい /自由主義陣営/
じゆうしゅぎてき /自由主義的/
じゆうしゅつげん /自由出現/
じゆうしんぽう /自由新報/
じゆうじかん /自由時間/
じゆうじざい /自由自在/
じゆうじっけん /自由実験/
じゆうじゅんぐん /自由準群/
じゆうじん /自由人/
じゆうせい /自由性/
じゆうせき /自由席/
じゆうせききんえんしゃ /自由席禁煙車/
じゆうせきけん /自由席券/
じゆうせきしゃ /自由席車/
じゆうせきしようしゃ /自由席仕様車/
じゆうせきとっきゅうけん /自由席特急券/
じゆうたん /自由端/
じゆうちいき /自由地域/
じゆうちょう /自由帳/
じゆうでんし /自由電子/
じゆうとう /自由党/
じゆうとうこう /自由投稿/
じゆうとうろん /自由討論/
じゆうど /自由度/
じゆうなんばん /自由軟盤/
じゆうは /自由派/自由波/
じゆうはんぐん /自由半群/
じゆうば /自由場/
じゆうふく /自由服/
じゆうぶん /自由文/
じゆうぶんし /自由分子/
じゆうぶんみゃくげんご /自由文脈言語/
じゆうへんすう /自由変数/
じゆうほんぽう /自由奔放/
じゆうぼうえき /自由貿易/
じゆうみんけん /自由民権/
じゆうみんしゅとう /自由民主党/
じゆうらっか /自由落下/
じゆうらっかくうかん /自由落下空間/
じゆうらっかほうそく /自由落下法則/
じゆうりょういき /自由領域/
じゆうりょこう /自由旅行/
じゆうれん /自由練/
じゆうれんそう /自由連想/
じゆうれんそうほう /自由連想法/
じゆうろんぶん /自由論文/
じょ /女/除/如/序/助/鋤/徐/恕/叙/所/汝/舒/抒/敍/敘/洳/絮/耡/茹/莇/蜍/
じょーく /ジョーク/
じょい /女医/
じょいなす /ジョイナス/
じょう /上/状/情/場/城/条/常/畳/乗/錠/譲/成/定/嬢/生/浄/杖/醸/丈/壌/冗/蒸/條/穣/剰/擾/丞/盛/静/星/乘/仍/仗/剩/塲/壤/嫋/嬲/孃/拯/攘/淨/滌/烝/疊/疉/疂/禳/穰/絛/繞/聶/蕘/蟐/襄/讓/躡/遶/釀/靜/饒/驤/繩/茸/帖/貞/瀞/縄/娘/
じょう> /上/
じょうい /上位/譲位/上意/攘夷/
じょういうち /上意討ち/
じょういかいそう /上位階層/
じょういかたつ /上意下達/
じょういがいねん /上位概念/
じょういきかく /上位規格/
じょういきしゅ /上位機種/
じょういけいさい /上位掲載/
じょういげんご /上位言語/
じょういこう /上位校/
じょういごかん /上位互換/
じょういごかんき /上位互換機/
じょういごかんせい /上位互換性/
じょういしめい /上位指名/
じょういしゃ /上位者/
じょういしゅぞく /上位種族/
じょういじん /上位陣/
じょういそう /上位層/
じょういち /譲一/
じょういちゃくじゅんば /上位着順馬/
じょういどうし /上位同士/
じょういどくせん /上位独占/
じょういにゅうしょう /上位入賞/
じょういにゅうしょうしゃ /上位入賞者/
じょういにんき /上位人気/
じょういば /上位馬/
じょういばん /上位版/
じょういばんち /上位番地/
じょういひょう /上位票/
じょういん /乗員/上院/
じょうえい /上映/
じょうえいかい /上映会/
じょうえいきんし /上映禁止/
じょうえいじ /上映時/
じょうえいじかん /上映時間/
じょうえいちゅう /上映中/
じょうえつ /上越/
じょうえつこくさい /上越国際/
じょうえつし /上越市/
じょうえつしんかんせん /上越新幹線/
じょうえつせん /上越線/
じょうえつせんえんせん /上越線沿線/
じょうえつなんせん /上越南線/
じょうえつほうめん /上越方面/
じょうえつほくせん /上越北線/
じょうえん /上演/
じょうえんけん /上演権/
じょうえんちゅう /上演中/
じょうおう /女王/
じょうおうへいか /女王陛下/
じょうおん /常温/
じょうおんかくゆうごう /常温核融合/
じょうか /浄化/城下/上下/情科/
じょうかい /上界/上階/場開/常会/
じょうかく /城郭/城閣/
じょうかけん /情科研/
じょうかさいりよう /浄化再利用/
じょうかそう /浄化槽/
じょうかそうち /浄化装置/
じょうかのうりょく /浄化能力/
じょうかまち /城下町/城下街/
じょうかん /上巻/上官/情感/
じょうかんてき /情感的/
じょうがい /場外/
じょうがいせん /場外戦/
じょうがいはつばいしょ /場外発売所/
じょうがいはつばいじょ /場外発売所/
じょうがいらんとう /場外乱闘/
じょうがくら /城ケ倉/
じょうがさき /城ケ崎/
じょうがしま /城ヶ島/
じょうがんじがわ /常願寺川/
じょうき /上記/蒸気/常軌/上気/条規/蒸氣/情機/
じょうきあつ /蒸気圧/
じょうきあて /上記宛/
じょうきあん /上記案/
じょうきいがい /上記以外/
じょうきおう /蒸氣王/
じょうきかいごう /上記会合/
じょうききかん /蒸気機関/上記期間/
じょうききかんしゃ /蒸気機関車/
じょうききかんない /上記期間内/
じょうきくどう /蒸気駆動/
じょうきげん /上機嫌/上喜元/
じょうきさんしょう /上記参照/
じょうきしき /蒸気式/
じょうきしつもん /上記質問/
じょうきしゅうごうじかん /上記集合時間/
じょうきしょうじょう /上記症状/
じょうきじょうけん /上記条件/
じょうきせいめい /上記声明/
じょうきせん /蒸気船/
じょうきせんげん /上記宣言/
じょうきてじゅん /上記手順/
じょうきないよう /上記内容/
じょうきはつげん /上記発言/
じょうきひょう /蒸気表/
じょうきぶんしょう /上記文章/
じょうきほうほう /上記方法/
じょうきほん /情機本/
じょうきほんぶ /情機本部/
じょうきもくてき /上記目的/
じょうきゃく /乗客/上客/
じょうきゃくすう /乗客数/
じょうきゃくぞう /乗客増/
じょうきゅう /上級/上丘/
じょうきゅうかいいん /上級会員/
じょうきゅうき /上級機/
じょうきゅうしかく /上級資格/
じょうきゅうしかん /上級士官/
じょうきゅうしきかん /上級指揮官/
じょうきゅうしゃ /上級者/
じょうきゅうしゃいじょう /上級者以上/
じょうきゅうしゃむけ /上級者向/
じょうきゅうしゃよう /上級者用/
じょうきゅうしょく /上級職/
じょうきゅうしん /上級審/
じょうきゅうしんぱん /上級審判/
じょうきゅうせい /上級生/
じょうきゅうひん /上級品/
じょうきゅうへん /上級編/
じょうきゅうよう /上級用/
じょうきゅうりょこうしゃ /上級旅行者/
じょうきょう /状況/情教/上京/情況/
じょうきょういぞん /状況依存/
じょうきょういぞんせい /状況依存性/
じょうきょういみろん /状況意味論/
じょうきょうか /状況下/
じょうきょうかんさつ /状況観察/
じょうきょうしだい /状況次第/
じょうきょうしょうこ /状況証拠/情況証拠/
じょうきょうせってい /状況設定/
じょうきょうせつめい /状況説明/
じょうきょうそうてい /状況想定/
じょうきょうてきにんち /状況的認知/
じょうきょうはんだん /状況判断/
じょうきょうびょうしゃ /状況描写/
じょうきょうほうこく /状況報告/
じょうきょうりろん /状況理論/
じょうきょうろんてき /状況論的/
じょうきようりょう /上記要領/
じょうきりゆう /上記理由/
じょうきれんらくさき /上記連絡先/
じょうきろんぶん /上記論文/
じょうきん /常勤/
じょうぎ /定規/
じょうく /冗句/
じょうくう /上空/
じょうけい /情景/常形/
じょうけいびょうしゃ /情景描写/
じょうけん /条件/條件/情研/
じょうけんいはん /条件違反/
じょうけんえんざんし /条件演算子/
じょうけんおんど /条件温度/
じょうけんか /条件下/
じょうけんしき /条件式/
じょうけんしだい /条件次第/
じょうけんすう /条件数/
じょうけんせってい /条件設定/
じょうけんせん /条件戦/
じょうけんたんさく /条件探索/
じょうけんつき /条件付き/条件付/
じょうけんつきかつりつ /条件付確率/
じょうけんつきぶんぷ /条件付き分布/
じょうけんづけ /条件付け/条件付/
じょうけんていじ /条件提示/
じょうけんてき /条件的/
じょうけんとうそう /条件闘争/
じょうけんとくべつ /条件特別/
じょうけんはんしゃ /条件反射/
じょうけんはんしゃてき /条件反射的/
じょうけんはんだん /条件判断/
じょうけんば /条件馬/
じょうけんぶ /条件部/
じょうけんぶぶん /条件部分/
じょうけんぶん /条件文/
じょうけんぶんき /条件分岐/
じょうけんぶんききこう /条件分岐機構/
じょうけんぶんきめいれい /条件分岐命令/
じょうけんへんこう /条件変更/
じょうけんへんすう /条件変数/
じょうけんほう /條件法/
じょうけんめい /条件名/
じょうげ /上下/
じょうげいどう /上下移動/
じょうげうんどう /上下運動/
じょうげかん /上下巻/
じょうげかんかく /上下間隔/
じょうげかんけい /上下関係/
じょうげさゆう /上下左右/↑↓→←/
じょうげすい /上下水/
じょうげすいしせつ /上下水施設/
じょうげすいどう /上下水道/
じょうげせん /上下線/
じょうげせんけんよう /上下線兼用/
じょうげどう /上下動/
じょうげぶんかつ /上下分割/
じょうげぶんさつ /上下分冊/
じょうげほう /上下法/
じょうげほうこう /上下方向/
じょうげめん /上下面/
じょうげやじるし /上下矢印/
じょうげん /上限/上弦/
じょうげんいない /上限以内/
じょうげんかかく /上限価格/
じょうげんかかくいか /上限価格以下/
じょうげんかげん /上限下限/
じょうげんがく /上限額/
じょうげんち /上限値/
じょうこう /条項/上皇/乗降/情交/情工/上向/
じょうこうきゃく /乗降客/
じょうこうきゃくすう /乗降客数/
じょうこうぐち /乗降口/
じょうこうしゃ /乗工社/
じょうこうじかん /乗降時間/
じょうこうじんいんすう /乗降人員数/
じょうこうせい /上向性/
じょうこうひんど /乗降頻度/
じょうこうよう /乗降用/
じょうこく /上告/
じょうこくちゅう /上告中/
じょうこん /乗根/
じょうご /上戸/漏斗/
じょうさい /城塞/城西/条西/城砦/
じょうさいだい /城西大/
じょうさいだいがく /城西大学/
じょうさし /状差し/状差/
じょうさま /嬢様/
じょうさん /乗算/
じょうさんめいれい /乗算命令/
じょうざい /錠剤/浄財/剰剤/常在/
じょうざん /乗算/
じょうざんえんざん /乗算演算/
じょうざんかいすう /乗算回数/
じょうざんかいろ /乗算回路/
じょうざんき /乗算器/
じょうざんけい /定山渓/
じょうざんごうどうほう /乗算合同法/
じょうざんそうさ /乗算操作/
じょうし /上司/上梓/城址/城市/情子/上肢/情シ/
じょうしき /常識/上式/
じょうしきいぜん /常識以前/
じょうしきか /常識化/常識家/
じょうしきじん /常識人/
じょうしきすいろん /常識推論/
じょうしきてき /常識的/
じょうしきてきおんりょう /常識的音量/
じょうしきてきけつろん /常識的結論/
じょうしきてきしょち /常識的処置/
じょうした /城下/
じょうしつ /上質/
じょうしつし /上質紙/
じょうしゃ /乗車/盛者/
じょうしゃいち /乗車位置/
じょうしゃえき /乗車駅/
じょうしゃかのう /乗車可能/
じょうしゃきゃく /乗車客/
じょうしゃきょひ /乗車拒否/
じょうしゃきろく /乗車記録/
じょうしゃきんし /乗車禁止/
じょうしゃくかん /乗車区間/
じょうしゃぐち /乗車口/
じょうしゃぐちふきん /乗車口付近/
じょうしゃけいろ /乗車経路/
じょうしゃけん /乗車券/
じょうしゃけんじたい /乗車券自体/
じょうしゃけんるい /乗車券類/
じょうしゃけんるいはいし /乗車券類廃止/
じょうしゃこうりつ /乗車効率/
じょうしゃじ /乗車時/
じょうしゃじかん /乗車時間/
じょうしゃじっせき /乗車実績/
じょうしゃじんいん /乗車人員/
じょうしゃせいりけん /乗車整理券/
じょうしゃせん /乗車船/
じょうしゃせんび /乗車船日/
じょうしゃせんよう /乗車専用/
じょうしゃそうち /乗車装置/
じょうしゃたいけん /乗車体験/
じょうしゃちょうさ /乗車調査/
じょうしゃていいん /乗車定員/
じょうしゃていいんへんこう /乗車定員変更/
じょうしゃとびら /乗車扉/
じょうしゃにんずう /乗車人数/
じょうしゃひっすい /盛者必衰/
じょうしゃひょう /乗車票/
じょうしゃび /乗車日/
じょうしゃへんこう /乗車変更/
じょうしゃほうほう /乗車方法/
じょうしゃまえ /乗車前/
じょうしゃりつ /乗車率/
じょうしゃりょう /乗車料/
じょうしゃりょうきん /乗車料金/
じょうしゃれっしゃばんごう /乗車列車番号/
じょうしゅ /城主/
じょうしゅう /上州/常習/
じょうしゅうきつえんしゃ /常習喫煙者/
じょうしゅうしゃ /常習者/
じょうしゅうじ /上州路/
じょうしゅうはん /常習犯/
じょうしゅうや /上州屋/上洲屋/
じょうしょ /情処/上書/情緒/浄書/
じょうしょう /上昇/丞相/常勝/
じょうしょうおん /上昇音/
じょうしょうおんけい /上昇音形/
じょうしょうかく /上昇角/
じょうしょうかん /上昇管/
じょうしょうがた /上昇型/
じょうしょうきりゅう /上昇気流/
じょうしょうけいこう /上昇傾向/
じょうしょうけいれつ /上昇系列/
じょうしょうじ /上昇時/
じょうしょうちゅう /上昇中/
じょうしょうど /上昇度/
じょうしょうはば /上昇幅/
じょうしょうりつ /上昇率/
じょうしょうりょう /上昇量/
じょうしょかい /情処会/
じょうしょがっかい /情処学会/
じょうしょく /常食/
じょうしょしょうがい /情緒障害/
じょうしょぶ /情処部/
じょうしょろん /情処論/
じょうしん /上申/上新/浄心/
じょうしんえつ /上信越/
じょうしんえつどう /上信越道/
じょうしんえつほうめん /上信越方面/
じょうしんしょ /上申書/
じょうしんでんき /上新電機/
じょうしんでんてつ /上信電鉄/
じょうしんでんてつえんせん /上信電鉄沿線/
じょうじ /常時/譲二/情事/丈嗣/丈二/常児/条二/丈治/
じょうじかいせんせつぞく /常時回線接続/
じょうじかいてん /常時回転/
じょうじかいほう /常時開放/
じょうじかんし /常時監視/
じょうじきつえんしゃ /常時喫煙者/
じょうじけいたい /常時携帯/
じょうじしよう /常時使用/
じょうじじゅうでん /常時充電/
じょうじせいたいない /常磁性体内/
じょうじせつぞく /常時接続/
じょうじつ /情実/
じょうじてんとう /常時点灯/
じょうじてんとうしき /常時点灯式/
じょうじま /城島/
じょうじゅ /成就/
じょうじゅう /常住/
じょうじゅつ /上述/
じょうじゅん /上旬/
じょうじゅんごろ /上旬頃/
じょうじょ /乗除/
じょうじょう /上々/上場/上乗/情状/嫋嫋/上上/条条/烝烝/常状/常常/常情/畳畳/擾擾/穣穣/
じょうじょうきぎょう /上場企業/
じょうじょうしゃくりょう /情状酌量/
じょうじょさんめいれい /乗除算命令/
じょうじょざん /乗除算/
じょうじん /常人/
じょうすい /上水/浄水/定水/
じょうすいき /浄水器/浄水機/
じょうすいきたんたい /浄水器単体/
じょうすいご /浄水後/
じょうすいじょう /浄水場/
じょうすいじょうせいび /浄水場整備/
じょうすいせいのう /浄水性能/
じょうすいち /浄水地/
じょうすいどう /上水道/
じょうすいのうりょく /浄水能力/
じょうすいほうしき /浄水方式/
じょうすう /乗数/定数/常数/剰数/
じょうすうけん /情数研/
じょうすうじかん /定数時間/
じょうすうち /定数値/
じょうすうばい /定数倍/
じょうすけ /譲介/
じょうず /上手/上図/
じょうずへた /上手下手/
じょうせい /情勢/醸成/状勢/上清/城西/上澄/
じょうせいほん /情制本/
じょうせき /定跡/定石/上席/乗積/上積/鐘石/
じょうせきか /定跡化/
じょうせきけい /定石形/
じょうせきしゅう /定石集/
じょうせきてき /定石的/
じょうせきひょう /乗積表/
じょうせきぶん /上積分/
じょうせつ /常設/
じょうせついん /浄雪院/
じょうせつてん /常設展/
じょうせつてんじ /常設展示/
じょうせつばしょ /常設場所/
じょうせん /乗船/情宣/
じょうせんけん /乗船券/
じょうせんじっけん /乗船実験/
じょうせんりょう /乗船料/
じょうせんわりびきけん /乗船割引券/
じょうぜつ /饒舌/
じょうぜん /定禅/
じょうぜんじ /定禅寺/
じょうぜんじどおり /定禅寺通り/定禅寺通/
じょうぜんみずのごとし /上善如水/
じょうそ /上訴/
じょうそう /上層/情操/上奏/常総/情想/
じょうそうがくいん /常総学院/
じょうそうぶ /上層部/
じょうぞう /醸造/
じょうぞうしゅ /醸造酒/
じょうぞうしょ /醸造所/
じょうぞうじょ /醸造所/
じょうぞうもと /醸造元/
じょうぞうよう /醸造用/
じょうたい /状態/常態/上体/常体;「敬体」の対義語。/
じょうたいいってい /状態一定/
じょうたいか /常態化/
じょうたいくうかん /状態空間/
じょうたいけんしゅつふのう /状態検出不能/
じょうたいしゅうごう /状態集合/
じょうたいじたい /状態自体/
じょうたいじょうほう /状態情報/
じょうたいすう /状態数/
じょうたいすうさいしょうか /状態数最小化/
じょうたいず /状態図/
じょうたいずない /状態図内/
じょうたいせんい /状態遷移/
じょうたいせんいかんすう /状態遷移関数/
じょうたいせんいきそく /状態遷移規則/
じょうたいせんいず /状態遷移図/
じょうたいせんいまとりっくす /状態遷移マトリックス/
じょうたいち /状態値/
じょうたいへんか /状態変化/
じょうたいへんすう /状態変数/
じょうたいべくとる /状態ベクトル/
じょうたいほうていしき /状態方程式/
じょうたいりょう /状態量/
じょうたつ /上達/
じょうたん /上端/
じょうだいかんとうご /上代関東語/
じょうだま /上玉/
じょうだん /冗談/上段/
じょうだんぬき /冗談抜/
じょうだんはんぶん /冗談半分/
じょうち /上智/常置/
じょうちそつ /上智卒/
じょうちだい /上智大/
じょうちだいがく /上智大学/
じょうちばしょ /常置場所/
じょうちゃく /蒸着/
じょうちゃくそう /蒸着層/
じょうちゃくまく /蒸着膜/
じょうちゅう /常駐/城中/静注/
じょうちゅうかいじょ /常駐解除/
じょうちゅうがた /常駐型/
じょうちゅうご /常駐後/
じょうちゅうじ /常駐時/
じょうちゅうはんてい /常駐判定/
じょうちゅうはんていか /常駐判定可/
じょうちゅうはんていふのう /常駐判定不能/
じょうちゅうぶ /常駐部/
じょうちゅうもの /常駐物/
じょうちゅうりょう /常駐量/
じょうちょ /情緒/
じょうちょう /冗長/情調/上長/
じょうちょうか /冗長化/
じょうちょうせい /冗長性/
じょうちょうど /冗長度/
じょうちょうぶぶん /冗長部分/
じょうちょせい /情緒性/
じょうちょてき /情緒的/
じょうちょてきよっきゅう /情緒的欲求/
じょうちょふあんてい /情緒不安定/
じょうちょろん /情緒論/
じょうつう /情通/
じょうつうけん /情通研/
じょうてい /上程/上帝/
じょうていめん /上底面/
じょうてんき /上天気/
じょうでき /上出来/
じょうでんけん /情電研/
じょうと /譲渡/
じょうとう /常套/上等/上道/城東/上棟/
じょうとうく /常套句/城東区/
じょうとうしき /上棟式/
じょうとうしゅだん /常套手段/
じょうとうせん /城東線/
じょうとうへい /上等兵/
じょうとさき /譲渡先/
じょうとしょうしょ /譲渡証書/
じょうとしょうめい /譲渡証明/
じょうとしょうめいしょ /譲渡証明書/
じょうとぜい /譲渡税/
じょうど /浄土/
じょうどいん /浄土因/
じょうどう /常道/情動/
じょうどがはま /浄土ヶ浜/
じょうどしんしゅう /浄土真宗/
じょうどじ /浄土寺/
じょうない /場内/城内/
じょうないそうぜん /場内騒然/
じょうないだいかんせい /場内大歓声/
じょうないねっきょう /場内熱狂/
じょうないはっぴょう /場内発表/
じょうないばくしょう /場内爆笑/
じょうないほうそう /場内放送/
じょうなん /城南/
じょうなんちょう /城南町/
じょうなんでんき /城南電器/
じょうなんどう /上南洞/
じょうにん /常任/
じょうにんしきしゃ /常任指揮者/
じょうねつ /情熱/
じょうねつてき /情熱的/
じょうねん /情念/
じょうの /上の/
じょうのう /上納/
じょうのうきん /上納金/
じょうのうち /城之内/
じょうのうやくもんだい /場農薬問題/
じょうはいじく /上胚軸/
じょうはくとう /上白糖/
じょうはつ /蒸発/
じょうはつげんしょう /蒸発現象/
じょうはつざら /蒸発皿/
じょうはつせんねつ /蒸発潜熱/
じょうはつそうち /蒸発装置/
じょうはつそくど /蒸発速度/
じょうはな /城端/
じょうはん /畳半/
じょうはんしん /上半身/
じょうはんしんはだか /上半身裸/
じょうば /乗馬/
じょうばん /常磐/定盤/
じょうばんかいそく /常磐快速/
じょうばんかいそくせん /常磐快速線/
じょうばんこうぎょうかいかん /常磐工業会館/
じょうばんこうそく /常磐高速/
じょうばんじどうしゃどう /常磐自動車道/
じょうばんせん /常磐線/
じょうばんせんあやせえき /常磐線綾瀬駅/
じょうばんせんえんせん /常盤線沿線/
じょうばんせんかいそく /常磐線快速/
じょうばんせんけいゆう /常磐線経由/
じょうばんせんたいらいき /常磐線平行/
じょうばんせんたいらゆき /常磐線平行/
じょうばんせんない /常磐線内/
じょうばんせんほうめん /常磐線方面/
じょうばんたんだい /常磐短大/
じょうばんどう /常磐道/
じょうひ /上皮/
じょうひん /上品/
じょうび /常備/
じょうびきかん /常備期間/
じょうびぶん /常微分/
じょうびぶんほうていしき /常微分方程式/
じょうびやく /常備薬/
じょうふ /情夫/情婦/
じょうぶ /丈夫/上部/
じょうぶくろ /状袋/
じょうぶこうぞう /上部構造/
じょうぶつ /成仏/
じょうぶろかき /上部濾過器/
じょうぶん /条文/
じょうぶんきてい /条文規定/
じょうへい /城兵/
じょうへき /城壁/
じょうへん /上辺/上編/城辺/
じょうほ /譲歩/
じょうほう /情報/上方/乗法/城宝/城寳/定法/常法/
じょうほうあっしゅく /情報圧縮/
じょうほういがい /情報以外/
じょうほういんぺい /情報隠蔽/
じょうほうえんしゅうしつ /情報演習室/
じょうほうおうよう /情報応用/
じょうほうおうようけんきゅうぶ /情報応用研究部/
じょうほうか /情報科/情報化/
じょうほうかいせき /情報解析/
じょうほうかいせきがく /情報解析学/
じょうほうかいせきぎじゅつ /情報解析技術/
じょうほうかいはつしつ /情報開発室/
じょうほうかがく /情報科学/
じょうほうかがくいいんかい /情報科学委員会/
じょうほうかがくか /情報科学科/
じょうほうかがくかんけい /情報科学関係/
じょうほうかがくきょうかい /情報科学協会/
じょうほうかがくきょうしつ /情報科学教室/
じょうほうかがくけんきゅうか /情報科学研究科/
じょうほうかがくしゃ /情報科学者/
じょうほうかがくじてん /情報科学辞典/
じょうほうかがくせんこう /情報科学専攻/
じょうほうかがくてき /情報科学的/
じょうほうかがくぶ /情報科学部/
じょうほうかがっか /情報科学科/
じょうほうかくとうぎばん /情報格闘技版/
じょうほうかしゃかい /情報化社会/
じょうほうかた /情報過多/
じょうほうかでん /情報家電/
じょうほうかん /情報館/
じょうほうかんきょうきょうかい /情報環境協会/
じょうほうかんけい /情報関係/
じょうほうかんり /情報管理/
じょうほうかんりがっか /情報管理学科/
じょうほうかんりしせつ /情報管理施設/
じょうほうかんれん /情報関連/
じょうほうがく /情報学/
じょうほうがくぶ /情報学部/
じょうほうがくるい /情報学類/
じょうほうがっか /情報学科/
じょうほうきおく /情報記憶/
じょうほうきか /情報幾何/
じょうほうきき /情報機器/
じょうほうききぶ /情報機器部/
じょうほうききほんぶ /情報機器本部/
じょうほうきじ /情報記事/
じょうほうきそ /情報基礎/
じょうほうきそかがく /情報基礎科学/
じょうほうきそかがくせんこう /情報基礎科学専攻/
じょうほうきょういく /情報教育/
じょうほうきょく /情報局/
じょうほうぎじゅつ /情報技術/
じょうほうぎじゅつか /情報技術科/
じょうほうぎじゅつかいはつ /情報技術開発/
じょうほうぎじゅつだい /情報技術第/
じょうほうぎじゅつぶんや /情報技術分野/
じょうほうぎょうれつ /情報行列/
じょうほうけい /情報系/
じょうほうけいがっか /情報系学科/
じょうほうけいさんぎょう /情報系産業/
じょうほうけいようご /情報系用語/
じょうほうけつらく /情報欠落/
じょうほうけん /情報研/
じょうほうけんきゅうしょ /情報研究所/
じょうほうけんきゅうじょ /情報研究所/
じょうほうけんさく /情報検索/
じょうほうげん /情報源/
じょうほうこう /情報工/情報交/
じょうほうこうかい /情報公開/
じょうほうこうかいほう /情報公開法/
じょうほうこうかん /情報交換/
じょうほうこうかんかい /情報交換会/
じょうほうこうかんよう /情報交換用/
じょうほうこうがく /情報工学/
じょうほうこうがくか /情報工学科/
じょうほうこうがくかてい /情報工学課程/
じょうほうこうがくきょうしつ /情報工学教室/
じょうほうこうがくけい /情報工学系/
じょうほうこうがくけんきゅうか /情報工学研究科/
じょうほうこうがくじっけん /情報工学実験/
じょうほうこうがくせんこう /情報工学専攻/
じょうほうこうがくぶ /情報工学部/
じょうほうこうがくぶんや /情報工学分野/
じょうほうこうがっか /情報工学科/
じょうほうこうぞうけんきゅう /情報構造研究/
じょうほうさいぜんせん /情報最前線/
じょうほうさんぎょう /情報産業/
じょうほうさんぎょうろん /情報産業論/
じょうほうさんらん /情報散乱/
じょうほうざっし /情報雑誌/
じょうほうし /情報誌/
じょうほうしつ /情報室/
じょうほうしゃかい /情報社会/
じょうほうしゃかいがく /情報社会学/
じょうほうしゃだん /情報遮断/
じょうほうしゅうしゅう /情報収集/
じょうほうしゅうしゅうかつどう /情報収集活動/
じょうほうしゅうしゅうのうりょく /情報収拾能力/
じょうほうしょり /情報処理/
じょうほうしょりえんしゅう /情報処理演習/
じょうほうしょりか /情報処理科/
じょうほうしょりかてい /情報処理過程/
じょうほうしょりかんけい /情報処理関係/
じょうほうしょりがいろん /情報処理概論/
じょうほうしょりがく /情報処理学/
じょうほうしょりがっかい /情報処理学会/
じょうほうしょりきかい /情報処理機械/
じょうほうしょりきき /情報処理機器/
じょうほうしょりきこう /情報処理機構/
じょうほうしょりきのう /情報処理機能/
じょうほうしょりきょういく /情報処理教育/
じょうほうしょりけんきゅう /情報処理研究/
じょうほうしょりこうざ /情報処理講座/
じょうほうしょりさぎょう /情報処理作業/
じょうほうしょりしけん /情報処理試験/
じょうほうしょりのうりょく /情報処理能力/
じょうほうしょりぶんや /情報処理分野/
じょうほうしょりほう /情報処理法/
じょうほうしょりようご /情報処理用語/
じょうほうしりょう /情報資料/
じょうほうじ /浄法寺/
じょうほうじっけんしつ /情報実験室/
じょうほうすうがく /情報数学/
じょうほうすうり /情報数理/
じょうほうすうりがっか /情報数理学科/
じょうほうすうりだい /情報数理第/
じょうほうすじ /情報筋/
じょうほうせいさんしゃ /情報生産者/
じょうほうせん /情報戦/
じょうほうせんこう /情報専攻/
じょうほうせんしんこく /情報先進国/
じょうほうせんりゃく /情報戦略/
じょうほうそうさ /情報操作/
じょうほうそうりょう /情報総量/
じょうほうたんさく /情報探索/
じょうほうだい /情報第/情報大/
じょうほうだいがく /情報大学/
じょうほうちくせき /情報蓄積/
じょうほうちしき /情報知識/
じょうほうちしきがっかい /情報知識学会/
じょうほうちゅうしゅつ /情報抽出/
じょうほうつう /情報通/
じょうほうつうしん /情報通信/
じょうほうつうしんかがく /情報通信科学/
じょうほうつうしんきき /情報通信機器/
じょうほうつうしんけん /情報通信研/
じょうほうつうしんけんきゅう /情報通信研究/
じょうほうつうしんぶ /情報通信部/
じょうほうていきょう /情報提供/
じょうほうていきょうがいしゃ /情報提供会社/
じょうほうていきょうけいたい /情報提供形態/
じょうほうていきょうしせつ /情報提供施設/
じょうほうていきょうしゃ /情報提供者/
じょうほうていきょうよう /情報提供用/
じょうほうてき /情報的/乗法的/
じょうほうてきじったい /情報的実体/
じょうほうてんそう /情報転送/
じょうほうでんしけん /情報電子研/
じょうほうでんたつ /情報伝達/
じょうほうでんたつがく /情報伝達学/
じょうほうでんたつせんこう /情報伝達専攻/
じょうほうでんたつのうりょく /情報伝達能力/
じょうほうでんたつりつ /情報伝達率/
じょうほうとう /情報棟/
じょうほうとうごう /情報統合/
じょうほうとうせい /情報統制/
じょうほうどうし /情報同士/
じょうほうないよう /情報内容/
じょうほうなど /情報等/
じょうほうにゅうしゅ /情報入手/
じょうほうにゅうしゅけいたい /情報入手形態/
じょうほうはいふ /情報配布/
じょうほうはっしん /情報発信/
じょうほうはっしんげん /情報発進源/
じょうほうばいたい /情報媒体/
じょうほうばん /情報板/
じょうほうばんぐみ /情報番組/
じょうほうひょうげん /情報表現/
じょうほうひょうじ /情報表示/
じょうほうひょうじき /情報表示器/
じょうほうひょうじゅんしゅつりょく /情報標準出力/
じょうほうふごうりろん /情報符号理論/
じょうほうぶ /情報部/
じょうほうぶいん /情報部員/
じょうほうぶそく /情報不足/
じょうほうぶつりがく /情報物理学/
じょうほうぶんや /情報分野/
じょうほうぶんるい /情報分類/
じょうほうへんかん /情報変換/
じょうほうほんぶ /情報本部/
じょうほうもう /情報網/
じょうほうや /情報屋/
じょうほうようりょう /情報容量/
じょうほうりがく /情報理学/
じょうほうりょう /情報量/情報料/
じょうほうりょうきん /情報料金/
じょうほうりょく /情報力/
じょうほうりろん /情報理論/
じょうほうりろんがく /情報理論学/
じょうほうりろんぶもん /情報理論部門/
じょうほうろん /情報論/
じょうほうろんり /情報論理/
じょうほうろんりがく /情報論理学/
じょうほうろんりがくこうざ /情報論理学講座/
じょうほく /城北/常北/
じょうほくせん /城北線/
じょうぼう /上房/
じょうまえ /錠前/
じょうみゃく /静脈/
じょうみゃくけつ /静脈血/
じょうみゃくちゅうしゃ /静脈注射/
じょうみん /常民/
じょうむ /常務/乗務/
じょうむいん /乗務員/
じょうむいんくみあい /乗務員組合/
じょうむいんしつ /乗務員室/
じょうむいんぶそく /乗務員不足/
じょうむいんよう /乗務員用/
じょうむこうたい /乗務交代/
じょうむしつ /常務室/
じょうむとりしまりやく /常務取締役/
じょうむりじ /常務理事/
じょうめん /上面/
じょうめんぞう /上面像/
じょうめんはっこう /上面醗酵/
じょうもうでんてつ /上毛電鉄/
じょうもうでんてつけいゆ /上毛電鉄経由/
じょうもうでんてつけいゆう /上毛電鉄経由/
じょうもの /上物/
じょうもん /城門/縄文/
じょうもんいぜん /縄文以前/
じょうもんこうき /縄文後期/
じょうもんご /縄文語/
じょうもんしきどき /縄文式土器/
じょうもんじだい /縄文時代/
じょうもんじだいぜんき /縄文時代前期/
じょうもんじん /縄文人/
じょうもんすぎ /縄文杉/
じょうもんぜんき /縄文前期/
じょうもんどき /縄文土器/
じょうもんぶんか /縄文文化/
じょうもんまえ /縄文前/
じょうやく /条約/
じょうやくあいてこく /条約相手国/
じょうやくいはん /条約違反/
じょうやくかいせい /条約改正/
じょうやくかめいこく /条約加盟国/
じょうやくは /条約派/
じょうやとい /常雇い/
じょうやとう /常夜燈/
じょうやど /常宿/
じょうよ /剰余/譲与/剩餘/
じょうよう /城陽/常用/常陽/乗用/上陽/
じょうようかんじ /常用漢字/
じょうようかんじひょう /常用漢字表/
じょうようぎんこう /常陽銀行/
じょうようしゃ /乗用車/常用者/
じょうようしゃたち /乗用車達/
じょうようしゃてったい /乗用車撤退/
じょうようしゃよう /乗用車用/
じょうようじ /常用字/
じょうよかち /剰余価値/
じょうよきん /剰余金/
じょうよきんしょぶんあん /剰余金処分案;財務諸表の1つ/
じょうよく /情欲/
じょうよけい /剰余系/
じょうよるい /剰余類/
じょうらく /上洛/
じょうらくかい /情洛会/
じょうらん /上覧/擾乱/
じょうらんずもう /上覧相撲/
じょうり /条理/
じょうりく /上陸/
じょうりくさくせん /上陸作戦/
じょうりつ /乗率/
じょうりゅう /上流/蒸留/蒸溜/
じょうりゅうきぞく /上流貴族/
じょうりゅうさいと /上流サイト/
じょうりゅうしゃかい /上流社会/
じょうりゅうしゅ /蒸留酒/
じょうりゅうじょ /蒸留所/
じょうりゅうすい /蒸留水/
じょうりゅうふじん /上流夫人/
じょうりゅうほうめん /上流方面/
じょうりょく /常緑/
じょうりょくこうようじゅりん /常緑広葉樹林/
じょうりょくしんようじゅ /常緑針葉樹/
じょうりょくじゅ /常緑樹/
じょうるり /浄瑠璃/
じょうれい /常例/条例/上例/
じょうれいしゅう /条例集/
じょうれいじゅつ /浄霊術/
じょうれん /常連/
じょうれんきゃく /常連客/
じょうれんたち /常連達/
じょうれんとうこうしゃ /常連投稿者/
じょうろ /如雨露/
じょうろう /上臈/
じょうわ /情話/
じょうわん /上腕/
じょうわんぶ /上腕部/
じょえん /助演/
じょえんだんゆうしょう /助演男優賞/
じょおう /女王/
じょおうあり /女王蟻/
じょおうごう /女王号/
じょおうさま /女王様/
じょおうばち /女王蜂/
じょおうへいか /女王陛下/
じょかく /除核/
じょがい /除外/
じょがいきてい /除外規定/
じょがいたいしょうば /除外対象馬/
じょがいば /除外馬/
じょがくいん /女学院/
じょがくえん /女学園/
じょがくせい /女学生/
じょがっかん /女学館/
じょがっこう /女学校/女學校/
じょきゃく /除却/
じょきょ /除去/
じょきょうじゅ /助教授/
じょきょうじゅしつ /助教授室/
じょきょうじゅどの /助教授殿/
じょきょきそく /除去規則/
じょきょく /序曲/
じょきょざい /除去剤/除去材/
じょきょのうりょく /除去能力/
じょきょほう /除去法/
じょきん /助勤/
じょく /辱/褥/溽/縟/蓐/
じょくそう /褥瘡/辱創/
じょくふ /褥婦/
じょくん /叙勲/
じょけい /叙景/
じょけいてき /叙景的/
じょけつ /女傑/
じょけん /女権/
じょげん /助言/序言/
じょげんしゃ /助言者/
じょこう /徐行/女工/
じょこううんてん /徐行運転/
じょこうじ /徐行時/
じょさい /如才/
じょさいぼう /助細胞/
じょさん /除算/
じょさんき /除算器/
じょさんし /助産師;保健婦助産婦看護婦法一部改正による呼称変更/
じょさんぷ /助産婦/
じょざん /除算/
じょざんかいろ /除算回路/
じょざんれいがい /除算例外/
じょし /女子/助詞/女史/序詞/
じょしい /女子医/
じょしがくいん /女子学院/
じょしがくえん /女子学園/
じょしがくせい /女子学生/
じょしきょうえい /女子競泳/
じょしけいむしょ /女子刑務所/
じょしこう /女子高/女子校/
じょしこうこう /女子高校/
じょしこうこうせい /女子高校生/
じょしこうせい /女子高生/
じょししゃいん /女子社員/
じょししょうぎょう /女子商業/
じょしじゅんけっしょう /女子準決勝/
じょしせいがくいん /女子聖学院/
じょしせいと /女子生徒/
じょしせんしゅ /女子選手/
じょしたいそう /女子体操/
じょしたんだい /女子短大/
じょしだい /女子大/
じょしだいがく /女子大学/
じょしだいしゅっしん /女子大出身/
じょしだいせい /女子大生/
じょしだいせいむき /女子大生向/
じょしだいせいやく /女子大生役/
じょしちゅうがくせい /女子中学生/
じょしちゅうせい /女子中生/
じょしつ /除湿/
じょしつき /除湿機/
じょしつきのう /除湿機能/
じょしつれいふうき /除湿冷風器/除湿冷風機/
じょしてんいん /女子店員/
じょしはつ /女子初/
じょしび /女子美/
じょしびじゅつだいがく /女子美術大学/
じょしぶ /女子部/
じょしぶいん /女子部員/
じょしめい /女子名/
じょしゃせきよう /助者席用/
じょしやきゅうぶ /女子野球部/
じょしゅ /助手/
じょしゅう /女囚/徐州/
じょしゅかい /助手会/
じょしゅしつ /助手室/
じょしゅせき /助手席/
じょしゅせきがわ /助手席側/
じょしゅせきよう /助手席用/
じょしょう /序章/女将/
じょしよう /女子用/
じょしようちえんじ /女子幼稚園児/
じょしりょう /女子寮/
じょしん /女真/
じょしんもじ /女真文字/
じょじ /女児/叙事/助辞/
じょじし /叙事詩/
じょじゅつ /叙述/
じょじょ /徐々/序々/
じょじょう /叙情/抒情/
じょじょうし /叙情詩/
じょじょうてき /叙情的/
じょじょに /徐々に/
じょじよう /女児用/
じょすい /如水/
じょすう /除数/序数/助数/
じょすうし /助数詞/
じょせい /女性/助成/女声/助勢/
じょせいあて /女性宛/
じょせいいっぱん /女性一般/
じょせいうんてんし /女性運転士/
じょせいか /女性化/
じょせいかしゅ /女性歌手/
じょせいかん /女性観/
じょせいかんけい /女性関係/
じょせいがた /女性型/女性方/
じょせいがっしょう /女声合唱/
じょせいがっしょうだん /女声合唱団/
じょせいがわ /女性側/
じょせいきゃく /女性客/
じょせいきょうし /女性教師/
じょせいきょうふしょう /女性恐怖症/
じょせいきょうゆ /女性教諭/
じょせいきん /助成金/
じょせいきんがく /助成金額/
じょせいぎいん /女性議員/
じょせいぐん /女性軍/
じょせいけい /女性系/
じょせいこうほ /女性候補/
じょせいこようしゃ /女性雇用者/
じょせいさいこん /女性再婚/
じょせいさっか /女性作家/
じょせいさべつ /女性差別/
じょせいさべつろん /女性差別論/
じょせいさんかしゃ /女性参加者/
じょせいざっし /女性雑誌/
じょせいし /女性誌/
じょせいしかん /女性士官/
じょせいしゃいん /女性社員/
じょせいしゃしょう /女性車掌/
じょせいしゅうかんし /女性週刊誌/
じょせいしゅしょう /女性首相/
じょせいしょこん /女性初婚/
じょせいしんさいん /女性審査員/
じょせいしんり /女性心理/
じょせいしんりがく /女性心理学/
じょせいじしん /女性自身/
じょせいじょういじだい /女性上位時代/
じょせいじん /女性陣/
じょせいせんしゅ /女性選手/
じょせいせんよう /女性専用/
じょせいせんようしゃ /女性専用車/
じょせいせんようしゃりょう /女性専用車両/
じょせいせんようしんだい /女性専用寝台/
じょせいせんようれっしゃ /女性専用列車/
じょせいそう /女性層/
じょせいぞう /女性像/
じょせいたち /女性達/
じょせいたんどく /女性単独/
じょせいだいかんげい /女性大歓迎/
じょせいつりし /女性釣師/
じょせいてき /女性的/
じょせいと /女生徒/
じょせいとうひょうしゃ /女性投票者/
じょせいとたち /女生徒達/
じょせいどうし /女性同士/
じょせいひとり /女性一人/
じょせいひょう /女性票/
じょせいび /女性美/
じょせいふたり /女性二人/
じょせいへんれき /女性遍歴/
じょせいべっし /女性蔑視/
じょせいべっしもんだい /女性蔑視問題/
じょせいめい /女性名/
じょせいめいし /女性名詞/
じょせいもんだい /女性問題/
じょせいゆうい /女性優位/
じょせいゆうせん /女性優先/
じょせいよう /女性用/
じょせいより /女性寄り/
じょせいりじ /女性理事/
じょせいりょうきん /女性料金/
じょせいれいのうしゃ /女性霊能者/
じょせいれき /女性歴/
じょせいろうどうしゃ /女性労働者/
じょせき /除籍/
じょせつ /序説/除雪/
じょせつしゃ /除雪車/
じょそう /女装/序奏/除草/助走/除装/
じょそうざい /除草剤/
じょそうぶ /序奏部/
じょたい /除隊/
じょたんぱく /除蛋白/
じょちゅう /女中/
じょちゅうぎく /除虫菊/
じょちょう /助長/
じょつう /除痛/
じょてい /女帝/
じょてんいん /女店員/
じょどうし /助動詞/
じょにー /ジョニー/
じょにだん /序二段/
じょにん /叙任/
じょのくち /序の口/序ノ口/
じょばす /女バス/
じょばん /序盤/序番/
じょばんせん /序盤戦/
じょひ /女卑/
じょひょう /除票/除表/
じょぶ /ジョブ/
じょぶん /序文/
じょへん /徐変/
じょほう /除法/
じょほうかがっか /情報科学科/
じょまく /序幕/除幕/
じょまくしき /除幕式/
じょめい /除名/助命/
じょめいしょぶん /除名処分/
じょや /除夜/
じょやく /助役/
じょやなべ /除夜鍋/
じょゆう /女優/
じょゆうやく /女優役/
じょりゅう /女流/
じょりゅうきし /女流棋士/
じょりゅうさっか /女流作家/
じょりゅうめいじん /女流名人/
じょりょく /助力/
じょれいし /除霊師/
じょれつ /序列/
じょろう /女郎/
じょろん /序論/
じよう /次葉/滋養/
じらい /地雷/
じらいげん /地雷原/
じらいや /児雷也/
じり /尻/
じりき /自力/
じりきかいけつ /自力解決/
じりきかいはつ /自力開発/
じりきこうかん /自力交換/
じりきこうこう /自力航行/
じりきそうこうかのう /自力走行可能/
じりきそうこうふのう /自力走行不能/
じりきゆうしょう /自力優勝/
じりつ /自立/自律/
じりつがたいどう /自立型移動/
じりつこうせい /自律更生/
じりつご /自立語/
じりつごちょう /自立語長/
じりつしん /自律心/自立心/
じりつしんけい /自律神経/
じりつしんけいけい /自律神経系/
じりつせい /自立性/自律性/
じりつてき /自律的/
じりつぶんさん /自律分散/
じりつぶんさんせいぎょ /自律分散制御/
じりゅう /自流/時流/
じりょく /磁力/恃力/
じりょくかいそう /自力回送/
じりょくけい /磁力計/
じりょくせん /磁力線/
じる /汁/
じるい /字類/
じるし /印/
じれい /事例/辞令/辞礼/自励/
じれいしき /自励式/
じれいしゅう /事例集/
じれいしょうかい /事例紹介/
じれいすう /事例数/
じれいてき /事例的/
じれいはっしん /自励発振/
じれいほうこく /事例報告/
じれつ /字列/
じれん /自連/
じれんま /ジレンマ/
じろ /字路/
じろう /二郎/次郎/治郎/二朗/子郎/次朗/治朗/痔瘻/
じろうかじゃ /次郎冠者/
じろちょう /次郎長/
じろん /持論/
じわり /地割り/
じわれ /地割れ/
じん /人/陣/尽/甚/尋/仁/迅/腎/神/靭/臣/訊/壬/刃/塵/進/仞/仭/刄/恁/潯/燼/盡/糂/蕁/贐/靱/荏/侭/稔/
じんあい /仁愛/塵埃/
じんい /人為/
じんいち /仁一/塵一/
じんいてき /人為的/
じんいん /人員/
じんいんさくげん /人員削減/
じんいんせいり /人員整理/
じんいんぶそく /人員不足/
じんいんぼしゅう /人員募集/
じんう /腎盂/
じんえい /陣営/
じんえん /腎炎/
じんか /人家/
じんかい /人海/燼灰/塵芥/
じんかいせんじゅつ /人海戦術/人海戰術/
じんかいは /塵芥破/
じんかく /人格/
じんかくかいぞう /人格改造/
じんかくけいせい /人格形成/
じんかくけいせいき /人格形成期/
じんかくけいせいじょう /人格形成上/
じんかくけん /人格権/
じんかくこうげき /人格攻撃/
じんかくしゃ /人格者/
じんかくてき /人格的/
じんかくてきりえき /人格的利益/
じんかくとくせいろん /人格特性論/
じんかくむし /人格無視/
じんがい /人外/
じんがいだいまきょう /人外大魔境/
じんがいまきょう /人外魔境/
じんきょ /人居/
じんぎ /人技/仁義/神器/
じんぎすかん /成吉思汗;大帝国の基礎を築いたモンゴルの指導者/ジンギスカン/
じんく /甚句/
じんくす /ジンクス/
じんぐう /神宮/神功/
じんぐうきゅうじょう /神宮球場/
じんぐうじ /神宮寺/
じんぐうまえ /神宮前/
じんぐうまえくみんかん /神宮前区民館/
じんけん /人権/人件/人絹/
じんけんいしき /人権意識/
じんけんかいぎ /人権会議/
じんけんかんかく /人権感覚/
じんけんききん /人権基金/
じんけんきやく /人権規約/
じんけんきょういく /人権教育/
じんけんしそう /人権思想/
じんけんしんがい /人権侵害/
じんけんしんぱん /人権侵犯/
じんけんじょう /人権上/
じんけんせんげん /人権宣言/
じんけんせんしんこく /人権先進国/
じんけんそんちょう /人権尊重/
じんけんだんたい /人権団体/
じんけんひ /人件費/人権費/
じんけんひさくげん /人権費削減/
じんけんほご /人権保護/
じんけんもんだい /人権問題/
じんけんようご /人権擁護/
じんけんよくあつ /人権抑圧/
じんこ /仁子/
じんこう /人工/人口/樒/櫁/人皇/沈香/
じんこううみ /人工海/
じんこうえいせい /人工衛星/
じんこうえさ /人工餌/
じんこうおんせい /人工音声/
じんこうか /人工化/
じんこうかいすい /人工海水/
じんこうかみつ /人口過密/
じんこうかん /人工感/
じんこうかんきょうとし /人工環境都市/
じんこうかんじょう /人工感情/
じんこうかんみりょう /人工甘味料/人工甘味量/
じんこうき /塵功記/
じんこうけい /人工系/
じんこうけつえき /人工血液/
じんこうげんご /人工言語/
じんこうげんごてき /人工言語的/
じんこうげんしょう /人口減少/
じんこうげんじつ /人工現実/
じんこうげんじつかん /人工現実感/
じんこうげんじつせかい /人工現実世界/
じんこうこ /人工湖/
じんこうこうう /人工降雨/
じんこうこうせつ /人工降雪/
じんこうこうせつき /人工降雪機/
じんこうこきゅう /人工呼吸/
じんこうこきゅうき /人工呼吸器/
じんこうしば /人工芝/
じんこうしんけい /人工神経/
じんこうしんけいかいろもう /人工神経回路網/
じんこうしんぞう /人工心臓/
じんこうじ /人工耳/
じんこうじゅうりょく /人工重力/
じんこうじゅせい /人工受精/人工授精/
じんこうすう /人口数/
じんこうすな /人工砂/
じんこうずのう /人工頭脳/
じんこうずのうけんきゅう /人工頭脳研究/
じんこうせいめい /人工生命/
じんこうせいめいかいぎ /人工生命会議/
じんこうせいめいけんきゅう /人工生命研究/
じんこうせいめいたい /人工生命体/
じんこうぞう /人口増/
じんこうぞうか /人口増加/
じんこうぞうかりつ /人口増加率/
じんこうぞうき /人工臓器/
じんこうぞうきかいはつ /人工臓器開発/
じんこうぞうきぎじゅつ /人工臓器技術/
じんこうたつまき /人工竜巻/
じんこうちせい /人工知性/
じんこうちのう /人工知能/
じんこうちのうかんけい /人工知能関係/
じんこうちのうがくしゃ /人工知能学者/
じんこうちのうがっかい /人工知能学会/
じんこうちのうぎじゅつ /人工知能技術/
じんこうちのうけんきゅう /人工知能研究/
じんこうちのうけんきゅうしつ /人工知能研究室/
じんこうちのうや /人工知能屋/
じんこうちゅうぜつ /人工中絶/
じんこうちょうさ /人口調査/
じんこうちょうせつ /人口調節/
じんこうてき /人工的/
じんこうとうせき /人工透析/
じんこうとうせきりょうほう /人工透析療法/
じんこうとうみんそうち /人工冬眠装置/
じんこうにゅう /人工乳/
じんこうにんしんちゅうぜつ /人工妊娠中絶/
じんこうばくはつ /人口爆発/
じんこうひ /人口比/
じんこうぶつ /人工物/
じんこうぶつこうがく /人工物工学/
じんこうぶんぷ /人口分布/
じんこうへき /人工壁/
じんこうみっしゅうちいき /人口密集地域/
じんこうみつど /人口密度/
じんこうゆき /人工雪/
じんこうよくせい /人口抑制/
じんこうよくせいさく /人口抑制策/
じんこうりん /人工林/
じんこうわくせい /人工惑星/
じんこつ /人骨/
じんごうき /塵劫記/
じんごじ /神護寺/
じんごろう /甚五郎/
じんさい /人災/
じんざい /人材/人財/
じんざいかいはつぶ /人材開発部/
じんざいけいせい /人材形成/
じんざいさくげん /人材削減/
じんざいはいち /人材配置/
じんざいはけん /人材派遣/
じんざいめん /人材面/
じんざいようせい /人材養成/
じんざぶろう /甚三郎/
じんしっかんかんじゃ /腎疾患患者/
じんしゅ /人種/
じんしゅかん /人種間/
じんしゅこくせき /人種国籍/
じんしゅさ /人種差/
じんしゅさべつ /人種差別/
じんしゅさべつじけん /人種差別事件/
じんしゅさべつだんたい /人種差別団体/
じんしゅさべつてき /人種差別的/
じんしゅさべつもんだい /人種差別問題/
じんしゅてき /人種的/
じんしん /人身/壬申/人心/
じんしんじこ /人身事故/
じんしんじこぜんたい /人身事故全体/
じんしんばいばい /人身売買/
じんじ /人事/神事/
じんじいどう /人事異動/
じんじいん /人事院/
じんじか /人事課/
じんじがかり /人事掛/
じんじきょういくぶ /人事教育部/
じんじそうむ /人事総務/
じんじたんとうしゃ /人事担当者/
じんじはいち /人事配置/
じんじぶ /人事部/
じんじぶちょう /人事部長/
じんじもんだい /人事問題/
じんじゃ /神社/
じんじゃぶっかく /神社仏閣/
じんじゃほんちょう /神社本庁/
じんじゅつ /仁術/
じんじょう /尋常/
じんすけ /甚介/
じんせい /人生/
じんせいかん /人生観/
じんせいくらぶ /人生倶楽部/
じんせいけいけん /人生経験/
じんせいけいけんほうふ /人生経験豊富/
じんせいげきじょう /人生劇場/
じんせいごくらく /人生極楽/
じんせいさいだい /人生最大/
じんせいせっけい /人生設計/
じんせいぜんぱん /人生全般/
じんせいそうだん /人生相談/
じんせいそうだんてき /人生相談的/
じんせいてき /人生的/
じんせいとうにょう /腎性糖尿/
じんせいもんだい /人生問題/
じんせいろん /人生論/
じんせき /神石/人跡/
じんせん /人選/仁山/仁川/
じんせんぬま /神仙沼/
じんぜん /人前/
じんぜんけっこんしき /人前結婚式/
じんぜんしき /人前式/
じんぜんじ /秦泉寺/
じんそく /迅速/
じんそくか /迅速化/
じんそくしょり /迅速処理/
じんそくせい /迅速性/
じんぞう /腎臓/人造/
じんぞうこ /人造湖/
じんぞうにんげん /人造人間/
じんたい /人体/靱帯/靭帯/
じんたいかいぼうず /人体解剖図/
じんたいじっけん /人体実験/
じんたいそんしょう /靭帯損傷/
じんたいたんさく /人体探索/
じんたいもけい /人体模型/
じんたん /仁丹/
じんだい /甚大/神代/
じんだいこ /陣太鼓/
じんだいじ /深大寺/
じんち /陣地/人知/人智/
じんちく /人畜/
じんちくむがい /人畜無害/
じんちけん /人知研/
じんちせんよう /陣地戦用/
じんちゅう /陣中/
じんちょうげ /沈丁花/
じんつう /陣痛/
じんつうがわ /神通川/
じんつうゆうはつざい /陣痛誘発剤/
じんつうりき /神通力/
じんてい /人定/
じんてき /人的/
じんてきいどうめん /人的移動面/
じんてきかしつ /人的過失/
じんてきこうりゅう /人的交流/
じんてきとうし /人的投資/
じんてきようそ /人的要素/
じんてん /人天/
じんとう /陣頭/人頭/
じんとうぜい /人頭税/
じんとく /人徳/
じんとり /神取/陣取/
じんどう /人道/
じんどうしゅぎしゃ /人道主義者/
じんどうてき /人道的/
じんどうてきけんち /人道的見地/
じんない /陣内/
じんなん /神南/
じんにく /人肉/
じんば /人馬/陣場/神馬/
じんばおり /陣羽織/
じんぱち /甚八/
じんぴ /じん皮/靭皮/
じんぴせんい /じん皮繊維/
じんぴん /人品/
じんぴんこつがら /人品骨柄/
じんふぜん /腎不全/
じんぶつ /人物/
じんぶつが /人物画/
じんぶつさつえい /人物撮影/
じんぶつしょうかい /人物紹介/
じんぶつしょうごう /人物照合/
じんぶつぞう /人物像/
じんぶつちょうしょ /人物調書/
じんぶつでんき /人物伝記/
じんぶつはんてい /人物判定/
じんぶん /人文/
じんぶんかがく /人文科学/
じんぶんかがくけい /人文科学系/
じんぶんかがくてき /人文科学的/
じんぶんかがくぶ /人文科学部/
じんぶんがく /人文学/
じんぶんがくしゃ /人文学者/
じんぶんけいかもく /人文系科目/
じんぶんけん /人文研/
じんぶんしゃかいぐん /人文社会群/
じんぶんちり /人文地理/
じんぶんちりがく /人文地理学/
じんぷう /陣風/
じんぷく /尋腹/
じんぷん /人糞/
じんぺい /仁平/甚平/
じんぼ /神保/
じんぼあきら /神保彰/
じんぼう /人望/神保/
じんぼうちょう /神保町/
じんぼうちょうえき /神保町駅/
じんぼちょう /神保町/
じんぽ /神保/
じんましん /蕁麻疹/
じんみゃく /人脈/
じんみん /人民/
じんみんかいほうぐん /人民解放軍/
じんみんきょうわこく /人民共和国/
じんみんぐん /人民軍/
じんみんげん /人民元/
じんみんだいかいどう /人民大会堂/
じんみんちゅうごく /人民中国/
じんみんにっぽう /人民日報/
じんみんぶんがく /人民文学/
じんみんへい /人民幣/
じんみんりょうきん /人民料金/
じんむ /神武/
じんむいぜん /神武以前/
じんむちょう /神武朝/
じんめい /人名/人命/神明/神名/
じんめいぐん /人名群/
じんめいじしょ /人名辞書/
じんめいじてん /人名辞典/
じんめいぼ /人名簿/
じんめいゆうせん /人命優先/
じんめいよう /人名用/
じんめいろく /人名録/
じんめん /人面/
じんめんいわ /人面岩/
じんめんじゅうしん /人面獣身/
じんめんそ /人面疽/
じんもん /尋問/訊問/
じんよう /陣容/
じんらい /人籟/
じんりき /人力/尽力/
じんりきき /人力機/
じんりきしゃ /人力車/俥/
じんりきひこうき /人力飛行機/
じんりゅう /神竜/
じんりょく /尽力/人力/
じんるい /人類/
じんるいあい /人類愛/
じんるいかちくか /人類家畜化/
じんるいがく /人類学/
じんるいきょうつう /人類共通/
じんるいしじょう /人類史上/
じんるいしんかろん /人類進化論/
じんるいぜんたい /人類全体/
じんるいどうし /人類同士/
じんるいはっせい /人類発生/
じんるいはんえい /人類繁栄/
じんるいふへん /人類普遍/
じんるいめつぼう /人類滅亡/
す /素/須/酢/諏/寿/巣/笥/洲/過/子/主/守/州/壽/籔/棲/栖/簾/
すーつ /スーツ/
すーぱー /スーパー/
すーぱせる /スパーセル/
すーぷ /スープ/
すあし /素足/
すあな /巣穴/
すい /水/吹/遂/垂/衰/酔/推/錘/錐/睡/粋/帥/炊/翠/膵/出/誰/埀/彗/悴/忰/捶/榱/燧/瘁/邃/粹/綏/翆/萃/醉/陲/隹/騅/穂/
すいあつ /水圧/
すいい /推移/水位/
すいいかくりつぎょうれつ /推移確率行列/
すいいき /水域/
すいいけい /推移系/
すいいじょうしょう /水位上昇/
すいいせい /推移性/
すいいそく /推移則/
すいいてき /推移的/
すいいほうそく /推移法則/
すいいりつ /推移律/
すいう /水宇/
すいうん /衰運/
すいえい /水泳/
すいえいたいかい /水泳大会/
すいえいぶ /水泳部/
すいえいぶいん /水泳部員/
すいえいよう /水泳用/
すいえん /膵炎/垂涎/
すいおん /水温/
すいおんけい /水温計/
すいおんちょうせつ /水温調節/
すいか /誰何/西瓜/垂下/水瓜/水火/
すいかん /水管/酔漢/
すいがい /水害/
すいがら /吸いがら/吸殻/
すいがん /酔眼/水眼/
すいきゃく /醉客/
すいきゅう /水球/
すいきょ /推挙/
すいきょう /酔狂/
すいぎゅう /水牛/
すいぎょうざ /水餃子/
すいぎょく /翠玉/
すいぎん /水銀/
すいぎんかごうぶつ /水銀化合物/
すいぎんせいりゅうき /水銀整流器/
すいぎんちゅう /水銀柱/
すいぎんでんち /水銀電池/
すいぎんとう /水銀灯/
すいくち /吸い口/
すいくん /垂訓/
すいぐん /水軍/
すいぐんせん /水郡線/
すいけい /水系/推計/
すいけん /推件/水圏/酔拳/
すいげい /酔鯨/
すいげつ /水月/
すいげん /水源/
すいげんかいはつ /水源開発/
すいげんち /水源地/
すいげんちたい /水原地帯/
すいこ /推古/水滸/
すいこう /遂行/推敲/推考/垂鉤/
すいこうしゃ /水光社/
すいこうちゅう /遂行中/
すいこでん /水滸伝/
すいこみ /吸い込み/
すいごう /水濠/
すいごうちたい /水郷地帯/
すいさい /水彩/
すいさいが /水彩画/
すいさいちょう /水彩調/
すいさつ /推察/
すいさん /水産/推算/水酸/炊爨/
すいさんか /水酸化/
すいさんけんきゅうしょ /水産研究所/
すいさんしげん /水産資源/
すいさんだい /水産大/
すいさんちょう /水産庁/
すいさんぶつ /水産物/
すいし /水死/
すいしつ /水質/
すいしつあっか /水質悪化/
すいしつおせん /水質汚染/
すいしつかいぜん /水質改善/
すいしつかんりよう /水質管理用/
すいしゃ /水車/
すいしゃごや /水車小屋/
すいしょう /推奨/水晶/推賞/水漿/
すいしょうあん /推奨案/
すいしょうかくちょうほう /推奨拡張法/
すいしょうきじゅん /推奨基準/
すいしょうけいれつ /推奨系列/
すいしょうしんどうし /水晶振動子/
すいしょうじこう /推奨事項/
すいしょうたい /水晶体/
すいしょうだま /水晶玉/
すいしょうち /推奨値/
すいしょうどう /水晶堂/
すいしょうはっしん /水晶発信/水晶発振/
すいしょうはっしんき /水晶発振器/
すいしょうはっしんし /水晶発振子/
すいしょうふく /推奨服/
すいしん /推進/水深/
すいしんいいんかい /推進委員会/
すいしんうんてん /推進運転/
すいしんか /推進課/
すいしんがわ /推進側/
すいしんき /推進器/推進機/
すいしんきかん /推進機関/
すいしんきこう /推進機構/
すいしんきょうぎかい /推進協議会/
すいしんけんきゅうぶ /推進研究部/
すいしんこうりつ /推進効率/
すいしんざい /推進剤/
すいしんしつ /推進室/
すいしんしゃ /推進者/
すいしんしゃがわ /推進者側/
すいしんじぎょうぶ /推進事業部/
すいしんだんたい /推進団体/
すいしんねんりょう /推進燃料/
すいしんは /推進派/
すいしんぶ /推進部/
すいしんほうさく /推進方策/
すいしんほんぶ /推進本部/
すいしんやくけんきゅうしつ /推進薬研究室/
すいしんりょく /推進力/
すいじ /炊事/
すいじか /炊事可/
すいじば /炊事場/
すいじゃく /衰弱/垂迹/
すいじゅん /水準/
すいじゅんいじょう /水準以上/
すいじゅんかん /水循環/
すいじゅんかんじ /水準漢字/
すいじゅんき /水準器/
すいじゅんすう /水準数/
すいじゅんち /水準値/
すいじゅんはば /水準幅/
すいじょう /水上/穂状/
すいじょうかじょ /穂状花序/
すいじょうき /水蒸気/水上機/
すいじょうきぶんあつ /水蒸気分圧/
すいじょうきりょう /水蒸気量/
すいじょうこうげき /水上攻撃/
すいじょうこうげきりょく /水上攻撃力/
すいじょうせんとう /水上戦闘/
すいじょうは /水上葉/
すいじょうぶたい /水上部隊/
すいじん /粋人/
すいす /瑞西/
すいず /水津/
すいせい /水星/水性/彗星/水勢/Mercury/水棲/水生/
すいせいかく /彗星核/
すいせいがん /水成岩/
すいせいこうきょうがく /翠星交響楽/
すいせいせいぶつ /水生生物/
すいせいぞう /彗星像/
すいせいどうしょくぶつ /水棲動植物/
すいせいどうぶつ /水棲動物/
すいせいむし /酔生夢死/
すいせん /推薦/垂線/水洗/水仙/
すいせんいいん /推薦委員/
すいせんさぎょう /推薦作業/
すいせんざいりょう /推薦材料/
すいせんしゃ /推薦者/
すいせんしょ /推薦書/
すいせんじゅか /スイセンジュ科/Tetracentraceae/
すいせんじょう /推薦状/
すいせんせんしゅ /推薦選手/
すいせんそくしんざい /水洗促進剤/
すいせんち /推薦値/
すいせんちょうしょ /推薦調書/
すいせんにゅうがく /推薦入学/
すいせんにゅうし /推薦入試/
すいせんにん /推薦人/
すいせんば /推薦馬/
すいせんばん /推薦盤/推薦版/
すいせんばんぐみ /推薦番組/
すいせんぶそく /水洗不足/
すいせんぶん /推薦文/
すいせんぼん /推薦本/
すいせんりゆう /推薦理由/
すいせんわく /推薦枠/
すいぜん /垂涎/
すいぜんじ /水前寺/
すいぜんじえきまえ /水前寺駅前/
すいぜんじこうえん /水前寺公園/
すいぜんじこうえんまえ /水前寺公園前/
すいそ /水素/
すいそう /水槽/吹奏/水漕/水葬/水層/垂層/水そう/
すいそうがく /吹奏楽/
すいそうがくだん /吹奏楽団/
すいそうがくばたけ /吹奏楽畑/
すいそうがくぶ /吹奏楽部/
すいそうきぼ /水槽規模/
すいそうぞく /吹奏族/
すいそうぶんれつ /垂層分裂/
すいそうよう /水槽用/
すいそうれいきゃく /水槽冷却/
すいそかく /水素核/
すいそがいそう /水素外層/
すいそく /推測/
すいそけつごう /水素結合/
すいそげんし /水素原子/
すいそぞうかん /水素増感/
すいそぞうかんしょり /水素増感処理/
すいそちくでんち /水素蓄電池/
すいそでんち /水素電池/
すいそばくだん /水素爆弾/
すいぞう /膵臓/酔象/
すいぞくえん /水族園/
すいぞくかん /水族館/
すいた /吹田/
すいたい /衰退/錐体/錘体/
すいたいき /衰退期/
すいたいさいぼう /錐体細胞/
すいたいろ /錐体路/
すいたし /吹田市/
すいたしんごうじょ /吹田信号所/
すいだし /吸出し/
すいちゅう /水中/
すいちゅうおんきょう /水中音響/
すいちゅうかんそく /水中観測/
すいちゅうかんそくよう /水中観測用/
すいちゅうさつえいよう /水中撮影用/
すいちゅうしゃしん /水中写真/
すいちゅうしゃしんか /水中写真家/
すいちゅうせいかつ /水中生活/
すいちゅうせんとう /水中戦闘/
すいちゅうだっちゃく /水中脱着/
すいちゅうとし /水中都市/
すいちゅうは /水中葉/
すいちゅうめがね /水中眼鏡/
すいちゅうよう /水中用/
すいちゅうよくせん /水中翼船/
すいちょう /水鳥/
すいちょく /垂直/
すいちょくかいぞうど /垂直解像度/
すいちょくかんせん /垂直感染/
すいちょくきせん /垂直帰線/
すいちょくけつごう /垂直結合/
すいちょくこうりょく /垂直抗力/
すいちょくしゅうはすう /垂直周波数/
すいちょくせい /垂直性/
すいちょくせん /垂直線/
すいちょくそうさよう /垂直走査用/
すいちょくてき /垂直的/
すいちょくどうき /垂直同期/
すいちょくどうきしんごう /垂直同期信号/
すいちょくにゅうしゃ /垂直入射/
すいちょくびよく /垂直尾翼/
すいちょくほうこう /垂直方向/
すいちょくよく /垂直翼/
すいちょくりりく /垂直離陸/
すいっち /スイッチ/
すいっちんぐ /スイッチング/
すいづ /水津/
すいてい /推定/水底/
すいていき /推定機/
すいていけっか /推定結果/
すいていごさ /推定誤差/
すいていしき /推定式/
すいていしんごう /推定信号/
すいていせいど /推定精度/
すいていそうぞくにん /推定相続人/
すいていち /推定値/
すいていねんれい /推定年齢/
すいていはんい /推定範囲/
すいていほう /推定法/
すいていほうほう /推定方法/
すいていほかん /推定補間/
すいていむざい /推定無罪/
すいていゆうざい /推定有罪/
すいていりょう /推定量/
すいてき /水滴/
すいてきちゅう /水滴中/
すいてきぼうしざい /水滴防止剤/
すいてん /水天/
すいてんぐう /水天宮/
すいてんぐうまえ /水天宮前/
すいでん /水田/
すいとう /水筒/出納/水稲/水痘/
すいとうがかり /出納係/
すいとうきおうれき /水痘既往歴/
すいとうちょう /出納帳/
すいとうぼ /出納簿/
すいとん /水団/
すいどう /水道/隧道/
すいどうかん /水道管/
すいどうきょく /水道局/
すいどうぐち /水道口/
すいどうこうじ /水道工事/
すいどうしようりょう /水道使用量/
すいどうすい /水道水/
すいどうせつび /水道設備/
すいどうだい /水道代/
すいどうばし /水道橋/
すいどうばしえき /水道橋駅/
すいどうばしちゃく /水道橋着/
すいどうりょう /水道料/
すいどうりょうきん /水道料金/
すいなん /水難/
すいにん /推認/
すいはん /炊飯/垂範/
すいはんき /炊飯器/
すいばく /水爆/
すいばら /水原/
すいばん /水盤/
すいび /衰微/
すいふ /炊フ/水夫/水府/
すいふよう /酔芙蓉/
すいぶん /水分/
すいぶんでんかいしつ /水分電解質/
すいぶんほきゅう /水分補給/
すいぶんりょう /水分量/
すいへい /水平/水兵/
すいへいいち /水平位置/
すいへいいどう /水平移動/
すいへいかいぞうど /水平解像度/
すいへいかくさん /水平拡散/
すいへいかくさんけいすう /水平拡散係数/
すいへいかんせいうんどう /水平慣性運動/
すいへいけつごう /水平結合/
すいへいしゃ /水平社/
すいへいしゃせんげん /水平社宣言/
すいへいしゅうはすう /水平周波数/
すいへいしょそくど /水平初速度/
すいへいしんぷく /水平振幅/
すいへいじょうたい /水平状態/
すいへいせいぶん /水平成分/
すいへいせん /水平線/
すいへいそくど /水平速度/
すいへいたぶ /水平タブ/
すいへいどう /水平動/
すいへいどうき /水平同期/
すいへいどうきしんごう /水平同期信号/
すいへいはっさん /水平発散/
すいへいばん /水平板/
すいへいひこう /水平飛行/
すいへいびよく /水平尾翼/
すいへいへんこう /水平偏向/
すいへいへんぱ /水平偏波/
すいへいほうこう /水平方向/
すいへいめん /水平面/
すいへいめんじょう /水平面上/
すいへいらっか /水平落下/
すいへん /水辺/
すいほ /酔歩/
すいほう /水泡/水疱/水胞/
すいぼう /衰亡/水防/
すいぼくが /水墨画/
すいぼつ /水没/
すいま /睡魔/
すいみつ /水密/水蜜/
すいみつかくへき /水密隔壁/
すいみつとう /水蜜桃/
すいみつひ /水密扉/
すいみゃく /水脈/
すいみん /睡眠/
すいみんしょうがい /睡眠障害/
すいみんじかん /睡眠時間/
すいみんじょうたい /睡眠状態/
すいみんちゅう /睡眠中/
すいみんぶそく /睡眠不足/
すいみんぶそくぎみ /睡眠不足気味/
すいみんぶっしつ /睡眠物質/
すいみんぼうすいは /睡眠紡錘波/
すいみんやく /睡眠薬/
すいめつ /衰滅/
すいめん /水面/錐面/睡眠/
すいめんか /水面下/
すいめんじょう /水面上/
すいめんは /水面波/
すいめんふきん /水面付近/
すいもく /水木/
すいもくきん /水木金/
すいもの /吸物/
すいもん /水門/
すいよう /水曜/水溶/
すいようえき /水溶液/
すいようせい /水溶性/
すいようび /水曜日/
すいようびはつ /水曜日発/
すいよく /水浴/
すいらい /水雷/
すいらいせん /水雷戦/
すいらいせんたい /水雷戦隊/
すいらいてい /水雷艇/
すいらん /翠嵐/
すいり /推理/水利/
すいりく /水陸/
すいりけん /水利権/
すいりしょう /推理賞/
すいりしょうせつ /推理小説/
すいりゅう /水流/水竜/
すいりゅうし /水龍士/
すいりょう /水量/推量/
すいりょく /水力/推力/
すいりょくせいぎょ /推力制御/
すいりょくはつでん /水力発電/
すいりょくはつでんしょ /水力発電所/
すいれい /水冷/
すいれいか /水冷化/
すいれいしき /水冷式/
すいれん /睡蓮/
すいれんあか /スイレン亜科/Nymphaeoideae/
すいれんか /スイレン科/Nymphaeaceae/
すいろ /水路/
すいろちょうせいしつ /水路調整室/
すいろぶ /水路部/
すいろん /推論/
すいろんかてい /推論過程/
すいろんきこう /推論機構/
すいろんきそく /推論規則/
すいろんしゅうやくてき /推論集約的/
すいろんちしき /推論知識/
すいろんのうりょく /推論能力/
すいろんぶ /推論部/
すいろんほうしき /推論方式/
すいんぐ /スイング/
すう /数/趨/雛/枢/嵩/崇/數/樞/芻/菘/鄒/陬/四/
すう> /数/
すうあんこ /四暗刻/
すうあんこう /四暗刻/
すうい /趨異/
すういんすう /数引数/
すうぇーでん /瑞典/
すうえき /数駅/
すうおく /数億/
すうおん /数音/
すうかい /数回/
すうかいけん /数解研/数理解析研究所/
すうかいさんか /数回参加/
すうかいしゅうり /数回修理/
すうかいしよう /数回使用/
すうかいちょう /数階調/
すうかいていど /数回程度/
すうかげつ /数ヶ月/数か月/数カ月/
すうかげつかん /数か月間/数カ月間/
すうかげつまえ /数か月前/数箇月前/数カ月前/
すうかしょ /数ヶ所/数個所/数箇所/数カ所/
すうかん /数巻/
すうがく /数学/
すうがくか /数学科/
すうがくかい /数学会/
すうがくかいせつしょ /数学解説書/
すうがくかくちょう /数学拡張/
すうがくかん /数学観/
すうがくかんけい /数学関係/
すうがくかんけいしゃ /数学関係者/
すうがくかんすう /数学関数/
すうがくがいねん /数学概念/
すうがくがくしゅう /数学学習/
すうがくがくしゅうかん /数学学習観/
すうがくきごう /÷/≦/∞/∴/∈/⇒/⇔/∀/∃/∂/√/∫/±/≠/≧/∋/⊆/⊇/⊂/⊃/∪/∩/∧/∨/¬/∝/
すうがくきそ /数学基礎/
すうがくきそろん /数学基礎論/
すうがくきょういく /数学教育/
すうがくきょうし /数学教師/
すうがくきょうしつ /数学教室/
すうがくけい /数学系/
すうがくけいさんきしつ /数学計算機室/
すうがくけいもうしょ /数学啓蒙書/
すうがくけんてい /数学検定/
すうがくけんていきょうかい /数学検定協会/
すうがくけんていしけん /数学検定試験/
すうがくげんご /数学言語/
すうがくご /数学語/
すうがくし /数学史/
すうがくしゃ /数学者/
すうがくしゅっしん /数学出身/
すうがくしょ /数学書/
すうがくしょう /数学賞/
すうがくしんりがく /数学心理学/
すうがくじてん /数学辞典/数学事典/
すうがくじてんてき /数学辞典的/
すうがくじゅけん /数学受験/
すうがくせんこう /数学専攻/
すうがくせんもん /数学専門/
すうがくせんもんか /数学専門家/
すうがくぜんたい /数学全体/
すうがくたいけい /数学体系/
すうがくちしき /数学知識/
すうがくてき /数学的/
すうがくてきかいとう /数学的回答/
すうがくてきがいねん /数学的概念/
すうがくてききそ /数学的基礎/
すうがくてききのうほう /数学的帰納法/
すうがくてきぎこう /数学的技巧/
すうがくてきけんしょう /数学的検証/
すうがくてきげんご /数学的言語/
すうがくてきこうぞう /数学的構造/
すうがくてきしこう /数学的思考/
すうがくてきしんり /数学的真理/
すうがくてきすいろん /数学的推論/
すうがくてきせいぶつぶつり /数学的生物物理/
すうがくてきせっきん /数学的接近/
すうがくてきそうさ /数学的操作/
すうがくてきそくめん /数学的側面/
すうがくてきたいけい /数学的体系/
すうがくてきたいしょう /数学的対象/
すうがくてきちしき /数学的知識/
すうがくてきちょっかん /数学的直感/数学的直観/
すうがくてきのうりょく /数学的能力/
すうがくてきほうほう /数学的方法/
すうがくてきようご /数学的用語/
すうがくてきりろん /数学的理論/
すうがくてきろんしょう /数学的論証/
すうがくとしょしつ /数学図書室/
すうがくにゅうもん /数学入門/
すうがくのうりょく /数学能力/
すうがくばたけ /数学畑/
すうがくひょうろんか /数学評論家/
すうがくぶ /数学部/
すうがくぶんや /数学分野/
すうがくもでる /数学モデル/
すうがくや /数学屋/
すうがくよう /数学用/
すうがくようご /数学用語/
すうがくりょく /数学力/
すうがくりろん /数学理論/
すうがくろん /数学論/
すうがそ /数画素/
すうがっか /数学科/
すうがっかい /数学会/
すうがめん /数画面/
すうき /数期/数基/数奇/数機/
すうきかん /数機関/
すうききょう /枢機卿/
すうきょうきょう /数教協/
すうきょく /数曲/数局/
すうぎょう /数行/
すうけい /崇敬/
すうけた /数桁/
すうけん /数件/数研/数理解析研究所/数軒/
すうげき /数撃/
すうこ /数個/
すうこう /数項/数校/崇高/
すうこく /数刻/
すうご /数語/
すうごう /数号/
すうさく /数作/
すうさつ /数冊/
すうし /数詞/
すうしあい /数試合/
すうしいほう /四喜和/
すうしき /数式/
すうしきかいせき /数式解析/
すうしきかんきょう /数式環境/
すうしききごう /数式記号/
すうしきしょり /数式処理/
すうしきしょりげんご /数式処理言語/
すうしきてき /数式的/
すうしきひょうじ /数式表示/
すうしきへんしゅう /数式編集/
すうしきもーど /数式モード/
すうしきもうど /数式モード/
すうしきよう /数式用/
すうしゃ /数社/
すうしゃしゅ /数車種/
すうしゅ /数種/
すうしゅう /数周/数週/
すうしゅうかん /数週間/
すうしゅうかんご /数週間後/
すうしゅうかんまえ /数週間前/
すうしゅうまえ /数週前/数周前/
すうしゅるい /数種類/
すうしゅるいついか /数種類追加/
すうしゅん /数瞬/
すうしょうせつ /数小節/
すうじ /数字/数次/
すうじいじょう /数字以上/
すうじおんせい /数字音声/
すうじかん /数時間/
すうじかんご /数時間後/
すうじかんていど /数時間程度/
すうじく /枢軸/樞軸/
すうじしてい /数字指定/
すうじじたい /数字自体/
すうじじょう /数字上/
すうじっかい /数十回/
すうじっかいいじょう /数十回以上/
すうじっかしょ /数十箇所/
すうじっこ /数十個/
すうじっつう /数十通/
すうじっぷん /数十分/
すうじっぽん /数十本/
すうじつ /数日/
すうじついない /数日以内/
すうじつかん /数日間/
すうじつご /数日後/
すうじつちゅう /数日中/
すうじつぶん /数日分/
すうじつまえ /数日前/
すうじつらい /数日来/
すうじにんしき /数字認識/
すうじふたけた /数字二桁/
すうじゅう /数十/
すうじゅうえん /数十円/
すうじゅうおく /数十億/
すうじゅうおくねんまえ /数十億年前/
すうじゅうじかん /数十時間/
すうじゅうだい /数十台/
すうじゅうにん /数十人/
すうじゅうねん /数十年/
すうじゅうねんまえ /数十年前/
すうじゅうばい /数十倍/
すうじゅうび /数十尾/
すうじゅうびょうかん /数十秒間/
すうじゅうへいほう /数十平方/
すうじゅうまい /数十枚/
すうじゅうまん /数十万/
すうじゅうまんえん /数十万円/
すうじゅうまんにん /数十万人/
すうじゅっかい /数十回/
すうじゅっかいいじょう /数十回以上/
すうじゅっき /数十機/
すうじゅっこ /数十個/
すうじゅっさつ /数十冊/
すうじゅっしゅるい /数十種類/
すうじゅっつう /数十通/
すうじゅっぷん /数十分/
すうじゅっぷんかん /数十分間/
すうじゅっぷんまえ /数十分前/
すうじゅっぽん /数十本/
すうじょう /数条/
すうじれつ /数字列/
すうせい /趨勢/
すうせいき /数世紀/
すうせいきご /数世紀後/
すうせいきまえ /数世紀前/
すうせみ /数セミ/
すうせん /数千/数戦/
すうせんえん /数千円/
すうせんおく /数千億/
すうせんかい /数千回/
すうせんさつ /数千冊/
すうせんじかん /数千時間/
すうせんにん /数千人/
すうせんねん /数千年/
すうせんねんまえ /数千年前/
すうせんぼん /数千本/
すうせんまい /数千枚/
すうせんまん /数千万/
すうせんまんえん /数千万円/
すうせんまんにん /数千万人/
すうたいけい /数体系/
すうだい /数台/
すうだいまえ /数台前/数代前/
すうだん /数段/
すうだんうえ /数段上/
すうち /数値/
すうちいがい /数値以外/
すうちえんざん /数値演算/
すうちえんざんかんすう /数値演算関数/
すうちおんじょう /数値音場/
すうちか /数値化/
すうちかい /数値解/
すうちかいせき /数値解析/
すうちかいせきけっか /数値解析結果/
すうちかいせきほう /数値解析法/
すうちかいほう /数値解法/
すうちきしょう /数値記象/
すうちけいさん /数値計算/
すうちけいさんおうよう /数値計算応用/
すうちけいさんこうがく /数値計算工学/
すうちけいさんへん /数値計算編/
すうちけんきゅう /数値研究/
すうちしょしき /数値書式/
すうちしょり /数値処理/
すうちしょりよう /数値処理用/
すうちじっけん /数値実験/
すうちせきぶん /数値積分/
すうちていすう /数値定数/
すうちてき /数値的/
すうちてきけんきゅう /数値的研究/
すうちないよう /数値内容/
すうちにゅうりょく /数値入力/
すうちひょうげん /数値表現/
すうちぶんさん /数値分散/
すうちもでる /数値モデル/
すうちょくせん /数直線/
すうちよほう /数値予報/
すうちりゅうたいりきがく /数値流体力学/
すうちりょういき /数値領域/
すうちれい /数値例/
すうつう /数通/
すうて /数手/
すうてき /数滴/数的/
すうてん /数点/数店/
すうとう /数頭/
すうど /数度/
すうにち /数日/
すうにちかん /数日間/
すうにん /数人/
すうにんていど /数人程度/
すうにんひつよう /数人必要/
すうにんぶん /数人分/
すうねん /数年/
すうねんかん /数年間/
すうねんご /数年後/
すうねんさき /数年先/
すうねんほどまえ /数年程前/
すうねんまえ /数年前/
すうねんまえいぜん /数年前以前/
すうねんらい /数年来/
すうはい /崇拝/
すうはいぶつ /崇拝物/
すうはつ /数発/
すうば /数馬/
すうばい /数倍/
すうぱい /数牌/
すうひき /数匹/
すうひゃく /数百/
すうひゃくえん /数百円/
すうひゃくえんていど /数百円程度/
すうひゃくおくこうねん /数百億光年/
すうひゃくじかん /数百時間/
すうひゃくだい /数百台/
すうひゃくにち /数百日/
すうひゃくにん /数百人/
すうひゃくねん /数百年/
すうひゃくねんいじょう /数百年以上/
すうひゃくねんご /数百年後/
すうひゃくねんさき /数百年先/
すうひゃくばい /数百倍/
すうひゃくぺーじ /数百頁/
すうひゃくまん /数百万/
すうひゃくまんにん /数百万人/
すうひゃくまんねん /数百万年/
すうひゃくまんまい /数百万枚/
すうひゃくめい /数百名/
すうひゃくもじごと /数百文字毎/
すうひゃっかい /数百回/数百階/
すうひゃっき /数百機/
すうひゅく /数百/
すうひょう /数表/数票/
すうひょうき /数表記/
すうびょう /数秒/
すうびょうかん /数秒間/
すうびょうご /数秒後/
すうふん /数分/
すうふんいない /数分以内/
すうふんかん /数分間/
すうふんご /数分後/
すうふんたんしゅく /数分短縮/
すうぶつ /数物/
すうぶつけい /数物系/
すうへいほう /数平方/
すうぺーじ /数ページ/
すうぺいじ /数ページ/
すうほん /数本/
すうまい /数枚/
すうまん /数万/
すうまんえん /数万円/
すうまんえんていど /数万円程度/
すうまんかいてん /数万回転/
すうまんにん /数万人/
すうまんにんたんい /数万人単位/
すうまんねん /数万年/
すうまんねんまえ /数万年前/
すうまんばい /数万倍/
すうみつ /枢密/
すうみつど /数密度/
すうめい /数名/
すうめいいじょう /数名以上/
すうめいぶん /数名分/
すうもじ /数文字/
すうもん /数問/
すうり /数理/数理情報科学/
すうりかい /数理解/
すうりかいせき /数理解析/
すうりかいせきけん /数理解析研/
すうりかいせきけんきゅうしょ /数理解析研究所/
すうりかがく /数理科学/
すうりかがくけんきゅうか /数理科学研究科/
すうりかがくこうざ /数理科学講座/
すうりかがくてき /数理科学的/
すうりかがっか /数理科学科/
すうりがく /数理学/
すうりがっか /数理学科/
すうりぎけん /数理技研/
すうりけい /数理系/
すうりけいかくほう /数理計画法/
すうりけいかくもんだい /数理計画問題/
すうりけいそく /数理計測/
すうりけん /数理研/数理解析研究所/
すうりげんごがく /数理言語学/
すうりこうがく /数理工学/
すうりこうがくか /数理工学科/
すうりこうがくてき /数理工学的/
すうりこうがっか /数理工学科/
すうりしすてむ /数理システム/
すうりじょうほう /数理情報/
すうりじょうほうかがく /数理情報科学/
すうりじょうほうがく /数理情報学/
すうりじょうほうがっか /数理情報学科/
すうりじょうほうこうざ /数理情報講座/
すうりせいぶつがく /数理生物学/
すうりてき /数理的/
すうりてききそ /数理的基礎/
すうりてつがく /数理哲学/
すうりとうけい /数理統計/
すうりもでる /数理モデル/
すうりょう /数量/
すうりょうか /数量化/
すうりょうかんけい /数量関係/
すうりょうてき /数量的/
すうりろんり /数理論理/
すうりろんりがく /数理論理学/
すうりろんりがくてき /数理論理学的/
すうれい /数例/
すうれつ /数列/
すうれつめ /数列目/
すうろん /数論/
すうろんてき /数論的/
すうわ /数話/
すうわぶん /数話分/
すうわり /数割/
すえ /末/据/陶/甄/裔/須恵/
すえあし /末足/
すえいし /末石/
すえお /末男/季雄/
すえおか /末岡/
すえおきがた /据置型/据置形/
すえかね /末包/
すえき /末木/
すえきち /末吉/
すえごろ /末頃/
すえざき /末崎/
すえじ /末治/
すえじま /末島/
すえっこ /末っ子/
すえつぐ /末次/
すえつけ /据付/
すえつむはな /末摘花/
すえなが /末永/
すえひろ /末広/
すえひろちょう /末広町/
すえまさ /末政/
すえまつ /末松/
すえみつ /末光/
すえやす /末安/
すえよし /末善/末吉/
すおう /周防/須王/
すかーと /スカート/
すかーれっと /スカーレット/
すかいほーる /スカイホール/
すかうと /スカウト/
すかがわ /須賀川/
すかさず /透かさず/
すかゆ /酢ケ湯/酸ヶ湯/
すから /スカラ/
すかんぴん /素寒貧/
すが /菅/須賀/管/須ヶ/
すがい /菅井/須貝/
すがお /素顔/菅尾/
すがさわ /菅澤/
すがすが /清々/
すがすがしさ /清々しさ/
すがた /姿/菅田/
すがたかたち /姿形/
すがたみ /姿見/
すがだいら /菅平/
すがちょう /須賀町/
すがぬま /菅沼/
すがの /菅野/
すがはら /菅原/
すがむら /管村/
すがも /巣鴨/
すがもかん /巣鴨間/
すがもと /菅本/
すがや /菅谷/
すがわ /須川/
すがわら /菅原/管原/
すき /隙/好き/鍬/鋤/耒/漉/須木/犂/数寄/
すきー /スキー/
すきーじょう /スキー場/
すきーやー /スキーヤー/
すきかって /好き勝手/
すききらい /好き嫌い/
すきぎ /透木/
すきぐし /篦/
すきしゃ /数寄者/
すきずき /好きずき/
すきっぷ /スキップ/
すきま /隙間/すき間/透き間/
すきまかぜ /隙間風/
すきみ /透見/
すきもの /好き者/
すきゃん /スキャン/
すきゃんだる /スキャンダル/
すきや /数奇屋/
すきやばし /数寄屋橋/数奇屋橋/
すきる /スキル/
すぎ /椙/杉/過ぎ/
すぎうち /杉内/
すぎうら /杉浦/
すぎえ /杉江/
すぎおか /杉岡/
すぎかふん /杉花粉/
すぎがき /杉垣/
すぎき /杉木/
すぎさき /杉崎/
すぎさわ /杉沢/
すぎざい /杉材/
すぎざき /杉崎/
すぎした /杉下/
すぎた /杉田/
すぎたこ /杉タコ/
すぎたに /杉谷/
すぎつま /杉妻/
すぎと /杉戸/
すぎとう /杉藤/
すぎなみ /杉並/
すぎなみく /杉並区/
すぎなみこうこう /杉並高校/
すぎぬま /杉沼/
すぎの /杉野/
すぎのした /杉之下/
すぎのはら /杉ノ原/
すぎはら /杉原/
すぎばやし /杉林/
すぎまち /杉町/
すぎむら /杉村/
すぎもと /杉本/
すぎもとちょう /杉本町/
すぎやま /杉山/椙山/
すぎりょうたろう /杉良太郎/
すく /少/
すくーぷ /スクープ/
すくーる /スクール/
すくいなげ /掬い投げ/
すくない /少ない/
すくなくとも /少なくとも/
すくなめ /少な目/
すくも /宿毛/粭/糘/
すくりーん /スクリーン/
すくろーる /スクロール/
すぐ /直/
すぐさま /直ぐ樣/
すぐり /村主/
すぐる /卓/勝/俊/英/
すけ /介/助/輔/祐/資/甫/佑/亮/丞/
すけーと /スケート/
すけーる /スケール/
すけかつ /資勝/
すけがわ /助川/
すけさこ /助迫/
すけじゅーる /スケジュール/
すけだち /助太刀/
すけっち /スケッチ/
すけっと /助っ人/助人/
すけのぶ /助信/
すけべ /スケベ/
すけよし /祐好/
すけろく /助六/
すげ /菅/
すげかわ /菅河/
すげない /素気ない/
すげぬま /菅沼/
すこーぷ /スコープ/
すこあ /スコア/
すこし /少し/
すこしも /少しも/
すこっとらんど /蘇格蘭/
すこぶる /頗/頗る/
すこやか /健やか/
すこら /スコラ/
すご /凄/
すごい /凄い/
すごう /菅生/
すごうせん /菅生戦/
すごうで /凄腕/
すごさ /凄さ/
すごしかた /過ごし方/
すごみ /凄味/
すごろく /双六/
すさ /須佐/
すさか /須坂/
すさき /須崎/
すさのおのみこと /須佐之男命/
すさまじさ /凄まじさ/
すさみ /須佐美/
すざか /須坂/
すざき /寿崎/洲崎/
すざく /朱雀/
すざわ /須沢/
すし /寿司/鮨/鮓/
すしづめ /寿司詰め/
すしてん /寿司店/
すしめし /鮨飯/
すしや /寿司屋/
すしょうきゅう /水晶宮/
すじ /筋/
すじあい /筋合/
すじかい /筋交い/
すじがき /筋書き/筋書/
すじがね /筋金/
すじがねいり /筋金入り/
すじこ /筋子/
すじちがい /筋違い/
すじみち /筋道/
すじめ /筋目/
すじゃく /朱雀/
すじや /筋屋/
すじゅうびょう /数十秒/
すじょう /素性/素姓/巣状/素場/
すじょうゆ /酢醤油/
すす /煤/
すすき /薄/芒/
すすきた /薄田/
すすきの /薄野/
すすみかた /進み方/
すすむ /晋/進/晉/奨/
すすめかた /進め方/
すすりなき /啜り泣き/
すず /鈴/錫/珠洲/スズ/鑾/
すずい /鈴井/
すずおき /鈴置/
すずか /鈴鹿/鈴香/
すずかしない /鈴鹿市内/
すずかぜ /涼風/
すずかちく /鈴鹿地区/
すずかとうげ /鈴鹿峠/
すずき /鈴木/鱸/
すずきあぐり /鈴木亜久里/
すずきほなみ /鈴木保奈美/
すずし /生絹/
すずしま /鈴嶋/
すずたに /鈴谷/
すずたん /鈴丹/
すずなり /鈴生り/
すずのすけ /鈴之助/
すずひこ /鈴彦/
すずむし /鈴虫/
すずむら /鈴村/
すずめ /雀/
すずめがおか /雀ヶ丘/
すずや /鈴谷/
すずやま /鈴山/
すずよ /鈴世/
すずらん /鈴蘭/
すずらんこうげん /鈴蘭高原/
すずり /硯/碩/
すずりや /硯屋/
すそ /裾/
すそとり /裾取り/
すその /裾野/
すそのし /裾野市/
すそのしざいじゅう /裾野市在住/
すそはらい /裾払い/
すそわけ /裾分け/
すたー /スター/
すたーと /スタート/
すたーりん /スターリン/
すたいる /スタイル/
すたじお /スタジオ/
すたっふ /スタッフ/
すたでぃ /スタディ/
すたみな /スタミナ/
すたんだーど /スタンダード/
すたんど /スタンド/
すたんぷ /スタンプ/
すたんれーでんき /スタンレー電気/
すだ /須田/
すだち /巣立ち/
すだま /須玉/
すだれ /簾/
すちーる /スチール/
すちろーる /スチロール/
すっとんきょう /素頓狂/
すっぱ /素破/透波/
すてーしょん /ステーション/
すてーじ /ステージ/
すていし /捨て石/
すてき /素敵/素的/
すてご /捨て子/
すてっかー /ステッカー/
すてっぷ /ステップ/
すてね /捨て値/
すてはい /捨て牌/
すてば /捨て場/
すてぱい /捨牌/
すてみ /捨て身/
すてやく /捨役/
すてれお /ステレオ/
すてんれす /ステンレス/
すで /既/素手/已/
すでに /既に/已に/
すと /スト/
すとーりー /ストーリー/
すとあ /ストア/
すとあー /ストアー/
すとう /須藤/周東/
すとく /崇徳/
すとっきんぐ /ストッキング/
すとっく /ストック/
すとっぷ /ストップ/
すとらいき /ストライキ/
すとりーと /ストリート/
すとれーと /ストレート/
すとれす /ストレス/
すとろーく /ストローク/
すとろべりー /ストロベリー/
すどう /須藤/
すどうふ /酢豆腐/
すどおし /素通し/
すどおり /素通り/
すな /砂/沙/
すなあらし /砂嵐/
すなお /素直/淳/砂緒/
すなおとこ /砂男/
すなかけばばあ /砂掛婆/
すなかわ /砂川/
すなかわえき /砂川駅/
すなかわしせん /砂川支線/
すなが /須永/
すながわ /砂川/
すながわいき /砂川行/
すながわちょう /砂川町/
すながわゆき /砂川行/
すなぎも /砂肝/
すなくら /砂倉/
すなけし /砂ケシ/
すなけむり /砂煙/
すなこ /砂子/
すなじ /砂地/
すなだ /砂田/
すなち /砂地/
すなっく /スナック/
すなっぷ /スナップ/
すなづるあか /スナヅル亜科/Cassythoideae/
すなどけい /砂時計/
すなぬき /砂抜き/
すなはち /則ち/即ち/
すなはま /砂浜/
すなはら /砂原/
すなば /砂場/
すなぶろ /砂風呂/
すなぼこり /砂埃/
すなみ /角南/巣南/
すなむし /砂蟲/
すなめり /鯆/砂滑/
すなわち /即ち/則ち/曾ち/曽ち/
すね /脛/臑/
すねかじり /臑かじり/
すねげ /すね毛/
すのこ /簀の子/
すのはら /春原/須野原/
すのまた /墨俣/
すのもの /酢の物/
すはだ /素肌/
すはら /寿原/栖原/須原/
すばこ /巣箱/
すばやさ /素早さ/
すばらしい /素晴しい/
すばる /昴/
すぱーく /スパーク/
すぱい /スパイ/
すぱげってぃ /スパゲッティ/
すぱん /スパン/
すびつ /炭櫃/
すぴーか /スピーカ/
すぴーち /スピーチ/
すぴーど /スピード/
すぴん /スピン/
すぷーる /スプール/
すべ /術/
すべからく /須く/須らく/
すべて /全て/総/総て/總/凡て/
すべり /辷/
すぺーす /スペース/
すぺあ /スペア/
すぺいん /スペイン/西班牙/
すぺいんご /スペイン語/
すぺくとる /スペクトル/
すぺしゃりすと /スペシャリスト/
すぺりんぐ /スペリング/
すぺる /スペル/
すぽーつ /スポーツ/
すぽっと /スポット/
すぽんさ /スポンサ/
すぽんさー /スポンサー/
すま /須磨/
すまーと /スマート/
すまい /住まい/営/住居/住い/
すまえき /須磨駅/
すまた /寸又/
すまたきょう /寸又峡/
すまちょう /須磨町/
すみ /済/隅/墨/純/澄/角/須見/住/炭/寿/須美/澂/濟/陬/
すみえ /純恵/スミ恵/寿美江/墨絵/澄江/
すみお /澄雄/澄夫/純雄/
すみか /住みか/住み家/住化/住処/鈴美香/棲み家/住み処/
すみかわ /澄川/
すみきん /住金/
すみぎん /住銀/
すみこ /澄子/寿美子/純子/
すみごこち /住み心地/
すみさわ /隅沢/
すみしょう /住商/
すみずみ /隅々/
すみそ /酢味噌/
すみぞめ /墨染/
すみた /住田/角田/
すみだ /墨田/隅田/住田/
すみだがわ /隅田川/墨田川/
すみだがわけっせん /隅田川決戦/
すみだく /墨田区/
すみっこ /隅っこ/
すみでん /住電/
すみと /澄人/
すみとも /住友/
すみともかがく /住友化学/
すみともかがくこうぎょう /住友化学工業/
すみともきんぞく /住友金属/
すみともきんぞくこうぎょう /住友金属工業/
すみともぎんこう /住友銀行/
すみともけんせつ /住友建設/
すみともしょうじ /住友商事/
すみともせいやく /住友製薬/
すみともせめんと /住友セメント/
すみともそうこ /住友倉庫/
すみともでんきこうぎょう /住友電気工業/
すみともでんこう /住友電工/
すみともふどうさん /住友不動産/
すみの /角野/墨野/
すみのえ /住之江/住江/
すみのどう /住道/
すみひら /住平/
すみび /炭火/
すみびやき /炭火焼/
すみません /済みません/
すみもと /住元/住本/
すみや /隅谷/住谷/墨屋/角屋/
すみやか /澄みやか/速やか/
すみやき /炭焼/
すみよ /純代/
すみよう /住用/
すみよし /住吉/澄義/
すみよしえき /住吉駅/
すみよしがわ /住吉川/
すみよしだい /住吉台/
すみよしちょう /住吉町/
すみれ /菫/
すみれもく /スミレ目/Violales/
すむ /住む/
すむーす /スムース/
すめらぎ /皇/天皇/
すもう /相撲/
すもうかい /相撲界/
すもうきょうかい /相撲協会/
すもうけん /相撲券/
すもうしょたい /相撲書体/
すもうせんしゅけん /相撲選手権/
すもうちゅうけい /相撲中継/
すもうとり /相撲取/相撲とり/
すもうにんき /相撲人気/
すもうべや /相撲部屋/
すもうもじ /相撲文字/
すもっぐ /スモッグ/
すもと /洲本/須本/栖本/
すもも /李/
すもん /守門/
すやき /素焼/
すやま /須山/隅山/
すら /／/
すらいす /スライス/
すらいど /スライド/
すらっしゅ /／/
すり /刷/摺/掏摸/
すりあがり /刷り上がり/
すりえ /擂り餌/
すりきず /擦り傷/
すりこぎ /擂り粉木/擂粉木/摺子木/
すりっと /スリット/
すりっとこう /スリット光/
すりっとぞう /スリット像/
すりっとばんごう /スリット番号/
すりっぱ /スリッパ/
すりっぷ /スリップ/
すりつぶ /すり潰/
すりばち /すり鉢/擂鉢/擂り鉢/摺鉢/
すりみ /摺身/
すりもの /刷り物/
すりる /スリル/
する /駿/
するーぷっと /スループット/
するが /駿河/
するがぎんこう /駿河銀行/
するがだい /駿河台/
するがだいした /駿河台下/
するがや /駿河屋/
するがわん /駿河湾/
するどさ /鋭さ/
するめ /鯣/
するめいか /するめイカ/
すれすれ /擦々/摩々/
すろーがん /スローガン/
すろうにん /素浪人/
すろっとる /スロットル/
すわ /諏訪/須羽/
すわおんせん /諏訪温泉/
すわこ /諏訪湖/
すわし /諏訪市/
すわじんじゃ /諏訪神社/
すわたいしゃ /諏訪大社/
すわちほう /諏訪地方/
すわない /諏訪内/
すわみなみ /諏訪南/
すわやま /諏訪山/
すん /寸/
すんか /寸暇/
すんけい /寸勁/
すんげき /寸劇/
すんげん /寸言/
すんごう /寸毫/
すんし /寸志/
すんしゅう /駿州/
すんじ /寸時/
すんぜん /寸前/
すんぜんしゃくま /寸善尺魔/
すんだい /駿台/
すんだいがくえん /駿台学園/
すんだいせい /駿台生/
すんだいもし /駿台模試/
すんだん /寸断/
すんてつ /寸鉄/
すんで /既/
すんとう /駿東/
すんどめ /寸止め/
すんひょう /寸評/
すんぴょう /寸評/
すんぶん /寸分/
すんぷじょう /駿府城/
すんぽう /寸法/
すんぽうち /寸法値/
すんわ /寸話/
ず /図/頭/津/逗/厨/寿/鶴/圖/廚/讎/讐/豆/Figure/
ず# /図#1/
ずーむ /ズーム/
ずあん /図案/
ずい /髄/瑞/随/蕊/惴/隋/膸/蘂/蕋/隨/隧/髓/
ずいい /随意/
ずいいすじ /随意筋/
ずいいち /随一/
ずいいん /随員/
ずいうん /瑞運/瑞雲/
ずいえん /隋圜/随縁/
ずいかく /瑞鶴/
ずいこう /随行/
ずいしょ /随所/隨處/
ずいしょう /瑞祥/
ずいじ /随時/
ずいじうけつけ /随時受付/
ずいじはっぴょう /随時発表/
ずいじょう /髄状分裂組織/
ずいじょうぶんれつそしき /髄状分裂組織/
ずいせんじ /瑞泉寺/
ずいそう /随想/
ずいだい /隋代/
ずいちょう /瑞兆/
ずいどう /隧道/
ずいはん /随伴/
ずいはんかんしゅ /随伴函手/
ずいはんけいすう /随伴係数/
ずいはんじゅうそしき /随伴柔組織/
ずいひつ /随筆/隨筆/
ずいひつか /随筆家/
ずいひつしゅう /随筆集/
ずいぶん /随分/隨分/
ずいぶんいぜん /随分以前/
ずいぶんまえ /随分前/
ずいぶんむかし /随分昔/
ずいぶんれつそしき /髄分裂組織/
ずいほうでん /瑞鳳殿/
ずいまく /髄膜/
ずいまくえん /髄膜炎/
ずいむし /螟虫/
ずうたい /図体/
ずか /図化/
ずかい /図解/
ずかいしょ /図解書/
ずかん /図鑑/
ずかんるい /図鑑類/
ずが /図画/
ずがい /頭骸/頭蓋/
ずがいこつ /頭蓋骨/頭骸骨/
ずがいこつけいじょう /頭蓋骨形状/
ずがいこつこっせつ /頭蓋骨骨折/
ずがく /図学/
ずがら /図柄/
ずきん /頭巾/
ずけ /付/附/
ずけい /図形/◆/
ずけいかがくきょうしつ /図形科学教室/
ずけいきじゅつ /図形記述/
ずけいしゅつりょく /図形出力/
ずけいしょり /図形処理/
ずけいてき /図形的/
ずけいはいち /図形配置/
ずけいひょうき /図形表記/
ずけいひょうじ /図形表示/
ずけいひょうじかのう /図形表示可能/
ずけいへんしゅう /図形編集/
ずけいへんしゅうかのう /図形編集可能/
ずけいもじ /図形文字/
ずけいようそ /図形要素/
ずけらん /瑞慶覧/
ずけん /図研/
ずこう /図工/図功/
ずさくせい /図作成/
ずさん /杜撰/
ずし /図示/逗子/寿司/鮨/
ずしかいがん /逗子海岸/
ずしき /図式/
ずしきか /図式化/
ずしきてき /図式的/
ずしこつぼこう /逗子小坪港/
ずしほうめん /逗子方面/
ずしょうりゃく /図省略/
ずしょのかみ /図書頭/
ずじ /図示/
ずじょう /図上/頭上/
ずせつ /図説/
ずぞうがく /図像学/
ずちゅう /図中/
ずっきーに /ズッキーニ/
ずつう /頭痛/
ずつき /頭突き/
ずてき /図的/
ずてきげんご /図的言語/
ずどり /図取り/
ずのう /頭脳/
ずのうてき /頭脳的/
ずのうない /頭脳内/
ずのうめいせき /頭脳明晰/
ずはん /図版/
ずばん /図版/図番/
ずばんごう /図番号/
ずばんしゅう /図版集/
ずひょう /図表/
ずひょうばんごう /図表番号/
ずひょうばんごうしゅつりょく /図表番号出力/
ずひょうるい /図表類/
ずふ /図譜/
ずぶねり /頭捻り/
ずほう /図法/
ずぼし /図星/
ずぼん /ズボン/
ずみ /済/桷/濟/済み/
ずめ /詰/
ずめん /図面/
ずめんかんり /図面管理/
ずめんちょう /図面帳/
ずり /刷/
ずりょう /受領/
ずる /ズル/
ずろく /図録/
ずんどう /寸胴/
せ /背/瀬/世/畝/勢/施/丗/畆/脊/衰/
せーたー /セーター/
せーぬ /塞納/折奴/
せーふ /セーフ/
せーぶ /セーブ/
せーる /セール/
せーるす /セールス/
せい /性/生/正/製/世/精/成/姓/星/声/西/制/青/勢/静/聖/清/牲/請/誠/整/盛/醒/斉/政/誓/逝/棲/晴/靖/省/栖/征/凄/齊/鯖/情/貰/所為/丗/嘶/悽/惺/掣/撕/擠/旌/晟/淒/睛/穽/筬/聲/腥/臍/萋/菁/蜻/齎/躋/靜/齏/韲/井/甥/歳/犀/錆/鉦/瀞/婿/背/
せい> /性/正/
せいあい /性愛/
せいあく /性悪/
せいあくせつ /性悪説/
せいあつ /制圧/静圧/
せいあん /成案/西安/
せいい /誠意/征夷/凄異/
せいいき /声域/整域/聖域/西域/
せいいきせい /整域性/
せいいく /成育/生育/
せいいくご /成育後/
せいいそう /正位相/
せいいち /聖一/正一/清一/精一/誠一/正位置/誠市/誓一/
せいいちろう /晴一郎/清一郎/精一郎/誠一郎/
せいいっぱい /精一杯/精いっぱい/
せいいん /成員/正員/成因/
せいう /晴雨/
せいうち /海象/
せいうん /青雲/星雲/盛運/
せいうんしゃ /星雲社/
せいうんしょう /星雲賞/
せいうんせいだん /星雲星団/
せいうんまる /青雲丸/
せいえい /清栄/精鋭/
せいえき /精液/
せいえきちゅう /性液中/
せいえつ /誠悦/凄咽/
せいえん /西遠/声援/製塩/正円/
せいえんぎょう /製塩業/
せいおう /西欧/
せいおうがた /西欧型/
せいおうしょこく /西欧諸国/
せいおうじん /西欧人/
せいおうてき /西欧的/
せいおうぶんめい /西欧文明/
せいおうりゅう /西欧流/
せいおおぜき /正大関/
せいおん /清音/生温/静穏/整音/
せいか /成果/西夏/精華/正価/正課/生家/生花/盛夏/聖火/製菓/青果/成香/正佳/正貨/精化/聖歌/生化/惺窩/清華/
せいかい /正解/盛会/政界/制海/精解/青海/
せいかいいん /正会員/
せいかいさいへん /政界再編/
せいかいしゃ /正解者/
せいかいちず /政界地図/
せいかいらく /性快楽/
せいかいりつ /正解率/
せいかがく /生化学/性科学/
せいかがくか /生化学科/
せいかがくじてん /生化学辞典/
せいかがくてき /生化学的/
せいかがくてきしゅほう /生化学的手法/
せいかがくや /生化学屋/
せいかぎょう /製菓業/
せいかく /正確/性格/精確/製革/正格/
せいかくけいせい /性格形成/
せいかくけいせいろん /性格形成論/
せいかくしんだん /性格診断/
せいかくじょう /性格上/
せいかくせい /正確性/
せいかくせいじゅうし /正確性重視/
せいかくせってい /性格設定/
せいかくづけ /性格付/
せいかくてき /性格的/
せいかくむひ /正確無比/
せいかけん /製科研/
せいかさんぎょう /西華産業/
せいかじゅう /静荷重/
せいかたいよう /聖歌隊用/
せいかたんでん /臍下丹田/
せいかだい /聖火台/
せいかちょう /精華町/
せいかつ /生活/
せいかついしき /生活意識/
せいかつおんど /生活温度/
せいかつか /生活科/
せいかつかいご /生活介護/
せいかつかがく /生活科学/
せいかつかがくぶ /生活科学部/
せいかつかん /生活感/生活環/
せいかつかんきょう /生活環境/
せいかつかんけい /生活関係/
せいかつかんれん /生活関連/
せいかつかんれんいがい /生活関連以外/
せいかつかんれんじょうほう /生活関連情報/
せいかつきはん /生活規範/
せいかつきばん /生活基盤/
せいかつく /生活苦/
せいかつくうかん /生活空間/
せいかつけん /生活圏/生活権/
せいかつこうどう /生活行動/
せいかつこうぼう /生活工房/
せいかつさんぎょうめん /生活産業面/
せいかつざっか /生活雑貨/
せいかつざんぎょう /生活残業/
せいかつし /生活誌/
せいかつしどう /生活指導/
せいかつしゃ /生活者/生活社/
せいかつしゃはつばい /生活社発売/
せいかつしゅうかん /生活習慣/
せいかつしゅうかんびょう /生活習慣病/
せいかつしんじょう /生活信条/
せいかつじょう /生活上/
せいかつじょうきょう /生活状況/
せいかつじょうほう /生活情報/
せいかつじょうほうよう /生活情報用/
せいかつすいじゅん /生活水準/
せいかつせっけい /生活設計/
せいかつぜんぱん /生活全般/
せいかつたいど /生活態度/
せいかつてき /生活的/
せいかつとし /生活都市/
せいかつなど /生活等/
せいかつはいすい /生活排水/
せいかつひ /生活費/
せいかつひつじゅひん /生活必需品/
せいかつふうしゅう /生活風習/
せいかつぶめん /生活部面/
せいかつほうしき /生活方式/
せいかつほごひ /生活保護費/
せいかつほしょう /生活保障/
せいかつぼうすい /生活防水/
せいかつようひん /生活用品/
せいかつりょく /生活力/
せいかつれっしゃ /生活列車/
せいかてん /成果展/
せいかなし /成果無/
せいかぶつ /青果物/成果物/
せいかほうこくしょ /成果報告書/
せいかよう /製菓用/
せいかん /青函/静観/生還/製缶/製罐/精悍/精管/星間/
せいかんたい /性感帯/
せいかんぶっしつ /星間物質/
せいかんぶんし /星間分子/
せいかんりにん /正管理人/
せいかんれんらくせん /青函連絡船/
せいかんろん /征韓論/
せいが /精華/
せいがく /声学/声楽/
せいがくいん /聖学院/
せいがくおんがく /声楽音楽/
せいがくきょく /声楽曲/
せいがくさくひん /声楽作品/
せいがくさくひんへん /声楽作品編/
せいがくてき /静学的/
せいがくぶ /声楽部/
せいがん /請願/西岸/正眼/青眼/制癌/
せいがんきょうかいりゅう /西岸境界流/
せいがんしゃ /晴眼者/
せいがんじ /誓願寺;京都河原町横にある寺院/
せいがんのかまえ /青眼の構え/
せいがんほうしき /請願方式/
せいき /正規/世紀/生気/生起/精気/精機/性器/聖記/星紀/誠紀/精器/製機/西紀/制機/成樹/盛基/
せいきいぜん /世紀以前/
せいきうへん /正規右辺/
せいきうへんぶんぽう /正規右辺文法/
せいきうんちん /正規運賃/
せいきか /正規化/
せいきかかく /正規価格/
せいきかてい /生起過程/
せいきかりろん /正規化理論/
せいきかん /正帰還/
せいきかんけいひょう /正規関係表/
せいきがぞう /正規画像/
せいきがわ /正規側/
せいきぐん /正規軍/
せいきけい /正規形/
せいきげんご /正規言語/
せいきこう /正規項/
せいきこうくうけん /正規航空券/
せいきこうはん /世紀後半/
せいきし /聖騎士/
せいきしゅうごう /正規集合/
せいきしょうめいず /正規証明図/
せいきしょくいん /正規職員/
せいきじゅん /正規順/
せいきじゅんじょ /正規順序/
せいきせい /正規性/
せいきぞく /正規族/
せいきだいりてん /正規代理店/
せいきち /清吉/
せいきちょっこう /正規直交/
せいきちょっこうきてい /正規直交基底/
せいきちょっこうぎょうれつ /正規直交行列/
せいきちょっこうけい /正規直交系/
せいきてん /正規点/
せいきばん /正規版/正規盤/
せいきひょうげん /正規表現/
せいきひょうげんかんけい /正規表現関係/
せいきひょうげんけんさく /正規表現検索/
せいきぶぶんぐん /正規部分群/
せいきぶんぷ /正規分布/
せいきほうていしき /正規方程式/
せいきまつ /聖飢魔II/世紀末/
せいきゅう /請求/性急/
せいきゅうがく /請求額/
せいきゅうけん /請求権/
せいきゅうこう /請求項/
せいきゅうさき /請求先/
せいきゅうしゃ /請求者/
せいきゅうしょ /請求書/
せいきゅうしょるい /請求書類/
せいきゅうひょう /請求票/
せいきゅうほう /請求法/
せいきゅうりょく /制球力/
せいきゆにゅうしゃ /正規輸入車/
せいきゆにゅうもと /正規輸入元/
せいきょ /逝去/盛挙/
せいきょう /生協/盛況/生活協同組合/
せいきょういく /性教育/
せいきょうか /精強化/
せいきょうかい /正教会/
せいきょうしょくいん /生協職員/
せいきょうしょくどう /生協食堂/
せいきょうそうだいかい /生協総代会/
せいきょうそしき /生協組織/
せいきょうと /正教徒/
せいきょうぶんり /政教分離/
せいきょく /政局/
せいきょくかい /制極界/
せいきらんすう /正規乱数/
せいきりょうきん /正規料金/
せいきわりびき /正規割引/
せいきわりびきうんちん /正規割引運賃/
せいきん /精勤/
せいぎ /正義/生技/声義/性戯/
せいぎかん /正義漢/正義感/
せいぎけん /生技研/
せいぎしん /正義心/
せいぎぶ /生技部/
せいぎゃく /正逆/
せいぎょ /制御/成魚/制禦/
せいぎょう /成業/盛業/正業/生業/
せいぎょおんげん /制御音源/
せいぎょか /制御化/
せいぎょかいはつぶ /制御開発部/
せいぎょかいろ /制御回路/
せいぎょかのう /制御可能/
せいぎょかんかく /制御間隔/
せいぎょかんけい /制御関係/
せいぎょかんすう /制御関数/
せいぎょがい /制御外/
せいぎょき /制御器/制御機/
せいぎょきき /制御機器/
せいぎょきこう /制御機構/
せいぎょきじ /制御記事/
せいぎょきのう /制御機能/
せいぎょぎじゅつ /制御技術/
せいぎょく /青玉/
せいぎょくどう /制御駆動/
せいぎょくどうほうしき /制御駆動方式/
せいぎょけい /制御系/
せいぎょけいたい /制御形態/
せいぎょけん /制御権/
せいぎょけんきゅう /制御研究/
せいぎょけんきゅうしつ /制御研究室/
せいぎょげんご /制御言語/
せいぎょこうがく /制御工学/
せいぎょこうがくきそろん /制御工学基礎論/
せいぎょこうがっか /制御工学科/
せいぎょこうぞう /制御構造/
せいぎょさんぎょう /制御産業/
せいぎょしき /制御式/
せいぎょしすてむ /制御システム/
せいぎょしつ /制御室/
せいぎょしゃ /制御車/
せいぎょしゅほう /制御手法/
せいぎょしんごう /制御信号/
せいぎょしんごうせん /制御信号線/
せいぎょじ /制御時/
せいぎょじかん /制御時間/制限時間/
せいぎょじぎょうぶ /制御事業部/
せいぎょじょうほう /制御情報/
せいぎょせいさくしょ /制御製作所/
せいぎょせん /制御線/
せいぎょせんりゃく /制御戦略/
せいぎょそうさばん /制御操作盤/
せいぎょそうち /制御装置/
せいぎょそく /制御則/
せいぎょたいしょう /制御対象/
せいぎょたんし /制御端子/
せいぎょたんまつ /制御端末/
せいぎょてん /制御点/
せいぎょでんどうしゃ /制御電動車/
せいぎょどうさ /制御動作/
せいぎょにゅうりょく /制御入力/
せいぎょはんいがい /制御範囲外/
せいぎょばん /制御盤/
せいぎょふごう /制御符号/
せいぎょふのう /制御不能/
せいぎょふのうもんだい /制御不能問題/
せいぎょぶ /制御部/
せいぎょぶぶん /制御部分/
せいぎょぶん /制御文/
せいぎょへんすう /制御変数/
せいぎょほう /制御法/
せいぎょほうしき /制御方式/
せいぎょほうほう /制御方法/
せいぎょぼう /制御棒/
せいぎょもじ /制御文字/
せいぎょもじしゅうごう /制御文字集合/
せいぎょもじふごう /制御文字符号/
せいぎょもんだい /制御問題/
せいぎょよう /制御用/
せいぎょようおんげん /制御用音源/
せいぎょりつ /制御率/
せいぎょりょう /制御量/
せいぎょりょういき /制御領域/
せいぎょりろん /制御理論/
せいぎょろん /制御論/
せいく /成句/
せいくう /制空/
せいくうけん /制空権/
せいくらべ /背比べ/
せいけ /清家/
せいけい /整形/成形/政経/生計/成蹊/星系/成型/西経/
せいけいき /整形器/
せいけいぎじゅつ /成形技術/
せいけいげか /整形外科/
せいけいげかい /整形外科医/
せいけいげかしゅじゅつ /整形外科手術/
せいけいこうこう /成蹊高校/
せいけいしゅじゅつ /整形手術/
せいけいしゅつりょく /整形出力/
せいけいしょく /整形色/
せいけいだい /成蹊大/
せいけいだいがく /成蹊大学/
せいけいない /星系内/
せいけいひん /整形品/成形品/
せいけつ /清潔/
せいけつかん /清潔感/
せいけん /政権/生研/政見/聖剣/正拳/生検/精検/
せいけんか /政権下/
せいけんこうたい /政権交代/
せいけんたんとうせいとう /政権担当政党/
せいけんだつしゅ /政権奪取/
せいけんづき /正拳突き/
せいけんでんせつ /聖剣伝説/
せいけんとう /政権党/
せいけんほうそう /政見放送/
せいげん /制限/正弦/
せいげんいじょう /制限以上/
せいげんいない /制限以内/
せいげんかいじょ /制限解除/
せいげんくいき /制限区域/
せいげんけい /制限形/
せいげんこうもく /制限項目/
せいげんじかん /制限時間/
せいげんじこう /制限事項/
せいげんじたい /制限自体/
せいげんじゅうりょう /制限重量/
せいげんすう /制限数/
せいげんそくど /制限速度/
せいげんそくどいはん /制限速度違反/
せいげんそくどない /制限速度内/
せいげんそくどふきん /制限速度付近/
せいげんそち /制限措置/
せいげんち /制限値/
せいげんてっぱい /制限撤廃/
せいげんない /制限内/
せいげんは /正弦波/
せいげんはしんごう /正弦波信号/
せいげんはてき /正弦波的/
せいげんはんいがい /制限範囲外/
せいげんわく /制限枠/
せいこ /聖子/
せいこう /成功/製鋼/性交/精巧/精工/精鋼/正孔/性向/生工/悽惶/正項/
せいこうい /性行為/
せいこういご /成功以後/
せいこううどく /晴耕雨読/
せいこうかくりつ /成功確率/
せいこうさく /成功作/
せいこうしゃ /成功者/
せいこうしょ /製鋼所/精工所/精巧所/
せいこうしょう /性交渉/
せいこうしん /正更新/
せいこうじれい /成功事例/
せいこうだん /成功談/
せいこうとうてい /西高東低/
せいこうどう /性行動/
せいこうほう /正攻法/
せいこうり /成功裏/成功裡/
せいこうりつ /成功率/
せいこうれい /成功例/
せいこく /正鵠/
せいこつ /整骨/
せいこつし /整骨師/
せいこん /成婚/精魂/精根/聖痕/
せいご /清吾/正誤/生後/成語/清悟/正吾/精吾/
せいごいちねん /生後一年/
せいごいちねんていど /生後一年程度/
せいごう /整合/正合/正剛/
せいごうき /整合器/
せいごうせい /整合性/
せいごうてき /整合的/
せいごうはいれつ /整合配列/
せいごうほう /整合法/
せいごひょう /正誤表/
せいごぶん /正誤文/
せいさ /性差/精査/
せいさい /制裁/正妻/精細/生彩/精彩/
せいさいきん /制裁金/
せいさいそち /制裁措置/
せいさいぼう /性細胞/精細胞/
せいさく /製作/政策/制作/清作/
せいさくいと /製作意図/
せいさくかがくか /政策科学科/
せいさくかつどう /制作活動/
せいさくかてい /制作過程/
せいさくがいしゃ /制作会社/製作会社/
せいさくがわ /制作側/製作側/
せいさくき /制作記/
せいさくきかん /制作期間/
せいさくきじ /製作記事/制作記事/
せいさくけってい /政策決定/
せいさくけっていじ /政策決定時/
せいさくげんば /製作現場/
せいさくこうい /制作行為/
せいさくしえん /政策支援/
せいさくしつ /制作室/
せいさくしゃ /製作者/制作者/
せいさくしゃがわ /製作者側/
せいさくしょ /製作所/
せいさくじ /制作時/製作時/
せいさくじじょう /製作事情/
せいさくじゅん /製作順/
せいさくじょ /製作所/
せいさくじょう /製作上/政策上/
せいさくそうしき /制作総指揮/
せいさくたいせい /制作体制/製作体制/
せいさくたんとうしゃ /政策担当者/
せいさくちゅう /製作中/制作中/
せいさくちゅうし /製作中止/
せいさくとうしょ /製作当初/
せいさくとちゅう /製作途中/
せいさくはんだん /政策判断/
せいさくひ /製作費/制作費/
せいさくひょうめい /政策表明/
せいさくへんこう /政策変更/
せいさくほうほう /製作方法/
せいさくもと /製作元/
せいさくりょう /製作料/
せいさつよだつ /生殺与奪/
せいさべつ /性差別/
せいさん /生産/精算/清算/凄惨/成算/青酸/正餐/聖餐/製産/悽惨/
せいさんかい /生産界/
せいさんかがくせんこう /生産科学専攻/
せいさんかくすい /正三角錐/
せいさんかじょう /生産過剰/
せいさんかっけい /正三角形/
せいさんかつどう /生産活動/
せいさんかり /青酸加里/
せいさんかんりょう /生産完了/
せいさんがく /精算額/
せいさんき /精算機/
せいさんきすう /生産機数/
せいさんきゅうし /生産休止/
せいさんきん /生産菌/
せいさんきんがく /精算金額/
せいさんぎじゅつ /生産技術/
せいさんぎじゅつぶ /生産技術部/
せいさんぎじゅつりょく /生産技術力/
せいさんぐち /清算口/
せいさんけいかく /生産計画/
せいさんけん /生産研/
せいさんこういじたい /生産行為自体/
せいさんこうがくぶ /生産工学部/
せいさんこうりつ /生産効率/
せいさんしゃ /生産者/生産車/
せいさんしゅうりょう /生産終了/
せいさんしょ /精算書/
せいさんじぎょうだん /清算事業団/
せいさんじょ /精算所/清算所/
せいさんじれんど /生産時練度/
せいさんすう /生産数/
せいさんせい /生産性/
せいさんせいぎじゅつ /生産性技術/
せいさんせつび /生産設備/
せいさんそしき /生産組織/
せいさんだいすう /生産台数/
せいさんだか /生産高/
せいさんだかひれいほう /生産高比例法/
せいさんだんかい /生産段階/
せいさんち /生産地/
せいさんちゅうし /生産中止/
せいさんてき /生産的/
せいさんひ /生産費/
せいさんひょう /清算表/
せいさんひん /生産品/
せいさんふどまり /生産歩留り/
せいさんぶつ /生産物/
せいさんぶもん /生産部門/
せいさんぶん /精算分/
せいさんまどぐち /清算窓口/
せいさんりょう /生産量/
せいさんりょく /生産力/
せいざ /星座/正座/
せいざい /製材/製剤/
せいざいしょ /製材所/
せいざえもん /清左衛門/
せいざじょうたい /正座状態/
せいざぶろう /清三郎/征三郎/
せいし /正視/精子/静止/制止/正史/生死/清史/製紙/姓氏/製糸/西施/誠史/誓紙/誓詞/
せいしえいせい /静止衛星/
せいしかい /静止解/
せいしが /静止画/
せいしがきかく /静止画規格/
せいしがぞう /静止画像/
せいしき /正式/制式/整式/
せいしきうんよう /正式運用/
せいしきかめい /正式加盟/
せいしきき /制式機/
せいしきけいやく /正式契約/
せいしきけってい /正式決定/
せいしきこうかい /正式公開/
せいしきこうにん /正式公認/
せいしきさいばん /正式裁判/
せいしきさいよう /正式採用/
せいしきしゅっか /正式出荷/
せいしきしゅもく /正式種目/
せいしきたいおうきしゅ /正式対応機種/
せいしきたいだん /正式退団/
せいしきどう /静止軌道/
せいしきはいふばん /正式配布版/
せいしきはっぴょう /正式発表/
せいしきばん /正式版/
せいしきぶんしょ /正式文書/
せいしきへいき /制式兵器/
せいしきほっそく /正式発足/
せいしきめい /正式名/
せいしきめいしょう /正式名称/
せいしきめんじょう /正式免状/
せいしきょくせんざひょう /静止曲線座標/
せいしけい /静止系/
せいしけいじょう /静止系上/
せいしこうぎょうぎじゅつ /製紙工業技術/
せいしこうじょう /製紙工場/
せいしざひょう /静止座標/
せいしざひょうけい /静止座標系/
せいししつりょう /静止質量/
せいししょ /製糸所/製紙所/
せいしじょうたい /静止状態/
せいしちゅうしん /静止中心/
せいしつ /性質/声質/正室/
せいしつさ /性質差/
せいしつじょう /性質上/
せいしつりょう /正質量/性質量/
せいしぶったい /静止物体/
せいしぶつ /静止物/
せいしまさつ /静止摩擦/
せいしまさつりょく /静止摩擦力/
せいしゃ /生者/精射/
せいしゃいん /正社員/
せいしゃえい /正射影/
せいしゅ /清酒/
せいしゅう /青州/
せいしゅく /静粛/整粛/静淑/静肅/
せいしゅん /青春/静瞬/
せいしゅんえいが /青春映画/
せいしゅんしょうせつ /青春小説/
せいしゅんじ /青春時/
せいしゅんじだい /青春時代/
せいしゅんへん /青春編/
せいしゅんものがたり /青春物語/
せいしょ /清書/成書/正書/聖書/整書/
せいしょう /清祥/清勝/斉唱/政商/西湘/精漿/
せいしょうじ /斉唱時/
せいしょうどう /性衝動/
せいしょうなごん /清少納言/
せいしょうねん /青少年/
せいしょうねんかいかん /青少年会館/
せいしょうねんきょういく /青少年教育/
せいしょかいしゃく /聖書解釈/
せいしょかんけい /聖書関係/
せいしょがく /聖書学/
せいしょき /清書機/
せいしょく /生殖/聖職/生食/星蝕/
せいしょくかくめい /生殖革命/
せいしょくき /生殖器/生殖期/
せいしょくきかん /生殖器官/
せいしょくけいちょう /生殖茎頂/
せいしょくこうい /生殖行為/
せいしょくこうぞう /生殖構造/
せいしょくこうどう /生殖行動/
せいしょくし /生殖枝/
せいしょくしゃ /聖職者/
せいしょくしゅーと /生殖シュート/
せいしょくせん /生殖腺/
せいしょくのうりょく /生殖能力/
せいしょくもくてき /生殖目的/
せいしょけい /清書系/
せいしょしゃくぎ /聖書釈義/
せいしょほう /正書法/
せいしょよう /清書用/
せいしろう /誠志郎/
せいしん /精神/聖心/誠心/清心/制振/清新/西進/誠信/星辰/
せいしんあんてい /精神安定/
せいしんあんていざい /精神安定剤/
せいしんい /精神医/
せいしんいがく /精神医学/
せいしんいぞん /精神依存/
せいしんいりょうてき /精神医療的/
せいしんえいせい /精神衛生/
せいしんえいせいじょう /精神衛生上/
せいしんか /精神科/精神化/
せいしんかい /精神科医/
せいしんかつどう /精神活動/
せいしんかつどうぜんたい /精神活動全体/
せいしんかつどうちゅう /精神活動中/
せいしんかん /正心館/
せいしんかんおうぶっしつ /精神感応物質/
せいしんかんのう /精神感応/
せいしんがく /精神学/
せいしんがっか /精神学科/
せいしんくうかん /精神空間/
せいしんくうかんない /精神空間内/
せいしんげんしょう /精神現象/
せいしんこうぞう /精神構造/
せいしんこうぞうじたい /精神構造自体/
せいしんし /精神史/
せいしんしゃ /青心社/
せいしんしゅうちゅう /精神集中/
せいしんしゅうようだんたい /精神修養団体/
せいしんしゅぎ /精神主義/
せいしんしょうがいじ /精神障害児/
せいしんしょぼう /誠信書房/
せいしんじょう /精神上/
せいしんじょうたい /精神状態/
せいしんじょがくいん /聖心女学院/
せいしんじょしがくいん /聖心女子学院/
せいしんじょしだいがく /聖心女子大学/
せいしんせいい /誠心誠意/
せいしんせかい /精神世界/
せいしんそくてい /精神測定/
せいしんそくていがく /精神測定学/
せいしんちゅうおう /西神中央/
せいしんてき /精神的/
せいしんてきくつう /精神的苦痛/
せいしんてきけんこう /精神的健康/
せいしんてきこうか /精神的効果/
せいしんてきこうふん /精神的興奮/
せいしんてきしょうがい /精神的障害/精神的損害/
せいしんてきじゆう /精神的自由/
せいしんてきとくしつ /精神的特質/
せいしんてきねんれい /精神的年齢/
せいしんてきよゆう /精神的余裕/
せいしんてん /精神的/
せいしんとういつ /精神統一/
せいしんねんれい /精神年齢/
せいしんはくじゃくしゃ /精神薄弱者/
せいしんはったつしょうがい /精神発達障害/
せいしんはついく /精神発育/
せいしんびょう /精神病/
せいしんびょういん /精神病院/
せいしんびょうかんじゃ /精神病患者/
せいしんぶんか /精神文化/
せいしんぶんせき /精神分析/
せいしんぶんせきい /精神分析医/
せいしんぶんせきか /精神分析家/
せいしんぶんせきがく /精神分析学/
せいしんぶんせきにゅうもん /精神分析入門/
せいしんぶんせきりょうほう /精神分析療法/
せいしんぶんせきりろん /精神分析理論/
せいしんへんちょう /精神変調/
せいしんめん /精神面/
せいしんやく /精神薬/
せいしんりょく /精神力/
せいしんろん /精神論/
せいじ /政治/征士/正時/正字/静二/征二/斎次/征爾/清司/清次/清治/清二/誠治/誠二/聖司/斉次/誠司/青磁/精二/征司/成二/整司/星史/聖次/製磁/征治/聖二/青児/青嗣/
せいじか /政治家/政治化/
せいじかいかく /政治改革/
せいじかいけつ /政治解決/
せいじかつどう /政治活動/
せいじかん /政治観/
せいじかんてん /政治観点/
せいじがく /政治学/
せいじがくしゃ /政治学者/
せいじきこう /政治機構/
せいじけいたい /政治形態/
せいじけっしゃ /政治結社/
せいじけんきん /政治献金/
せいじけんりょく /政治権力/
せいじざひょう /斎次座標/
せいじし /政治史/
せいじしきん /政治資金/
せいじしきんちょうたつ /政治資金調達/
せいじしゅう /政治囚/
せいじしゅうだん /政治集団/
せいじじょう /政治上/
せいじじょうきょう /政治状況/
せいじじょうほう /政治情報/
せいじせいど /政治制度/
せいじせきにん /政治責任/
せいじせんそう /政治戦争/
せいじたいせい /政治体制/
せいじだい /生時代/
せいじっすう /正実数/
せいじつ /誠実/凄日/
せいじてき /政治的/
せいじてきあつれき /政治的軋轢/
せいじてきいみ /政治的意味/
せいじてきかつどう /政治的活動/
せいじてきぎろん /政治的議論/
せいじてきけんり /政治的権利/
せいじてきしっぱい /政治的失敗/
せいじてきしはいりょく /政治的支配力/
せいじてきしゅほう /政治的手法/
せいじてきしんじょう /政治的信条/
せいじてきじっせき /政治的業績/
せいじてきじょうきょう /政治的状況/
せいじてきたちば /政治的立場/
せいじてきはんだん /政治的判断/
せいじてきぶんみゃく /政治的文脈/
せいじてきもんだい /政治的問題/
せいじてきようそ /政治的要素/
せいじてきりゆう /政治的理由/
せいじてつがく /政治哲学/
せいじどうとく /政治道徳/
せいじは /静磁波/
せいじはん /政治犯/
せいじば /静磁場/
せいじばちゅう /静磁場中/
せいじひょう /政治評/
せいじひょうろんか /政治評論家/
せいじふうど /政治風土/
せいじまんが /政治漫画/
せいじもんだい /政治問題/
せいじもんだいか /政治問題化/
せいじゃ /聖者/正邪/
せいじゃく /静寂/
せいじゃくしゃこ /正雀車庫/
せいじゃはんてい /正邪判定/
せいじや /政治屋/
せいじゅ /誠樹/
せいじゅう /聖獣/西戎/
せいじゅく /成熟/
せいじゅくど /成熟度/
せいじゅくらん /成熟卵/
せいじゅん /清純/正順/正準/
せいじゅんか /正準化/
せいじゅんけい /正準形/
せいじゅんこう /正準項/
せいじゅんぶんせき /正準分析/
せいじゅんほうていしき /正準方程式/
せいじょ /成女/聖女/
せいじょう /正常/成城/清浄/政情/星条/性状/星状/
せいじょうい /正常位/
せいじょうか /正常化/清浄化/
せいじょうかん /成城間/
せいじょうがくえん /成城学園/
せいじょうがくえんまえ /成城学園前/
せいじょうき /星条旗/
せいじょうきのう /正常機能/
せいじょうけい /正常系/
せいじょうけいさつしょ /成城警察署/
せいじょうこうへきいけいさいぼう /星状厚壁異形細胞/
せいじょうさいぼう /正常細胞/
せいじょうしゃ /正常者/
せいじょうしゅうりょう /正常終了/
せいじょうせい /正常性/
せいじょうそしき /正常組織/
せいじょうたい /正常体/星状体/
せいじょうだい /成城大/
せいじょうだいがく /成城大学/
せいじょうどうさ /正常動作/
せいじょうはいそう /正常配送/
せいじょうはんいない /正常範囲内/
せいじょうふあん /政情不安/
せいじょうもう /星状毛/
せいじりょく /政治力/
せいじれい /正事例/
せいじろう /清次郎/征二郎/
せいじろん /政治論/
せいじん /成人/聖人/星人/
せいじんくんし /聖人君子/
せいじんくんしゅ /聖人君主/
せいじんご /成人後/
せいじんしき /成人式/
せいじんしてい /成人指定/
せいじんだんし /成人男子/
せいじんだんしむき /成人男子向き/
せいじんだんしむけ /成人男子向け/
せいじんだんせい /成人男性/
せいじんびょう /成人病/
せいすい /盛衰/聖水/静水/
せいすいき /整水器/清水器/製水器/
せいすいせき /青水石/
せいすう /整数/正数/
せいすうかい /整数解/
せいすうかんけい /整数関係/
せいすうがた /整数型/
せいすうけいかく /整数計画/
せいすうじ /整数次/
せいすうぜんたい /整数全体/
せいすうち /整数値/
せいすうていすうしき /整数定数式/
せいすうばい /整数倍/
せいすうばいたんい /整数倍単位/
せいすうひ /整数比/
せいすうひおんてい /整数比音程/
せいすうぶ /整数部/
せいすうぶぶん /整数部分/
せいすうへんかん /整数変換/
せいすうれつ /整数列/
せいすうろん /整数論/
せいすけ /清助/誠亮/
せいず /星図/製図/
せいずい /精髄/
せいずこう /製図工/
せいずだい /製図台/
せいずどうぐ /製図道具/
せいずばん /製図板/
せいせい /生成/正々/清々/精製/生々/正声/凄凄/悽悽/
せいせいえん /精製塩/
せいせいかく /生成核/
せいせいかつ /性生活/
せいせいかてい /生成過程/
せいせいかのう /生成可能/
せいせいがた /生成型/
せいせいき /生成器/
せいせいきこう /生成機構/
せいせいきそく /生成規則/
せいせいけい /生成系/
せいせいげん /生成元/
せいせいこうこう /悽悽惶惶/
せいせいさんさん /凄凄惨惨/
せいせいじ /生成時/
せいせいすう /正整数/生成数/
せいせいせつせつ /凄凄切切/
せいせいそく /生成則/
せいせいたこうしき /生成多項式/
せいせいだんめんせき /生成断面積/
せいせいてき /生成的/
せいせいどうどう /正々堂々/
せいせいぶ /生成部/
せいせいぶつ /生成物/
せいせいぶんぽう /生成文法/
せいせいほう /生成法/
せいせいほうほう /生成方法/
せいせいまえ /精製前/
せいせいりつ /生成率/
せいせいりょう /生成量/
せいせいりょうりょう /凄凄涼涼/
せいせいるてん /生生流転/
せいせいれい /生成例/
せいせき /成績/聖石/
せいせきしょうめいしょ /成績証明書/
せいせきじゅん /成績順/
せいせきじょうい /成績上位/
せいせきていめい /成績低迷/
せいせきてき /成績的/
せいせきひょう /成績表/
せいせきふしん /成績不振/
せいせきべつ /成績別/
せいせきゆうしゅう /成績優秀/
せいせつ /正節/
せいせん /清泉/生鮮/精選/聖戦/精線/聖戰/井泉/性腺/
せいせんしゅ /正選手/
せいせんしょくたい /性染色体/
せいせんしょくりょうひん /生鮮食料品/
せいせんじょしだい /清泉女子大/
せいせんじょしだいがく /清泉女子大学/
せいぜつ /悽絶/凄絶/
せいぜつさ /凄絶さ/
せいぜん /整然/生前/正善/性善/凄然/悽然/
せいぜんせつ /性善説/
せいぜんぶんよ /生前分与/
せいそ /整礎/清楚/凄楚/精粗/
せいそう /清掃/正装/成層/政争/盛装/星霜/凄愴/悽愴/精巣/
せいそういん /清掃員/
せいそうかつどう /清掃活動/
せいそうきょく /清掃局/
せいそうぎょうむ /清掃業務/
せいそうけん /成層圏/
せいそうけんいじょう /成層圏以上/
せいそうこうか /清掃効果/
せいそうしゃ /清掃者/清掃車/
せいそうしょくいん /清掃職員/
せいそうじぎょう /清掃事業/
せいそうじむしょ /清掃事務所/
せいそうちゅう /清掃中/
せいそうねん /青荘年/
せいそうひ /清掃費/
せいそうひよう /清掃費用/
せいそうようぐ /清掃用具/
せいそく /棲息/生息/正則/栖息/悽惻/
せいそくいき /生息域/
せいそくえんざん /正則演算/
せいそくか /正則化/
せいそくかいしゅうごう /正則開集合/
せいそくかんすう /正則関数/
せいそくぎょうれつ /正則行列/
せいそくげん /正則元/
せいそくげんご /正則言語/
せいそくこう /正則項/
せいそくすう /生息数/
せいそくせい /正則性/
せいそくち /生息地/棲息地/
せいそくてき /正則的/
せいそくひょうげん /正則表現/
せいそくみつど /生息密度/
せいぞう /製造/清三/清蔵/誓三/
せいぞうかいしゃめい /製造会社名/
せいぞうかてい /製造過程/
せいぞうかんりぶ /製造管理部/
せいぞうがいしゃ /製造会社/
せいぞうがわ /製造側/
せいぞうき /製造機/
せいぞうぎじゅつ /製造技術/
せいぞうぎじゅつしゃ /製造技術者/
せいぞうぎじゅつしゃきょうかい /製造技術者協会/
せいぞうぎじゅつぶ /製造技術部/
せいぞうぎょう /製造業/
せいぞうぎょうしゃ /製造業者/
せいぞうこうじょう /製造工場/
せいぞうこうてい /製造工程/
せいぞうさき /製造先/
せいぞうしじしょ /製造指示書/
せいぞうしゃ /製造者/
せいぞうしゃせきにん /製造者責任/
せいぞうしゃめい /製造社名/
せいぞうしゅうりょうご /製造終了後/
せいぞうしょ /製造所/
せいぞうじ /製造時/
せいぞうじき /製造時期/
せいぞうじっしゅう /製造実習/
せいぞうじゅん /製造順/
せいぞうじょ /製造所/
せいぞうじょう /製造上/
せいぞうだんかい /製造段階/
せいぞうちゅう /製造中/
せいぞうちゅうし /製造中止/
せいぞうでんりょく /製造電力/
せいぞうぬし /製造主/
せいぞうねんがっぴ /製造年月日/
せいぞうねんげつ /製造年月/
せいぞうはんばい /製造販売/
せいぞうはんばいもと /製造販売元/
せいぞうばんごう /製造番号/
せいぞうび /製造日/
せいぞうぶ /製造部/
せいぞうほう /製造法/
せいぞうほうほう /製造方法/
せいぞうほしょうねんすう /製造保証年数/
せいぞうもと /製造元/
せいぞうりょう /製造量/
せいぞく /聖俗/
せいぞろい /勢ぞろい/勢揃い/
せいぞん /生存/
せいぞんかくりつ /生存確率/
せいぞんきかん /生存期間/
せいぞんきょうそう /生存競争/
せいぞんけん /生存権/
せいぞんしゃ /生存者/
せいぞんせい /生存性/
せいぞんりつ /生存率/
せいた /清太/清田/
せいたい /生態/生体/声帯/正対/政体/静態/整体/成体/
せいたいかんきょう /生態環境/
せいたいかんさつ /生態観察/
せいたいがく /生態学/
せいたいけい /生態系/生体系/
せいたいけいかんきょう /生態系環境/
せいたいけいぜんたい /生態系全体/
せいたいけん /生態研/
せいたいこうがく /生体工学/
せいたいこうぶんし /生体高分子/
せいたいざいりょう /生体材料/
せいたいざつおん /生体雑音/
せいたいしすてむか /生体システム課/
せいたいじっけん /生体実験/
せいたいじば /生体磁場/
せいたいじょうほう /生体情報/
せいたいじょうほうがく /生体情報学/
せいたいじょうほうこうがく /生体情報工学/
せいたいじょうほうしょり /生体情報処理/
せいたいちょうさ /生態調査/
せいたいてき /生体的/
せいたいでんし /生体電子/
せいたいでんしじょうほう /生体電子情報/
せいたいでんしじょうほうこうがく /生体電子情報工学/
せいたいない /生体内/
せいたいのうしゅく /生体濃縮/
せいたいは /声帯波/
せいたいはんのう /生体反応/
せいたいへいさおん /声帯閉鎖音/
せいたいへんか /生態変化/
せいたいほぞん /静態保存/
せいたいぼうぎょきこう /生体防御機構/
せいたいまく /生体膜/
せいたかくけい /正多角形/
せいたかくちゅう /正多角柱/
せいたかっけい /正多角形/
せいたぼうたい /正多胞体/
せいためんたい /正多面体/
せいたろう /清太郎/
せいたん /生誕/西端/
せいだい /盛大/正大/
せいだく /清濁/
せいだん /政談/星団/清談/
せいち /聖地/整地/正値/生地/精緻/静置/正置/
せいちせい /正値性/
せいちゃ /製茶/
せいちゃく /正着/
せいちゅう /正中/成虫/掣肘/精虫/
せいちゅうしんけい /正中神経/
せいちゅうせん /正中線/
せいちゅうめん /正中面/
せいちゅうめんていい /正中面定位/
せいちょう /成長/整調/静聴/正調/生長/清帳/清張/声調/成鳥/
せいちょうかてい /成長過程/
せいちょうかぶ /成長株/
せいちょうき /成長期/
せいちょうきょくせん /成長曲線/
せいちょうきろく /成長記録/
せいちょうご /成長後/
せいちょうさんぎょう /成長産業/
せいちょうじょうきょう /成長状況/
せいちょうせい /成長性/
せいちょうせき /成長石/
せいちょうそくしん /生長促進/
せいちょうだんかい /成長段階/生長段階/
せいちょうとじょう /成長途上/
せいちょうぶつ /成長物/
せいちょうぶん /成長分/
せいちょうほう /成長法/
せいちょうものがたり /成長物語/
せいちょうりつ /成長率/
せいつう /精通/
せいてい /制定/
せいていし /斉停止/
せいていじ /制定時/
せいていすう /整定数/
せいていち /正定値/
せいていちせい /正定値性/
せいていり /性定理/
せいてき /静的/性的/政敵/
せいてきいみろん /静的意味論/
せいてきかいせき /静的解析/
せいてきかいらくもくてき /性的快楽目的/
せいてきかてい /性的過程/
せいてきかんけい /性的関係/
せいてきがいしょうたいけん /性的外傷体験/
せいてきがた /静的型/
せいてきこうふん /性的興奮/
せいてきじゅうりょく /静的重力/
せいてきふかぶんさん /静的負荷分散/
せいてきへんすう /静的変数/
せいてきぼうりょく /性的暴力/
せいてきやくわりぶんたん /性的役割分担/
せいてきようそ /性的要素/
せいてきよくぼう /性的欲望/
せいてつ /製鉄/製鐵/
せいてつぎょう /製鉄業/
せいてつしょ /製鉄所/製鐵所/
せいてつじょ /製鉄所/
せいてん /晴天/盛典/性典/聖典/青天/征典/
せいてんいき /晴天域/
せいてんか /聖典化/
せいてんかん /性転換/
せいてんじ /晴天時/
せいてんたいせい /斉天大聖/
せいてんのへきれき /青天の霹靂/
せいてんはくじつ /青天白日/
せいてんりつ /晴天率/
せいでん /静電/正殿/星電/聖伝/
せいでんき /静電気/
せいでんきじょきょ /静電気除去/
せいでんきたいさく /静電気対策/
せいでんげん /正電源/
せいでんば /静電場/
せいでんようりょう /静電容量/
せいと /生徒/成都/
せいとう /正当/政党/正答/正統/製糖/精糖/
せいとうか /正当化/
せいとうぎょう /製糖業/
せいとうこういろん /正当行為論/
せいとうしじ /政党支持/
せいとうじたい /政党自体/
せいとうじゆう /正当事由/
せいとうせい /正当性/正統性/
せいとうせいじ /政党政治/
せいとうたんい /政党単位/
せいとうてき /正統的/
せいとうない /政党内/
せいとうは /正統派/正当派/
せいとうほうしゃせん /制/
せいとうぼうえい /正当防衛/
せいとうりつ /正答率/
せいとうりゆう /正当理由/
せいとかい /生徒会/
せいとかいしつ /生徒会室/
せいとかいちょう /生徒会長/
せいとかいちょうせんきょ /生徒会長選挙/
せいとかんり /生徒管理/
せいとく /生得/成徳/聖徳/政徳/
せいとくがくえん /成徳学園/
せいとくせつ /生得説/
せいとくたんだい /成徳短大/
せいとくてき /生得的/
せいとこころえ /生徒心得/
せいとしどう /生徒指導/
せいとしどうしつ /生徒指導室/
せいとじしん /生徒自身/
せいとじち /生徒自治/
せいとすう /生徒数/
せいとたち /生徒達/
せいとてちょう /生徒手帳/
せいとぼしゅう /生徒募集/
せいとん /整頓/
せいど /精度/制度/
せいどいじょう /精度以上/
せいどう /正道/声道/制動/正堂/聖堂/青銅/
せいどうかじゅう /制動荷重/
せいどうかん /制動感/
せいどうき /制動機/
せいどうきょり /制動距離/
せいどうけいじょう /声道形状/
せいどうこうか /制動効果/
せいどうちゅう /制動中/
せいどうちょう /声道長/
せいどうとう /制動灯/
せいどうとく /性道徳/
せいどうとくせい /声道特性/
せいどうにゅう /制導入/
せいどうほうしゃ /制動放射/
せいどうほうしゃせん /制動放射線/
せいどうもくてき /制動目的/
せいどうよう /制動用/
せいどうりょく /制動力/
せいどか /制度化/制度下/
せいどかくちょう /精度拡張/
せいどく /精読/西独/
せいどけいかく /精度計画/
せいどこうじょう /精度向上/
せいどしゃ /青土社/
せいどじたい /制度自体/
せいどじっしご /制度実施後/
せいどじょう /制度上/
せいどていど /制度程度/
せいどてき /制度的/
せいどひはん /制度批判/
せいどみなおし /制度見直し/
せいどみにこ /聖ドミニコ/
せいどみにこがくえん /聖ドミニコ学園/
せいどめん /制度面/
せいどもんだい /制度問題/
せいなん /勢南/西南/
せいなんがくいんだいがく /西南学院大学/
せいなんせい /西南西/
せいなんだい /西南大/
せいなんにほん /西南日本/
せいにく /精肉/
せいにくてん /精肉店/
せいねん /青年/生年/成年/
せいねんかいぎ /青年会議/
せいねんかん /青年館/
せいねんがっぴ /生年月日/
せいねんき /青年期/
せいねんざっし /青年雑誌/
せいねんし /青年誌/
せいねんしき /成年式/
せいねんしけいとう /青年誌系統/
せいねんしゃ /成年者/
せいねんしんりがく /青年心理学/
せいねんじだい /青年時代/
せいねんだん /青年団/
せいねんだんし /成年男子/青年男子/
せいねんぶ /青年部/
せいねんまんが /青年漫画/
せいの /清野/
せいのう /性能/西濃/
せいのうあんていせい /性能安定性/
せいのういぞんせい /性能依存性/
せいのううんゆ /西濃運輸/
せいのうかいぜん /性能改善/
せいのうかじょう /性能過剰/
せいのうきょくせんず /性能曲線図/
せいのうこうじょう /性能向上/
せいのうさ /性能差/
せいのうじょう /性能上/
せいのうじょうけん /性能条件/
せいのうそくてい /性能測定/
せいのうち /性能値/
せいのうていか /性能低下/
せいのうてき /性能的/
せいのうとくせい /性能特性/
せいのうはっき /性能発揮/
せいのうひ /性能比/
せいのうひかく /性能比較/
せいのうひょうか /性能評価/
せいのうひょうかけっか /性能評価結果/
せいのうぶそく /性能不足/
せいのうほしょう /性能保証/
せいのうめん /性能面/
せいのうようきゅう /性能要求/
せいのうれっか /性能劣化/
せいのすけ /誠之助/
せいは /征覇/制覇/
せいはい /聖杯/成敗/
せいはく /精薄/精白/製箔/
せいはくぶあい /精白歩合/
せいはご /制覇後/
せいはちめんたい /正八面体/
せいはつ /整髪/
せいはつざい /整髪剤/
せいはつりょう /整髪料/
せいはん /製版/正反/整版/
せいはんざい /性犯罪/
せいはんざいしゃ /性犯罪者/
せいはんざいりつ /性犯罪率/
せいはんたい /正反対/
せいばい /成敗/
せいばつ /征伐/
せいばん /製番/
せいぱん /製パン/
せいひ /正否/成否/西肥/性比/西彼/
せいひこ /聖彦/
せいひつ /静謐/
せいひょう /製氷/星表/
せいひょうい /生標委/
せいひょうき /製氷器/
せいひょうげん /性表現/
せいひょうげんもんだい /性表現問題/
せいひょうこ /製氷庫/
せいひょうざら /製氷皿/
せいひょうしつ /製氷室/
せいひれい /正比例/
せいひん /製品/清貧/
せいひんいがい /製品以外/
せいひんか /製品化/
せいひんかいはつ /製品開発/
せいひんかいはついちぶ /製品開発一部/
せいひんかいはつじ /製品開発時/
せいひんかいはつぶ /製品開発部/
せいひんかいりょう /製品改良/
せいひんかがくけんきゅうしょ /製品科学研究所/
せいひんかん /製品間/
せいひんかんり /製品管理/
せいひんきょうそうりょく /製品競争力/
せいひんこうにゅうけいかく /製品購入計画/
せいひんごと /製品毎/
せいひんしょうかい /製品紹介/
せいひんしよう /製品仕様/
せいひんぜんたい /製品全体/
せいひんてんじ /製品展示/
せいひんばん /製品版/
せいひんばんごう /製品番号/
せいひんひかく /製品比較/
せいひんひょうか /製品評価/
せいひんふどまり /製品歩留り/
せいひんふりょう /製品不良/
せいひんめい /製品名/
せいひんりゅうつうりょう /製品流通量/
せいひんれい /製品例/
せいび /整備/星美/
せいびいがい /整備以外/
せいびいん /整備員/
せいびか /整備科/
せいびかいせつしょ /整備解説書/
せいびかくちょう /整備拡張/
せいびがくえん /星美学園/
せいびき /正引き/
せいびきろくぼ /整備記録簿/
せいびけいひ /整備経費/
せいびこう /整備工/
せいびこうじょう /整備工場/
せいびこうじょうせんよう /整備工場専用/
せいびし /整備士/
せいびしきん /整備資金/
せいびしつ /整備室/
せいびしめんきょ /整備士免許/
せいびしょ /整備書/
せいびしんかんせん /整備新幹線/
せいびじゅつ /整備術/
せいびじょうきょう /整備状況/
せいびじょうたい /整備状態/
せいびじょうまえ /整備場前/
せいびせい /整備性/
せいびたんとうしゃ /整備担当者/
せいびちゅう /整備中/
せいびちょう /整備長/
せいびづくえ /整備机/
せいびてちょう /整備手帳/
せいびてんけん /整備点検/
せいびとちゅう /整備途中/
せいびどうしゅっぱん /成美堂出版/
せいびなど /整備等/
せいびひ /整備費/
せいびひよう /整備費用/
せいびふりょう /整備不良/
せいびへい /整備兵/
せいびほうしん /整備方針/
せいびょう /性病/
せいびょうしゃ /性描写/
せいびよう /整備用/
せいふ /政府/正負/
せいふあん /政府案/
せいふう /清風/西風/
せいふかん /政府館/
せいふかんけいしゃ /政府関係者/
せいふかんこうきょく /政府観光局/
せいふかんこうちょう /政府観光庁/
せいふかんぶ /政府幹部/
せいふがわ /政府側/
せいふきかん /政府機関/
せいふく /制服/征服/正副/
せいふくこうい /征服行為/
せいふくご /征服後/
せいふくしゃ /征服者/
せいふくすがた /制服姿/
せいふくちゃくよう /制服着用/
せいふくみんぞく /征服民族/
せいふぐん /政府軍/
せいふこうかん /政府高官/
せいふこうにん /政府公認/
せいふこうほう /政府広報/
せいふごう /正符号/
せいふさき /請負先/
せいふしゅっし /政府出資/
せいふじみんとう /政府自民党/
せいふじょうやく /政府条約/
せいふすじ /政府筋/
せいふせいめい /政府声明/
せいふそしき /政府組織/
せいふちゅうすう /政府中枢/
せいふてんぷく /政府転覆/
せいふどうし /政府同士/
せいふねんかん /政府年鑑/
せいふまい /政府米/
せいふより /政府寄り/
せいふん /製粉/
せいふんしょ /製粉所/
せいぶ /西武/西部/声部/
せいぶいけぶくろ /西武池袋/
せいぶいけぶくろせん /西武池袋線/
せいぶえん /西武園/
せいぶがわ /西武側/
せいぶきゅうじょう /西武球場/
せいぶくれじっと /西武クレジット/
せいぶけい /西武系/
せいぶけいさつ /西部警察/
せいぶけんせつ /西武建設/
せいぶげき /西部劇/
せいぶげきじょう /西武劇場/
せいぶしんじゅく /西武新宿/
せいぶしんじゅくえき /西武新宿駅/
せいぶしんじゅくかん /西武新宿間/
せいぶしんじゅくせん /西武新宿線/
せいぶじどうしゃ /西武自動車/
せいぶせん /西武戦/西武線/
せいぶせんせん /西部戦線/
せいぶつ /生物/静物/
せいぶつか /生物科/
せいぶつかい /生物界/
せいぶつかがく /生物化学/生物科学/
せいぶつかがくけい /生物科学系/
せいぶつかがくてき /生物化学的/
せいぶつかがっか /生物化学科/
せいぶつかん /生物観/生物間/
せいぶつかんけい /生物関係/
せいぶつかんれん /生物関連/
せいぶつがく /生物学/
せいぶつがくしゃ /生物学者/
せいぶつがくじてん /生物学辞典/生物学事典/
せいぶつがくじょせつ /生物学序説/
せいぶつがくせんこう /生物学専攻/
せいぶつがくてき /生物学的/
せいぶつがくてきげんしょう /生物学的現象/
せいぶつがくてきこたい /生物学的個体/
せいぶつがくてきこんきょ /生物学的根拠/
せいぶつがくてきぶんせき /生物学的分析/
せいぶつがくてきようきゅう /生物学的要求/
せいぶつけい /生物系/
せいぶつけん /生物圏/生物研/
せいぶつしせつ /生物施設/
せいぶつしゃかい /生物社会/
せいぶつしゅ /生物種/
せいぶつじてん /生物辞典/
せいぶつじょうほう /生物情報/
せいぶつじょうほうかがく /生物情報科学/
せいぶつじょうほうしょり /生物情報処理/
せいぶつたんたい /生物単体/
せいぶつてき /生物的/
せいぶつのうやく /生物農薬/
せいぶつぶ /生物部/
せいぶつぶつり /生物物理/
せいぶつぶつりがく /生物物理学/
せいぶつぶつりがくてき /生物物理学的/
せいぶつや /生物屋/
せいぶてつどう /西武鉄道/
せいぶひゃっかてん /西武百貨店/
せいぶほんしゃ /西部本社/
せいぶやなぎさわえき /西武柳沢駅/
せいぶゆうらくちょうせん /西武有楽町線/
せいぶん /成分/成文/正文/
せいぶんおん /成分音/
せいぶんか /成文化/
せいぶんけいさん /成分計算/
せいぶんけんけつ /成分献血/
せいぶんちょうせい /成分調整/
せいぶんどうしんこうしゃ /誠文堂新光社/
せいぶんひょうじ /成分表示/
せいぶんぴつえき /性分泌液/
せいぶんほう /成文法/
せいへい /精兵/
せいへき /性癖/
せいへん /政変/
せいべつ /性別/
せいほ /生保/
せいほう /正方/製法/西方/
せいほうぎょうれつ /正方行列/
せいほうけい /正方形/
せいほうこう /正方向/
せいほうとっきょ /製法特許/
せいほく /西北/
せいほくせい /西北西/
せいほくにほん /西北日本/
せいほん /製本/正本/
せいほんき /製本機/製本噐/
せいほんじ /製本時/
せいほんのう /性本能/
せいほんや /製本屋/
せいぼ /歳暮/生母/聖母/清保/
せいぼう /制帽/
せいぼつねん /生没年/
せいま /製麻/
せいまい /精米/
せいまいき /精米機/
せいまいご /精米後/
せいまいじ /精米時/
せいまいじょ /精米所/
せいまいぶあい /精米歩合/
せいまいほうほう /精米方法/
せいまく /成膜/
せいまさつ /静摩擦/
せいまさつけいすう /静摩擦係数/
せいまさつりょく /静摩擦力/
せいみつ /精密/
せいみつか /精密化/
せいみつかえんざんし /精密化演算子/
せいみつかがく /精密科学/
せいみつきかい /精密機械/
せいみつきき /精密機器/
せいみつけんさ /精密検査/
せいみつこうがく /精密工学/
せいみつこうがっか /精密工学科/
せいみつせっちゃくよう /精密接着用/
せいみや /清宮/
せいみょう /精妙/
せいむ /政務/
せいむじかん /政務次官/
せいめい /生命/姓名/声明/清明/
せいめいいじ /生命維持/
せいめいいじそうち /生命維持装置/
せいめいかがく /生命科学/
せいめいかつどう /生命活動/
せいめいがく /生命学/
せいめいけいたい /生命形態/
せいめいけん /生命研/生命工学工業技術研究所/
せいめいげんしょう /生命現象/
せいめいこうがく /生命工学/
せいめいこうがくこうぎょうぎじゅつけんきゅうしょ /生命工学工業技術研究所/
せいめいしょ /声明書/
せいめいしんか /生命進化/
せいめいせん /生命線/
せいめいたい /生命体/
せいめいたいどうし /生命体同士/
せいめいはんだん /姓名判断/生命判断/
せいめいほけん /生命保険/
せいめいほけんがいしゃ /生命保険会社/
せいめいほけんぎょうかい /生命保険業界/
せいめいりょく /生命力/
せいめいりんり /生命倫理/
せいめいろん /生命論/
せいめん /製麺/
せいもう /製網/
せいもん /正門/声紋/声門/
せいもんしゅえいしつ /正門守衛室/
せいもんひだりて /正門左手/
せいもんまえ /正門前/
せいや /聖夜/誠也/星谷/聖矢/生也/靖也/星矢/青夜/
せいやく /制約/誓約/製薬/成約/
せいやくがいしゃ /製薬会社/
せいやくがく /製薬学/
せいやくしょ /誓約書/
せいやくじこう /制約事項/
せいやくじゅうそく /制約充足/
せいやくじゅうそくほう /制約充足法/
せいやくじゅうそくもんだい /制約充足問題/
せいやくじょう /制約上/
せいやくじょうけん /制約条件/
せいやくつき /制約付き/
せいやくひょうかけい /制約評価系/
せいやくもじ /制約文字/
せいやくもじれつ /制約文字列/
せいやくろんり /制約論理/
せいゆ /製油/精油/
せいゆう /声優/西友/
せいゆうじん /声優陣/
せいゆうすとあー /西友ストアー/
せいよう /静養/西洋/
せいよういがく /西洋医学/
せいよういりょう /西洋医療/
せいようおんがく /西洋音楽/
せいようかがく /西洋科学/
せいようかん /西洋館/
せいようがく /西洋学/
せいようがたかがく /西洋型科学/
せいようがっき /西洋楽器/
せいようけん /精養軒/
せいようご /西洋語/
せいようし /西洋史/
せいようしがく /西洋史学/
せいようしき /西洋式/
せいようしょくじ /西洋食事/
せいようじん /西洋人/
せいようてき /西洋的/
せいようてつがく /西洋哲学/
せいようてつがくし /西洋哲学史/
せいようてんもんがく /西洋天文学/
せいようびじゅつ /西洋美術/
せいようびじゅつかん /西洋美術館/
せいようふう /西洋風/
せいようぶんめい /西洋文明/
せいようへいほう /西洋兵法/
せいようわがし /西洋和菓子/
せいよく /性欲/
せいら /聖良/
せいらい /生来/
せいらいてき /生来的/
せいらん /晴嵐/青蘭/
せいらんがくいん /青蘭学院/
せいり /整理/生理/
せいりかい /整理会/
せいりかっせいぶっしつ /生理活性物質/
せいりがく /生理学/
せいりがくてき /生理学的/
せいりがくようごしゅう /生理学用語集/
せいりきこう /生理機構/
せいりけん /整理券/
せいりけんせい /整理券制/
せいりけんはっこうき /整理券発行機/
せいりけんはっこうずみ /整理券発行済み/
せいりけんばんごう /整理券番号/
せいりげんしょう /生理現象/
せいりせいとん /整理整頓/
せいりちゅう /整理中/
せいりつ /成立/正立/
せいりついぜん /成立以前/
せいりつかてい /成立過程/
せいりつかのう /成立可能/
せいりつきじゅん /成立基準/
せいりつご /成立後/
せいりつしき /正立式/
せいりつじ /成立時/
せいりつじてん /成立時点/
せいりつじょうけん /成立条件/
せいりつぞう /正立像/
せいりつねんがっぴ /成立年月日/
せいりつねんだい /成立年代/
せいりつはいけい /成立背景/
せいりつふせいりつ /成立不成立/
せいりつまえ /成立前/
せいりてき /生理的/
せいりてききょどう /生理的挙動/
せいりてきけんお /生理的嫌悪/
せいりてきけんおかん /生理的嫌悪感/
せいりてきげんしょう /生理的現象/
せいりてきこうか /生理的効果/
せいりてきじゅんび /生理的準備/
せいりとうごう /整理統合/
せいりばんごう /整理番号/
せいりぶもん /生理部門/
せいりほう /整理法/
せいりほうほう /整理方法/
せいりゃく /政略/
せいりゃくてき /政略的/
せいりゅう /整流/清流/成龍/青竜/青龍/
せいりゅうき /整流器/整流機/
せいりゅうし /整流子/
せいりゅうばん /整流板/
せいりょう /声量/清涼/星陵/清陵/青陵/星稜/凄涼/凄寥/
せいりょういんりょう /清涼飲料/
せいりょういんりょうすい /清涼飲料水/
せいりょうかいかん /星陵会館/星陵会舘/
せいりょうかん /清涼感/
せいりょうざい /清涼剤/
せいりょうだい /星陵台/
せいりょうちょう /星陵町/
せいりょうてき /声量的/
せいりょく /勢力/精力/
せいりょくか /勢力下/
せいりょくけん /勢力圏/
せいりょくしょく /青緑色/
せいりょくぞうしん /精力増進/
せいりょくてき /精力的/勢力的/
せいりょくはんい /勢力範囲/
せいりよう /生理用/
せいりようひん /生理用品/
せいりん /青林/
せいりんしょいん /青林書院/
せいりんどう /青林堂/
せいれい /聖隷/政令/精霊/精励/生霊/聖霊/蜻蛉/悽戻/正例/
せいれいしていとし /政令指定都市/
せいれいとし /政令都市/
せいれき /西暦/
せいれき#ねん /西暦#0年/西暦#1年/西暦#2年/西暦#3年/(skk-ad-to-gengo 0 nil "年")/(skk-ad-to-gengo 1 nil "年")/
せいれきなんねん /西暦何年/
せいれきねんがっぴ /西暦年月日/
せいれつ /整列/清冽/
せいれつかのう /整列可能/
せいれつこうか /整列効果/
せいれつじゅん /整列順/
せいれつほうほう /整列方法/
せいれん /精錬/清廉/精練/製練/清簾/
せいれんしょ /精錬所/
せいれんじこ /青蓮寺湖/
せいれんじょ /精錬所/
せいろ /征露/蒸籠/
せいろう /精蝋/晴朗/蒸篭/聖篭/蒸籠/
せいろがん /征露丸/正露丸/
せいろく /西麓/
せいろん /正論/
せいろんり /正論理/
せいろんりしき /正論理式/
せいわ /勢和/清和/
せいわだい /清和台/
せう /召/抄/招/消/焼/焦/照/笑/紹/肖/詔/
せお /瀬尾/妹尾/
せおりー /セオリー/
せかい /世界/
せかいいち /世界一/
せかいいっしゅう /世界一周/
せかいいっしゅうびん /世界一周便/
せかいいっしゅうりょうきん /世界一周料金/
せかいいっしゅうりょこう /世界一周旅行/
せかいえいがさくひん /世界映画作品/
せかいおうざ /世界王座/
せかいおうじゃ /世界王者/
せかいかいよう /世界海洋/
せかいかくち /世界各地/
せかいかっこく /世界各国/
せかいかようさい /世界歌謡祭/
せかいかん /世界観/
せかいきゅうせいきょう /世界救世教/
せかいきょうつう /世界共通/
せかいきろく /世界記録/
せかいけいざい /世界経済/
せかいこうぞう /世界構造/
せかいさいきょう /世界最強/
せかいさいこう /世界最高/
せかいさいこうそく /世界最高速/
せかいさいしょ /世界最初/
せかいさいしょう /世界最小/
せかいさいそく /世界最速/
せかいさいた /世界最多/
せかいさいたんきろく /世界最短記録/
せかいさいだい /世界最大/
せかいさいちょう /世界最長/
せかいし /世界史/
せかいしじょう /世界市場/
せかいしゅぎ /世界主義/
せかいじ /世界時/
せかいじたい /世界自体/
せかいじゅ /世界樹/
せかいじゅう /世界中/
せかいじょうせい /世界情勢/
せかいじんけんかいぎ /世界人権会議/
せかいじんけんせんげん /世界人権宣言/
せかいじんこうかいぎ /世界人口会議/
せかいじんるい /世界人類/
せかいせいは /世界制覇/
せかいせいふく /世界征服/世界制服/
せかいせいふくせんげん /世界征服宣言/
せかいせん /世界選/世界戦/世界線/
せかいせんしゅけん /世界選手権/
せかいせんりゃく /世界戦略/
せかいぜんたい /世界全体/
せかいぜんど /世界全土/
せかいぞう /世界像/
せかいたいかい /世界大会/
せかいたいせん /世界大戦/
せかいだいきょうこう /世界大恐慌/
せかいちず /世界地図/
せかいちょう /世界長/
せかいていこく /世界帝国/
せかいてき /世界的/
せかいてきえいきょうりょく /世界的影響力/
せかいてききぼ /世界的規模/
せかいてきちゅうしん /世界的中心/
せかいとういつ /世界統一/
せかいにっぽう /世界日報/
せかいはつ /世界初/
せかいはつとうさい /世界初搭載/
せかいはんがたいけい /世界版画体系/
せかいひょうじゅん /世界標準/
せかいびじゅつずかん /世界美術図鑑/
せかいびじゅつぜんしゅう /世界美術全集/
せかいふうけい /世界風景/
せかいぶっさんてん /世界物産展/
せかいぶもん /世界部門/
せかいぶんがく /世界文学/
せかいぶんがくぜんしゅう /世界文学全集/
せかいへいきん /世界平均/
せかいへいわ /世界平和/
せかいぼうえき /世界貿易/
せかいもじ /世界文字/
せかいりくじょう /世界陸上/
せかいりょこう /世界旅行/
せがみ /瀬上/
せがれ /倅/伜/悴/
せがわ /瀬川/瀬河/
せき /席/積/籍/関/昔/寂/夕/石/赤/跡/責/析/績/晰/碩/蹟/隻/戚/惜/脊/斥/咳/堰/赫/蹠/瀬木/×/勣/晢/淅/瘠/皙/磧/蓆/藉/蜥/螫/裼/跖/蹐/迹/關/鶺/錫/威/汐/潟/
せきい /赤緯/
せきうち /関内/
せきうら /関浦/
せきうん /積雲/
せきえい /石英/
せきお /世紀夫/
せきか /石化/赤化/石果/
せきかえ /席替え/
せきかく /刺客/
せきかわ /関川/
せきがい /赤外/
せきがいきゅうしゅう /赤外吸収/
せきがいこう /赤外光/
せきがいしよう /赤外仕様/
せきがいせん /赤外線/
せきがいせんさつえい /赤外線撮影/
せきがいせんしゃしん /赤外線写真/
せきがいせんほうしき /赤外線方式/
せきがいりょういき /赤外領域/
せきがえ /席替え/
せきがきゅう /赤芽球/
せきがく /碩学/
せきがね /関金/
せきがはら /関ケ原/関ヶ原/
せきがわ /関川/
せきがん /隻眼/赤岩/
せきくうかん /積空間/
せきぐち /関口/
せきぐん /赤軍/
せきこう /赤光/積項/
せきさい /積載/
せきさいじゅうりょう /積載重量/
せきさいせい /積載性/
せきさいのうりょく /積載能力/
せきさいぶつ /積載物/
せきさいぼう /石細胞/
せきさいりょう /積載量/
せきさん /積算/
せきざい /石材/
せきざわ /関沢/
せきし /積志/
せきしま /関島/
せきしゅうごう /積集合/
せきしゅつ /析出/
せきしょ /関所/
せきしょう /石勝/
せきしょうせん /石勝線/
せきしょく /赤色/
せきしょくかいてん /赤色回転/
せきしょくかいてんとう /赤色回転灯/
せきしょくけい /赤色系/
せきしょくけいこうとう /赤色警光灯/
せきしょくこう /赤色光/
せきしょくとう /赤色灯/赤色燈/
せきしん /赤心/
せきじ /席次/
せきじひょう /席次表/
せきじま /関島/
せきじゅうじ /赤十字/
せきじゅうじき /赤十字旗/
せきじゅん /席順/石筍/
せきじょう /席上/惜譲/関上/関城/
せきすい /積水/
せきすいかがくこうぎょう /積水化学工業/
せきすいはうす /積水ハウス/
せきすう /隻数/
せきずい /脊髄/
せきずいしょう /脊髄症/
せきずいはんしゃ /脊髄反射/
せきずいはんしゃどうさ /脊髄反射動作/
せきせいいんこ /セキセイインコ/
せきせつ /積雪/
せきせつき /積雪期/
せきせつじょうきょう /積雪状況/
せきせつじょうほう /積雪情報/
せきせつりょう /積雪量/
せきせつろ /積雪路/
せきぜん /関前/
せきぜんかい /責善会/
せきそう /積層/
せきぞう /石像/
せきた /関田/
せきたに /関谷/
せきたん /石炭/
せきたんさん /石炭酸/
せきたんゆそう /石炭輸送/
せきちゅう /脊柱/石柱/
せきちゅうけんさ /脊柱検査/
せきつい /脊椎/
せきついがわわんしょう /脊椎側湾症/
せきついこてい /脊椎固定/
せきついどうぶつ /脊椎動物/
せきづか /関塚/
せきてい /石庭/
せきとう /石塔/
せきとり /関取/
せきど /関戸/
せきどう /赤道/
せきどうか /赤道下/
せきどうぎ /赤道儀/
せきどうちょっか /赤道直下/
せきどうはんけい /赤道半径/
せきどうふきん /赤道付近/
せきにん /責任/
せきにんか /責任下/
せきにんかいひ /責任回避/
せきにんかん /責任感/
せきにんしゃ /責任者/
せきにんじゅうだい /責任重大/
せきにんじょう /責任上/
せきにんたいせい /責任体制/
せきにんたんとう /責任担当/
せきにんついきゅう /責任追及/責任追求/
せきにんてんか /責任転嫁/
せきにんはんいない /責任範囲内/
せきにんばらい /責任払い/
せきにんぶんたん /責任分担/
せきにんほうき /責任放棄/
せきにんむのうりょくしゃ /責任無能力者/
せきにんもんだい /責任問題/
せきにんろんぎ /責任論議/
せきね /関根/
せきねつ /赤熱/
せきねん /積年/
せきの /関野/
せきのみや /関宮/
せきはい /惜敗/
せきはん /赤飯/
せきばく /寂莫/寂寞/
せきばらい /咳払い/
せきばん /石版/石板/石盤/
せきひ /石碑/
せきひん /赤貧/
せきぶつ /石仏/
せきぶん /積分/∫/
せきぶんかいろ /積分回路/
せきぶんかのうせい /積分可能性/
せきぶんかん /積文館/
せきぶんかんすう /積分関数/
せきぶんがた /積分型/
せきぶんき /積分器/
せきぶんきこう /積分機構/
せきぶんきごう /積分記号/
せきぶんけい /積分型/
せきぶんこうしき /積分公式/
せきぶんしき /積分式/
せきぶんち /積分値/
せきぶんちょくせんせい /積分直線性/
せきぶんていり /積分定理/
せきぶんはんい /積分範囲/
せきぶんへんかん /積分変換/
せきぶんほう /積分法/
せきぶんほうていしき /積分方程式/
せきぶんろ /積分路/
せきぶんろん /積分論/
せきべ /関部/
せきべつ /惜別/
せきほく /石北/
せきほくせん /石北線/
せきほくほんせん /石北本線/
せきぼく /石墨/
せきまち /関町/
せきみず /関水/
せきむ /責務/
せきめ /関目/
せきめん /赤面/石綿/
せきもと /関本/
せきもり /関守/
せきや /関谷/関屋/
せきやきねん /関屋記念/
せきやど /関宿/
せきやま /関山/
せきゅりてぃ /セキュリティ/
せきゆ /石油/
せきゆいぞんど /石油依存度/
せきゆおう /石油王/
せきゆきき /石油危機/
せきゆきょうきゅう /石油供給/
せきゆぎょうかい /石油業界/
せきゆこうがっか /石油工学科/
せきゆこうだん /石油公団/
せきゆしゅうえき /石油収益/
せきゆしゅっか /石油出荷/
せきゆせいさん /石油生産/
せきゆせいひん /石油製品/
せきゆたんさ /石油探査/
せきゆたんさぎし /石油探査技師/
せきゆるい /石油類/
せきらら /赤裸裸/
せきらんうん /積乱雲/
せきり /赤痢/
せきりつ /積率/
せきりゅう /石榴/
せきりょう /寂寥/席料/
せきりょく /斥力/赤緑/
せきりょくさよう /斥力作用/
せきりょくしきじゃく /赤緑色弱/
せきりょくしきもう /赤緑色盲/
せきりん /赤燐/
せきれい /鶺鴒/
せきわ /積和/
せきわえんざん /積和演算/
せきわけ /関脇/
せきわけいか /関脇以下/
せきわけざんりゅう /関脇残留/
せきわじっこうじかん /積和実行時間/
せぎょう /施業/施行/
せぎょうほう /施業法/
せぎん /世銀/
せくしょん /セクション/§/
せくたすう /セクタ数/
せくとしゅぎ /セクト主義/
せぐち /瀬口/
せぐめんとじょうほう /セグメント情報/
せけん /世間/
せけんいっぱん /世間一般/
せけんいっぱんてき /世間一般的/
せけんぎ /世間気/
せけんさま /世間様/
せけんし /世間師/
せけんじょうしき /世間常識/
せけんずれ /世間擦れ/
せけんてい /世間体/
せけんてき /世間的/
せけんばなし /世間話/
せこ /世古/瀬古/瀬虎/
せこう /施工/施行/
せこうしえん /施工支援/
せこうじき /施行時期/
せこうぬし /施工主/
せこうび /施行日/
せこうまえ /施行前/
せこうれい /施行令/
せこぐち /世古口/
せしゅ /施主/
せしゅう /世襲/
せしりあ /セシリア/
せじ /世辞/世事/
せじざい /世自在/
せじざいおうぶつ /世自在王仏/
せじょう /施錠/世情/
せじん /世人/
せすじ /背筋/
せそう /世相/
せそうてき /世相的/
せぞく /世俗/
せぞくか /世俗化/
せた /瀬田/勢多/
せたい /世帯/
せたいごと /世帯毎/
せたいすう /世帯数/
せたいすうひょう /世帯数表/
せたいにんじょう /世態人情/
せたいぬし /世帯主/
せたえきまえ /瀬田駅前/
せたか /瀬高/
せたがや /世田谷/
せたがやく /世田谷区/
せたがやくみん /世田谷区民/
せたがやせん /世田谷線/
せたがやだいた /世田谷代田/
せたがやびじゅつかん /世田谷美術館/
せたけ /背丈/
せたこうさてん /瀬田交差点/
せたな /瀬棚/
せだ /瀬田/
せだい /世代/
せだいかくさ /世代格差/
せだいかん /世代間/
せだいかんきそく /世代間規則/
せだいこうたい /世代交代/世代交替/
せだいてき /世代的/
せだいめ /世代目/
せち /節/世知/世智/窃/褻/折/
せちばる /世知原/
せぢか /瀬近/
せっ /接/
せっか /石火/叱呵/
せっかい /節介/切開/石灰/雪塊/
せっかいがん /石灰岩/
せっかいほう /切開法/
せっかく /折角/切角/刺客/
せっかん /切換/折檻/石棺/
せっき /石器/節気/
せっきじだい /石器時代/
せっきゃく /接客/
せっきゃくせつび /接客設備/
せっきゃくたいど /接客態度/
せっきょう /説教/
せっきょく /積極/
せっきょくさく /積極策/
せっきょくさんせい /積極賛成/
せっきょくすいしん /積極推進/
せっきょくせい /積極性/
せっきょくてき /積極的/
せっきょくてきさんせい /積極的賛成/
せっきょくてきはきゅう /積極的波及/
せっきょくてきれんけい /積極的連係/
せっきょくろん /積極論/
せっきん /接近/
せっきんせん /接近戦/接近戰/
せっく /節句/
せっくす /セックス/
せっけい /設計/雪渓/雪溪/切形/
せっけいいっか /設計一課/
せっけいか /設計課/設計家/
せっけいかいし /設計開始/
せっけいかいはつ /設計開発/
せっけいかいはつしゃ /設計開発者/
せっけいかいはつぶ /設計開発部/
せっけいがい /設計外/
せっけいがくせんこう /設計学専攻/
せっけいがっか /設計学科/
せっけいきじゅつ /設計記述/
せっけいきじゅん /設計基準/
せっけいぎじゅつ /設計技術/
せっけいぎじゅつかいはつ /設計技術開発/
せっけいぎじゅつぶ /設計技術部/
せっけいけんきゅうしつ /設計研究室/
せっけいけんしょう /設計検証/
せっけいこうてい /設計工程/
せっけいし /設計士/
せっけいしえん /設計支援/
せっけいしき /設計式/
せっけいしそう /設計思想/
せっけいしだい /設計次第/
せっけいしつ /設計室/
せっけいしゃ /設計者/
せっけいしゅほう /設計手法/
せっけいしょ /設計書/
せっけいしょき /設計初期/
せっけいじ /設計時/
せっけいじたい /設計自体/
せっけいじてん /設計時点/
せっけいじむしょ /設計事務所/
せっけいじょう /設計上/
せっけいじょうけん /設計条件/
せっけいず /設計図/
せっけいずほう /設計図法/
せっけいせいさく /設計製作/
せっけいせいさん /設計生産/
せっけいせいず /設計製図/
せっけいたんい /設計単位/
せっけいだいいちぶ /設計第一部/
せっけいだんかい /設計段階/
せっけいち /設計値/
せっけいちゅう /設計中/
せっけいていこうち /設計抵抗値/
せっけいにゅうもん /設計入門/
せっけいひ /設計費/
せっけいぶ /設計部/
せっけいぶせっけいか /設計部設計課/
せっけいぶんしょ /設計文書/
せっけいへんこう /設計変更/
せっけいほう /設計法/
せっけいほうしん /設計方針/
せっけいほうほう /設計方法/
せっけいもくひょう /設計目標/
せっけいようそ /設計要素/
せっけいれい /設計例/
せっけいろん /設計論/
せっけっきゅう /赤血球/
せっけん /石鹸/接見/席巻/席捲/
せっけんえき /石鹸液/
せっけんこうじょう /石鹸工場/
せっけんすい /石鹸水/
せっけんせんざい /石鹸洗剤/
せっけんばこ /石鹸箱/
せっけんまく /石鹸膜/
せっこう /石膏/拙稿/浙江/斥候/
せっこうせっこく /窃鉤窃国/
せっこうぞう /石膏像/
せっこつ /接骨/
せっさ /切磋/
せっさく /拙作/切削/
せっさたくま /切磋琢磨/切瑳琢磨/
せっし /℃/摂氏/
せっしゃ /拙者/接写/
せっしゃじ /接写時/
せっしやくわん /切歯扼腕/
せっしゅ /摂取/接種/
せっしゅう /接収/雪舟/
せっしゅご /接種後/摂取後/
せっしゅばしょ /接種場所/
せっしゅりつ /接種率/
せっしゅりょう /摂取量/
せっしょう /折衝/殺生/摂政/
せっしょく /接触/節食/摂食/接觸/
せっしょくあつ /接触圧/
せっしょくあつぶそく /接触圧不足/
せっしょくげんば /接触現場/
せっしょくしゅうでん /接触集電/
せっしょくじ /接触時/
せっしょくじこ /接触事故/
せっしょくでんいさ /接触電位差/
せっしょくふりょう /接触不良/
せっしょくぶ /接触部/
せっしょくぶぶん /接触部分/
せっしょくめんせき /接触面積/
せっしょくりょういき /接触領域/
せっしょん /セッション/
せっすい /節水/
せっせい /摂生/節制/拙生/摂制/
せっせん /接戦/接線/切線/
せっせんじゅうだんめん /接線縦断面/
せっせんぶんれつ /接線分裂/
せっせんほうこう /接線方向/
せっそう /節操/拙僧/
せっそく /拙速/
せっそくどうぶつ /節足動物/
せっそん /折損/
せったい /接待/
せったいひ /接待費/
せったいよう /接待用/
せったく /拙宅/
せっち /設置/接地/
せっちあつ /接地圧/
せっちいち /設置位置/
せっちかもく /設置科目/
せっちかん /接地感/
せっちかんかく /設置間隔/
せっちきじゅん /設置基準/
せっちご /設置後/
せっちさぎょう /設置作業/
せっちしゃ /設置者/
せっちじゅんび /設置準備/
せっちじゅんびいいんかい /設置準備委員会/
せっちじょう /設置上/
せっちじょうけん /設置条件/
せっちじょうたい /設置状態/
せっちすう /設置数/
せっちせん /接地線/
せっちそうだいすう /設置総台数/
せっちたい /接地帯/
せっちだいすう /設置台数/
せっちちょうせいほうほう /設置調整方法/
せっちていこう /接地抵抗/
せっちてん /接地点/設置店/
せっちはば /接地幅/
せっちばしょ /設置場所/
せっちぶぶん /接地部分/
せっちほうほう /設置方法/
せっちほぞん /設置保存/
せっちめん /接地面/
せっちめんせき /接地面積/
せっちゃく /接着/
せっちゃくかしょ /接着箇所/
せっちゃくざい /接着剤/接着材/
せっちゃくぶ /接着部/
せっちゃくめん /接着面/
せっちゃくめんせき /接着面積/
せっちゅう /折衷/雪中/折中/
せっちゅうあん /折衷案/
せっちょ /拙著/
せっちょう /折衝/
せっちよてい /設置予定/
せっちよていち /設置予定地/
せっちん /雪隠/
せっつ /摂津/
せっついずみ /摂津和泉/
せっついたがみ /摂津板紙/
せっつう /切通/
せっつてつどう /摂津鉄道/
せってい /設定/
せっていいがい /設定以外/
せっていか /設定可/
せっていかくにん /設定確認/
せっていかのう /設定可能/
せっていがめん /設定画面/
せっていきょうりょく /設定協力/
せっていぎょう /設定行/
せっていこうい /設定行為/
せっていこうもく /設定項目/
せっていさいこうおんど /設定最高温度/
せっていさぎょう /設定作業/
せっていしだい /設定次第/
せっていしゃ /設定者/
せっていしりょう /設定資料/
せっていしりょうしゅう /設定資料集/
せっていじ /設定時/
せっていじかん /設定時間/
せっていじこく /設定時刻/
せっていじたい /設定自体/
せっていじょう /設定上/
せっていじょうきょう /設定状況/
せっていじょうたい /設定状態/
せっていすう /設定数/
せっていずみ /設定済み/
せっていち /設定値/
せっていちゅう /設定中/
せっていどうさ /設定動作/
せっていないよう /設定内容/
せっていなど /設定等/
せっていねんれい /設定年齢/
せっていふび /設定不備/
せっていふりょう /設定不良/
せっていへんこう /設定変更/
せっていへんこうなし /設定変更無し/
せっていほう /設定法/
せっていほうほう /設定方法/
せっていよう /設定用/
せっていりゆう /設定理由/
せっていれい /設定例/
せってん /接点/節点/
せってんすう /節点数/
せってんふりょう /接点不良/
せってんめい /節点名/
せっと /セット/
せっとう /接頭/窃盗/竊盜/
せっとうこうい /窃盗行為/
せっとうご /接頭語/
せっとうじ /接頭辞/
せっとうせつびご /接頭接尾語/
せっとうだん /窃盗団/
せっとうぶ /接頭部/
せっとく /説得/
せっとくざいりょう /説得材料/
せっとくぶそく /説得不足/
せっとくりょく /説得力/
せっとくりょくぶそく /説得力不足/
せっぱ /切羽/
せっぱく /切迫/
せっぱくかん /切迫感/
せっぱん /折半/
せっぴ /雪庇/切皮/
せっぶく /折伏/
せっぷう /雪風/
せっぷく /切腹/
せっぷん /接吻/
せっぺん /切片/
せっぽう /説法/
せつ /節/説/切/設/折/接/雪/摂/窃/拙/泄/§/卩/啜/截/攝/晢/晰/椄/楔/浙/渫/竊/紲/絏/緤/薛/褻/セツ/鱈/屑/洩/刹/殺/
せつえい /設営/雪影/
せつえん /節煙/
せつお /節夫/節男/節雄/
せつかん /節間/
せつがい /雪害/
せつがん /接眼/接岸/
せつがんぶ /接眼部/
せつくうかん /接空間/
せつけいしき /節形式/
せつけいもじ /楔形文字/
せつげん /節減/雪原/
せつこ /節子/説乎/
せつこうぞう /節構造/
せつごう /接合/
せつごうし /接合子/
せつごうたい /接合体/
せつごうてん /接合点/
せつごうぶ /接合部/
せつごうようりょう /接合容量/
せつしゅうごう /節集合/
せつじ /接辞/
せつじつ /切実/
せつじゅ /接受/
せつじょ /切除/
せつじょう /雪上/
せつじょうきょうぎ /雪上競技/
せつじょうこうどう /雪上行動/
せつじょうしゃ /雪上車/
せつじょうせいのう /雪上性能/
せつじょく /雪辱/
せつじょくせん /雪辱戦/
せつぜい /節税/
せつぜいこうい /節税行為/
せつぜん /切前/
せつぞく /接続/
せつぞくあいて /接続相手/
せつぞくえき /接続駅/
せつぞくか /接続可/
せつぞくかのう /接続可能/
せつぞくかのうせい /接続可能性/
せつぞくかんけい /接続関係/
せつぞくき /接続器/
せつぞくきき /接続機器/
せつぞくきょうど /接続強度/
せつぞくきょく /接続局/
せつぞくけいたい /接続形態/
せつぞくけいやく /接続契約/
せつぞくけんさ /接続検査/
せつぞくご /接続後/接続語/
せつぞくさき /接続先/
せつぞくさぎょう /接続作業/
せつぞくさぎょうちゅう /接続作業中/
せつぞくし /接続詞/
せつぞくしゃ /接続者/
せつぞくしょり /接続処理/
せつぞくしんせい /接続申請/
せつぞくしんせいしょ /接続申請書/
せつぞくじ /接続時/
せつぞくじかん /接続時間/
せつぞくじかんまえ /接続時間前/
せつぞくじっけん /接続実験/
せつぞくじっせき /接続実績/
せつぞくじっせきすう /接続実績数/
せつぞくじゅんじょ /接続順序/
せつぞくじょうきょう /接続状況/
せつぞくじょうけん /接続条件/
せつぞくじょうたい /接続状態/
せつぞくじょうほう /接続情報/
せつぞくじれい /接続事例/
せつぞくず /接続図/
せつぞくずみ /接続済/
せつぞくせい /接続性/
せつぞくせん /接続線/
せつぞくそくど /接続速度/
せつぞくたんし /接続端子/
せつぞくだいすう /接続台数/
せつぞくちゅう /接続中/
せつぞくてじゅん /接続手順/
せつぞくてん /接続点/
せつぞくばしょ /接続場所/
せつぞくびん /接続便/
せつぞくふかのう /接続不可能/
せつぞくぶ /接続部/
せつぞくぶひん /接続部品/
せつぞくほう /接続法/
せつぞくほうほう /接続方法/
せつぞくほんすう /接続本数/
せつぞくもう /接続網/
せつぞくよう /接続用/
せつぞくりょう /接続料/
せつぞくれい /接続例/
せつぞくれっしゃ /接続列車/
せつたんい /節単位/
せつだん /切断/
せつだんてん /切断点/
せつだんめん /切断面/
せつてん /節点/
せつでん /節電/
せつど /節度/
せつどう /摂動/
せつどうけいさん /摂動計算/
せつどうこう /摂動項/
せつどうこうか /摂動効果/
せつどうほう /摂動法/
せつどうろん /摂動論/
せつな /殺那/刹那/
せつなしん /刹那心/
せつなん /摂南/
せつび /設備/接尾/折尾/
せつびかんり /設備管理/
せつびかんりしゃ /設備管理者/
せつびけいかく /設備計画/
せつびこうにゅう /設備購入/
せつびご /接尾語/
せつびしせつ /設備施設/
せつびじ /接尾辞/
せつびじょうきょう /設備状況/
せつびじんめい /接尾人名/
せつびぜんたい /設備全体/
せつびてき /設備的/
せつびとうし /設備投資/
せつびひ /設備費/
せつびひよう /設備費用/
せつびびひん /設備備品/
せつびびひんひ /設備備品費/
せつびぶ /設備部/
せつびりょうきん /設備料金/
せつぶん /節分/拙文/説文/
せつへいめん /接平面/
せつぼう /切望/
せつめい /説明/
せつめいいん /説明員/
せつめいえいぞう /説明映像/
せつめいかい /説明会/
せつめいかのう /説明可能/
せつめいきじ /説明記事/
せつめいきのう /説明機能/
せつめいげんり /説明原理/
せつめいこう /説明項/
せつめいご /説明後/
せつめいしょ /説明書/
せつめいしょあり /説明書有り/
せつめいしょつき /説明書付き/
せつめいしょなし /説明書無し/
せつめいしょるい /説明書類/
せつめいしりょう /説明資料/
せつめいじかん /説明時間/
せつめいじしん /説明自身/
せつめいず /説明図/
せつめいずてき /説明図的/
せつめいてき /説明的/
せつめいてきせりふ /説明的台詞/
せつめいふじゅうぶん /説明不十分/
せつめいふよう /説明不要/
せつめいぶそく /説明不足/
せつめいぶん /説明文/
せつめいぶんしょ /説明文書/
せつめいぶんちゅう /説明文中/
せつめいほう /説明法/
せつめいほうほう /説明方法/
せつめいよう /説明用/
せつめん /雪面/
せつもん /設問/説文/
せつもんかいじ /説文解字/
せつもんしゃ /設問者/
せつや /摂也/
せつやく /節約/拙訳/
せつやくいがい /節約以外/
せつやくかのう /節約可能/
せつやくがく /節約額/
せつやくがた /節約型/
せつやくこうか /節約効果/
せつやくぶん /節約分/
せつやくほうほう /節約方法/
せつゆ /説諭/
せつようすい /雪溶水/
せつり /摂理/切離/
せつりつ /設立/
せつりついぜん /設立以前/
せつりつうんえいしゅし /設立運営主旨/
せつりつきねん /設立記念/
せつりつさんせいとうひょう /設立賛成投票/
せつりつしゅいしょ /設立趣意書/
せつりつしゅし /設立趣旨/
せつりつじ /設立時/
せつりつじゅんび /設立準備/
せつりつそうかい /設立総会/
せつりつとうじ /設立当時/
せつりつとうひょう /設立投票/
せつりつりゆう /設立理由/
せつりゅう /設立/
せつれつ /拙劣/
せつろん /拙論/
せつわ /説話/
せつわちょう /説話調/
せと /瀬戸/
せとう /瀬藤/
せとうち /瀬戸内/
せとうちえんがん /瀬戸内沿岸/
せとうちけいざいけん /瀬戸内経済圏/
せとうちさん /瀬戸内産/
せとうちじゃくちょう /瀬戸内寂聴/
せとうちちほう /瀬戸内地方/
せとえき /瀬戸駅/
せとおおはし /瀬戸大橋/
せとおおはしじょう /瀬戸大橋上/
せとおおはしせん /瀬戸大橋線/
せとおおはしほうめん /瀬戸大橋方面/
せとぎわ /瀬戸際/
せとぐち /瀬戸口/
せとし /瀬戸市/
せとせ /瀬戸瀬/
せとせん /瀬戸線/
せとだ /瀬戸田/
せとちょう /瀬戸町/
せとないかい /瀬戸内海/
せともの /瀬戸物/
せどうか /旋頭歌/
せな /瀬女/
せなか /背中/
せなかがわ /背中側/
せなかげり /背中蹴り/
せなかぜんたい /背中全体/
せの /瀬野/
せのう /瀬能/
せのお /妹尾/
せのおえき /妹尾駅/
せのおえきこうない /妹尾駅構内/
せのがわ /瀬野川/
せのび /背伸び/背伸/
せばた /瀬端/
せばんごう /背番号/
せひょう /世評/
せびょうし /背表紙/
せびれ /背鰭/
せびろ /背広/
せびろくみ /背広組/
せびろすがた /背広姿/
せびろふう /背広風/
せぴあ /セピア/
せふ /妾/捷/渉/
せふり /背振/
せぶみ /瀬踏み/
せぼね /背骨/
せま /瀬間/
せみ /蝉/
せみころん /セミコロン/
せみしぐれ /蝉時雨/
せみな /セミナ/
せみなー /セミナー/
せみなーしつ /セミナー室/
せみね /瀬峰/
せむし /傴僂/
せむら /瀬村/
せめ /責/
せめんと /セメント/
せもじ /背文字/
せや /瀬谷/
せやく /瀬谷区/
せやま /瀬山/
せら /世良/世羅/
せらにし /世羅西/
せり /芹/競/糶/世利/
せりいち /競り市/
せりか /芹香/
せりざわ /芹沢/芹澤/
せりふ /台詞/セリフ/科白/
せりもく /セリ目/Apiales/Umbelliflorae/
せる /セル/
せるおおとまとん /セルオートマトン/
せるが /セル画/
せるけいさん /セル計算/
せれくと /セレクト/
せれなーど /セレナード/
せろん /世論/
せわ /世話/
せわがかり /世話係/
せわにん /世話人/
せわにんかい /世話人会/
せわにんほうしき /世話人方式/
せわびと /世話人/
せわもの /世話物/
せわやく /世話役/
せん /線/千/戦/先/洗/船/選/繊/占/川/銭/践/遷/鮮/泉/薦/腺/旋/染/仙/潜/穿/箭/箋/浅/専/賎/銑/詮/閃/舛/羨/煽/煎/扇/宣/尖/餞/撰/栓/栴/―/蝉/仟/倩/僉/僊/僭/僣/刋/剪/吮/嬋/孅/專/尠/孱/巛/戰/擅/擶/旃/暹/栫/槧/槫/殲/殱/氈/沾/涎/淺/湶/潺/潛/濳/濺/燹/牋/甎/疝/痊/癬/瞻/磚/筌/筅/簽/籤/籖/綫/纖/纎/羶/翦/舩/荐/蘚/蟾/譫/賤/贍/跣/踐/銓/銛/錢/鐫/闡/阡/陝/韆/顫/饌/斬/釧/揃/苫/亘/茜/喘/
せんい /遷移/繊維/線維/戦意/瞻依/船医/
せんいかくりつ /遷移確率/
せんいかくりつぎょうれつ /遷移確率行列/
せんいかてい /遷移過程/
せんいかどうかん /繊維仮導管/
せんいかんすう /遷移関数/
せんいきそく /遷移規則/
せんいぎょうれつ /遷移行列/
せんいこうへきいけいさいぼう /繊維厚壁異形細胞/
せんいし /繊維糸/
せんいしつ /繊維質/
せんいしょう /線維/
せんいじかん /遷移時間/
せんいじょう /繊維状/
せんいじょうかどうかん /繊維状仮導管/
せんいず /遷移図/
せんいそ /線維素/
せんいそうしつ /戦意喪失/
せんいそく /繊維束/
せんいひょう /遷移表/
せんいん /船員/
せんいんたち /船員達/
せんえい /先鋭/千映/尖鋭/
せんえいか /先鋭化/
せんえいち /先鋭値/
せんえいぶつ /先鋭物/
せんえき /戦役/
せんえつ /僭越/先鋭/
せんえん /千円/
せんえんいか /千円以下/
せんえんくらい /千円位/
せんえんさつ /千円札/
せんえんさつせんよう /千円札専用/
せんえんぜんご /千円前後/
せんえんたんい /千円単位/
せんえんだい /千円台/
せんえんていど /千円程度/
せんえんなり /千円也/
せんえんぶん /千円分/
せんおう /専横/擅横/
せんおくえん /千億円/
せんか /専科/戦果/戦火/線化/戦禍/戰果/戰火/
せんかい /千回/旋回/先回/
せんかいうんどう /旋回運動/
せんかいえん /旋回円/
せんかいえんじょう /旋回円上/
せんかいきどうじょう /旋回軌道上/
せんかいしき /旋回式/
せんかいせいのう /旋回性能/
せんかいちゅう /旋回中/
せんかいはんけい /旋回半径/
せんかいほうとう /旋回砲塔/
せんかいりつ /旋回率/
せんかく /線画/先覚/尖閣/
せんかくしゃ /先覚者/
せんかじゅう /線荷重/
せんかた /為ん方/詮方/爲ん方/
せんかわ /仙川/千川/
せんかわえき /千川駅/
せんかん /戦艦/選管/線間/戰艦/
せんかんかんたい /戦艦艦隊/
せんかんはっこう /選管発行/
せんかんやまと /戦艦大和/
せんが /線画/千賀/
せんがい /選外/船外/
せんがか /線画化/
せんがく /先学/浅学/
せんがくじ /泉岳寺/
せんがくひさい /浅学非才/
せんがけいれつ /線画系列/
せんがぞう /線画像/
せんがん /洗顔/洗眼/腺癌/先願/
せんがんざい /洗顔剤/
せんがんしゅぎ /先願主義/
せんがんせっけん /洗顔石鹸/
せんがんりょう /洗顔料/
せんき /戦記/戦旗/先期/
せんきち /詮吉/
せんきゃく /先客/船客/
せんきゃくばんらい /千客万来/
せんきゅうがん /選球眼/
せんきゅうはく /船中泊/
せんきょ /選挙/占拠/占居/
せんきょいいんかい /選挙委員会/
せんきょいはん /選挙違反/
せんきょう /宣教/戦況/泉郷/船橋/
せんきょうし /宣教師/
せんきょうんえい /選挙運営/
せんきょうんどう /選挙運動/
せんきょうんどうきかん /選挙運動期間/
せんきょかつどう /選挙活動/
せんきょかんけい /選挙関係/
せんきょかんり /選挙管理/
せんきょかんりいいん /選挙管理委員/
せんきょかんりきかん /選挙管理機関/
せんきょく /選曲/戦局/選局/選挙区/
せんきょくいがい /選挙区以外/
せんきょくない /選挙区内/
せんきょくわり /選挙区割/
せんきょけっか /選挙結果/
せんきょけん /選挙権/
せんきょこうほう /選挙公報/選挙広報/
せんきょせいど /選挙制度/
せんきょせいどかいかく /選挙制度改革/
せんきょせいどじょう /選挙制度上/
せんきょせん /選挙戦/
せんきょそくほう /選挙速報/
せんきょたいさく /選挙対策/
せんきょにん /選挙人/
せんきょにんめいぼ /選挙人名簿/
せんきょほう /選挙法/
せんきょまえ /選挙前/
せんきょみん /選挙民/
せんきょむこう /選挙無効/
せんきん /千金/
せんぎ /先議/詮議/
せんぎく /千菊/
せんぎょ /鮮魚/
せんぎょう /専業/
せんぎょうか /専業化/
せんぎょうしゅふ /専業主婦/専業主夫/
せんぎょうしゅふぎょう /専業主婦業/
せんぎょてん /鮮魚店/
せんぎり /千切り/
せんく /先駆/線区/
せんくかん /線区間/
せんくしゃ /先駆者/
せんくしゃてき /先駆者的/
せんくてき /先駆的/
せんぐ /船具/
せんぐん /線群/
せんけ /千家/
せんけい /線型/線形/扇形/戦形/
せんけいえんこうだあねっとわあく /線形エンコーダーネットワーク/
せんけいえんざんし /線形演算子/
せんけいおうとう /線型応答/
せんけいか /線形化/線型化/
せんけいかいりょう /線形改良/
せんけいかいろ /線形回路/
せんけいかいろろん /線形回路論/
せんけいきんじ /線形近似/
せんけいくうかん /線型空間/線形空間/
せんけいけい /線形系/
せんけいけいかく /線型計画/
せんけいけいかくほう /線形計画法/
せんけいけいしき /線形形式/
せんけいけいりろん /線形系理論/
せんけいけつごう /線形結合/線型結合/
せんけいこうぞう /扇形構造/
せんけいこうたい /線形後退/
せんけいさいしょうじじょう /線形最小二乗/
せんけいざひょうへんかん /線形座標変換/
せんけいしゃぞう /線型写像/
せんけいしんしゅく /線形伸縮/
せんけいしんぷく /線形振幅/
せんけいじかん /線形時間/
せんけいじょうびぶんほうていしき /線型常微分方程式/
せんけいせい /線型性/線形性/
せんけいせいのう /線形性能/
せんけいぞうふく /線形増幅/
せんけいだいすう /線形代数/線型代数/
せんけいだいすうがく /線形代数学/
せんけいでんそうろ /線型伝送路/
せんけいどくりつ /線形独立/
せんけいぶぶんくうかん /線形部分空間/
せんけいぶんさん /線形分散/
せんけいぶんぽう /線形文法/
せんけいぶんり /線型分離/
せんけいへんかん /線形変換/
せんけいほう /線形法/
せんけいほうていしき /線型方程式/
せんけいほかん /線形補間/
せんけいよそく /線形予測/
せんけいよそくぶんせき /線形予測分析/
せんけいりろん /線形理論/
せんけいろんり /線型論理/線形論理/
せんけいわ /線形和/
せんけつ /先決/鮮血/潜血/
せんけつごう /線結合/
せんけん /先見/先験/先件/淺見/選研/選鉱精錬研究所/仙建/浅見/先遣/擅権/
せんけんさそうち /線検査装置/
せんけんじこう /専権事項/
せんけんせい /先見性/
せんけんてき /先験的/先見的/
せんけんてきにんしき /先験的認識/
せんけんのめい /先見の明/
せんげつ /先月/
せんげつごう /先月号/
せんげつちゅうじゅん /先月中旬/
せんげつちゅうもん /先月注文/
せんげつど /先月度/
せんげつはつばい /先月発売/
せんげつぶん /先月分/
せんげつまつ /先月末/
せんげん /宣言/選言/∨/浅間/線源/
せんげんがた /宣言型/
せんげんし /宣言子/
せんげんしていし /宣言指定子/
せんげんじんじゃ /浅間神社/
せんげんだい /千間台/
せんげんてき /宣言的/
せんげんてきいみろん /宣言的意味論/
せんげんぶ /宣言部/
せんげんぶん /宣言文/
せんこ /千古/
せんこう /先行/選考/専攻/線香/穿孔/潜行/先攻/選好/閃光/潜降/選鉱/戦功/染工/潜航/踐行/せん孔/詮衡/
せんこういいんかい /選考委員会/
せんこうおん /先行音/
せんこうか /専攻科/
せんこうかい /選考会/
せんこうかいぎ /専攻会議/
せんこうかせい /専攻科生/
せんこうき /穿孔機/
せんこうきしつ /穿孔機室/
せんこうきじゅん /選考基準/
せんこうきょうじゅかい /専攻教授会/
せんこうけい /先行系/
せんこうげん /線光源/
せんこうこうかい /先行公開/
せんこうさぎょう /先行作業/
せんこうさく /先行策/
せんこうし /先行誌/先行詞/先行子/
せんこうしゃ /先行車/
せんこうしゅうろく /先行収録/
せんこうしゅにん /専攻主任/
せんこうしゅにんかい /専攻主任会/
せんこうじっこう /先行実行/
せんこうじゅん /選考順/
せんこうじょうえい /先行上映/
せんこうせい /先行性/
せんこうたい /先行隊/
せんこうたいしょう /選考対象/
せんこうち /先行値/
せんこうちゅう /選考中/
せんこうとうし /先行投資/
せんこうどうさ /先行動作/
せんこうにゅうりょく /先行入力/
せんこうはっぴょうかい /先行発表会/
せんこうはつばい /先行発売/
せんこうはなび /線香花火/
せんこうば /先行馬/
せんこうばゆうり /先行馬有利/
せんこうひょうか /先行評価/
せんこうび /選考日/
せんこうべつ /専攻別/
せんこうめい /専攻名/
せんこうよやく /先行予約/
せんこうりょく /先行力/
せんこうれっしゃ /先行列車/
せんこく /宣告/先刻/
せんこくごしょうち /先刻御承知/
せんこつ /仙骨/
せんこのせいじゃく /千古の静寂/
せんご /戦後/選語/戰後/
せんごく /戦国/千石/仙石/戰國/
せんごくき /戦国期/
せんごくじえいたい /戦国自衛隊/
せんごくじだい /戦国時代/
せんごくだいみょう /戦国大名/
せんごくつうしょう /千石通商/
せんごくぶしょう /戦国武将/
せんごくやろう /戦国野郎/
せんごし /戦後史/
せんごしょり /戦後処理/
せんごせい /戦後製/
せんごねんきん /戦後年金/
せんごは /戦後派/
せんごばん /先後番/
せんごほう /選語法/
せんごほしょう /戦後補償/
せんごほしょうもんだい /戦後補償問題/
せんごみんしゅしゅぎ /戦後民主主義/
せんさ /千差/
せんさい /繊細/戦災/先妻/浅才/
せんさく /詮策/詮索/穿鑿/
せんさばんべつ /千差万別/
せんざい /潜在/洗剤/千載/前栽/
せんざいいしき /潜在意識/
せんざいいちぐう /千載一遇/
せんざいがくしゅう /潜在学習/
せんざいじたい /洗剤自体/
せんざいじゅよう /潜在需要/
せんざいじんこう /潜在人口/
せんざいてき /潜在的/
せんざいてきあいじょう /潜在的愛情/
せんざいのうりょく /潜在能力/
せんざいふまん /潜在不満/
せんざいふよう /洗剤不要/
せんざいりょう /洗剤量/
せんざいりょく /潜在力/
せんざき /先崎/
せんざん /仙山/
せんざんせん /仙山線/
せんざんせんけいゆう /仙山線経由/
せんし /戦士/先史/戦死/穿刺/戦史/戦志/千士/戰死/擅恣/
せんしきめん /線織面/
せんしけい /戦士系/
せんししゃ /戦死者/
せんししょう /戦士賞/
せんしたい /戦死体/戰死體/
せんしたち /戦士達/
せんしつ /船室/線質/
せんしつがわ /船室側/
せんしつけいすう /線質係数/
せんしつけん /船室券/
せんしひょうか /戦士評価/
せんしふう /戦士風/
せんしゃ /洗車/戦車/戰車/
せんしゃき /洗車機/
せんしゃじょう /洗車場/
せんしゃせん /戦車戦/
せんしゃたい /戦車隊/
せんしゃはくぶつかん /戦車博物館/
せんしゃへい /戦車兵/
せんしゃや /洗車屋/
せんしやく /戦士役/
せんしゅ /選手/先取/線種/専守/船首/僭主/
せんしゅいちらん /選手一覧/
せんしゅう /先週/泉州/専修/選集/千秋/
せんしゅうかようび /先週火曜日/
せんしゅうがっこう /専修学校/
せんしゅうこうかい /先週公開/
せんしゅうごう /先週号/
せんしゅうだい /専修大/
せんしゅうだいがく /専修大学/
せんしゅうちゅう /先週中/
せんしゅうどようび /先週土曜日/
せんしゅうはつばい /先週発売/
せんしゅうまつ /先週末/
せんしゅうらく /千秋楽/
せんしゅかい /千趣会/選手会/
せんしゅかいちょう /選手会長/
せんしゅかん /選手間/
せんしゅがわ /選手側/
せんしゅきよう /選手起用/
せんしゅけん /選手権/
せんしゅけんしゃ /選手権者/
せんしゅけんじあい /選手権試合/
せんしゅけんじゅんけっしょう /選手権準決勝/
せんしゅけんたいかい /選手権大会/
せんしゅしょうかい /選手紹介/
せんしゅじしん /選手自身/
せんしゅじゅみょう /選手寿命/
せんしゅすう /選手数/
せんしゅせいめい /選手生命/
せんしゅせんこう /選手選考/
せんしゅせんせい /選手宣誓/
せんしゅぜんいん /選手全員/
せんしゅぜんたい /選手全体/
せんしゅそう /選手層/
せんしゅたち /選手達/
せんしゅだん /選手団/
せんしゅつ /選出/
せんしゅつじょうけん /選出条件/
せんしゅつてじゅん /選出手順/
せんしゅつとうひょう /選出投票/
せんしゅつば /選出馬/
せんしゅつび /選出日/
せんしゅつほうほう /選出方法/
せんしゅてん /先取点/
せんしゅとくゆう /選手特有/
せんしゅどうし /選手同士/
せんしゅにゅうじょう /選手入場/
せんしゅにゅうじょうしき /選手入場式/
せんしゅひとりひとり /選手一人一人/
せんしゅほきょう /選手補強/
せんしゅほんにん /選手本人/
せんしゅぼうえい /専守防衛/
せんしゅめい /選手名/
せんしゅめいかん /選手名鑑/
せんしゅりゅうしゅつ /選手流出/
せんしょ /選書/
せんしょう /先勝/戦賞/戦勝/戦捷/僭称/僭上/戰捷/
せんしょうこく /戦勝国/
せんしょく /染織/染色/
せんしょくこうじょう /染色工場/
せんしょくたい /染色体/
せんしん /先進/千進/専心/線審/
せんしんぎほう /先進技法/
せんしんこく /先進国/
せんしんしょこく /先進諸国/
せんしんしょこくいっぱん /先進諸国一般/
せんしんせい /先進性/
せんしんだいがく /先進大学/
せんしんちいき /先進地域/
せんしんてき /先進的/
せんしんほう /千進法/
せんじ /戦時/潜時/戰時/
せんじいない /千字以内/
せんじか /戦時下/
せんじちゅう /戦時中/戰時中/
せんじつ /先日/
せんじつとうこう /先日投稿/
せんじつはつばい /先日発売/
せんじつらい /先日来/
せんじばいしゅう /戦時買収/
せんじひょうじゅんがた /戦時標準型/
せんじもん /千字文/
せんじゃ /選者/撰者/
せんじゅ /仙寿/千住/千種/
せんじゅう /専従/先住/
せんじゅうしゃ /専従者/
せんじゅうしゃしょとく /専従者所得/
せんじゅうじ /千手寺/
せんじゅうみん /先住民/
せんじゅかもつえき /千住貨物駅/
せんじゅかんのん /千手観音/
せんじゅつ /戦術/仙術/先述/戰術/占術/
せんじゅつか /戦術家/
せんじゅつき /戦術機/
せんじゅつきゅう /戦術級/
せんじゅつせい /戦術性/
せんじゅつてき /戦術的/
せんじゅつてきかち /戦術的価値/
せんじゅんい /先順位/
せんじょう /線上/線状/戦場/洗浄/扇状/船上/仙丈/千丈/洗滌/戰場/煽情/
せんじょうえき /洗浄液/
せんじょうえきちゅう /洗浄液中/
せんじょうき /洗浄器/洗浄機/
せんじょうざい /洗浄剤/
せんじょうじき /千畳敷/
せんじょうたんさく /線上探索/
せんじょうだけ /仙丈岳/
せんじょうだん /扇状弾/
せんじょうち /扇状地/
せんじょうちゅう /洗浄中/
せんじょうよう /洗浄用/
せんじょうりょく /洗浄力/
せんじん /先人/千尋/先陣/
せんす /扇子/センス/
せんすい /潜水/仙水/線錐/
せんすいかん /潜水艦/
せんすいかんぶたい /潜水艦部隊/
せんすいきぐ /潜水器具/
せんすいぎじゅつ /潜水技術/
せんすいし /潜水士/
せんすいじかん /潜水時間/
せんすいじっけん /潜水実験/
せんすいちゅう /潜水中/
せんすいてい /潜水艇/
せんすいとうげ /仙水峠/
せんすいびょう /潜水病/
せんすいふく /潜水服/
せんすうひゃく /千数百/
せんすうひゃくえん /千数百円/
せんず /線図/
せんずけい /線図形/
せんせーしょん /センセーション/
せんせい /先生/宣誓/先制/占星/専制/専政/
せんせいがた /先生方/
せんせいくんしゅ /専制君主/
せんせいくんしゅせい /専制君主制/
せんせいこうげき /先制攻撃/
せんせいしょ /宣誓書/
せんせいしよう /先制使用/
せんせいじゅつ /占星術/
せんせいじゅつし /占星術師/
せんせいせいじ /専制政治/
せんせいぞう /先生像/
せんせいだ /先制打/
せんせいてきじえいけん /先制的自衛権/
せんせいてきじだ /先制適時打/
せんせいてん /先制点/
せんせいひょう /賛成票/
せんせいやく /先生役/
せんせいよう /先生用/
せんせき /戦績/仙石/船籍/
せんせきせん /仙石線/
せんせきてき /戦績的/
せんせきぶん /線積分/
せんせん /先々/戦々/戦線/宣戦/宣戰/戰々/戰線/
せんせんきょうきょう /戦々兢々/戦々恐々/
せんせんげつ /先々月/先先月/
せんせんしゅう /先々週/先先週/
せんせんじつ /先先日/
せんせんじゅつ /占星術/
せんせんふこく /宣戦布告/
せんせんふっき /戦線復帰/
せんせんりだつ /戦線離脱/
せんぜん /戦前/戰前/
せんぜんがたきゅうこく /戦前型旧国/
せんぜんせだい /戦前世代/
せんぜんせんご /戦前戦後/
せんそ /線素/践祚/
せんそう /戦争/先走/船倉/戰爭/船艙/
せんそうえいが /戦争映画/
せんそうかくだい /戦争拡大/
せんそうかんれん /戦争関連/
せんそうぎせいしゃ /戦争犠牲者/
せんそうけいけん /戦争経験/
せんそうけいぞく /戦争継続/
せんそうこうい /戦争行為/
せんそうご /戦争後/
せんそうさんか /戦争賛歌/
せんそうさんび /戦争賛美/
せんそうさんびしゃ /戦争賛美者/
せんそうしょき /戦争初期/
せんそうじ /浅草寺/戦争時/
せんそうじょうたい /戦争状態/
せんそうせきにん /戦争責任/
せんそうせきにんもんだい /戦争責任問題/
せんそうたいけん /戦争体験/
せんそうちゅう /戦争中/
せんそうとうじ /戦争当時/
せんそうはんざい /戦争犯罪/戰爭犯罪/
せんそうはんざいにん /戦争犯罪人/戰爭犯罪人/
せんそうはんたい /戦争反対/
せんそうばいしょう /戦争賠償/
せんそうひがい /戦争被害/
せんそうひがいしゃ /戦争被害者/
せんそうまっき /戦争末期/
せんそうもくてき /戦争目的/
せんそうもんだい /戦争問題/
せんそか /線素化/
せんそく /洗足/戦速/栓塞/線束/
せんそだいじょうさい /践祚大嘗祭/
せんぞ /先祖/
せんぞい /線沿/
せんぞう /線増/仙三/
せんぞく /専属/洗足/
せんぞくいけ /洗足池/
せんぞくいけかん /洗足池間/
せんぞくえき /洗足駅/
せんぞくがくえん /洗足学園/
せんぞくがくえんいちこう /洗足学園一高/
せんぞくがくえんだい /洗足学園大/
せんぞくけいやくりょう /専属契約料/
せんぞさま /先祖様/
せんた /センタ/
せんたー /センター/
せんたーない /センター内/
せんたい /戦隊/船体/蘚苔/
せんたいこうぞうぶんせき /船体構造分析/
せんたいしょう /線対称/
せんたいもの /戦隊物/
せんたく /選択/洗濯/撰択/
せんたくいた /洗濯板/
せんたくか /選択可/
せんたくかのう /選択可能/
せんたくかもく /選択科目/選択課目/
せんたくがめん /選択画面/
せんたくき /洗濯機/
せんたくきじゅん /選択基準/
せんたくきのう /選択機能/
せんたくぐん /選択群/
せんたくけっか /選択結果/
せんたくけん /選択権/
せんたくこうもく /選択項目/
せんたくこうり /選択公理/
せんたくし /選択肢/選択子/選択枝/
せんたくしき /選択式/
せんたくしんごう /選択信号/
せんたくじ /選択時/
せんたくじかん /洗濯時間/
せんたくじょうけん /選択条件/
せんたくじょうしゃ /選択乗車/
せんたくじょうたい /選択状態/
せんたくすう /選択数/
せんたくせい /選択性/
せんたくせっけん /洗濯石鹸/
せんたくそう /洗濯漕/
せんたくだい /洗濯代/
せんたくちゅう /選択中/洗濯中/
せんたくてき /選択的/
せんたくてん /選択点/
せんたくにゅうりょく /選択入力/
せんたくはば /選択幅/
せんたくはんい /選択範囲/
せんたくひっしゅう /選択必修/
せんたくひょうじ /選択表示/
せんたくふかのう /選択不可能/
せんたくぶ /選択部/
せんたくぶぶん /選択部分/
せんたくほう /選択法/
せんたくほうしき /選択方式/
せんたくほうほう /選択方法/
せんたくまえ /洗濯前/
せんたくもの /洗濯物/
せんたくもんだい /選択問題/
せんたくや /洗濯屋/
せんたくよう /洗濯用/選択用/
せんたくようせんざい /洗濯用洗剤/
せんたくようそ /選択要素/
せんたくりょう /洗濯量/
せんたくわく /選択枠/
せんたろう /煎太郎/
せんたん /先端/戦端/尖端/
せんたんい /千単位/
せんたんいりょう /先端医療/
せんたんかがく /先端科学/
せんたんかがくぎじゅつ /先端科学技術/
せんたんかがくぎじゅつけんきゅうせんたー /先端科学技術研究センター/
せんたんきょうふしょう /先端恐怖症/
せんたんぎじゅつ /先端技術/
せんたんぎじゅつけんきゅう /先端技術研究/
せんたんけいじょう /先端形状/
せんたんけん /先端研/
せんたんざいりょうけん /先端材料研/
せんたんだい /先端大/
せんたんつうしんぎじゅつ /先端通信技術/
せんたんてき /先端的/
せんたんぶ /先端部/
せんたんぶつり /先端物理/
せんたんりろんぶつり /先端理論物理/
せんだ /千田/仙田/
せんだい /仙台/先代/川内/千台/
せんだいいくえい /仙台育英/
せんだいいち /仙台一/
せんだいえいぎょうしょ /仙台営業所/
せんだいえき /仙台駅/
せんだいえきちか /仙台駅地下/
せんだいえきにしぐち /仙台駅西口/
せんだいかん /仙台間/
せんだいがき /仙台牡蛎/
せんだいくうこう /仙台空港/
せんだいけんきゅうしょ /仙台研究所/
せんだいけんきゅうじょ /仙台研究所/
せんだいこう /仙台港/
せんだいこうぎょうこうとうせんもんがっこう /仙台工業高等専門学校/
せんだいこうふきん /仙台港付近/
せんだいざか /仙台坂/
せんだいし /仙台市/
せんだいしかわうち /仙台市川内/
せんだいしない /仙台市内/
せんだいしみん /仙台市民/
せんだいしゅうへん /仙台周辺/
せんだいしゅっしん /仙台出身/
せんだいしりつ /仙台市立/
せんだいたいかい /仙台大会/
せんだいたなばた /仙台七夕/
せんだいだい /仙台大/
せんだいだいにこう /仙台第二高/
せんだいちかてつ /仙台地下鉄/
せんだいちく /仙台地区/
せんだいていしゃ /仙台停車/
せんだいてん /仙台店/
せんだいでんしゃくさい /仙台電車区祭/
せんだいでんぱ /仙台電波/
せんだいでんぱこうせん /仙台電波高専/
せんだいにこう /仙台二高/
せんだいはつ /仙台発/
せんだいべん /仙台弁/
せんだいほうそう /仙台放送/
せんだいほうめん /仙台方面/
せんだいまつど /専大松戸/
せんだいみそ /仙台味噌/
せんだいみやぎ /仙台宮城/
せんだがや /千駄ヶ谷/千駄谷/
せんだぎ /千駄木/
せんだち /先達/
せんだつ /先達/
せんだまち /千田町/
せんだん /船団/栴檀/剪断/旃檀/
せんだんりょく /せん断力/
せんち /センチ/戦地/糎/
せんちぐらむ /甅/
せんちめーとる /糎/
せんちゃ /煎茶/
せんちゃく /先着/
せんちゃくしゃゆうせん /先着者優先/
せんちゃくじゅん /先着順/
せんちゅう /戦中/船中/線虫/
せんちゅうはく /船中泊/
せんちょう /線長/船長/
せんちょうかいせき /線長解析/
せんちょうけいさんほう /線長計算法/
せんちょうしつ /船長室/
せんちりっとる /竰/
せんつう /疝痛/千通/
せんて /先手/
せんてい /選定/剪定/
せんていさぎょう /選定作業/
せんていしゃ /選定者/
せんていじょうけん /選定条件/
せんていば /選定馬/
せんてごて /先手後手/
せんてつ /銑鉄/仙鉄/鮮鉄/
せんてひっしょう /先手必勝/
せんてゆうり /先手有利/
せんてん /千点/先天/
せんてんせい /先天性/
せんてんてき /先天的/
せんてんてきしょうがい /先天的障害/
せんてんてきようそ /先天的要素/
せんでき /洗滌/
せんでん /宣伝/
せんでんかつどう /宣伝活動/
せんでんこうか /宣伝効果/
せんでんこうこくひ /宣伝広告費/
せんでんたんとう /宣伝担当/
せんでんばいたい /宣伝媒体/
せんでんひ /宣伝費/
せんでんぶそく /宣伝不足/
せんでんぶたい /宣伝部隊/
せんでんぶちょう /宣伝部長/
せんでんぶもん /宣伝部門/
せんでんぶん /宣伝文/
せんでんもんく /宣伝文句/
せんでんや /宣伝屋/
せんでんよう /宣伝用/
せんでんりょく /宣伝力/
せんと /遷都/セント/仙都/
せんとう /先頭/戦闘/銭湯/戰闘/尖塔/千頭/宣統/
せんとうあらそい /先頭争い/
せんとういと /戦闘意図/
せんとういん /戦闘員/
せんとうかいし /戦闘開始/
せんとうかいしじ /戦闘開始時/
せんとうかん /戦闘艦/
せんとうがめん /戦闘画面/
せんとうき /戦闘機/
せんとうきどうし /戦闘機同士/
せんとうきふう /戦闘機風/
せんとうきょく /戦闘曲/
せんとうきろく /戦闘記録/
せんとうぎじゅつ /戦闘技術/
せんとうくんれん /戦闘訓練/
せんとうけいかく /戦闘計画/
せんとうこうい /戦闘行為/
せんとうこうどうちゅう /戦闘行動中/
せんとうご /戦闘後/
せんとうごしょ /仙洞御所/
せんとうさいかい /戦闘再開/
せんとうしき /戦闘志気/
せんとうしゃ /先頭車/
せんとうしゃりょう /先頭車両/
せんとうしゅうだん /先頭集団/
せんとうじ /戦闘時/
せんとうじょう /戦闘場/
せんとうじょうたい /戦闘状態/
せんとうせんしゅ /先頭選手/
せんとうぜんご /戦闘前後/
せんとうそくりょく /戦闘速力/
せんとうだしゃ /先頭打者/
せんとうちゅう /戦闘中/
せんとうてい /宣統帝/
せんとうのうりょく /戦闘能力/
せんとうはっせい /戦闘発生/
せんとうはん /戦闘班/
せんとうふのう /戦闘不能/
せんとうぶ /先頭部/
せんとうぶぶん /先頭部分/
せんとうぶんせつかくてい /先頭文節確定/
せんとうゆうどういん /先頭誘導員/
せんとうよう /戦闘用/
せんとうりょく /戦闘力/
せんとらるがらす /セントラル硝子/
せんとらるぱーく /セントラルパーク/
せんど /鮮度/先途/尖度/
せんどう /先導/仙道/千堂/煽動/船頭/扇動/千同/
せんどうし /線同士/
せんどうしゃ /先導車/
せんどうてき /先導的/
せんどうふう /船頭風/
せんどうやく /先導役/
せんない /船内/線内/
せんないせいかつ /船内生活/
せんなん /泉南/仙南/
せんにち /千日/
せんにちせんそう /千日戦争/
せんにちて /千日手/
せんにちどう /千日堂/
せんにちまえ /千日前/
せんにちまえせん /千日前線/
せんにゅう /潜入/
せんにゅうかん /先入観/
せんにゅうかんねん /先入観念/
せんにん /専任/仙人/千人/選任/先任/
せんにんいじょう /千人以上/
せんにんかしかん /先任下士官/
せんにんかんりにん /専任管理人/
せんにんきょうじゅ /専任教授/
せんにんきょうじゅかい /専任教授会/
せんにんぎり /千人斬り/
せんにんけん /選任権/
せんにんこうし /専任講師/
せんにんしゃ /専任者/
せんにんしょうこう /先任将校/
せんぬき /栓抜き/
せんねつ /潜熱/
せんねん /専念/千年/先年/
せんねんいじょうまえ /千年以上前/
せんねんたんい /千年単位/
せんのう /洗脳/
せんのうき /洗脳機/
せんはた /千畑/
せんはつめい /先発明/
せんはば /線幅/
せんはら /千原/
せんば /仙波/船場/千羽/仙葉/
せんばい /専売/
せんばいいじょう /千倍以上/
せんばいこうしゃ /専売公社/
せんばいせい /専売制/
せんばいとっきょ /専売特許/
せんばがん /選馬眼/
せんばしょ /先場所/
せんばつ /選抜/
せんばつこうこうやきゅう /選抜高校野球/
せんばつたいかい /選抜大会/
せんばづる /千羽鶴/
せんばやしかん /千林間/
せんばりき /千馬力/
せんばん /千万/旋盤/先番/
せんぱい /先輩/
せんぱいがた /先輩方/
せんぱいこうはい /先輩後輩/
せんぱいたち /先輩達/
せんぱく /船舶/浅薄/銭帛/
せんぱくぎょうかい /船舶業界/
せんぱくでんわ /船舶電話/
せんぱくでんわばん /船舶電話版/
せんぱくめんきょ /船舶免許/
せんぱつ /先発/洗髪/染髪/
せんぱつかいひ /先発回避/
せんぱつかんとう /先発完投/
せんぱつかんとうかんぷう /先発完投完封/
せんぱつかんとうがた /先発完投型/
せんぱつさんるいしゅ /先発三塁手/
せんぱつし /先発枝/
せんぱつじん /先発陣/
せんぱつぜんいんあんだ /先発全員安打/
せんぱつたい /先発隊/
せんぱつとうしゅ /先発投手/
せんぱつとうしゅじん /先発投手陣/
せんぱつゆうげきしゅ /先発遊撃手/
せんぱつよそう /先発予想/
せんぱつりょう /洗髪料/
せんぱん /先般/戦犯/戰犯/
せんぱんしょり /戦犯処理/
せんひき /線引/線引き/
せんび /船尾/
せんびき /線引き/
せんびん /船便/先便/
せんぴょう /線表/選評/
せんぶん /線分/千分/
せんぶんか /線分化/
せんぶんじょう /線分上/
せんぶんず /線分図/
せんぶんりつ /千分率/
せんぷ /戦斧/先負/
せんぷう /旋風/
せんぷうき /扇風機/
せんぷく /潜伏/線幅/船腹/
せんぷくが /潜伏芽/
せんぷくき /潜伏期/
せんぷくきかん /潜伏期間/
せんべい /煎餅/
せんべつ /選別/餞別/
せんべつひん /選別品/
せんべん /先鞭/
せんべんばんか /千変万化/
せんぺい /尖兵/
せんぺんばんか /千変万化/
せんほく /泉北/
せんぼう /羨望/
せんぼうきょう /潜望鏡/
せんぼく /泉北/仙北/
せんぼつ /戦没/
せんぼつしゃ /戦没者/
せんぼん /千本/
せんぼんざくら /千本桜/
せんぼんはま /千本浜/
せんぽう /先方/戦法/旋法/先鋒/
せんぽうもち /先方持ち/
せんぽく /泉北/
せんまい /千枚/洗米/
せんまいじ /洗米時/
せんまいだ /千枚田/
せんまいだけ /千枚岳/
せんまや /千厩/
せんまん /千万/
せんまんにん /千万人/
せんみつど /線密度/
せんみん /選民/
せんみんかいきゅう /賎民階級/
せんむ /専務/
せんめい /鮮明/線名/
せんめつ /殲滅/剪滅/殱滅/
せんめん /洗面/線面/
せんめんき /洗面器/
せんめんじょ /洗面所/
せんめんだい /洗面台/
せんもう /線毛/繊毛/譫妄/剪毛/腺毛/
せんもうせん /釧網線/
せんもうほんせん /釧網本線/
せんもん /専門/
せんもんい /専門医/
せんもんいいん /専門委員/
せんもんいいんかい /専門委員会/
せんもんいいんちょう /専門委員長/
せんもんいん /専門員/
せんもんか /専門家/専門化/
せんもんかいがい /専門家以外/
せんもんかてい /専門過程/専門課程/
せんもんかもく /専門科目/
せんもんかんけい /専門関係/
せんもんがい /専門外/
せんもんがっこう /専門学校/
せんもんがっこうせい /専門学校生/
せんもんきょういく /専門教育/
せんもんご /専門語/
せんもんざっし /専門雑誌/
せんもんし /専門誌/専門紙/
せんもんしけん /専門試験/
せんもんしゅっぱんしゃ /専門出版社/
せんもんしょ /専門書/
せんもんしょく /専門職/
せんもんしょせき /専門書籍/
せんもんせい /専門性/
せんもんだんたい /専門団体/
せんもんちしき /専門知識/
せんもんてき /専門的/
せんもんてきちしき /専門的知識/
せんもんてん /専門店/
せんもんてんがい /専門店街/
せんもんてんがた /専門店型/
せんもんとしょかん /専門図書館/
せんもんはんいがい /専門範囲外/
せんもんぶかい /専門部会/
せんもんぶんや /専門分野/
せんもんめい /専門名/
せんもんよう /専門用/
せんもんようご /専門用語/
せんもんりょういき /専門領域/
せんもんわく /専門枠/
せんや /千夜/
せんやいちや /千夜一夜/
せんやく /先約/
せんゆう /占有/専有/戦友/先憂/
せんゆうか /占有下/
せんゆうきょか /占有許可/
せんゆうけん /占有権/専有権/
せんゆうしゃ /占有者/
せんゆうじかん /占有時間/
せんゆうじょうほう /専有情報/
せんゆうめんせき /占有面積/
せんゆうりつ /占有率/
せんゆうりょう /占有量/
せんよう /専用/宣揚/
せんようおんげん /専用音源/
せんようかいせん /専用回線/
せんようかもつ /専用貨物/
せんようがいしゃ /専用会社/
せんようき /専用機/
せんようきどう /専用軌道/
せんようきどうあと /専用軌道跡/
せんようくうこう /専用空港/
せんようけいさんきじょう /専用計算機上/
せんようこうぐ /専用工具/
せんようしゃ /専用車/
せんようしゃりょう /専用車両/
せんようしゅうのう /専用収納/
せんようしょく /専用色/
せんようせん /専用線/
せんようせんじたい /専用線自体/
せんようせんよう /専用線用/
せんようそ /線要素/
せんようたんまつ /専用端末/
せんようちゅうしゃじょう /専用駐車場/
せんようどう /専用道/
せんようどうぐ /専用道具/
せんようどうろ /専用道路/
せんようないぞうがた /専用内蔵型/
せんようば /専用馬/
せんようばん /専用版/
せんようひん /専用品/
せんようぶんぱいき /専用分配器/
せんようへんせい /専用編成/
せんようほぞんこ /専用保存庫/
せんようめんきょ /専用免許/
せんようれっしゃ /専用列車/
せんらん /戦乱/
せんり /千里/戦利/
せんりがん /千里眼/
せんりせん /千里線/
せんりちゅうおう /千里中央/
せんりちゅうおうえき /千里中央駅/
せんりつ /旋律/戦慄/先立/
せんりつてき /旋律的/
せんりつぶ /旋律部/
せんりはまかいがん /千里浜海岸/
せんりはんきゅう /千里阪急/
せんりはんきゅうほてる /千里阪急ホテル/
せんりひん /戦利品/
せんりゃく /戦略/
せんりゃくかくへいき /戦略核兵器/
せんりゃくきゅう /戦略級/
せんりゃくくうぐん /戦略空軍/
せんりゃくじょう /戦略上/
せんりゃくじょうゆうこう /戦略上有効/
せんりゃくせい /戦略性/
せんりゃくちしき /戦略知識/
せんりゃくてき /戦略的/
せんりゃくてきしどう /戦略的指導/
せんりゃくてきじょうほう /戦略的情報/
せんりゃくばくげき /戦略爆撃/
せんりゃくぶっし /戦略物資/
せんりゅう /川柳/千流/潜龍/
せんりょ /浅慮/千慮/
せんりょう /占領/線量/染料/千両/
せんりょうか /占領下/占領可/センリョウ科/Chloranthaceae/
せんりょうかのう /占領可能/
せんりょうけい /線量計/
せんりょうけいかく /占領計画/
せんりょうご /占領後/
せんりょうしはい /占領支配/
せんりょうじょうたい /占領状態/
せんりょうせいさく /占領政策/
せんりょうそくてい /線量測定/
せんりょうち /占領地/
せんりょうちいき /占領地域/
せんりょうちゅう /占領中/
せんりょうとうりょう /線量等量/線量当量/
せんりょうみん /占領民/
せんりょうりつ /線量率/
せんりょく /戦力/
せんりょくがい /戦力外/
せんりょくこうそう /戦力構想/
せんりょくひ /戦力比/
せんりょのいっし /千慮の一矢/
せんりん /線輪/
せんりんかく /線輪郭/
せんれい /洗礼/先例/
せんれき /戦歴/
せんれつ /鮮烈/戦列/
せんれん /洗練/洗錬/
せんれんか /洗練化/
せんれんけつ /線連結/
せんろ /線路/
せんろあと /線路跡/
せんろかいぜん /線路改善/
せんろかんかく /線路間隔/
せんろぎじゅつ /線路技術/
せんろぎわ /線路際/
せんろしき /線路敷/
せんろした /線路下/
せんろしゅうへん /線路周辺/
せんろしょうがい /線路障害/
せんろじょう /線路上/
せんろじょうきょう /線路状況/
せんろじょうけん /線路条件/
せんろぞい /線路沿/
せんろはば /線路幅/
せんろほうこう /線路方向/
せんろようりょう /線路容量/
せんろよこ /線路横/
せんろわき /線路脇/
せんわく /煽惑/
ぜ /是/
ぜい /税/脆/勢/贅/説/噬/筮/
ぜいかん /税関/
ぜいかんしんこくしょ /税関申告書/
ぜいがく /税額/
ぜいがくひょう /税額表/
ぜいきん /税金/
ぜいきんいがい /税金以外/
ぜいきんかんけい /税金関係/
ぜいきんこうじょ /税金控除/
ぜいきんぶん /税金分/
ぜいきんもんだい /税金問題/
ぜいきんりつ /税金率/
ぜいきんるい /税金類/
ぜいげん /税源/贅言/
ぜいこみ /税込み/税込/
ぜいしゅう /税収/
ぜいしゅうぞう /税収増/
ぜいしゅうにゅう /税収入/
ぜいしゅうひ /税収比/
ぜいじゃく /脆弱/
ぜいせい /税制/
ぜいせいかいかく /税制改革/
ぜいせいじょう /税制上/
ぜいたく /贅沢/
ぜいたくざんまい /贅沢三昧/
ぜいたくひん /贅沢品/
ぜいちょう /税調/
ぜいにく /ぜい肉/贅肉/
ぜいぬき /税抜/
ぜいびきまえとうきりえき /税引前当期利益/
ぜいふたん /税負担/
ぜいぶつ /贅物/
ぜいべつ /税別/
ぜいべつかかく /税別価格/
ぜいほう /税法/
ぜいほうじょう /税法上/
ぜいむ /税務/
ぜいむしょ /税務署/税務所/
ぜいむじむしょ /税務事務所/
ぜいめい /喘鳴/
ぜいり /税吏/税理/
ぜいりし /税理士/
ぜいりつ /税率/
ぜえた /Ζ/
ぜがひでも /是が非でも/
ぜき /関/關/
ぜげん /女衒/
ぜせい /是正/
ぜせいろんしゃ /是正論者/
ぜぜ /膳所/
ぜぜこう /膳所高/
ぜぜこうこう /膳所高校/
ぜっか /舌禍/
ぜっかい /絶海/
ぜっきょう /絶叫/
ぜっく /絶句/
ぜっけい /絶景/
ぜっこう /絶好/絶交/
ぜっこうきゅう /絶好球/
ぜっこうせんげん /絶交宣言/
ぜっこうちょう /絶好調/
ぜっこつ /舌骨/
ぜっさん /絶賛/絶讃/絶讚/
ぜっさんじょうえいちゅう /絶賛上映中/
ぜっさんはつばいちゅう /絶賛発売中/
ぜっさんほうえいちゅう /絶賛放映中/
ぜっしょう /絶唱/
ぜっしょく /絶食/
ぜっせい /絶世/
ぜっせん /舌戦/
ぜったい /絶対/絶体/舌苔/
ぜったいあんていせい /絶対安定性/
ぜったいいち /絶対位置/
ぜったいうずど /絶対渦度/
ぜったいおん /絶体音/絶対音/
ぜったいおんかん /絶対音感/
ぜったいか /絶対化/
ぜったいかく /絶対格/
ぜったいかせき /絶対可積/
ぜったいかせきぶん /絶対可積分/
ぜったいくんしゅせい /絶対君主制/
ぜったいけい /絶対系/
ぜったいけんりょく /絶対権力/
ぜったいごさ /絶対誤差/
ぜったいざひょう /絶対座標/
ぜったいし /絶対視/
ぜったいしき /絶対式/
ぜったいしゃ /絶対者/
ぜったいしゅうそく /絶対収束/
ぜったいじかん /絶対時間/
ぜったいじかんせい /絶対時間制/
ぜったいじゅうよう /絶対重要/
ぜったいじょうけん /絶対条件/
ぜったいじょうせきぶん /絶対上積分/
ぜったいすう /絶対数/
ぜったいせいきすう /絶対正規数/
ぜったいせいしくうかん /絶対静止空間/
ぜったいせいしけい /絶対静止系/
ぜったいせいのう /絶対性能/
ぜったいぜつめい /絶体絶命/
ぜったいそし /絶対阻止/
ぜったいそん /絶対損/
ぜったいたすう /絶対多数/
ぜったいたんいけい /絶対単位系/
ぜったいだいじょうぶ /絶対大丈夫/
ぜったいだめ /絶対駄目/
ぜったいち /絶対値/
ぜったいてき /絶対的/
ぜったいてきいみ /絶対的意味/
ぜったいてききゅうきょくせい /絶対的究極性/
ぜったいてきけんりょく /絶対的権力/
ぜったいてきこうい /絶対的行為/
ぜったいてきしゃくど /絶対的尺度/
ぜったいてきしんり /絶対的真理/
ぜったいてきふそく /絶対的不足/
ぜったいてきゆういせい /絶対的優位性/
ぜったいとうきゅう /絶対等級/
ぜったいとうせん /絶対当選/
ぜったいとうひょうすう /絶対投票数/
ぜったいのうりょく /絶対能力/
ぜったいはんたい /絶対反対/
ぜったいぱす /絶対パス/
ぜったいぱすめい /絶対パス名/
ぜったいひつよう /絶対必要/
ぜったいひょうか /絶対評価/
ぜったいひょうげん /絶対表現/
ぜったいふくじゅう /絶対服従/
ぜったいまけ /絶対負/
ぜったいむせいやく /絶対無制約/
ぜったいむてき /絶対無敵/
ぜったいむり /絶対無理/
ぜったいりょう /絶対量/
ぜったいれいど /絶対零度/
ぜったいれんぞく /絶対連続/
ぜったいろん /絶対論/
ぜったん /舌端/
ぜっちょう /絶頂/
ぜっちょうき /絶頂期/
ぜっとへんかん /Ｚ変換/
ぜっぱん /絶版/
ぜっぴつ /絶筆/
ぜっぴん /絶品/
ぜっふうん /絶不運/
ぜっふちょう /絶不調/
ぜっぺき /絶壁/
ぜっぽう /舌鋒/
ぜつ /絶/舌/説/
ぜつ> /絶/
ぜついん /舌咽/
ぜつえん /絶縁/
ぜつえんえきたい /絶縁液体/
ぜつえんざい /絶縁材/
ぜつえんせんげん /絶縁宣言/
ぜつえんたい /絶縁体/
ぜつえんたいはそん /絶縁体破損/
ぜつえんふりょう /絶縁不良/
ぜつえんぶ /絶縁部/
ぜつおん /舌音/
ぜつご /絶後/
ぜつだい /絶大/
ぜつぼう /絶望/
ぜつぼうかん /絶望感/
ぜつぼうてき /絶望的/
ぜつみょう /絶妙/
ぜつむ /絶無/
ぜつめい /絶命/
ぜつめつ /絶滅/
ぜつめつきぐしゅ /絶滅危惧種/
ぜつめつきけんしゅ /絶滅危険種/
ぜつめつしゅ /絶滅種/
ぜつめつしゅほぞん /絶滅種保存/
ぜつめつすんぜん /絶滅寸前/
ぜつめつどうぶつ /絶滅動物/
ぜつりん /絶倫/
ぜに /銭/錢/
ぜにがた /銭形/
ぜにがたへいじ /銭形平次/
ぜにたかぐみ /錢高組/
ぜにばこ /銭函/銭箱/
ぜにん /是認/
ぜねすと /ゼネスト/
ぜねらるせきゆ /ゼネラル石油/
ぜひ /是非/
ぜひいちど /是非一度/
ぜひごきょうりょく /是非御協力/
ぜひさんか /是非参加/
ぜひしょうかい /是非紹介/
ぜひよく /是非欲/
ぜみ /ゼミ/
ぜみしりょう /ゼミ資料/
ぜみなーる /ゼミナール/
ぜめ /攻め/
ぜろ /ゼロ/零/〇/
ぜろいんし /零因子/
ぜろくうかん /零空間/
ぜろげん /零元/
ぜろじ /０次/
ぜろせん /零戦/
ぜろてん /ゼロ点/零点/
ぜん /全/前/然/膳/禅/善/繕/漸/千/冉/喘/禪/譱/苒/蠕/髯/蝉/嶄/
ぜん< /全/
ぜん> /前/全/
ぜんあく /善悪/
ぜんあつ /前圧/
ぜんあつちょうせい /前圧調整/
ぜんい /善意/前位/
ぜんいいん /全委員/
ぜんいき /全域/
ぜんいきてき /全域的/
ぜんいち /善一/
ぜんいでんし /全遺伝子/
ぜんいん /全員/
ぜんいんいっち /全員一致/
ぜんいんきょうつう /全員共通/
ぜんいんさんか /全員参加/
ぜんいんしゅうごう /全員集合/
ぜんいんしんにん /全員信任/
ぜんいんせいぞんちゅう /全員生存中/
ぜんいんだいそつ /全員大卒/
ぜんいんちゃくせき /全員着席/
ぜんいんひっしゅう /全員必修/
ぜんいんぶん /全員分/
ぜんうちゅう /全宇宙/
ぜんうりあげ /全売上/
ぜんえい /全英/前衛/
ぜんえいおんがっか /前衛音楽家/
ぜんえいだいひょう /全英代表/
ぜんえいちゅうけい /全英中継/
ぜんえいてき /前衛的/
ぜんえいびじゅつ /前衛美術/
ぜんえいぶとう /前衛舞踏/
ぜんえいもじ /全英文字/
ぜんえき /全駅/
ぜんえききんえん /全駅禁煙/
ぜんえきつうか /全駅通過/
ぜんえん /全縁/前縁/
ぜんおう /全欧/
ぜんおん /全音/
ぜんおんいき /全音域/
ぜんおんいん /全音韻/
ぜんおんかい /全音階/
ぜんおんぷ /全音譜/全音符/
ぜんか /前科/漸化/全科/
ぜんかい /前回/全開/全快/全解/全会/全壊/全回/全階/全潰/
ぜんかいいっち /全会一致/
ぜんかいいん /全会員/
ぜんかいかいじょう /前回会場/
ぜんかいきどう /前回起動/
ぜんかいこうえん /前回公演/
ぜんかいこうそう /前回好走/
ぜんかいこうひょう /前回好評/
ぜんかいしょうかい /前回紹介/
ぜんかいじゅんい /前回順位/
ぜんかいじょう /全会場/
ぜんかいせいせきじゅん /前回成績順/
ぜんかいせんたく /前回選択/
ぜんかいそう /全階層/
ぜんかいそくでんしゃ /全快速電車/
ぜんかいたんさく /全解探索/
ぜんかいちゅうもん /前回注文/
ぜんかいてんいき /全回転域/
ぜんかいとうこう /前回投稿/
ぜんかいとうしゃ /全回答者/
ぜんかいどうよう /前回同様/
ぜんかいはっぴょう /前回発表/
ぜんかいぶん /前回分/
ぜんかいまで /前回迄/
ぜんかいよこく /前回予告/
ぜんかいれいかい /前回例会/
ぜんかいろず /全回路図/
ぜんかく /全角/前核/
ぜんかくうんどうりょう /全角運動量/
ぜんかくえいすうきりかえ /全角英数切替/
ぜんかくえいすうこてい /全角英数固定/
ぜんかくえいすうじ /全角英数字/
ぜんかくか /全角化/
ぜんかくかな /全角仮名/
ぜんかくき /前核期/
ぜんかくくうはくにゅうりょく /全角空白入力/
ぜんかくこう /前各項/
ぜんかくてい /全確定/
ぜんかくにゅうりょく /全角入力/
ぜんかくはんかく /全角半角/
ぜんかくもじ /全角文字/
ぜんかさん /全加算/
ぜんかさんき /全加算器/
ぜんかし /全歌詞/
ぜんかしき /漸化式/
ぜんかもくじゅけんしゃ /全科目受験者/
ぜんかもの /前科者/
ぜんかん /全館/全巻/全艦/前巻/
ぜんかんきんえん /全館禁煙/
ぜんかんしよう /全館使用/
ぜんかんとく /前監督/
ぜんかんりにん /前管理人/
ぜんがく /全学/全額/
ぜんがくきふ /全額寄付/
ぜんがくしきゅう /全額支給/
ぜんがくしょう /全楽章/
ぜんがくせい /全学生/
ぜんがくだいきん /全額代金/
ぜんがくだいぎいん /全学代議員/
ぜんがくだいひょうしゃかい /全学代表者会/
ぜんがくてき /全学的/
ぜんがくはいとう /全額配当/
ぜんがくふたん /全額負担/
ぜんがくぶ /全学部/
ぜんがくへんきん /全額返金/
ぜんがくぼっしゅう /全額没収/
ぜんがくむしょう /全額無償/
ぜんがくめんじょ /全額免除/
ぜんがくれん /全学連/
ぜんがっき /前学期/
ぜんがめん /全画面/
ぜんがめんひょうじ /全画面表示/
ぜんき /前期/前記/全期/全機/
ぜんきかてい /前期課程/
ぜんきかん /全期間/
ぜんきかんゆうこう /全期間有効/
ぜんきがた /前期型/
ぜんきさいだい /前期最大/
ぜんきしけん /前期試験/
ぜんきしゃ /前期車/
ぜんきしゅ /全機種/
ぜんきしゅせいは /全機種制覇/
ぜんきじ /前記事/全記事/
ぜんきち /善吉/
ぜんきつえんしゃ /全喫煙者/
ぜんきにってい /前期日程/
ぜんきばん /前期版/
ぜんきひ /前期比/
ぜんきゃく /前脚/
ぜんきゅう /全休/
ぜんきゅうこうれっしゃ /全急行列車/
ぜんきゅうしゅうがくせい /全九州学生/
ぜんきゅうだん /全球団/
ぜんきゆうしょう /前期優勝/
ぜんきょうだい /全兄弟/
ぜんきょうとう /全共闘/
ぜんきょく /全曲/全極/全局/
ぜんきょくえんそう /全曲演奏/
ぜんきょくがた /全極型/
ぜんきょくさくし /全曲作詞/
ぜんきょくしゅう /全曲集/
ぜんきょくすう /全曲数/
ぜんきょくちゅう /全曲中/
ぜんきょくばん /全曲版/
ぜんきよう /前期用/
ぜんきん /漸近/前金/
ぜんきんあんていせい /漸近安定性/
ぜんきんしき /漸近式/
ぜんきんせん /漸近線/
ぜんきんせんじょう /漸近線上/
ぜんきんだい /前近代/
ぜんきんち /漸近値/
ぜんきんてき /漸近的/
ぜんきんほう /漸近法/
ぜんぎ /前戯/
ぜんぎょう /前行/
ぜんぎろん /全議論/
ぜんぎん /全銀/
ぜんぎんきょう /全銀協/
ぜんぎんてじゅん /全銀手順/
ぜんく /前駆/全区/
ぜんくうかん /全空間/
ぜんくかん /全区間/前区間/
ぜんくかんきんいつ /全区間均一/
ぜんくたい /前駆体/
ぜんくつ /前屈/
ぜんくみあわせ /全組合せ/
ぜんくろう /善九郎/
ぜんぐん /全軍/全郡/前群/
ぜんけい /前掲/全形/全景/前傾/全系/前景/
ぜんけいさん /全計算/
ぜんけいしせい /前傾姿勢/
ぜんけいしょく /全景色/前景色/
ぜんけいじ /全掲示/
ぜんけいせいそう /前形成層/
ぜんけいど /前傾度/
ぜんけいよう /前景用/
ぜんけいろ /全経路/
ぜんけん /前件/全権/全県/
ぜんけんいにんじょう /全権委任状/
ぜんけんかんとく /全権監督/
ぜんけんぶ /前件部/
ぜんげつ /前月/
ぜんげつぶん /前月分/
ぜんげん /前言/漸減/
ぜんげんてっかい /前言撤回/
ぜんげんほう /漸減法/
ぜんこ /全戸/
ぜんこう /前項/全校/善行/全高/
ぜんこうがく /全光学/
ぜんこうがくてき /全光学的/
ぜんこうき /前後期/
ぜんこうざ /全講座/
ぜんこうしきせん /全公式戦/
ぜんこうしゃりん /前後車輪/
ぜんこうじ /善光寺/
ぜんこうせい /前向性/
ぜんこうせいと /全校生徒/
ぜんこうせつ /前後節/
ぜんこうだいいちごう /前項第一号/
ぜんこうてい /全工程/全行程/
ぜんこうはん /前後半/
ぜんこうへん /前後編/
ぜんこうほ /前候補/全候補/
ぜんこうほぐん /前候補群/
ぜんこうもく /全項目/
ぜんこうりんかじゅう /前後輪荷重/
ぜんこく /全国/
ぜんこくいち /全国一/
ぜんこくいっせい /全国一斉/
ぜんこくかくち /全国各地/
ぜんこくきぼ /全国規模/
ぜんこくきょうつう /全国共通/
ぜんこくく /全国区/
ぜんこくこうかい /全国公開/
ぜんこくこうこう /全国高校/
ぜんこくこうこうたいかい /全国高校大会/
ぜんこくこうせん /全国高専/
ぜんこくこうせんたいこう /全国高専対抗/
ぜんこくし /全国紙/
ぜんこくじゅうだん /全国縦断/
ぜんこくじゅんぎょうせい /全国巡業制/
ぜんこくじんこう /全国人口/
ぜんこくせいは /全国制覇/
ぜんこくせんばつ /全国選抜/
ぜんこくそしき /全国組織/
ぜんこくたいかい /全国大会/
ぜんこくたんい /全国単位/
ぜんこくちゅうけい /全国中継/
ぜんこくつうしんもう /全国通信網/
ぜんこくてき /全国的/
ぜんこくてんかい /全国展開/
ぜんこくてんそうけい /全国転送系/
ぜんこくはつ /全国初/
ぜんこくはつばい /全国発売/
ぜんこくはんばい /全国販売/
ぜんこくばん /全国版/
ぜんこくへいきん /全国平均/
ぜんこくほうえい /全国放映/
ぜんこくほうそう /全国放送/
ぜんこくみん /全国民/
ぜんこくれんらくかい /全国連絡会/
ぜんこたい /全個体/
ぜんこっく /全国区/
ぜんこていえき /前固定液/
ぜんこみぞう /前古未曾有/
ぜんこようしゃ /全雇用者/
ぜんご /前後/善後/善吾/
ぜんごう /前号/全豪/
ぜんごえき /前後駅/
ぜんごかんけい /前後関係/
ぜんごぎゃく /前後逆/
ぜんごさ /前後差/
ぜんごさく /善後策/
ぜんごさゆう /前後左右/
ぜんごじく /前後軸/
ぜんごどう /前後動/
ぜんごどうさ /前後動作/
ぜんごどうじ /前後同時/
ぜんごはんとし /前後半年/
ぜんごひとくみ /前後一組/
ぜんごぶんかつ /前後分割/
ぜんごへん /前後編/
ぜんごほうこう /前後方向/
ぜんごようこうかん /前後要交換/
ぜんごりん /前後輪/
ぜんさい /前菜/
ぜんさぎょう /全作業/
ぜんさく /前作/
ぜんさくじょ /全削除/
ぜんさくちゅう /前作中/
ぜんさくひん /全作品/
ぜんさくひんちゅう /全作品中/
ぜんさりん /前左輪/
ぜんさんか /全参加/
ぜんさんかしゃ /全参加者/
ぜんさんかん /全三巻/
ぜんさんぎょうちゅう /全産業中/
ぜんざ /前座/
ぜんざい /善哉/
ぜんざいさん /全財産/
ぜんざじあい /前座試合/
ぜんざん /前残/
ぜんざんじ /前山寺/
ぜんし /全市/全紙/全姉/禅師/前肢/
ぜんしあい /全試合/前試合/
ぜんしぜんぐん /全市全郡/
ぜんしつ /前室/
ぜんしつきんえん /全室禁煙/
ぜんしつりょう /全質量/
ぜんしゃ /前者/全社/前車/全射/全車/
ぜんしゃいん /全社員/
ぜんしゃく /前借/
ぜんしゃしてい /全車指定/
ぜんしゃしていせき /全車指定席/
ぜんしゃしゅ /全車種/
ぜんしゃたいしょう /全車対象/
ぜんしゃてき /全社的/
ぜんしゃふべん /善者不辯/
ぜんしゃりょう /全車両/
ぜんしゃりょうしていせき /全車両指定席/
ぜんしゅ /髯鬚/
ぜんしゅう /全集/前週/全周/禅宗/全州/
ぜんしゅうこうせい /全集攻勢/
ぜんしゅうはすう /全周波数/
ぜんしゅうばん /全集版/
ぜんしゅうもの /全集物/
ぜんしゅうろく /全収録/
ぜんしゅしょう /前首相/
ぜんしゅだいか /全主題歌/
ぜんしゅつ /前出/
ぜんしゅるい /全種類/
ぜんしょ /善処/全書/全所/
ぜんしょう /前章/全称/全勝/全焼/前哨/∀/全章/
ぜんしょうきごう /全称記号/
ぜんしょうきょ /全消去/
ぜんしょうせん /前哨戦/
ぜんしょうば /全勝馬/
ぜんしょうへんすう /全称変数/
ぜんしょうめい /全証明/
ぜんしょうろんりしき /全称論理式/
ぜんしょく /前職/
ぜんしょくぎょう /前職業/
ぜんしょちょう /前所長/
ぜんしょり /全処理/
ぜんしろう /善四郎/
ぜんしん /前進/全身/漸進/前身/前震/
ぜんしんうんどう /全身運動/
ぜんしんがた /前進型/
ぜんしんけい /全神経/
ぜんしんごう /全信号/
ぜんしんしてい /前進指定/
ぜんしんしゃしん /全身写真/
ぜんしんしゅび /前進守備/
ぜんしんぜんれい /全身全霊/
ぜんしんだぼく /全身打撲/
ぜんしんちゅう /前進中/
ぜんしんてき /漸進的/
ぜんしんますい /全身麻酔/
ぜんしんやけど /全身火傷/
ぜんじ /漸次/善司/
ぜんじぎょう /全事業/
ぜんじく /全軸/
ぜんじくくどう /全軸駆動/
ぜんじくじゅうりょう /前軸重量/
ぜんじこく /全時刻/
ぜんじたい /前時代/
ぜんじだいてき /前時代的/
ぜんじちたい /全自治体/
ぜんじっけん /前実験/
ぜんじつ /前日/全日/
ぜんじつせつえい /前日設営/
ぜんじつらい /前日来/
ぜんじどう /全自動/
ぜんじどうせんたくき /全自動洗濯機/
ぜんじゅうきょ /前住居/
ぜんじゅつ /前述/
ぜんじゅん /前順/
ぜんじゅんい /全順位/
ぜんじゅんじょ /全順序/前順序/
ぜんじゅんそうさ /前順走査/
ぜんじょ /全女/
ぜんじょう /善場/前条/禅譲/禅定/
ぜんじょうきゃく /全乗客/
ぜんじょせい /全女性/
ぜんじろう /善次郎/善二郎/
ぜんじん /前人/
ぜんじんいん /全人員/
ぜんじんかいぎ /善人会議/
ぜんじんかくてき /全人格的/
ぜんじんかくてききょういく /全人格的教育/
ぜんじんこう /全人口/
ぜんじんてき /全人的/
ぜんじんみとう /前人未踏/全人未踏/
ぜんじんるい /全人類/
ぜんすう /全数/
ぜんすうちょうさ /全数調査/
ぜんず /全図/
ぜんせ /前世/
ぜんせい /全盛/全勢/善政/前世/
ぜんせいき /全盛期/
ぜんせいじ /全盛時/全勢時/
ぜんせいじだい /全盛時代/
ぜんせいせき /全成績/
ぜんせいは /全制覇/
ぜんせいひん /全製品/
ぜんせいぶん /全成分/
ぜんせいめいたい /全生命体/
ぜんせいりょく /全勢力/
ぜんせかい /全世界/前世界/
ぜんせかいきょうつう /全世界共通/
ぜんせかいたいおう /全世界対応/
ぜんせかいてき /全世界的/
ぜんせき /全席/
ぜんせききんえん /全席禁煙/
ぜんせきこしつ /全席個室/
ぜんせきしてい /全席指定/
ぜんせきしていとっきゅう /全席指定特急/
ぜんせきじゆう /全席自由/
ぜんせきじゆうせき /全席自由席/
ぜんせきにん /全責任/
ぜんせだい /前世代/
ぜんせつ /前節/
ぜんせん /前線/善戦/全線/
ぜんせんかいぎょう /全線開業/
ぜんせんかいつう /全線開通/
ぜんせんきゅうこう /全線急行/
ぜんせんきょく /全選挙区/
ぜんせんきんむ /前線勤務/
ぜんせんしゅ /全選手/
ぜんせんしゅさんか /全選手参加/
ぜんせんしゅにゅうじょうしき /全選手入場式/
ぜんせんぜんえき /全線全駅/
ぜんせんたんせん /全線単線/
ぜんせんちか /全線地下/
ぜんせんちょくりゅうか /全線直流化/
ぜんせんつうかまえ /前線通過前/
ぜんせんでんか /全線電化/
ぜんせんふくせん /全線複線/
ぜんせんふつう /全線不通/
ぜんせんほうそう /全戦放送/
ぜんせんほこうゆうりょう /全線歩行有料/
ぜんぜん /全然/前々/前前/全々/
ぜんぜんかい /前々回/前前回/
ぜんぜんげつ /前々月/
ぜんぜんしつ /前々室/
ぜんぜんしゅう /前々週/
ぜんぜんじつ /前々日/
ぜんぜんそう /前前走/
ぜんぜんだめ /全然駄目/
ぜんぜんへいき /全然平気/
ぜんぜんべつ /全然別/
ぜんぜんもんだい /全然問題/
ぜんそ /髯蘇/
ぜんそう /前奏/前走/禅僧/全奏/
ぜんそうきょく /前奏曲/
ぜんそうきょくさくひん /前奏曲作品/
ぜんそうきょくしゅう /前奏曲集/
ぜんそうこうきょり /全走行距離/
ぜんそうご /前走後/全奏後/
ぜんそうさ /全操作/
ぜんそうしゃ /前走車/前走者/
ぜんそうなみ /前走並/
ぜんそく /喘息/全速/
ぜんそくりょく /全速力/
ぜんそん /全損/全村/
ぜんぞう /漸増/
ぜんたい /全体/
ぜんたいいき /全帯域/
ぜんたいいし /全体意思/
ぜんたいかいぎ /全体会議/
ぜんたいかんり /全体管理/
ぜんたいかんりしゃ /全体管理者/
ぜんたいかんりにん /全体管理人/
ぜんたいこうげき /全体攻撃/
ぜんたいこうせい /全体構成/
ぜんたいし /全体子/
ぜんたいしゅうごう /全体集合/
ぜんたいしゅぎ /全体主義/
ぜんたいしゅぎしゃ /全体主義者/
ぜんたいしゅぎてき /全体主義的/
ぜんたいじゅう /全体重/
ぜんたいじょうほう /全体情報/
ぜんたいすう /全体数/
ぜんたいず /全体図/
ぜんたいぞう /全体像/
ぜんたいてき /全体的/
ぜんたいひょうか /全体評価/
ぜんたいほうしん /全体方針/
ぜんたろう /善太郎/
ぜんたん /前端/
ぜんたんしゃ /全単射/
ぜんたんしょうてん /全単焦点/
ぜんたんまつ /全端末/
ぜんだい /前代/
ぜんだいじん /前大臣/
ぜんだいひょう /前代表/
ぜんだいみもん /前代未聞/
ぜんだせき /全打席/
ぜんだて /膳立て/
ぜんだてん /全打点/
ぜんだま /善玉/
ぜんだん /前段/
ぜんだんかい /前段階/
ぜんだんぶ /前段部/
ぜんだんめんせき /全断面積/
ぜんち /全治/前置/全知/全地/
ぜんちきゅう /全地球/
ぜんちく /全地区/
ぜんちし /前置詞/
ぜんちぜんのう /全知全能/
ぜんちゅううら /全中裏/
ぜんちょ /前著/
ぜんちょう /全長/前兆/
ぜんちょうげんしょう /前兆現象/
ぜんちょさく /全著作/
ぜんつう /全通/
ぜんつうじ /善通寺/
ぜんつうじし /善通寺市/
ぜんてい /前提/前庭/
ぜんていごうい /前提合意/
ぜんていしき /前提式/
ぜんていじょうけん /前提条件/
ぜんていちしき /前提知識/
ぜんてん /全店/前転/全点/
ぜんてんしゅう /全天周/
ぜんてんせんぶん /全天線分/
ぜんてんとう /全点灯/
ぜんでんか /全電化/
ぜんでんげん /全電源/
ぜんと /前途/全都/
ぜんとう /前頭/全島/
ぜんとうぶ /前頭部/
ぜんとうぶじょは /前頭部徐波/
ぜんとうよう /前頭葉/
ぜんとくてん /全得点/
ぜんとそう /全塗装/
ぜんとたなん /前途多難/
ぜんど /全土/髯奴/
ぜんどう /善導/蠕動/
ぜんなんかん /全何巻/
ぜんなんぜんにょ /善男善女/
ぜんにこう /前二項/
ぜんにごう /前二号/
ぜんにじゅう /全二重/
ぜんにじゅうきかく /全二重規格/
ぜんにじょう /前二条/
ぜんにち /全日/
ぜんにちじょし /全日女子/
ぜんにちせい /全日制/
ぜんにっくう /全日空/
ぜんにっくうしてん /全日空支店/
ぜんにっくうびん /全日空便/
ぜんにってい /全日程/
ぜんにっていしゅうりょう /全日程終了/
ぜんにっぽん /全日本/
ぜんにっぽんくうゆ /全日本空輸/
ぜんにほん /全日本/
ぜんにほんがくせい /全日本学生/
ぜんにほんくうゆ /全日本空輸/
ぜんにほんこくみん /全日本国民/
ぜんにほんじつぎょうだん /全日本実業団/
ぜんにほんじょし /全日本女子/
ぜんにほんせんしゅ /全日本選手/
ぜんにほんせんばつ /全日本選抜/
ぜんにほんそうごう /全日本総合/
ぜんにん /善人/前任/
ぜんにんしゃ /前任者/
ぜんにんち /前任地/
ぜんねん /前年/
ぜんねんど /前年度/
ぜんねんどけっさん /前年度決算/
ぜんねんどひ /前年度比/
ぜんねんひ /前年比/
ぜんねんぶん /前年分/
ぜんのーど /全ノード/
ぜんのう /全能/前納/全納/全農/全脳/
ぜんのうしゃ /全能者/
ぜんのうりょく /全能力/
ぜんのすけ /善之助/
ぜんはい /全廃/前胚/
ぜんはっせい /全発声/
ぜんはん /前半/全版/
ぜんはんい /全範囲/
ぜんはんき /前半期/
ぜんはんこうはん /前半後半/
ぜんはんころ、ぜんはんごろ /前半頃/
ぜんはんさいご /前半最後/
ぜんはんしゃ /全反射/
ぜんはんしゅうりょう /前半終了/
ぜんはんせい /前半生/
ぜんはんせん /前半戦/
ぜんはんせんさいしゅうび /前半戦最終日/
ぜんはんぶ /前半部/
ぜんはんぶぶん /前半部分/
ぜんはんぶん /前半分/
ぜんば /全馬/前場/
ぜんばん /全判/前版/
ぜんばんぐみ /全番組/
ぜんぱい /全廃/全敗/
ぜんぱく /前泊/全泊/
ぜんぱん /全般/前半/
ぜんぱんてき /全般的/
ぜんひてい /全否定/
ぜんひょう /全票/全表/
ぜんひょうひ /前表皮/
ぜんびん /前便/全便/
ぜんびんうんきゅう /全便運休/
ぜんぴん /全品/
ぜんぴんけんさ /全品検査/
ぜんふくじこうえん /善福寺公園/
ぜんふくじじょうすいじょう /善福寺浄水場/
ぜんふつ /全仏/
ぜんふつう /全普通/
ぜんふれんけつ /全不連結/
ぜんふんにゅう /全粉乳/
ぜんぶ /全部/前部/
ぜんぶいんよう /全部引用/
ぜんぶおおもじ /全部大文字/
ぜんぶこうかん /全部交換/
ぜんぶざせき /前部座席/
ぜんぶざせきよう /前部座席用/
ぜんぶしょうりゃく /全部省略/
ぜんぶすう /全部数/
ぜんぶどうれつ /全部同列/
ぜんぶにゅうりょく /全部入力/
ぜんぶはいし /全部廃止/
ぜんぶふよう /全部不要/
ぜんぶへんかん /全部変換/
ぜんぶへんこう /全部変更/
ぜんぶまんいん /全部満員/
ぜんぶりゃく /全部略/
ぜんぶん /全文/前文/
ぜんぶんいんよう /全文引用/
ぜんぶんけん /全文献/
ぜんぶんれつそしき /前分裂組織/
ぜんぷく /全幅/
ぜんへいじ /全閉時/
ぜんへんかん /全変換/
ぜんへんきょく /全編曲/
ぜんへんどう /全変動/
ぜんべい /全米/
ぜんべいいち /全米一/
ぜんべいおうざ /全米王座/
ぜんべいかくち /全米各地/
ぜんべいがくせい /全米学生/
ぜんべいこうかい /全米公開/
ぜんべいしんこう /全米侵攻/
ぜんべいじょし /全米女子/
ぜんべいせんしゅけん /全米選手権/
ぜんべいだいひょう /全米代表/
ぜんぺい /全閉/
ぜんぺき /前壁/
ぜんぺん /全編/前編/前篇/
ぜんぺんじょうえい /全編上映/
ぜんほうい /全方位/
ぜんほういたいせい /全方位体制/
ぜんほうこう /全方向/
ぜんほうしき /全方式/
ぜんほうそうきょく /全放送局/
ぜんほそう /全舗装/
ぜんぼいん /全母音/
ぜんぼう /全貌/
ぜんぽう /前方/
ぜんぽういっち /前方一致/
ぜんぽうかいてん /前方回転/
ぜんぽうかいへいがた /前方開閉型/
ぜんぽうさゆう /前方左右/
ぜんぽうさんしょう /前方参照/
ぜんぽうさんらんこう /前方散乱光/
ぜんぽうしかい /前方視界/
ぜんぽうしょうがいぶつ /前方障害物/
ぜんぽうじ /善宝寺/
ぜんぽうていい /前方定位/
ぜんぽうふちゅうい /前方不注意/
ぜんぽうやく /前方約/
ぜんまい /薇/全妹/発条/發条/
ぜんまく /善悪/
ぜんみりょく /全魅力/
ぜんみんぞく /全民族/
ぜんめいがら /全銘柄/
ぜんめいじん /前名人/
ぜんめつ /全滅/
ぜんめつすんぜん /全滅寸前/
ぜんめつせんそう /全滅戦争/
ぜんめん /全面/前面/
ぜんめんうんきゅう /全面運休/
ぜんめんえいぎょうていし /全面営業停止/
ぜんめんか /全面可/
ぜんめんかいしゅう /全面回収/
ぜんめんかいてい /全面改定/
ぜんめんかぶ /前面下部/
ぜんめんかんつう /前面貫通/
ぜんめんかんつうろ /前面貫通路/
ぜんめんきんえん /全面禁煙/
ぜんめんきんし /全面禁止/
ぜんめんきんしろん /全面禁止論/
ぜんめんこうこく /全面広告/
ぜんめんさんか /全面参加/
ぜんめんさんせい /全面賛成/
ぜんめんせんそう /全面戦争/
ぜんめんたいけつ /全面対決/
ぜんめんちゅうし /全面中止/
ぜんめんちゅうしゃきんし /全面駐車禁止/
ぜんめんつうこうきんし /全面通行禁止/
ぜんめんてき /全面的/
ぜんめんてきかいそう /全面的改装/
ぜんめんてききょうりょく /全面的協力/
ぜんめんてったい /全面撤退/
ぜんめんてんぼう /前面展望/
ぜんめんはいし /全面廃止/
ぜんめんひかんつう /前面非貫通/
ぜんもう /全盲/全毛/
ぜんもじしょうきょ /全文字消去/
ぜんもん /前問/全問/前門/
ぜんもんかいとう /全問解答/
ぜんもんせいかい /全問正解/
ぜんもんどう /禅問答/
ぜんもんどうよう /前問同様/
ぜんや /前夜/善也/
ぜんやく /全訳/善役/
ぜんやさい /前夜祭/
ぜんゆうかい /全有界/
ぜんゆうきたんそりょう /全有機炭素量/
ぜんゆうれん /全遊連/
ぜんよう /全容/善用/前葉/
ぜんようそ /全要素/
ぜんようりょう /全容量/
ぜんよく /前翼/
ぜんら /全裸/
ぜんりったいこうさ /全立体交差/
ぜんりつ /全律/
ぜんりつせん /前立腺/
ぜんりゃく /前略/全略/
ぜんりょう /善良/全量/
ぜんりょういき /全領域/
ぜんりょうせい /全寮制/
ぜんりょく /全力/
ぜんりょくうんてん /全力運転/
ぜんりょくかそく /全力加速/
ぜんりょくしっそう /全力疾走/
ぜんりょくとうきゅう /全力投球/
ぜんりょてい /全旅程/
ぜんりん /前輪/善隣/
ぜんりんかじゅう /前輪荷重/
ぜんりんがわ /前輪側/
ぜんりんくどう /前輪駆動/
ぜんりんしゅうへん /前輪周辺/
ぜんれい /前例/全霊/全例/全零/
ぜんれいちゅう /全冷中/
ぜんれいていじ /前例提示/
ぜんれき /前歴/
ぜんれっしゃ /全列車/
ぜんれっしゃちょくつう /全列車直通/
ぜんれっしゃつうか /全列車通過/
ぜんれっしゃていしゃ /全列車停車/
ぜんれつ /前列/全裂/
ぜんろうさい /全労災/全労済/
ぜんろせん /全路線/
ぜんわ /全話/
ぜんわくせい /全惑星/
ぜんわだい /前話題/
ぜんわろくが /全話録画/
ぜんわん /前腕/前弯/全湾/
そ /素/組/粗/祖/礎/訴/遡/曽/疎/蘇/阻/鼠/狙/楚/租/措/噌/塑/疏/曾/岨/姐/想/疽/俎/咀/囎/徂/愬/泝/沮/溯/爼/甦/祚/胙/蔬/蘓/詛/踈/酥/醋/麁/鼡/齟/酢/會/
そーす /ソース/
そーだ /曹達/
そーぷ /ソープ/
そあく /粗悪/
そあくひん /粗悪品/
そあん /素案/
そい /添い/
そいずみ /祖泉/
そいね /添寝/
そいん /素因/訴因/
そいんし /素因子/
そいんすう /素因数/
そいんすうぶんかい /素因数分解/
そう /総/層/相/送/想/装/早/荘/騒/草/争/走/漕/挿/槽/聡/霜/操/蒼/掃/奏/遭/鎗/倉/僧/壮/宋/双/噪/綜/藻/惣/創/痩/燥/曹/掻/巣/槍/葬/窓/爽/箏/匝/捜/糟/喪/叢/宗/聰/愴/艘/繰/瘡/偬/剏/勦/匆/雙/叟/嗾/嗽/壯/奘/妝/嫂/孀/屮/崢/帚/弉/怱/愡/懆/抓/搜/掫/插/搶/梍/樔/歃/淙/滄/漱/澡/炒/爭/窗/笊/箒/筝/簇/籔/總/艙/艚/艸/莊/菷/蔟/裝/諍/譟/赱/蹌/踪/躁/輳/騷/髞/然/廂/漿/竈/竃/曾/曽/鯵/桑/庄/贈/爪/葱/蚤/湊/崇/噌/甑/薮/扱/箱/瀧/滝/将/
そう< /総/
そう> /総/双/
そうあい /相愛/
そうあたり /総当たり/
そうあん /草案/創案/
そうい /相違/相異/創意/総意/創痍/
そういくふう /創意工夫/
そういち /宗一/宗市/聡一/壮一/
そういちじ /双一次/
そういちょうさ /総意調査/
そういちろう /聡一郎/宗一郎/壮一郎/惣一郎/総一郎/総一朗/
そういてん /相違点/相異点/
そういれば /総入れ歯/
そういん /僧院/総員/挿引/
そううつ /躁鬱/
そううつびょう /躁鬱病/
そううりあげ /総売上/
そううん /層雲/曾雲/
そううんきょう /層雲峡/
そうえんすい /双円錐/
そうえんそう /総演奏/
そうえんちょう /総延長/
そうおう /相応/
そうおうぼしゃすう /総応募者数/
そうおん /騒音/噪音/宋音/
そうおんきせい /騒音規制/
そうおんけい /騒音計/
そうおんげん /騒音源/
そうおんせいぎょ /騒音制御/
そうおんせいぎょこうがくじょう /騒音制御工学上/
そうおんそくてい /騒音測定/
そうおんたいさく /騒音対策/
そうおんひょうか /騒音評価/
そうおんぼうし /騒音防止/
そうおんもんだい /騒音問題/
そうおんれべる /騒音レベル/
そうか /相加/総科/草加/送荷/痩果/僧伽/創価/層化/装荷/
そうかい /総会/爽快/壮快/掃海/
そうかいかん /爽快感/
そうかいしゅうりょうご /総会終了後/
そうかいじょう /層階状/
そうかいじょうけいせいそう /層階状形成層/
そうかいじょうざい /層階状材/
そうかいせつ /総解説/
そうかいてい /掃海艇/
そうかいや /総会屋/
そうかく /総画/双角/
そうかくさくいん /総画索引/
そうかくすう /総画数/
そうかくすうさくいん /総画数索引/
そうかこうこう /創価高校/
そうかし /草加市/
そうかだいがく /創価大学/
そうかつ /総括/総轄/
そうかつしゅうし /総括収支/
そうかつてき /総括的/
そうかつはん /総括班/
そうかん /相関/壮観/相姦/創刊/送還/層間/総監/送棺/挿菅/
そうかんかんけい /相関関係/
そうかんかんすう /相関関数/
そうかんき /相関器/
そうかんぎょうれつ /相関行列/
そうかんけいすう /相関係数/
そうかんごう /創刊号/
そうかんず /相関図/
そうかんせい /相関性/総完成/
そうかんとく /総監督/
そうかんど /相関度/
そうが /総画/挿画/装画/
そうがい /窓外/
そうがく /総額/
そうがくどう /奏楽堂/
そうがそすう /総画素数/
そうがん /双眼/
そうがんきょう /双眼鏡/
そうき /早期/想起/総記/
そうきかいけつ /早期解決/
そうきがん /早期癌/
そうききょういく /早期教育/
そうきけっちゃく /早期決着/
そうきさくせい /早期作成/
そうきじすう /総記事数/
そうきじつようか /早期実用化/
そうきたいおう /早期対応/
そうきたいしょく /早期退職/
そうきはっけん /早期発見/
そうきば /双牙/
そうきひじゅん /早期批准/
そうきゅう /早急/送球/蒼穹/
そうきゅうるい /双弓類/
そうきょ /壮挙/
そうきょく /双曲/総局/箏曲/双極/
そうきょくし /双極子/
そうきょくせん /双曲線/
そうきょくせんかんすう /双曲線関数/
そうきょくほうしゃ /双極放射/
そうきょくめん /双曲面/
そうきん /送金/
そうきんがく /送金額/
そうきんしゃすう /送金者数/
そうきんしゃふたん /送金者負担/
そうきんだい /送金代/
そうきんだいこう /送金代行/
そうきんほうほう /送金方法/
そうきんりつ /送金率/
そうきんりょう /送金料/
そうぎ /葬儀/争議/
そうぎけん /争議権/
そうぎしゃ /葬儀社/
そうぎや /葬儀屋/
そうぎょう /創業/操業/早暁/
そうぎょうしゃ /創業者/
そうぎょうとうじ /創業当時/
そうぎょうど /操業度/
そうぎょうひょう /総合表/
そうく /痩躯/走狗/
そうくう /蒼空/
そうくうかん /相空間/
そうくかく /総区画/
そうくずれ /総崩れ/
そうくつ /巣窟/
そうくん /宗薫/
そうぐ /装具/
そうぐう /遭遇/
そうぐうじょうけん /遭遇条件/
そうぐうりつ /遭遇率/
そうぐん /総軍/
そうけ /宗家/
そうけい /総計/早計/早慶/
そうけいせん /早慶戦/
そうけいちょくせつたいけつ /早慶直接対決/
そうけいめい /早慶明/
そうけっきしゅうかい /総決起集会/
そうけっさん /総決算/
そうけつ /総結/
そうけつごう /総結合/
そうけつごうすう /総結合数/
そうけん /総研/壮健/双肩/送検/創建/
そうけんえいぞうぎけん /総研映像技研/
そうけんしゅっぱん /総研出版/
そうげい /送迎/
そうげいかい /送迎会/
そうげいよう /送迎用/
そうげつ /草月/
そうげん /草原/創元/荘厳/
そうげんしゃ /創元社/
そうげんすいりぶんこ /創元推理文庫/
そうげんちたい /草原地帯/
そうげんてん /総減点/
そうげんばん /創元版/
そうげんぶんこ /創元文庫/
そうこ /倉庫/
そうこう /走行/草稿/壮行/装甲/操行/霜降/奏効/曹洪/相好/送稿/走向/
そうこうあんていせい /走行安定性/走行安全性/
そうこうおん /走行音/
そうこうか /走行可/
そうこうかい /壮行会/走行会/
そうこうかいしご /走行開始後/
そうこうかいほう /走行解放/
そうこうかのう /走行可能/
そうこうかんきょう /走行環境/
そうこうきせい /走行規制/
そうこうきょり /走行距離/
そうこうきょりすう /走行距離数/
そうこうくかん /走行区間/
そうこうくぶん /走行区分/
そうこうぐんだん /装甲軍団/
そうこうけい /走行系/
そうこうけっか /走行結果/
そうこうげき /総攻撃/
そうこうご /走行後/
そうこうしゃ /装甲車/走行車/
そうこうしゃせん /走行車線/
そうこうしゃせんがわ /走行車線側/
そうこうしゅ /走攻守/
そうこうしゅうだん /装甲集団/
そうこうじ /走行時/
そうこうじかん /走行時間/
そうこうじょうきょう /走行状況/
そうこうじょうけん /走行条件/
そうこうじょうたい /走行状態/
そうこうせい /走行性/
そうこうせいのう /走行性能/
そうこうそくど /走行速度/
そうこうちゅう /走行中/
そうこうちゅうぜんかい /走行中全開/
そうこうちょくご /走行直後/
そうこうていこう /走行抵抗/
そうこうばん /装甲板/装甲鈑/
そうこうひ /総工費/
そうこうふのう /走行不能/
そうこうふりょう /走行不良/
そうこうまえ /走行前/
そうこうめん /走行面/
そうこうもくすう /総項目数/
そうこうよう /走行用/
そうこうりゅうほうしき /相交流方式/
そうこうりょういき /走行領域/
そうこうろ /走行路/
そうこがい /倉庫街/
そうこぎょうしゃ /倉庫業者/
そうこく /相克/相剋/
そうこしょう /双虎掌/
そうこすう /総戸数/
そうこだい /倉庫代/
そうこばん /倉庫番/
そうこん /早婚/愴恨/
そうご /相互/壮語/双吾/總吾/総吾/
そうごいぞん /相互依存/
そうごいたくきこう /相互委託機構/
そうごう /総合/綜合/相好/相互/
そうごうあんないじょ /総合案内所/
そうごううんどうじょう /総合運動場/
そうごうえいようしょく /総合栄養食/
そうごうかがく /総合科学/
そうごうかがくか /総合科学科/
そうごうかがくぶ /総合科学部/
そうごうかくとうぎ /総合格闘技/
そうごうかもく /総合科目/
そうごうかんせいりょく /総合慣性力/
そうごうかんぼうやく /総合感冒薬/
そうごうがくえん /総合学園/
そうごうきかくぶ /総合企画部/
そうごうききてん /総合機器展/
そうごうぎじゅつ /総合技術/
そうごうけい /総合計/
そうごうけっか /総合結果/
そうごうけんきゅう /総合研究/
そうごうけんきゅうしょ /総合研究所/
そうごうけんきゅうじょ /総合研究所/
そうごうこう /総合校/
そうごうこうざ /総合口座/総合講座/
そうごうこうざていき /総合口座定期/
そうごうさく /総合策/
そうごうし /総合誌/
そうごうしかい /総合司会/
そうごうしけんじょ /総合試験所/
そうごうしゅい /総合首位/
そうごうしょく /総合職/
そうごうしょくじょし /総合職女子/
そうごうしれいじょ /総合指令所/
そうごうじゅんい /総合順位/
そうごうじょうほう /総合情報/
そうごうじょうほうしょり /総合情報処理/
そうごうせいさく /総合政策/
そうごうせいさくがく /総合政策学/
そうごうせいさくがくぶ /総合政策学部/
そうごうせいせき /総合成績/
そうごうだいがく /総合大学/
そうごうち /総合値/
そうごうつうしんもう /総合通信網/
そうごうつうしんもうすいしんしつ /総合通信網推進室/
そうごうてき /総合的/綜合的/
そうごうてきかんてん /総合的観点/
そうごうてきがいねん /綜合的概念/
そうごうてきけんきゅう /総合的研究/
そうごうてん /総合点/
そうごうとうろん /総合討論/
そうごうとくてん /総合得点/
そうごうとしょかん /総合図書館/
そうごうにんげんがくぶ /総合人間学部/
そうごうのうりょく /総合能力/
そうごうはんだん /総合判断/
そうごうひょうか /総合評価/
そうごうひょうかひょう /総合評価表/
そうごうひょうかほうほう /総合評価方法/
そうごうびょういん /総合病院/
そうごうゆうしょう /総合優勝/
そうごうりこう /総合理工/
そうごうりょく /総合力/
そうごうんよう /相互運用/
そうごうんようきょうてい /相互運用協定/
そうごうんようせい /相互運用性/
そうごえいきょう /相互影響/
そうごかしだし /相互貸出/
そうごかん /相互間/
そうごかんけい /相互関係/
そうごかんしょう /相互干渉/
そうごぎんこう /相互銀行/
そうごけつごう /相互結合/
そうごけつごうがた /相互結合型/
そうごけつごうもう /相互結合網/
そうごこうかん /相互交換/
そうごこうしん /相互交信/
そうごこうりゅう /相互交流/
そうごごかい /相互誤解/
そうごさよう /相互作用/
そうごさようじかん /相互作用時間/
そうごさんしょう /相互参照/
そうごしえん /相互支援/
そうごしえんてき /相互支援的/
そうごしゅぎ /相互主義/
そうごしんらい /相互信頼/
そうごせつぞく /相互接続/
そうごせつぞくじっけん /相互接続実験/
そうごせつぞくせい /相互接続性/
そうごそうかん /相互相関/
そうごそうかんかんすう /相互相関関数/
そうごちょくつう /相互直通/
そうごちょくつううんてん /相互直通運転/
そうごつうこう /相互通行/
そうごてんさい /相互転載/
そうごのりいれ /相互乗入/
そうごはいじょ /相互排除/
そうごはっちゃく /相互発着/
そうごひはん /相互批判/
そうごへんかん /相互変換/
そうごもほうせい /相互模倣性/
そうごゆうづう /相互融通/
そうごゆうづうていけい /相互融通提携/
そうごよくせい /相互抑制/
そうごよくせいがた /相互抑制型/
そうごりかい /相互理解/
そうごりよう /相互利用/
そうごれいき /相互励起/
そうごれんそうきおく /相互連想記憶/
そうごれんらく /相互連絡/
そうごん /荘厳/
そうさ /操作/走査/捜査/
そうさい /相殺/葬祭/総裁/
そうさいじょう /葬祭場/
そうさいせん /総裁選/
そうさいち /走査位置/
そうさいっかちょう /捜査一課長/
そうさいん /操作員/
そうさおん /操作音/
そうさかのう /操作可能/
そうさかん /操作感/捜査官/
そうさかんきょう /操作環境/
そうさきろく /操作記録/
そうさぎょう /総作業/
そうさく /創作/捜索/
そうさくけい /創作系/
そうさくしょうねん /創作少年/
そうさくしんわ /創作神話/
そうさくじょう /創作上/
そうさくせい /創作性/
そうさくたい /捜索隊/
そうさくてき /創作的/
そうさくにん /創作人/
そうさくぶつ /創作物/
そうさくぼん /創作本/
そうさくよう /創作用/
そうさくりょく /創作力/
そうさくれんあいぼん /創作恋愛本/
そうさけい /操作系/
そうさけん /捜査権/
そうさげんご /操作言語/
そうさし /操作子/
そうさしゃ /操作者/
そうさしゅうはすう /走査周波数/
そうさじっこう /操作実行/
そうさじゅつ /操作術/
そうさじょう /操作上/捜査上/
そうさじん /捜査陣/
そうさせい /操作性/
そうさせつめいしょ /操作説明書/
そうさせん /走査線/
そうさせんじょう /走査線上/
そうさせんすう /走査線数/
そうさせんほうこう /走査線方向/
そうさせんもん /捜査専門/
そうさぜんぱん /操作全般/
そうさそうち /走査装置/
そうさそくど /走査速度/
そうさたいけい /操作体系/
そうさたいしょう /操作対象/
そうさたく /操作卓/
そうさちゅう /走査中/
そうさつ /相殺/
そうさていど /操作程度/
そうさてき /操作的/
そうさてきいみ /操作的意味/
そうさてきいみろん /操作的意味論/
そうさてきかち /創作的価値/
そうさてじゅん /操作手順/
そうさてつづき /操作手続/操作手続き/
そうさはば /走査幅/
そうさはんい /走査範囲/
そうさば /操作場/
そうさばん /操作盤/
そうさひょうじかんけい /操作表示関係/
そうさぶ /操作部/
そうさぶん /走査分/
そうさほう /操作法/走査法/
そうさほうしき /走査方式/
そうさほうほう /操作方法/
そうさめい /操作名/
そうさらすう /総皿数/
そうさりょう /操作量/
そうされい /操作例/
そうざい /惣菜/
そうざん /早産/
そうし /創始/相思/草紙/荘子/総司/壮士/壮志/双紙/宗祀/
そうしき /葬式/
そうしきかん /総指揮官/
そうしきゅう /総支給/
そうしきゅうがく /総支給額/
そうししゃ /総支社/創始者/
そうしそうあい /相思相愛/
そうしち /惣七/
そうしつ /喪失/
そうしつかん /喪失感/
そうしはいにん /総支配人/
そうしほん /総資本/
そうしほんかいてんりつ /総資本回転率/
そうしゃ /奏者/双射/走者/操車/壮者/掃射/
そうしゃいっそう /走者一掃/
そうしゃえき /総社駅/
そうしゃじょう /操車場/
そうしゅ /双手/
そうしゅう /総集/
そうしゅうえき /総収益/
そうしゅうにゅう /総収入/
そうしゅうへん /総集編/
そうしゅこく /宗主国/
そうしゅっかだいすう /総出荷台数/
そうしゅつ /送出/創出/走出/
そうしゅついちげんか /送出一元化/
そうしゅつえん /総出演/
そうしゅつけん /送出権/
そうしゅつし /走出枝/
そうしゅつじ /送出時/
そうしゅん /早春/
そうしゅんふ /早春賦/
そうしょ /草書/双書/叢書/
そうしょう /総称/争訟/相称/相生/創傷/
そうしょうかんすう /総称関数/
そうしょうきほう /総称記法/
そうしょうきん /総賞金/
そうしょうてき /総称的/
そうしょうひ /総消費/
そうしょく /装飾/草食/
そうしょくおん /装飾音/
そうしょくご /装飾後/
そうしょくせい /草食性/
そうしょくてき /装飾的/
そうしょくひん /装飾品/
そうしょくほう /装飾法/
そうしょくまえ /装飾前/
そうしょくもじ /装飾文字/
そうしょたい /草書体/
そうしょだい /叢書第/
そうしょとく /総所得/
そうしょようじかん /総所要時間/
そうしよう /双子葉/
そうしようしょくぶつ /双子葉植物/
そうしようるい /双子葉類/
そうしれいかん /総司令官/
そうしれいぶ /総指令部/総司令部/
そうしん /送信/痩身/装身/喪心/
そうしんあいて /送信相手/
そうしんあてさき /送信宛先/
そうしんおん /送信音/
そうしんかいぞう /送信改造/
そうしんがわ /送信側/
そうしんき /送信機/送信器/
そうしんきけいとうず /送信機系統図/
そうしんきのう /送信機能/
そうしんきろく /送信記録/
そうしんぎょう /送信行/
そうしんくうちゅうせん /送信空中線/
そうしんぐ /装身具/
そうしんけん /送信権/
そうしんげき /総進撃/
そうしんこうぶん /送信構文/
そうしんご /送信後/
そうしんさき /送信先/
そうしんしき /送信式/
そうしんしゃ /送信者/
そうしんしゅうはすう /送信周波数/
そうしんしゅだん /送信手段/
そうしんしゅつりょく /送信出力/
そうしんしょり /送信処理/
そうしんじ /送信時/
そうしんじかん /送信時間/
そうしんじょ /送信所/
そうしんじょう /送信状/
そうしんじょうたい /送信状態/
そうしんせいのう /送信性能/
そうしんそくど /送信速度/
そうしんちゅう /送信中/
そうしんてん /送信点/
そうしんひょう /送信票/送信表/
そうしんぶ /送信部/
そうしんぶぶん /送信部分/
そうしんまえ /送信前/
そうしんもじれつ /送信文字列/
そうしんもと /送信元/
そうしんもとじしん /送信元自身/
そうしんよう /送信用/
そうしんようきゅう /送信要求/
そうじ /掃除/相似/送辞/荘司/挿耳/走時/宗司/
そうじかん /総時間/
そうじがた /挿耳型/
そうじき /掃除器/掃除機/
そうじきよう /掃除機用/
そうじけい /相似形/
そうじさ /走時差/
そうじしょく /総辞職/
そうじせい /相似性/
そうじつ /桑実/
そうじつどうじかん /総実働時間/
そうじつはい /桑実胚/
そうじてん /相似点/
そうじでら /総持寺/
そうじとうばん /掃除当番/
そうじひ /相似比/
そうじふ /掃除婦/
そうじふへん /相似不変/
そうじへんかん /相似変換/
そうじほうほう /掃除方法/
そうじゃ /総社/壮者/
そうじゅ /送受/双樹/
そうじゅう /操縦/層重/
そうじゅうかん /操縦桿/操縦竿/
そうじゅうきいがい /操縦機以外/
そうじゅうぎじゅつ /操縦技術/
そうじゅうこうぞう /層重構造/
そうじゅうし /操縦士/
そうじゅうしつ /操縦室/
そうじゅうしゃ /操縦者/
そうじゅうせい /操縦性/
そうじゅうせき /操縦席/
そうじゅうほう /操縦法/
そうじゅうりょう /総重量/
そうじゅうりょくせい /走重力性/
そうじゅうりん /操縦輪/
そうじゅき /送受器/
そうじゅく /早熟/
そうじゅくば /早熟馬/
そうじゅしん /送受信/
そうじゅしんかのう /送受信可能/
そうじゅしんき /送受信機/
そうじゅしんきかん /送受信機間/
そうじゅしんきのう /送受信機能/
そうじゅしんじょうたい /送受信状態/
そうじゅしんせつび /送受信設備/
そうじゅしんりょうよう /送受信両用/
そうじゅとも /送受共/
そうじゅわ /送受話/
そうじゅわき /送受話器/
そうじゅん /走順/
そうじょう /僧上/層状/相乗/早場/僧正/奏上/相生/総状/
そうじょうかじょ /総状花序/
そうじょうこうか /相乗効果/
そうじょうたい /躁状態/
そうじょうてき /相乗的/
そうじょうほうりょう /総情報量/
そうじろう /宗次郎/
そうじんこう /総人口/
そうすい /総帥/送水/
そうすいかん /送水管/
そうすう /総数/層数/曹嵩/双数/
そうず /挿図/索子/
そうせい /創成/創生/早世/早逝/創製/簇生/
そうせいき /創世記/創世紀/
そうせいさくひ /総製作費/
そうせいさんすう /総生産数/
そうせいさんりょう /総生産量/
そうせいしんわ /創成神話/
そうせいじ /双生児/
そうせいそく /双正則/
そうせいねんだんし /青壮年男子/
そうせき /漱石/踪跡/
そうせきちんりゅう /漱石枕流/
そうせつ /創設/総説/
そうせついらい /創設以来/
そうせつご /創設後/
そうせつしゃ /創設者/
そうせつじ /創設時/
そうせつとうじ /創設当時/
そうせつひ /創設費/
そうせつろんぶん /総説論文/
そうせん /操船/
そうせんきょ /総選挙/
そうせんけい /双線型/
そうぜい /総勢/
そうぜつ /壮絶/
そうぜん /騒然/蒼然/愴然/
そうそ /曾祖/
そうそう /早々/草々/葬送/曹操;三国時代・魏の太祖/草創/怱々/錚錚/壮々/愴愴/早早/怱怱/匆匆/草草/草叢/送葬/淙淙/喪葬/滄桑/層層/総総/蒼蒼/簇簇/蹌蹌/鏘鏘/然う然う/
そうそうき /草創期/
そうそうこうきょり /総走行距離/
そうそうこうしんきょく /葬送行進曲/
そうそうこうじかん /総走行時間/
そうそく /総則/
そうそふ /曾祖父/
そうそぼ /曾祖母/
そうそん /曾孫/
そうそんしつじかん /総損失時間/
そうぞう /想像/創造/送像/莊三/
そうぞういじょう /想像以上/
そうぞうがい /想像外/
そうぞうこうい /創造行為/
そうぞうしゃ /創造者/
そうぞうしゅ /創造主/
そうぞうしょすう /総蔵書数/
そうぞうしん /創造神/
そうぞうせい /創造性/
そうぞうせつ /創造説/
そうぞうてき /創造的/想像的/
そうぞうてきげいじゅつ /創造的芸術/
そうぞうてきこうい /創造的行為/
そうぞうどおり /想像通り/
そうぞうにんしん /想像妊娠/
そうぞうぶつ /創造物/
そうぞうりょく /想像力/創造力/
そうぞく /相続/相續/宗族/
そうぞくあいてさき /接続相手先/
そうぞくかいふく /相続回復/
そうぞくけん /相続権/
そうぞくざいさん /相続財産/
そうぞくぜい /相続税/
そうぞくにん /相続人/
そうぞくぶん /相続分/
そうぞくほう /相続法/
そうたい /相対/早退/双対/総体/総隊/
そうたいいち /相対位置/
そうたいいちひょうげん /相対位置表現/
そうたいうずど /相対渦度/
そうたいおん /相対音/
そうたいおんかん /相対音感/
そうたいか /相対化/双対化/
そうたいかかく /相対価格/
そうたいかんけい /相対関係/
そうたいきけんど /相対危険度/
そうたいきょり /相対距離/
そうたいくうかん /双対空間/
そうたいごさ /相対誤差/
そうたいざひょう /相対座標/
そうたいじかん /相対時間/
そうたいせい /相対性/双対性/
そうたいせいげんり /相対性原理/
そうたいせいりろん /相対性理論/
そうたいそくど /相対速度/
そうたいち /相対値/
そうたいてき /相対的/総体的/
そうたいてきかち /相対的価値/
そうたいてききじゅつ /相対的記述/
そうたいてきはいち /相対的配置/
そうたいてきはいちしげき /相対的配置刺激/
そうたいはどうかんすう /相対波動関数/
そうたいひ /相対比/
そうたいひょうか /相対評価/
そうたいろん /相対論/
そうたいろんいぜん /相対論以前/
そうたいろんかんけい /相対論関係/
そうたいろんてき /相対論的/
そうたいろんてきごうたい /相対論的剛体/
そうたつ /送達/
そうたん /操短/
そうだ /操舵/曹達/左右田/宗田/早田/崇田/
そうだい /壮大/早大/総代/早稲田大学/
そうだいいちぶん /早大一文/
そうだいいん /早大院/
そうだいえいぶん /早大英文/
そうだいおうぶつ /早大応物/
そうだいかい /総代会/
そうだいしゅっぱんぶ /早大出版部/
そうだいしょう /総大将/
そうだいせん /早大戦/
そうだいむひ /壮大無比/
そうだいりこう /早大理工/
そうだいりこうおうぶつ /早大理工応物/
そうだいりこうけん /早大理工研/
そうだいりこうじょうほう /早大理工情報/
そうだいりこうつうしん /早大理工通信/
そうだいりこうぶつり /早大理工物理/
そうだいりてん /総代理店/
そうだおれ /総倒れ/
そうだか /総高/
そうだかん /操舵感/
そうだしつ /操舵室/
そうだち /総立ち/
そうだつ /争奪/
そうだつせん /争奪戦/
そうだりん /操舵輪/
そうだん /相談/早弾/装弾数/
そうだんあいて /相談相手/
そうだんいん /相談員/
そうだんか /相談可/
そうだんかい /相談会/
そうだんしつ /相談室/
そうだんしゃ /相談者/
そうだんしょ /相談所/
そうだんじょ /相談所/
そうだんすう /装弾数/
そうだんないよう /相談内容/
そうだんび /相談日/
そうだんまどぐち /相談窓口/
そうだんやく /相談役/
そうち /装置/送致/
そうちけい /装置系/
そうちこうじょう /装置工場/
そうちぜんたい /装置全体/
そうちばんごう /装置番号/
そうちほんたい /装置本体/
そうちめい /装置名/
そうちゃく /装着/早着/
そうちゃくいち /装着位置/
そうちゃくえき /装着液/
そうちゃくか /装着可/
そうちゃくかくにん /装着確認/
そうちゃくかのう /装着可能/
そうちゃくかん /装着感/
そうちゃくがた /装着型/
そうちゃくきせい /装着規制/
そうちゃくぎむ /装着義務/
そうちゃくしゃ /装着車/
そうちゃくじ /装着時/
そうちゃくじかん /装着時間/
そうちゃくじょうたい /装着状態/
そうちょう /早朝/総長/荘重/双調/曹長/宗澄/
そうちょうしんや /早朝深夜/
そうちょうばんぐみ /早朝番組/
そうつい /双対/相対/
そうついくうかん /双対空間/
そうついてき /双対的/
そうついてん /相対点/
そうてい /想定/装丁/装釘/送呈/装幀/漕艇/
そうていじょう /想定上/
そうていじょうけん /想定条件/
そうていず /想定図/
そうていずみ /想定済み/
そうていもんだいしゅう /想定問題集/
そうてつ /相鉄/蒼鉄/
そうてつかもつせん /相鉄貨物線/
そうてつせん /相鉄線/
そうてつどう /総鉄道/
そうてつやまとえき /相鉄大和駅/
そうてん /争点/装填/操典/蒼天/総点/
そうてんい /相転移/層転移/
そうてんいてき /相転移的/
そうてんいてきげんしょう /相転移的現象/
そうてんかんりょう /装填完了/
そうてんけん /総点検/
そうで /総出/
そうでん /送電/叢伝/相伝/
そうでんけい /送電系/
そうでんせん /送電線/
そうでんもう /送電網/
そうと /壮図/壮途/
そうとう /相当/争闘/双頭/総統/総当/掃討/
そうとうあくしつ /相当悪質/
そうとうかいぶつ /双頭怪物/
そうとうかくご /相当覚悟/
そうとうがく /相当額/
そうとうきけん /相当危険/
そうとうこうすう /総投稿数/
そうとうざん /相当算/
そうとうしがく /総投資額/
そうとうしゅう /曹洞宗/
そうとうしんこく /相当深刻/
そうとうすう /相当数/相等数/
そうとうせい /相等性/
そうとうたいへん /相当大変/
そうとうひょうしゃ /総投票者/
そうとうひょうすう /総投票数/
そうとうひん /相当品/
そうとうへんか /相当変化/
そうとうまえ /相当前/
そうとうむり /相当無理/
そうとうめんどう /相当面倒/
そうとうよぶん /相当余分/
そうとうりょう /相当量/
そうとく /総督/
そうとくてん /総得点/
そうとめ /早乙女/
そうどう /騒動/相同/
そうどういん /総動員/
そうない /層内/
そうなん /遭難/
そうなんき /遭難機/
そうなんしゃ /遭難者/
そうなんじ /遭難時/
そうにっすう /総日数/
そうにゅう /挿入/総入/
そうにゅうか /挿入歌/総入荷/
そうにゅうかしゅう /挿入歌集/
そうにゅうがた /挿入型/
そうにゅうきょく /挿入曲/
そうにゅうく /挿入句/
そうにゅうぐち /挿入口/
そうにゅうご /挿入後/
そうにゅうさくじょ /挿入削除/
そうにゅうちょくご /挿入直後/
そうにゅうてん /挿入点/
そうにゅうほうこう /挿入方向/
そうにゅうほうほう /挿入方法/
そうにゅうよう /挿入用/
そうにゅうようかくちょう /挿入用拡張/
そうねん /壮年/
そうねんき /壮年期/
そうねんだんし /壮年男子/
そうは /争覇/走破/掻爬/
そうはい /送配/
そうはいきりょう /総排気量/
そうはく /蒼白/
そうはくそ /曾伯祖/
そうはせい /走破性/
そうはち /壮八/
そうはつ /創発/双発/
そうはつてき /創発的/
そうはつでんりょう /総発電量/
そうはん /相反/
そうはんかんけい /相反関係/
そうば /相場/
そうばし /相場師/
そうばつ /挿抜/
そうばな /総花/
そうばん /早晩/
そうばんちょう /総番長/
そうひょう /総評/
そうひよう /総費用/
そうび /装備/
そうびかのう /装備可能/
そうびしゃ /装備車/創美社/
そうびち /装備値/
そうびひん /装備品/
そうびまんさい /装備満載/
そうびょう /躁病/
そうふ /送付/奏譜/総譜/
そうふう /送風/
そうふうき /送風機/
そうふうこう /送風口/
そうふえんそう /奏譜演奏/
そうふきん /送付金/
そうふくしゅう /総復習/
そうふさき /送付先/
そうふほう /送付法/
そうぶ /総武/創部/
そうぶかいそく /総武快速/
そうぶかいそくけいゆ /総武快速経由/
そうぶかいそくせん /総武快速線/
そうぶかんこうせん /総武緩行線/
そうぶけいゆ /総武経由/
そうぶせん /総武線/
そうぶせんかんこう /総武線緩行/
そうぶせんりようしゃ /総武線利用者/
そうぶだい /相武台/
そうぶちかせん /総武地下線/
そうぶてつどう /総武鉄道/
そうぶふつう /総武普通/
そうぶほんせん /総武本線/
そうへい /僧兵/
そうへいりょく /総兵力/
そうへき /双璧/双壁/
そうへんしゅうばん /総編集版/
そうべつ /送別/壮瞥/層別/
そうべつかい /送別会/
そうほ /相補/宗歩/
そうほう /双方/奏法/走法/双峰/宗豊/総包/総苞/
そうほうこう /双方向/
そうほうこうつうしん /双方向通信/
そうほうこうへんかん /双方向変換/
そうほうなっとく /双方納得/
そうほうへん /総苞片/
そうほかんけい /相補関係/
そうほさ /相補鎖/
そうほせい /相補性/
そうほせいげんり /相補性原理/
そうほてき /相補的/
そうほてきいでん /相補的遺伝/
そうほん /草本/
そうほんざん /総本山/
そうほんすう /総本数/
そうほんせい /草本性/
そうほんてん /総本店/
そうほんぶ /総本部/
そうぼう /蒼氓/双眸/相貌/蒼茫/
そうぼうきん /僧帽筋/
そうぼうべん /僧帽弁/
そうま /相馬/
そうまいすう /総枚数/
そうまとう /走馬燈/走馬灯/
そうむ /創夢/総務/双務/
そうむか /総務課/
そうむかかり /総務掛/
そうむかかりちょう /総務掛長/
そうむがかり /総務掛/
そうむしつ /総務室/
そうむしょう /総務省;総務庁、自治省、郵政省が2001年1月の中央省庁再編で再編されたもの/
そうむちょう /総務庁;2001年1月の中央省庁再編で総務省に再編された/
そうむてき /双務的/
そうむはん /総務班/
そうむひ /総務費/
そうむぶ /総務部/
そうむぶそうむか /総務部総務課/
そうむぶちょう /総務部長/
そうむら /荘村/
そうめい /聰明/早明/聡明/
そうめいせん /早明戦/
そうめん /素麺/索麺/
そうめんせき /総面積/
そうもく /草木/
そうもくじ /総目次/
そうもくろく /総目録/
そうもん /艸門/桑門/
そうや /宗谷/
そうやく /創薬/
そうやま /相山/
そうやみさき /宗谷岬/
そうゆう /曾遊/
そうゆそうりょう /総輸送量/
そうよう /装用/掻痒/
そうようしゃ /装用者/
そうようそすう /総要素数/
そうようりょう /総容量/
そうらく /相楽/
そうらん /総覧/騒乱/争乱/
そうり /総理/總理/
そうりえき /総利益/
そうりだいじん /総理大臣/
そうりつ /創立/総立/
そうりつきねんび /創立記念日/
そうりつしゃ /創立者/
そうりふ /総理府;2001年1月の中央省庁再編で内閣府に再編された/
そうりふれい /総理府令/
そうりゅう /双龍/総流/蒼竜/蒼龍/宗留/
そうりゅうしゃ /蒼竜社/
そうりゅうでん /創竜伝/
そうりゅうよく /層流翼/
そうりゅうよくけい /層流翼形/
そうりょ /僧侶/
そうりょう /送料/総量/惣領/総領/
そうりょうきせい /総量規制/
そうりょうきせいせいど /総量規制制度/
そうりょうこみ /送料込/
そうりょうさくげんけいかく /総量削減計画/
そうりょうじ /総領事/
そうりょうふたん /送料負担/
そうりょうぶん /送料分/
そうりょうべっと /送料別途/
そうりょうべつ /送料別/
そうりょうりちょう /総料理長/
そうりょく /総力/走力/
そうりょくせん /総力戦/
そうりょふう /僧侶風/
そうりん /叢林/総輪/
そうるい /草類/藻類/走塁/
そうれい /壮麗/
そうれつ /壮烈/葬列/
そうれん /操練/
そうれんしゅう /総練習/
そうろ /走路/
そうろう /候/早漏/
そうろうぶん /候文/
そうろん /総論/争論/
そうろんさんせい /総論賛成/
そうろんり /総論理/
そうわ /総和/挿話/送話/
そうわき /送話器/
そうわぐち /送話口/
そうわん /双腕/
そえ /添/添え/副/儲/貮/
そえかみ /添上/
そえがき /添え書き/
そえき /素液/
そえじ /添字/添え字/
そえじしき /添字式/
そえじま /副島/
そえだ /添田/
そえだこうつう /添田交通/
そえだせん /添田線/
そえの /添野/
そえや /添谷/
そえん /疎遠/
そお /囎唹/
そかい /疎開/租界/
そかく /疎隔/組閣/素核/
そが /蘇我/曽我/曾我/
そがい /阻害/疎外/阻碍/
そがいかん /疎外感/
そがいざい /阻害剤/
そがいせい /疎外性/
そがいよういん /阻害要因/
そがえき /蘇我駅/
そがかん /蘇我間/
そがきょうだい /曽我兄弟/
そがく /訴額/
そがけいゆ /蘇我経由/
そがべ /曽我部/
そがん /訴願/
そきゅう /遡及/遡求/
そきゅうりょく /訴求力/
そぎ /枌/
そぎょうれつ /疎行列/
そく /速/即/側/足/則/束/捉/測/息/促/塞/仄/喞/惻/熄/蔟/
そくい /即位/測位/
そくいはん /即違反/
そくいん /惻隠/
そくおう /即応/
そくおん /促音/
そくおんびん /促音便/
そくかんばい /即完売/
そくが /側芽/
そくき /測器/
そくこん /側根/
そくさ /側鎖/
そくさい /息災/
そくさいばんざた /即裁判沙汰/
そくざ /即座/
そくし /即死/
そくしこう /即施行/
そくしゃ /速写/即車/速射/
そくしゃせい /速射性/
そくしゃほう /速射砲/
そくしゅうせい /即修正/
そくしん /促進/
そくしんろせん /促進路線/
そくじ /即時/
そくじがた /即時型/
そくじく /側軸/
そくじせい /即時性/
そくじせいじゅうし /即時性重視/
そくじっこう /即実行/
そくじつ /即日/
そくじつうしん /即時通信/
そくじつかのう /即日可能/
そくじつこうふ /即日交付/
そくじてき /即時的/
そくじはっきゅう /即時発給/
そくじょ /息女/
そくせい /促成/速成/側生/
そくせき /即席/足跡/
そくせこう /即施行/
そくせん /側線/塞栓/測線/
そくせんき /側線器/
そくせんりょく /即戦力/
そくそう /惻愴/
そくそく /促促/惻惻/測々/
そくたいばつ /即体罰/
そくたいほ /即逮捕/
そくたいほこう /側帯歩行/
そくたつ /速達/
そくだく /即諾/
そくだん /即断/速断/
そくち /即値/測地/
そくちけい /測地系/
そくちせん /測地線/
そくちゅうせいし /速中性子/
そくづみ /即詰/
そくづめ /即詰/
そくてい /測定/足底/
そくていかのう /測定可能/
そくていがく /測定学/
そくていき /測定器/測定機/
そくていきぐ /測定器具/
そくていきじゅん /測定基準/
そくていきょり /測定距離/
そくていきよう /測定機用/
そくていぎじゅつぶ /測定技術部/
そくていけい /測定系/
そくていけっか /測定結果/
そくていごさ /測定誤差/
そくていし /即停止/
そくていしんごうきょうど /測定信号強度/
そくていじ /測定時/
そくていじかん /測定時間/
そくていじょうけん /測定条件/
そくていせいど /測定精度/
そくていそうち /測定装置/
そくていそうちぜんたい /測定装置全体/
そくていたいしょう /測定対象/
そくていち /測定値/
そくていちゅう /測定中/
そくていてん /測定点/
そくていはんい /測定範囲/
そくていぶ /測定部/
そくていぶつ /測定物/
そくていほう /測定法/
そくていほうじたい /測定法自体/
そくていほうほう /測定方法/
そくていめん /測定面/
そくていや /測定屋/
そくていよう /測定用/
そくていりょう /測定量/
そくていれい /測定例/
そくてん /測点/側転/
そくとう /即答/側頭/速答/側倒/足刀/
そくとうせい /即答性/
そくとうにゅう /即投入/
そくとうぶ /側頭部/
そくとうよう /側頭葉/
そくど /速度/測度/束度/
そくどいき /速度域/
そくどいはん /速度違反/
そくどいはんしゃ /速度違反車/
そくどいはんしゃりょう /速度違反車両/
そくどう /速動/側道/
そくどかいぜん /速度改善/
そくどかのう /測度可能/
そくどかん /速度感/
そくどきせい /速度規制/
そくどきろく /速度記録/
そくどく /速読/
そくどけい /速度計/
そくどけいそく /速度計測/
そくどけいそくちゅう /速度計測中/
そくどげん /速度源/
そくどこうじょう /速度向上/
そくどこうじょうげんかい /速度向上限界/
そくどごうせい /速度合成/
そくどさ /速度差/
そくどしてい /速度指定/
そくどしゅべつ /速度種別/
そくどしんごう /速度信号/
そくどじょうしょう /速度上昇/
そくどせいげん /速度制限/
そくどせいげんくかん /速度制限区間/
そくどせいげんひょうしき /速度制限標識/
そくどせいのう /速度性能/
そくどせいぶん /速度成分/
そくどせってい /速度設定/
そくどそくてい /速度測定/
そくどちょうか /速度超過/
そくどちょうせい /速度調整/
そくどちょうせつ /速度調節/
そくどていか /速度低下/
そくどてき /速度的/
そくどとりしまり /速度取締り/
そくどとりしまりき /速度取締機/
そくどば /速度場/
そくどひ /速度比/
そくどひょうか /速度評価/
そくどぶんさん /速度分散/
そくどぶんぷ /速度分布/
そくどほうこういがい /速度方向以外/
そくどむせいげん /速度無制限/
そくどゆうせん /速度優先/
そくどろん /測度論/
そくのう /即納/
そくは /側波/
そくはく /束帛/
そくはたい /側波帯/
そくはっしん /速発進/
そくはつ /即発/
そくはら /束原/
そくはん /測範/
そくはんかい /即販会/
そくばい /即売/即買/
そくばいかい /即売会/
そくばいかいぜんぱん /即売会全般/
そくばいかいたんとうしゃ /即売会担当者/
そくばいきゃく /即売却/
そくばいじょ /即売所/
そくばく /束縛/
そくばくうんどう /束縛運動/
そくばくかいてん /束縛回転/
そくばくかん /束縛感/
そくばくじょうけん /束縛条件/
そくばくへんすう /束縛変数/
そくばくりょく /束縛力/
そくばん /測板/
そくばんこうかん /側板交換/
そくび /足尾/
そくぶ /側部/
そくぶつてき /即物的/
そくぶぶんれつそしき /側部分裂組織/
そくぶん /仄聞/
そくへき /側壁/
そくほう /速報/側方/
そくほうかんかく /側方感覚/
そくほうさんらんこう /側方散乱光/
そくほうせい /速報性/
そくほうち /速報値/
そくほうつうか /側方通過/
そくほうふちゅうい /側方不注意/
そくほうぶんし /側方分枝/
そくほうや /速報屋/
そくまく /側膜/
そくまくたいざ /側膜胎座/
そくまくたいざもく /側膜胎座目/Parietales/
そくみゃく /側脈/
そくめつ /熄滅/
そくめん /側面/
そくめんしえん /側面支援/
そくめんしょうとつ /側面衝突/
そくめんず /側面図/
そくよくせい /側抑制/
そくよくせいきこう /側抑制機構/
そくよくせいきのう /側抑制機能/
そくりゅう /測流/
そくりょう /測量/
そくりょうかんけい /測量関係/
そくりょうき /測量器/
そくりょうきじゅんせん /測量基準線/
そくりょうぎじゅつ /測量技術/
そくりょうし /測量士/
そくりょうじゅつ /測量術/
そくりょく /速力/
そくろ /側路/
そくろう /足労/
そくろにゅうろん /側路ニューロン/
そくろん /束論/
そくろんてき /束論的/
そくわん /側弯/
そくわんしょう /側弯症/
そけっと /ソケット/
そけつごう /疎結合/
そけつごうがた /疎結合型/
そけん /訴権/
そげき /狙撃/
そこ /底/其処/其所/
そこあげ /底上げ/
そこいじ /底意地/
そこいれ /底入れ/
そこう /粗稿/素行/粗鋼/遡航/遡行/
そこうふりょう /素行不良/
そこく /祖国/
そこここ /其処此処/
そこじゃり /底砂利/
そこせんよう /底専用/
そこち /底地/
そこぢから /底力/
そこつ /粗忽/
そこなし /底なし/
そこぬけ /底抜け/
そこね /底値/
そこねじょうほう /底値情報/
そこびえ /底冷え/
そこびき /底引き/底引/
そご /齟齬/
そさい /蔬菜/
そさつ /粗擦/
そざい /素材/
そざいけん /素材研/
そざいこうがくせんこう /素材工学専攻/
そざいじたい /素材自体/
そざいてき /素材的/
そざつ /粗雑/
そし /阻止/素子/粗視/
そしか /粗視化/
そしかん /素子間/
そしがや /祖師ヶ谷/
そしがやおおくら /祖師ヶ谷大蔵/
そしき /組織/素式/
そしきか /組織化/
そしきかん /組織間/
そしきがい /組織外/
そしきがく /組織学/
そしきがわ /組織側/
そしききのう /組織機能/
そしきけい /組織系/
そしきげんり /組織原理/
そしきこうがく /組織工学/
そしきこうがくせんこう /組織工学専攻/
そしきこうぞう /組織構造/
そしきじょう /組織上/
そしきじん /組織人/
そしきず /組織図/
そしきぜんたい /組織全体/
そしきたい /組織体/組織帯/
そしきてき /組織的/
そしきてきへんか /組織的変化/
そしきない /組織内/
そしきないがい /組織内外/
そしきないせんよう /組織内専用/
そしきひょう /組織表/組織票/
そしきぶんか /組織文化/
そしきへんこう /組織変更/
そしきぼうりょく /組織暴力/
そしきぼうりょくはんざいしゃ /組織暴力犯罪者/
そしきめい /組織名/
そしきりつ /組織率/
そしこうげき /阻止攻撃/
そしじしん /素子自身/
そしつ /素質/
そして /而して/然して/
そしな /粗品/
そしのう /阻止能/
そしめい /素子名/
そしゃく /租借/咀嚼/
そしょう /訴訟/粗鬆/酢漿/
そしょうじけん /訴訟事件/
そしょうたいしょう /訴訟対象/
そしょうちゅう /訴訟中/
そしょうぶつ /訴訟物/
そしょうもんだい /訴訟問題/
そしょく /粗食/
そしり /謗り/誹り/
そじ /素地/
そじょう /遡上/訴状/俎上/祖上/爼上/
そすい /疎水/
そすいせい /疎水性/
そすう /素数/
そすうじゅんかいぐん /素数巡回群/
そすうていり /素数定理/
そすうぶんかい /素数分解/
そせい /素性/塑性/粗製/組成/蘇生/甦生/疎性/
そせいこうぞう /素性構造/
そせいしき /組成式/
そせいじゅつ /蘇生術/
そせいち /素性値/蘇生地/
そせいほう /蘇生法/
そせいめい /素性名/
そせいらんぞう /粗製乱造/
そせき /礎石/
そせん /祖先/
そぜい /租税/
そぜいじょうやく /租税条約/
そぜいほう /租税法/
そそ /楚楚/素々/楚々/
そそう /粗相/阻喪/沮喪/楚愴/
そそぎ /曽々木/
そそん /祖孫/
そぞう /塑像/
そぞろ /漫/
そた /曽田/
そだ /曽田/粗朶/
そだい /粗大/
そだち /育ち/
そち /措置/埣/
そちゃ /粗茶/
そっき /測器/速記/
そっきしゃ /測機舎/速記者/
そっきゅう /速球/
そっきょ /測距/
そっきょう /即興/
そっきょうえんそう /即興演奏/
そっきょうおんがく /即興音楽/
そっきょうきょく /即興曲/
そっきょうてき /即興的/
そっきょてん /測距点/
そっきろく /速記録/
そっきん /側近/即金/
そっけ /素気/
そっけつ /即決/
そっけつせい /即決性/
そっこう /速攻/即効/測光/側溝/速効/即興/
そっこうけい /測光系/
そっこうしき /測光式/
そっこうじょ /測候所/
そっこうせい /即効性/
そっこうてき /即効的/
そっこうぶ /測光部/
そっこうぶんぷ /測光分布/
そっこうやく /即効薬/
そっこく /即刻/
そっせん /率先/
そっちゅう /卒中/
そっちょく /卒直/率直/
そって /沿って/
そっとう /卒倒/
そっぱ /反歯/
そっぽ /外方/
そつ /卒/率/卆/猝/
そつい /訴追/
そつう /疎通/疏通/
そつぎょう /卒業/
そつぎょうけんきゅう /卒業研究/
そつぎょうけんきゅうせい /卒業研究生/
そつぎょうけんしゅう /卒業研修/
そつぎょうけんてい /卒業検定/
そつぎょうご /卒業後/
そつぎょうしき /卒業式/
そつぎょうしゃ /卒業者/
そつぎょうしゃしん /卒業写真/
そつぎょうしょうしょ /卒業証書/
そつぎょうしょうめいしょ /卒業証明書/
そつぎょうせい /卒業生/
そつぎょうたんい /卒業単位/
そつぎょうねん /卒業年/
そつぎょうねんじ /卒業年次/
そつぎょうねんど /卒業年度/
そつぎょうひっしゅうようけん /卒業必修要件/
そつぎょうび /卒業日/
そつぎょうへん /卒業編/
そつぎょうみこみ /卒業見込/卒業見込み/
そつぎょうりょこう /卒業旅行/
そつぎょうろんぶん /卒業論文/
そつけん /卒研/
そつけんしつ /卒研室/
そつけんせい /卒研生/
そつけんはっぴょう /卒研発表/
そつぶ /卒部/
そつろん /卒論/
そつろんはっぴょう /卒論発表/
そつろんはっぴょうかい /卒論発表会/
そてつあこう /ソテツ亜綱/Cycadidae/
そてつこう /ソテツ綱/Cycadopsida/
そてつしだもく /ソテツシダ目/Cycadofilicales/
そてん /素点/
そで /袖/
そでがうら /袖ヶ浦/
そでき /袖木/
そでぐち /袖口/
そでぐり /袖刳り/
そでまく /袖幕/
そでやま /袖山/
そでんか /素電荷/
そと /外/
そとあし /外足/
そとあしかじゅう /外足加重/外足荷重/
そといた /外板/
そとう /粗糖/蘇東/
そとうら /外浦/
そとかいてん /外回転/
そとかわ /外皮/
そとかん /外環/
そとかんだ /外神田/
そとかんわこうでぐち /外環和光出口/
そとがけ /外掛け/
そとがわ /外側/
そとくぼ /外久保/
そとこば /外木場/
そとこまた /外小股/
そとぜい /外税/
そとたすきぞり /外襷反り/
そとづけ /外付け/外付/
そとづけき /外付機/
そとづつ /外筒/
そとで /外出/
そとば /卒都婆/卒塔婆/率堵婆/率塔婆/外刃/
そとばき /外履き/
そとばこ /外箱/
そとばこいり /外箱入り/
そとぼう /外房/
そとぼうせん /外房線/
そとぼうせんえんせん /外房線沿線/
そとぼうせんそが /外房線蘇我/
そとぼり /外堀/
そとま /外間/
そとまき /外巻/
そとまわり /外回り/
そとみ /外見/
そとむそう /外無双/
そとめ /外目/外海/
そとやま /外山/
そとわく /外枠/
そどうめい /ソ同盟/蘇同盟/
そどく /素読/
そなえ /供え/備え/
そなえつけ /備え付け/備付/
そなえもの /供物/
そなた /ソナタ/
そに /曾爾/
そにちは /疎日派/
そね /曽根/曾根/埣/曽祢/
そねおか /曽根岡/
そねけん /曽根研/
そねけんきゅうしつ /曽根研究室/
そねけんぼうおんしつ /曽根研防音室/
そねざき /曽根崎/
そねつ /粗熱/
その /園/其/薗/苑/瀬能/曾野/其の/
その# /その#1/
そのあと /その後/
そのあやこ /曾野綾子/
そのかわ /園川/
そのかん /その間/
そのぎ /彼杵/
そのぐち /園口/薗口/
そのこ /園子/その子/苑子/
そのころ /その頃/
そのご /その後/
そのた /その他/
そのだ /薗田/園田/苑田/
そのつき /其月/
そのて /その手/
そのてん /その点/
そのとき /その時/
そのな /その名/
そののち /その後/
そのば /その場/
そのへん /その辺/
そのべ /園部/
そのほう /その方/
そのほか /その他/
そのまえ /その前/
そのむら /園村/
そのやま /園山/
そはん /組版/
そはんのう /素反応/
そば /側/傍/蕎麦/
そばお /曽場尾/
そばきじ /蕎麦生地/
そばこ /蕎麦粉/
そばちゃ /蕎麦茶/
そばや /そば屋/蕎麦屋/
そびょう /素描/
そびょうしゅうなど /素描集等/
そびょうばんが /素描版画/
そふ /祖父/
そふぃあ /ソフィア/
そふえ /祖父江/
そふけん /ソフ研/
そふと /ソフト/
そふとうぇあ /ソフトウェア/
そふとうぇあかがく /ソフトウェア科学/
そふぼ /祖父母/
そぶえ /祖父江/
そぶり /素振り/
そへん /素片/
そほう /粗放/
そほうか /素封家/
そぼ /祖母/
そぼう /粗暴/
そぼく /素朴/
そぼくしゅうごうろん /素朴集合論/
そぼくしんりがく /素朴心理学/
そま /杣/
そまつ /粗末/
そまみち /杣道/
そみつ /疎密/粗密/
そみや /曽宮/
そむく /乖/
そめ /染/
そめい /染井/
そめいよしの /染井吉野/
そめたろう /染太郎/
そめち /染地/
そめのすけ /染乃助/
そめもの /染物/
そめや /染谷/
そや /粗野/
そやま /曽山/
そよう /素養/蘇陽/
そよかぜ /そよ風/
そら /空/
そらいろ /空色/
そらぞらしい /空々しい/
そらち /空知/
そらに /空似/
そらほうこう /空方向/
そらみみ /空耳/
そらみみけんぶんろく /空耳見聞録/
そらみみのおか /空耳の丘/
そらもよう /空模様/
そり /反り/橇/艝/轌/
そりた /返田/
そりのこし /剃り残し/
そりまち /反町/
そりみ /反り身/
そりゃく /粗略/
そりゅうし /素粒子/
そりゅうしかん /素粒子間/
そりゅうしばたけ /素粒子畑/
そりゅうしぶつり /素粒子物理/
そりゅうしぶつりがく /素粒子物理学/
そりゅうしりろん /素粒子理論/
そりゅうしろん /素粒子論/
そりゅうど /粗粒度/
それ /其/
それい /租霊/
それがし /某/
それぞれ /夫々/其其/夫夫/各々/
それとなく /其と無く/
それどころ /其処/
それゆえ /それ故/
それん /ソ連/蘇連/蘇聯/ソ聯/
それんへい /ソ連兵/
それんぽう /ソ聯邦/
そろう /粗漏/疎漏/
そろばん /算盤/十露盤/
そわ /曽和/
そん /損/存/村/遜/尊/孫/忖/拵/蹲/邨/噂/巽/樽/鱒/
そんえい /村営/
そんえき /損益/
そんえきけいさんしょ /損益計算書;財務諸表の1つ/
そんえきぶんきてん /損益分岐点/
そんかい /損壊/村会/
そんがい /損害/
そんがいしんせい /損害申請/
そんがいとう /損害等/
そんがいばいしょう /損害賠償/
そんがいばいしょうがく /損害賠償額/
そんがいばいしょうさいばん /損害賠償裁判/
そんがいばいしょうせいきゅう /損害賠償請求/
そんがいほけん /損害保険/
そんがいほけんがいしゃ /損害保険会社/
そんがいほしょうせきにん /損害賠償責任/
そんがん /尊顔/
そんきょ /蹲踞/
そんきん /損金/
そんぐ /ソング/
そんけい /尊敬/
そんけいご /尊敬語/
そんけん /孫権;三国時代・呉の初代皇帝/
そんげん /尊厳/
そんげんし /尊厳死/
そんこう /損耗/
そんごくう /孫悟空/
そんざい /存在/∃/
そんざいいき /存在域/
そんざいいぎ /存在意義/
そんざいいち /存在位置/
そんざいいみ /存在意味/
そんざいか /存在下/
そんざいかくりつ /存在確率/
そんざいかち /存在価値/
そんざいかん /存在感/
そんざいきごう /存在記号/
そんざいきばん /存在基盤/
そんざいしゃ /存在者/
そんざいしょうめい /存在証明/
そんざいじたい /存在自体/
そんざいせい /存在性/
そんざいていり /存在定理/
そんざいばしょ /存在場所/
そんざいひ /存在比/
そんざいぶつ /存在物/
そんざいへんすう /存在変数/
そんざいりゆう /存在理由/
そんざいろん /存在論/
そんざいろんりしき /存在論理式/
そんし /孫子;春秋時代の呉の将軍/尊子/尊師/尊司/
そんしつ /損失/
そんしつかんすう /損失関数/
そんしつけいさん /損失計算/
そんしつじかん /損失時間/
そんしつじかんりょういき /損失時間領域/
そんしつていげん /損失低減/
そんしつほてん /損失補填/
そんしゅ /尊守/
そんしょう /損傷/尊称/
そんしょうかん /損傷艦/
そんしょうきろくひょう /損傷記録表/
そんしょうど /損傷度/
そんしょうひん /損傷品/
そんしょうりつ /損傷率/
そんしょく /遜色/
そんじゅく /村塾/
そんぜい /村税/
そんぞく /存続/尊属/
そんぞくきかん /存続期間/
そんぞくきかんちゅう /存続期間中/
そんぞくきかんない /存続期間内/
そんぞくさつじん /尊属殺人/
そんぞくもんだい /存続問題/
そんたく /忖度/
そんだい /尊大/
そんち /存置/
そんちょう /尊重/村長/
そんちょうせんきょ /村長選挙/
そんてん /尊天/
そんとく /損得/
そんとくかんじょう /損得勘定/
そんとくぶんきてん /損得分岐点/
そんどう /村道/
そんない /村内/
そんのう /尊皇/尊王/
そんのうじょうい /尊皇攘夷/
そんぱい /存廃/
そんぴ /存否/村費/
そんぶ /孫武/
そんぶん /孫文/
そんぷ /尊父/
そんぷうし /村夫子/
そんぼう /存亡/
そんぽ /損保/
そんみん /村民/
そんもう /損耗/
そんもうぶん /損耗分/
そんゆう /村有/
そんらく /村落/
そんりつ /存立/村立/
そんりょう /損料/
ぞ /祖/曾/曽/
ぞう /像/蔵/臓/造/贈/象/増/憎/三/雑/僧/慥/梍/臟/臧/藏/贓/賍/襍/雜/曾/曽/噌/
ぞうあく /増悪/
ぞういん /増員/
ぞういんようきゅう /増員要求/
ぞうえい /造影/造営/
ぞうえいざい /造影剤/
ぞうえき /増益/
ぞうえん /増援/造園/
ぞうえんがかり /造園係/
ぞうえんぶたい /増援部隊/
ぞうお /憎悪/
ぞうか /増加/造花/造化/
ぞうかきょくせん /増加曲線/
ぞうかけいこう /増加傾向/
ぞうかてき /増加的/
ぞうかぶん /増加分/
ぞうかぶんや /増加分野/
ぞうかりつ /増加率/
ぞうかりょう /増加量/
ぞうかれつ /増加列/
ぞうかん /増刊/増感/
ぞうかんげんぞう /増感現像/
ぞうかんげんぞうざい /増感現像剤/
ぞうかんごう /増刊号/
ぞうかんし /増感紙/
ぞうかんしょり /増感処理/
ぞうかんすう /像関数/
ぞうかんとくせい /増感特性/
ぞうかんほう /増感法/
ぞうがく /増額/
ぞうがん /象嵌/象眼/造龕/
ぞうき /臓器/造機/
ぞうきいしょく /臓器移植/
ぞうきいしょくよう /臓器移植用/
ぞうきかんせんしょう /臓器感染症/
ぞうきていきょう /臓器提供/
ぞうきばやし /雑木林/
ぞうきょう /増強/
ぞうきょうこうじちゅう /増強工事中/
ぞうきょうりょう /増強量/
ぞうきん /雑巾/
ぞうけい /造詣/造形/造型/
ぞうけいきかく /造形企画/
ぞうけいひょうげん /造形表現/
ぞうけつ /増結/造血/
ぞうけつかのう /増結可能/
ぞうけつぶん /増結分/
ぞうけつよう /増結用/
ぞうけつようだいしゃ /増結用台車/
ぞうげ /象牙/
ぞうげん /増減/
ぞうご /造語/
ぞうごのうりょく /造語能力/
ぞうごりょく /造語力/
ぞうごん /雑言/
ぞうさ /造作/雑作/
ぞうさく /増作/造作/
ぞうさつ /増刷/
ぞうさつじ /増刷時/
ぞうさん /増産/
ぞうざい /造材/
ぞうし /増資/造詣/
ぞうしき /雑色/
ぞうしゅう /増収/贈収/
ぞうしゅうわい /贈収賄/
ぞうしょ /蔵書/
ぞうしょう /蔵相/
ぞうしょく /増殖/
ぞうしょくそくど /増殖速度/
ぞうしょくちゅう /増殖中/
ぞうしょくほう /増殖法/
ぞうしょこうせい /蔵書構成/
ぞうしょすう /蔵書数/
ぞうしん /増進/
ぞうじ /造次/造字/
ぞうじてんぱい /造次顛沛/
ぞうじょうじ /増上寺/
ぞうじるし /象印/
ぞうすい /雑炊/増水/
ぞうせい /造成/増勢/増生/
ぞうせいせいびちゅう /造成整備中/
ぞうせいちゅう /造成中/
ぞうせつ /増設/
ぞうせつかのう /増設可能/
ぞうせつじ /増設時/
ぞうせつとびら /増設扉/
ぞうせつぶぶん /増設部分/
ぞうせつよう /増設用/
ぞうせつようたんし /増設用端子/
ぞうせん /造船/
ぞうせんかい /造船界/
ぞうせんじょ /造船所/
ぞうぜい /増税/増勢/
ぞうそく /増速/
ぞうだい /増大/
ぞうだいかてい /増大過程/
ぞうちく /増築/
ぞうちくちゅう /増築中/
ぞうちょう /増長/
ぞうてい /贈呈/増訂/
ぞうていしき /贈呈式/
ぞうていばん /増訂版/
ぞうてん /像点/
ぞうとう /贈答/
ぞうとうひん /贈答品/
ぞうどしてい /像度指定/
ぞうに /雑煮/
ぞうは /増派/
ぞうはい /増配/
ぞうはつ /増発/
ぞうはつぶん /増発分/
ぞうはつよう /増発用/
ぞうはん /増版/
ぞうばい /増倍/
ぞうばいかん /増倍管/
ぞうばいりつ /増倍率/
ぞうひょうたち /雑兵達/
ぞうび /増備/
ぞうびがた /増備型/
ぞうびしゃ /増備車/
ぞうびしゃりょう /増備車両/
ぞうびん /増便/
ぞうふ /臓腑/
ぞうふく /増幅/
ぞうふくき /増幅器/
ぞうふくきのう /増幅機能/
ぞうふくど /増幅度/
ぞうふくりつ /増幅率/
ぞうぶつしゅ /造物主/
ぞうぶん /増分/
ぞうぶんち /増分値/
ぞうへい /造幣/
ぞうへいきょく /造幣局/
ぞうほ /増補/
ぞうほう /増俸/
ぞうほかいていばん /増補改訂版/
ぞうほばん /増補版/
ぞうまえ /像前/
ぞうめんろこうりょう /像面露光量/
ぞうめんわんきょく /像面湾曲/
ぞうもつ /臓物/
ぞうよ /贈与/
ぞうよぜい /贈与税/
ぞうり /草履/
ぞうりょう /増量/
ぞうりょうかのう /増量可能/
ぞうりょく /増力/
ぞうりょくざい /増力剤/
ぞうりん /造林/
ぞうりんち /造林地/
ぞうわい /贈賄/
ぞうわいざい /贈賄罪/
ぞえ /添/
ぞく /属/族/続/賊/俗/束/足/續/屬/粟/
ぞくあく /俗悪/
ぞくえん /続演/
ぞくか /俗化/
ぞくかい /俗界/続開/
ぞくがら /続柄/
ぞくぐん /賊軍/
ぞくご /俗語/
ぞくごしゅう /俗語集/
ぞくし /賊子/
ぞくしゅ /俗手/
ぞくしゅう /俗臭/
ぞくしゅつ /続出/
ぞくしょう /俗称/
ぞくしん /続伸/
ぞくじ /俗事/俗字/
ぞくじょう /俗情/
ぞくじん /俗人/俗塵/属人/
ぞくじんてき /属人的/
ぞくせい /属性/俗世/族生/
ぞくせいじょうけん /属性条件/
ぞくせいち /属性値/
ぞくせいちしゅどう /属性値主導/
ぞくせいひょうか /属性評価/
ぞくせいひょうかき /属性評価器/
ぞくせいぶんぽう /属性文法/
ぞくせいへんか /属性変化/
ぞくせいめい /属性名/
ぞくせかい /俗世界/
ぞくせつ /俗説/
ぞくぞく /続々/
ぞくとう /続騰/続投/
ぞくはく /粟帛/
ぞくはつ /続発/
ぞくぶつ /俗物/
ぞくぶつずかん /俗物図鑑/
ぞくへん /続編/続篇/
ぞくへんぐん /続編群/
ぞくほう /続報/
ぞくみょう /俗名/
ぞくめい /属名/
ぞくらく /続落/
ぞくりゅう /粟粒/
ぞくりょう /属領/
ぞくりょうち /属領地/
ぞくろん /俗論/続論/
ぞっか /俗化/
ぞっかい /俗界/
ぞっかん /続刊/
ぞっこう /続行/
ぞっこうかのう /続行可能/
ぞっこうちゅう /続行中/
ぞっこく /属国/
ぞの /薗/
ぞろめ /ゾロ目/
ぞん /存/
ぞんがい /存外/
ぞんじ /存知/存じ/
ぞんぢ /存知/
ぞんぶん /存分/
ぞんめい /存命/
ぞんめいちゅう /存命中/
た /他/田/多/太/詑/汰/手/夛/詫/佗/侘/咤/它/岔/躱/朶/蛇/
た> /多/他/
た? /他/
たーげっと /ターゲット/
たーとる /タートル/
たーびん /タービン/
たーぼ /ターボ/
たーみなる /ターミナル/
たーん /ターン/
たあい /他愛/
たあいしょう /多相性/
たあちゃ /他家/
たあはい /多牌/
たい /対/体/隊/退/大/態/袋/帯/代/泰/他意/滞/逮/怠/替/待/太/苔/胎/腿/貸/黛/鯛/堆/耐/戴/岱/田井/諦/殆/對/帶/擡/抬/滯/玳/紿/褪/躰/軆/隶/靆/頽/颱/駘/體/vs/タイ/碓/載/汰/台/
たい< /耐/
たい> /対/耐/
たいあたり /体当り/
たいあっぷ /タイアップ/
たいあつ /耐圧/
たいあつけんさ /耐圧検査/
たいあつしけん /耐圧試験/
たいあつせい /耐圧性/
たいあん /大安/対案/
たいあんきちじつ /大安吉日/
たいい /大意/体位/退位/大尉/
たいいき /帯域/大域/
たいいきあっしゅくぎじゅつ /帯域圧縮技術/
たいいきかくだい /帯域拡大/
たいいきかんすう /大域関数/
たいいききょくしょうち /大域極小値/
たいいきこうぞう /大域構造/
たいいきざつおん /帯域雑音/
たいいきしょうめい /大域照明/
たいいきしょり /帯域処理/
たいいきせい /大域性/
たいいきせいげん /帯域制限/
たいいきだっしゅつ /大域脱出/
たいいきつうか /帯域通過/
たいいきてき /大域的/
たいいきてきかそうかそうきおく /大域的仮想仮想記憶/
たいいきてきかそうきおく /大域的仮想記憶/
たいいきとくせい /帯域特性/
たいいきない /帯域内/
たいいきはば /帯域幅/
たいいきぶんかつ /帯域分割/
たいいきぶんせき /帯域分析/
たいいきへんすう /大域変数/
たいいきほうしき /大域方式/
たいいく /体育/
たいいくかい /体育会/
たいいくかいがくせい /体育会学生/
たいいくかいけい /体育会系/
たいいくかいしゅっしん /体育会出身/
たいいくかがくけい /体育科学系/
たいいくかん /体育館/
たいいくかんない /体育館内/
たいいくがく /体育学/
たいいくがくけんきゅう /体育学研究/
たいいくきょく /体育局/
たいいくけい /体育系/
たいいくさい /体育祭/
たいいくじつぎ /体育実技/
たいいち /太一/対一/
たいいほう /対位法/
たいいほうてき /対位法的/
たいいん /退院/隊員/
たいいんたいようれき /太陰太陽暦/
たいいんたち /隊員達/
たいいんれき /太陰暦/
たいえい /大栄/
たいえき /体液/退役/
たいえきぐんじん /退役軍人/
たいえん /退園/
たいおう /対応/対欧/對應/
たいおうか /対応可/
たいおうかじゅういき /対応荷重域/
たいおうかのう /対応可能/
たいおうかんけい /対応関係/
たいおうがた /対応型/
たいおうきしゅ /対応機種/
たいおうきそく /対応規則/
たいおうけんばいき /対応券売機/
たいおうごく /対応語句/
たいおうさく /対応策/
たいおうしゃ /対応車/
たいおうしゃしゅ /対応車種/
たいおうしゃりょう /対応車両/
たいおうしゅだん /対応手段/
たいおうじょうきょう /対応状況/
たいおうず /対応図/
たいおうずみ /対応済/
たいおうづけ /対応付け/
たいおうてん /対応点/
たいおうどりょく /対応努力/
たいおうばん /対応版/
たいおうばんぐみ /対応番組/
たいおうひょう /対応表/
たいおうひん /対応品/
たいおうふかのう /対応不可能/
たいおうぶつ /対応物/
たいおうぶひん /対応部品/
たいおうほう /対応法/
たいおうよてい /対応予定/
たいおせんせい /耐汚染性/
たいおん /体温/
たいおんけい /体温計/
たいおんじょうしょう /体温上昇/
たいおんそくてい /体温測定/
たいおんちょうせい /体温調整/
たいおんちょうせつ /体温調節/
たいか /退化/大家/大過/耐火/大化/滞貨/対価/大火/大厦/大廈/袋果/耐過/
たいかい /大会/大海/退会/
たいかいいいんちょう /大会委員長/
たいかいかいさい /大会開催/
たいかいかいじょう /大会会場/
たいかいかんじ /大会幹事/
たいかいけっしょう /大会決勝/
たいかいご /大会後/
たいかいさんか /大会参加/
たいかいさんかしゃ /大会参加者/
たいかいさんかひ /大会参加費/
たいかいしゃ /退会者/
たいかいしゅうりょうご /大会終了後/
たいかいしゅつじょう /大会出場/
たいかいしんきろく /大会新記録/
たいかいじむきょく /大会事務局/
たいかいぜんたい /大会全体/
たいかいぜんぱん /大会全般/
たいかいっそう /滞貨一掃/
たいかいへん /大会篇/
たいかいほんぶ /大会本部/
たいかいまえ /大会前/
たいかいめい /大会名/
たいかいやくいん /大会役員/
たいかいようこう /大会要項/
たいかく /体格/対角/対格/
たいかくか /対角化/
たいかくぎょうれつ /対角行列/
たいかくぎょがん /対角魚眼/
たいかくこう /対角項/
たいかくさ /体格差/
たいかくしゃぞう /対角写像/
たいかくせいぶん /対角成分/
たいかくせん /対角線/
たいかくせんじょう /対角線上/
たいかくせんろんぽう /対角線論法/
たいかくてき /体格的/
たいかくようそ /対角要素/
たいかこうろう /大廈高楼/
たいかざい /耐火材/
たいかせい /耐火性/
たいかん /退官/体感/体幹/耐寒/戴冠/対艦/
たいかんおんど /体感温度/
たいかんきかんちゅう /大会期間中/
たいかんきねん /退官記念/
たいかんこうぎ /退官講義/
たいかんこうげき /対艦攻撃/
たいかんこく /対韓国/
たいかんしき /戴冠式/
たいかんしよう /耐寒仕様/
たいかんじかん /体感時間/
たいかんそくど /体感速度/
たいかんてき /体感的/
たいかんみんこく /大韓民国/
たいが /大河/胎芽/
たいがい /大概/対外/体外/大外/
たいがいかつどう /対外活動/
たいがいじあい /対外試合/
たいがいせっしょう /対外折衝/
たいがいせんでん /対外宣伝/
たいがいてき /対外的/
たいがいぶ /対外部/
たいがく /退学/
たいがくかんこく /退学勧告/
たいがくしょち /退学処置/
たいがくしょぶん /退学処分/
たいがん /対岸/大願/
たいき /待機/大気/大器/大樹/対気/
たいきあつ /大気圧/
たいきおせん /大気汚染/
たいきおせんたいさく /大気汚染対策/
たいきけん /大気圏/
たいきけんさいとつにゅう /大気圏再突入/
たいきけんない /大気圏内/
たいきげんしょう /大気現象/
たいきこう /大気光/
たいきしゃ /大気社/大氣社/
たいきじょうたい /待機状態/
たいきそくど /対気速度/
たいきそせい /大気組成/
たいきだいじゅんかん /大気大循環/
たいきだいじゅんかんもでる /大気大循環モデル/
たいきちゅう /待機中/大気中/
たいきばんせいがた /大器晩成型/
たいきぶんれつそしき /待機分裂組織/
たいきゃく /退却/
たいきゃくちゅう /退却中/
たいきゅう /耐久/
たいきゅうしけん /耐久試験/
たいきゅうせい /耐久性/
たいきゅうせいのう /耐久性能/
たいきゅうせんしゅけん /耐久選手権/
たいきゅうりょく /耐久力/
たいきょ /大挙/退去/退却/
たいきょう /胎教/
たいきょうさん /対共産/
たいきょうよう /胎教用/
たいきょく /対極/太極/対局/大局/大極/
たいきょくかた /対局過多/
たいきょくかん /大局観/
たいきょくけいか /対局経過/
たいきょくけん /太極拳/大極拳/
たいきょくし /大局視/
たいきょくしゃ /対局者/
たいきょくしゃめい /対局者名/
たいきょくすう /対局数/
たいきょくちゅう /対局中/
たいきょくてき /大局的/大極的/対極的/
たいきょくばんごう /対局番号/
たいきょくへんすう /大局変数/
たいきょようにゅうりょく /耐許容入力/
たいきりゅうし /大気粒子/
たいきん /大金/退勤/
たいきんじ /退勤時/
たいきんてつ /対近鉄/
たいきんてつせん /対近鉄戦/
たいぎ /大義/大儀/
たいぎご /対義語/
たいぎめいぶん /大義名分/
たいぎょう /怠業/
たいく /体躯/
たいくう /対空/体腔/滞空/
たいくうかき /対空火器/
たいくうけいかく /対空計画/
たいくうしゃげき /対空射撃/
たいくうじかん /滞空時間/
たいくうだん /対空弾/
たいくうない /体腔内/
たいくうへいき /対空兵器/
たいくうほう /対空砲/
たいくうほうだん /対空砲弾/
たいくうぼうぎょ /対空防御/
たいくうりょく /対空力/
たいくつ /退屈/
たいくつおとこ /退屈男/
たいくん /大君/
たいぐ /大愚/
たいぐう /待遇/対偶/
たいぐうかいぜん /待遇改善/
たいぐん /大群/大軍/
たいぐんか /大群化/
たいけい /体系/体型/体形/大慶/隊型/大系/腿頚/
たいけいか /体系化/
たいけいがく /体系学/
たいけいず /体系図/
たいけいせい /体系性/
たいけいてき /体系的/
たいけいてきじょうほう /体系的情報/
たいけいてきちくせき /体系的蓄積/
たいけいない /体系内/
たいけいろん /体系論/
たいけつ /対決/
たいけつじょう /対決場/
たいけん /体験/大圏/大権/大剣/
たいけんき /体験記/
たいけんきおく /体験記憶/
たいけんしゃ /体験者/
たいけんじょう /体験上/
たいけんだん /体験談/
たいけんばん /体験版/
たいけんへん /体験編/
たいけんれい /体験例/
たいげん /体現/体言/大言/
たいげんそうご /大言壮語/
たいげんどめ /体言止め/
たいこ /太古/太鼓/鯛子/大古/
たいこう /対抗/対向/退行/太閣/大公/大綱/大興/大功/帯鉤/体講/体育講義/
たいこういしき /対抗意識/
たいこううせつしゃ /対向右折車/
たいこうかくしゃ /対抗各社/
たいこうき /太閣記/太閤記/
たいこうくうき /対航空機/
たいこうさく /対抗策/対抗作/
たいこうしき /対向式/
たいこうしゃ /対向車/対抗車/対行車/対抗者/
たいこうしゃせん /対向車線/対抗車線/対行車線/
たいこうしゃせんがわ /対抗車線側/
たいこうしゅだん /対抗手段/
たいこうしょうひん /対抗商品/
たいこうしん /対抗心/
たいこうじあい /対抗試合/
たいこうじょう /対抗上/
たいこうせい /退行性/耐候性/
たいこうせん /対抗戦/
たいこうちょくしんしゃ /対向直進車/
たいこうにりんしゃ /対向二輪車/
たいこうはんしゃ /対光反射/
たいこうば /対抗馬/
たいこうぼう /太公望;周王朝の臣で、魯の開祖/
たいこうれっしゃ /対向列車/
たいこく /大国/
たいこくかん /大国間/
たいこしょう /耐故障/
たいこしょうせい /耐故障性/
たいこたい /太鼓隊/
たいこばん /太鼓判/
たいこへん /大古編/
たいこやき /太鼓焼/
たいご /隊伍/
たいさ /大差/大佐/
たいさいぼう /体細胞/
たいさく /対策/大作/
たいさくあん /対策案/
たいさくいいんかい /対策委員会/
たいさくきょうぎかい /対策協議会/
たいさくご /対策後/
たいさくそうち /対策装置/
たいさくなんかい /対策難解/
たいさくひ /対策費/
たいさくひん /対策品/
たいさくぶひん /対策部品/
たいさくほう /対策法/
たいさくほうほう /対策方法/
たいさくまえ /対策前/
たいさくよう /対策用/
たいさなし /大差無/
たいさん /退散/
たいざ /対座/胎座/
たいざい /滞在/大罪/帯在/
たいざいかのう /滞在可能/
たいざいがたりょこう /滞在型旅行/
たいざいきかん /滞在期間/
たいざいきかんちゅう /滞在期間中/
たいざいきょか /滞在許可/
たいざいけいけん /滞在経験/
たいざいさき /帯在先/滞在先/
たいざいじかん /滞在時間/
たいざいちゅう /滞在中/
たいざいにっすう /滞在日数/
たいざいひ /滞在費/
たいざいび /滞在日/
たいざん /泰山/鯛山/大山/
たいし /大史/大使/大志/太子/大師/対し/
たいしかん /大使館/
たいしかんりょうじぶ /大使館領事部/
たいしせん /大師線/
たいした /大した/
たいしつ /体質/退室/
たいしつかいぜん /体質改善/
たいしつかいぞう /体質改造/
たいしつてき /体質的/
たいしでんきてつどう /大師電気鉄道/
たいしどう /太子堂/大師堂/
たいしぼう /体脂肪/
たいしゃ /退社/代謝/大赦/大社/
たいしゃく /貸借/帝釈/
たいしゃくきょう /帝釈峡/
たいしゃくたいしょうひょう /貸借対照表;財務諸表の1つ/
たいしゃくてん /帝釈天/
たいしゃせいさんぶつ /代謝生産物/
たいしゃび /退社日/
たいしゃりつ /代謝率/
たいしゃりょう /代謝量/
たいしゅう /体臭/大衆/大周/
たいしゅうえんげきふう /大衆演劇風/
たいしゅうおんがく /大衆音楽/
たいしゅうか /大衆化/
たいしゅうかん /大修館/
たいしゅうかんしょてん /大修館書店/
たいしゅうごらく /大衆娯楽/
たいしゅうし /大衆誌/
たいしゅうしょくどう /大衆食堂/
たいしゅうしんり /大衆心理/
たいしゅうすしや /大衆寿司屋/
たいしゅうせい /大衆性/
たいしゅうだいひょう /大衆代表/
たいしゅうてき /大衆的/
たいしゅうてきにんき /大衆的人気/
たいしゅつ /貸出/退出/体出/
たいしゅつしゃ /退出者/
たいしゅつれい /退出例/
たいしょ /対処/対蹠/大暑/大書/大所/
たいしょあん /対処案/
たいしょう /対象/大賞/大正/対称/大将/対照/対症/隊商/大勝/大笑/大捷/代償/
たいしょう#ねん /大正#0年/大正#1年/大正#2年/大正#3年/(skk-gengo-to-ad "" "年")/(skk-gengo-to-ad "西暦" "年")/
たいしょういけ /大正池/
たいしょうか /対象化/
たいしょうがい /対象外/
たいしょうがいせい /耐障害性/
たいしょうがた /対称型/
たいしょうがんねん /大正元年/
たいしょうき /大正期/
たいしょうきかん /対象期間/
たいしょうきごう /対象記号/
たいしょうきしゅ /対象機種/
たいしょうぎょうれつ /対称行列/
たいしょうくかん /対象区間/
たいしょうぐん /対称群/対照群/
たいしょうけい /対称形/
たいしょうげき /耐衝撃/
たいしょうげんご /対象言語/
たいしょうこう /対象項/
たいしょうこく /対象国/
たいしょうごと /大正琴/
たいしょうざっし /対象雑誌/
たいしょうしこう /対象指向/
たいしょうしてい /対象指定/
たいしょうしゃ /対象者/対象車/
たいしょうしゃしゅかんり /対象車種管理/
たいしょうしゃりょう /対象車両/
たいしょうしゅうだん /対象集団/
たいしょうしんじん /大賞新人/
たいしょうじく /対称軸/
たいしょうじだい /大正時代/
たいしょうじっけん /対照実験/
たいしょうじどうしゃ /対象自動車/
たいしょうじんいん /対象人員/
たいしょうすうりょう /対象数量/
たいしょうせい /対称性/
たいしょうせいやく /大正製薬/
たいしょうせかい /対象世界/
たいしょうせんしゅ /対象選手/
たいしょうそう /対象層/
たいしょうたいかい /対象大会/
たいしょうちいき /対象地域/
たいしょうちいきない /対象地域内/
たいしょうちしき /対象知識/
たいしょうてき /対照的/対称的/対象的/
たいしょうてんのう /大正天皇/
たいしょうど /対称度/
たいしょうにんしき /対象認識/
たいしょうねんど /対象年度/
たいしょうねんれい /対象年齢/
たいしょうひょう /対照表/
たいしょうぶつ /対象物/
たいしょうへんすう /対象変数/
たいしょうまっき /大正末期/
たいしょうめい /対象名/
たいしょうめん /対称面/
たいしょうりつ /対称律/
たいしょうりょういき /対象領域/
たいしょうりょうほう /対症療法/対象療法/
たいしょうわしゃ /対象話者/
たいしょかのう /対処可能/
たいしょく /退職/大食/退色/褪色/
たいしょくかん /大食漢/
たいしょくきん /退職金/
たいしょくきんかんけい /退職金関係/
たいしょくきんきてい /退職金規定/
たいしょくけいじ /退職刑事/
たいしょくご /退職後/
たいしょくしゃ /退職者/
たいしょくじゆう /退職事由/
たいしょくび /退職日/
たいしょくぼうしざい /褪色防止剤/
たいしょくりゆう /退職理由/
たいしょこうしょ /大所高所/
たいしょどうさ /対処動作/
たいしょほう /対処法/対処方/
たいしょほうほう /対処方法/
たいしょりょうほう /対処療法/対症療法/
たいしん /耐震/太信/大信/
たいしんくう /対真空/
たいしんせい /耐震性/
たいじ /退治/胎児/泰次/対峙/帯磁/泰二/泰司/太地/胎仔/
たいじく /体軸/
たいじそしき /胎児組織/
たいじゅ /大樹/
たいじゅう /体重/
たいじゅういどう /体重移動/
たいじゅうけい /体重計/
たいじゅうさ /体重差/
たいじゅうしんちょう /体重身長/
たいじゅうそくてい /体重測定/
たいじゅうひじゅうりょう /体重比重量/
たいじゅうりょう /耐重量/
たいじゅつ /体術/
たいじゅん /泰淳/
たいじょう /退場/
たいじょうかい /帯状回/
たいじょうしゃ /退場者/
たいじょうしょぶん /退場処分/
たいじょうじゅん /退場順/
たいじょうほうしん /帯状疱疹/
たいじん /対人/退陣/泰人/大人/
たいじんかんけい /対人関係/
たいすい /耐水/
たいすいせい /耐水性/
たいすう /対数/大数/
たいすうじく /対数軸/
たいすうじくひょうげん /対数軸表現/
たいすうち /対数値/
たいすうひょう /対数表/
たいすうぶん /帯分数/
たいすうめもり /対数目盛/
たいすけ /泰介/泰佑/退助/泰祐/
たいする /対する/
たいずし /鯛鮨/
たいせい /体制/態勢/大勢/耐性/大成/体性/体勢/胎生/対生/大政/
たいせいいでんし /耐性遺伝子/
たいせいか /体制化/
たいせいかんかく /体性感覚/
たいせいがわ /体制側/
たいせいけんせつ /大成建設/
たいせいこうこう /大成高校/
たいせいしんこうげき /対精神攻撃/
たいせいてき /体制的/
たいせいどう /大盛堂/
たいせいどうろ /大成道路/
たいせいひはん /体制批判/
たいせいぶせん /対西武戦/
たいせいぶつ /対生物/
たいせいまる /大成丸/
たいせいよう /大西洋/
たいせいようかんたい /大西洋艦隊/
たいせいようがん /大西洋岸/
たいせいようじょ /対生葉序/
たいせいようせん /大西洋線/
たいせき /体積/退席/堆積/滞積/対蹠/
たいせきかのう /堆積可能/
たいせきがん /堆積岩/
たいせきじ /大石寺/
たいせきそう /堆積層/
たいせきそくど /体積速度/
たいせきは /体積波/
たいせきぶつ /体積物/堆積物/
たいせきようそ /体積要素/
たいせきりょく /体積力/
たいせつ /大切/大雪/体節/
たいせつさ /大切さ/
たいせん /対戦/大戦/対潜/大戰/
たいせんあいて /対戦相手/
たいせんかいすう /対戦回数/
たいせんがた /対戦型/
たいせんがたかくとう /対戦型格闘/
たいせんがたきょうぎ /対戦型競技/
たいせんけいしき /対戦形式/
たいせんけっか /対戦結果/
たいせんご /対戦後/大戦後/
たいせんしゃ /対戦車/対戦者/
たいせんしゃほう /対戦車砲/
たいせんしゃぼしゅうちゅう /対戦者募集中/
たいせんしょき /対戦初期/
たいせんじ /対戦時/
たいせんすう /対戦数/
たいせんすうひょう /対戦数表/
たいせんせいせき /対戦成績/
たいせんちゅう /対戦中/大戦中/
たいせんとちゅう /対戦途中/
たいせんひょう /対戦表/
たいせんひわ /大戦秘話/
たいせんまっき /大戦末期/
たいせんりつ /対旋律/
たいぜん /泰然/大全/
たいぜんじじゃく /泰然自若/
たいそう /大層/体操/大喪/大葬/
たいそうふく /体操服/
たいそしき /体組織/
たいぞう /太造/泰三/大造/泰造/泰蔵/大蔵/諦三/退蔵/
たいだ /怠惰/
たいだん /対談/退団/
たいだんきじ /対談記事/
たいだんけいしき /対談形式/
たいだんしゅう /対談集/
たいだんしょぶん /退団処分/
たいち /対地/太一/対置/多一/
たいちきどう /対地軌道/
たいちこうげき /対地攻撃/
たいちこうげきりょく /対地攻撃力/
たいちしえん /対地支援/
たいちそくど /対地速度/
たいちゅうごく /対中国/
たいちゅうにちせん /対中日戦/
たいちょ /大著/
たいちょう /体調/隊長/体長/退庁/
たいちょういへん /体調異変/
たいちょうかく /対頂角/
たいちょうじたい /体調自体/
たいちょうたち /隊長達/
たいちょうばんぜん /体調万全/
たいちょうふじゅうぶん /体調不十分/
たいちょうふちょう /体調不調/
たいちょうふりょう /体調不良/
たいちよう /退治用/
たいちろう /太一郎/
たいてい /大抵/大帝/退廷/
たいてき /大敵/
たいてん /退店/
たいでん /帯電/
たいと /泰斗/タイト/
たいとう /対等/台東/台頭/体当/台糖/擡頭/帯刀/
たいとういじょう /対等以上/
たいとうかんけい /対等関係/
たいとうきょう /対東京/
たいとうく /台東区/
たいとうせい /対等性/
たいとく /体得/
たいとしん /対都心/
たいとりーじょん /タイトリージョン/
たいとる /タイトル/
たいど /態度/
たいどう /胎動/帯同/
たいどひょうめい /態度表明/
たいどみてい /態度未定/
たいない /体内/胎内/対内/隊内/
たいないどけい /体内時計/
たいないはいかん /胎内拝観/
たいないぶ /体内部/
たいなごや /対名古屋/
たいにし /対西/
たいにち /対日/滞日/
たいにちさんせん /対日参戦/
たいにん /退任/大任/
たいにんげん /対人間/
たいねつ /耐熱/
たいねつしょり /耐熱処理/
たいねつようせっちゃくざい /耐熱用接着剤/
たいねん /耐年/
たいのう /滞納/怠納/
たいのうしゃ /怠納者/滞納者/
たいのうしょぶん /滞納処分/
たいは /大破/
たいはい /大敗/退廃/頽廃/頽廢/
たいはいてき /退廃的/
たいはく /太白/
たいはくく /太白区/
たいはくさん /太白山/
たいはん /大半/
たいばつ /体罰/
たいばついがい /体罰以外/
たいばつきょうし /体罰教師/
たいばつぜんひてい /体罰全否定/
たいばつひつようろん /体罰必要論/
たいばつもんだい /体罰問題/
たいばん /胎盤/
たいばんちゅうしゅつぶつ /胎盤抽出物/
たいひ /退避/対比/堆肥/待避/
たいひえき /退避駅/
たいひか /堆肥化/
たいひかのう /退避可能/
たいひかん /退避艦/
たいひこうぞう /退避構造/
たいひじょ /退避所/待避所/
たいひせつび /待避設備/退避設備/
たいひせん /待避線/退避線/
たいひづくり /堆肥作り/
たいひてき /対比的/
たいひひょう /対比表/
たいひょうめん /体表面/
たいひょうめんせき /体表面積/
たいひよう /退避用/
たいひりょういき /退避領域/
たいひろしま /対広島/
たいびょう /大病/
たいぴすと /タイピスト/
たいふ /大夫/
たいふう /台風/颱風/
たいふうか /台風下/
たいふうじょうりく /台風上陸/
たいふうせっきんちゅう /台風接近中/
たいぶ /退部/大部/体部/
たいぶつ /対物/
たいぶん /大分/
たいぶんすう /帯分数/
たいぷ /タイプ/
たいぷらいた /タイプライタ/
たいへい /太平/泰平/大平/
たいへいき /太平記/大平記/
たいへいこうぎょう /太平工業/
たいへいざん /太平山/
たいへいよう /太平洋/
たいへいようおうだん /太平洋横断/
たいへいようおうふく /太平洋往復/
たいへいようがわ /太平洋側/
たいへいようせん /太平洋線/
たいへいようせんそう /太平洋戦争/
たいへいようせんそうまえ /太平洋戦争前/
たいへいようちいき /太平洋地域/
たいへいようでんてつ /太平洋電鉄/
たいへいらく /太平楽/
たいへん /大変/対辺/
たいへんかんしゃ /大変感謝/
たいへんきけん /大変危険/
たいへんきょうしゅく /大変恐縮/
たいへんけっこう /大変結構/
たいへんこんなん /大変困難/
たいへんごめいわく /大変御迷惑/
たいへんざんねん /大変残念/
たいへんしつれい /大変失礼/
たいへんしんせつ /大変親切/
たいへんじゅうよう /大変重要/
たいへんふゆかい /大変不愉快/
たいへんべんり /大変便利/
たいへんまんぞく /大変満足/
たいへんめいわく /大変迷惑/
たいへんゆうめい /大変有名/
たいべい /対米/滞米/
たいべいこく /対米国/
たいべいしよう /対米仕様/
たいべいゆしゅつよう /対米輸出用/
たいべつ /大別/
たいぺい /台北/
たいぺいけいゆ /台北経由/
たいぺいしゅっぱつ /台北出発/
たいほ /逮捕/退歩/
たいほう /大砲/大峰/大豊/大鵬/
たいほうやくひん /大鵬薬品/
たいほく /台北/
たいほくおうふく /台北往復/
たいほしゃ /逮捕者/
たいぼう /待望/耐乏/大望/
たいぼうろん /待望論/
たいぼく /大木/
たいま /大麻/タイマ/当麻/
たいまー /タイマー/
たいまい /大枚/玳瑁/
たいまけんきゅうしゃ /大麻研究者/
たいまつ /松明/
たいまとりしまりほう /大麻取締法/
たいまもうせい /耐磨耗性/
たいまん /怠慢/
たいみんぐ /タイミング/
たいむ /タイム/
たいめい /岱明/
たいめいがっき /体鳴楽器/
たいめし /鯛飯/
たいめん /対面/体面/泰緬/
たいめんしき /対面式/
たいめんつうこう /対面通行/
たいめんてつどう /泰緬鐵道/
たいめんのりかえ /対面乗換/
たいもう /体毛/大望/大網/
たいや /タイヤ/
たいやく /対訳/大役/
たいやくしゅう /対訳集/
たいゆう /大勇/大邑/大雄/
たいよ /貸与/
たいよう /大要/太陽/大洋/耐用/大陽/太洋/
たいようかつどう /太陽活動/
たいようかつどうしゅうき /太陽活動周期/
たいようきゅうだん /大洋球団/
たいようぎょぎょう /大洋漁業/
たいようけい /太陽系/
たいようけいいっしゅう /太陽系一周/
たいようけいしょうてんたい /太陽系小天体/
たいようけいぜんたい /太陽系全体/
たいようけいていこく /太陽系帝国/
たいようけいない /太陽系内/
たいようこう /太陽光/
たいようこうか /太陽光下/
たいようこうさいにゅうまど /太陽光採入窓/
たいようこうせん /太陽光線/
たいようこうはつでん /太陽光発電/
たいようこうべ /太陽神戸/
たいようこくてん /太陽黒点/
たいようさんそ /太陽酸素/
たいようしゅう /大洋州/
たいようしょぼう /大洋書房/
たいようしん /太陽神/
たいようしんけいそう /太陽神経叢/
たいようしんこうみんぞく /太陽信仰民族/
たいようじ /太陽時/
たいようじば /太陽磁場/
たいようせいもうまくえん /太陽性網膜炎/
たいようせきゆ /太陽石油/
たいようせん /大洋戦/
たいようぞく /太陽族/
たいようでんち /太陽電池/
たいようでんちしき /太陽電池式/
たいようでんちはつでん /太陽電池発電/
たいようとしょ /大洋図書/
たいようねつ /太陽熱/
たいようねつおんすいき /太陽熱温水器/
たいようねつりよう /太陽熱利用/
たいようねん /太陽年/
たいようねんすう /耐用年数/
たいようはつでん /太陽発電/
たいようふう /太陽風/
たいようゆうでん /太陽誘電/
たいようゆし /太陽油脂/
たいようれき /太陽暦/
たいよかのう /貸与可能/
たいよけん /貸与権/
たいよこはま /対横浜/
たいよこはません /対横浜戦/
たいら /平/
たいらけいりんじょう /平競輪場/
たいらのきよもり /平清盛/
たいり /大利/
たいりく /大陸/
たいりくおうだん /大陸横断/
たいりくさん /大陸産/
たいりくしき /大陸式/
たいりくしょぼう /大陸書房/
たいりくしんしゅつ /大陸進出/
たいりくせい /大陸性/
たいりくだな /大陸棚/
たいりくちたい /大陸地帯/
たいりくなんぶ /大陸南部/
たいりくはっけん /大陸発見/
たいりくぶんか /大陸文化/
たいりくほう /大陸法/
たいりつ /対立/
たいりついけん /対立意見/
たいりついでんし /対立遺伝子/
たいりつかんけい /対立関係/
たいりつがいねん /対立概念/
たいりつてん /対立点/
たいりゃく /大略/
たいりゅう /対流/滞留/
たいりゅうけいたい /対流形態/
たいりゅうけん /対流圏/
たいりゅうちょうせつ /対流調節/
たいりょう /大量/退寮/大漁/
たいりょういんさつ /大量印刷/
たいりょういんじ /大量印字/
たいりょうこうにゅう /大量購入/
たいりょうこうにゅうわりびき /大量購入割引/
たいりょうさいよう /大量採用/
たいりょうさつじん /大量殺人/
たいりょうしってん /大量失点/
たいりょうしぼうじけん /大量死亡事件/
たいりょうしょうひ /大量消費/
たいりょうしよう /大量使用/
たいりょうせいさん /大量生産/
たいりょうせいさんち /大量生産地/
たいりょうせいさんひん /大量生産品/
たいりょうぜつめつ /大量絶滅/
たいりょうてん /大量点/
たいりょうとうこう /大量投稿/
たいりょうとうにゅう /大量投入/
たいりょうとくてん /大量得点/
たいりょうにゅうがく /大量入学/
たいりょうにゅうりょく /大量入力/
たいりょうはいきしゃかい /大量廃棄社会/
たいりょうはかいへいき /大量破壊兵器/
たいりょうはっせい /大量発生/
たいりょうはっそう /大量発送/
たいりょうはっちゅう /大量発注/
たいりょうはんばい /大量販売/
たいりょうゆそう /大量輸送/
たいりょうゆそうきかん /大量輸送機関/
たいりょうり /タイ料理/
たいりょく /体力/
たいりょくかいふく /体力回復/
たいりょくこうじょう /体力向上/
たいりょくしょうぶ /体力勝負/
たいりょくしょうもう /体力消耗/
たいりょくそくてい /体力測定/
たいりょくぞうしん /体力増進/
たいりょくてき /体力的/
たいりょくぶそく /体力不足/
たいりょくようせい /体力養成/
たいりん /大輪/
たいる /タイル/
たいれい /胎齢/
たいれつ /隊列/
たいれんぽうこうさく /対連邦工作/
たいろ /退路/
たいろん /対論/
たいわ /対話/大和/対和/
たいわかた /対話型/
たいわがた /対話型/
たいわけいしき /対話形式/
たいわけんきゅうかい /対話研究会/
たいわしき /対話式/
たいわしょり /対話処理/
たいわちょう /大和町/
たいわてき /対話的/
たいわへん /対話篇/
たいわほうしき /対話方式/
たいわよう /対話用/
たいわん /台湾/
たいわんけいゆ /台湾経由/
たいわんさん /台湾産/
たいわんじん /台湾人/
たいわんせい /台湾製/
たいわんよしのや /台湾吉野屋/
たう /多雨/Τ/τ/
たうえ /田植え/田上/
たうち /田内/
たうら /田浦/
たうん /タウン/
たえ /妙/栲/
たえこ /妙子/多恵子/
たえず /絶えず/
たえだえ /絶え絶え/
たえま /絶えま/絶え間/
たお /田尾/垰/嵶/
たおか /田岡/
たおやめ /手弱女/
たおる /タオル/
たおんせつ /多音節/
たか /高/隆/鷹/貴/孝/亨/多価/多寡/孚/宇/尭/敬/尚/臣/崇/嵩/任/
たかあき /隆明/貴昭/孝明/貴章/学聡/孝哲/
たかあら /高荒/
たかい /高井/他界/
たかいし /高石/
たかいずみ /高泉/
たかいそう /多階層/
たかいち /高市/隆一/
たかいど /高井戸/
たかいびき /高鼾/
たかうじ /尊氏/
たかうち /高内/
たかえだ /高枝/
たかお /高尾/貴男/隆夫/尚夫/隆男/孝夫/高雄/高夫/孚夫/隆雄/貴雄/孝男/孝雄/崇夫/貴朗/貴生/貴夫/貴士/
たかおいせい /高尾以西/
たかおえき /高尾駅/
たかおか /高丘/高岡/高岳/
たかおかえき /高岡駅/
たかおかし /高岡市/
たかおかしょてん /高岡書店/
たかおかせいさくしょ /高岳製作所/
たかおかちゃく /高岡着/
たかおかちょう /高岡町/
たかおさん /高尾山/
たかおさんぐち /高尾山口/
たかおざん /高尾山/
たかおそうぶせん /高尾総武線/
たかおの /高尾野/
たかか /多花果/
たかかげ /隆景/
たかかず /剛一/剛和/
たかかわ /高河/
たかかんすう /多価関数/
たかがき /高垣/
たかがみね /鷹峯/
たかき /高樹/高木/高来/孝紀/
たかぎ /高木/高樹/高城/鷹木/高来/喬木/
たかぎあきみつ /高木彬光/
たかぎし /高岸/
たかぎわ /高際/
たかく /高久/多角/
たかくか /多角化/
たかくけい /多角形/
たかくすい /多角錐/
たかくすいだい /多角錐台/
たかくちゅう /多角柱/
たかくてき /多角的/
たかくら /高倉/高蔵/
たかくらけん /高倉健/
たかくらだい /高倉台/
たかくらやま /高倉山/
たかくわ /高鍬/高桑/
たかこ /貴子/孝子/多香子/敬子/多賀子/高子/堂子/隆子/
たかこう /高高/
たかこくご /多ヶ国語/多カ国語/
たかさ /高さ/
たかさか /高坂/
たかさき /高崎/
たかさきせいし /高崎製紙/
たかさきせん /高崎線/
たかさきせんほうめん /高崎線方面/
たかさきせんみやはら /高崎線宮原/
たかさきはまがわ /高崎浜川/
たかさきほうめん /高崎方面/
たかさご /高砂/
たかさごえきりようしゃ /高砂駅利用者/
たかさごかん /高砂間/
たかさごしゃこ /高砂車庫/
たかさごはつ /高砂発/
たかさと /高郷/
たかさわ /高沢/高澤/
たかざわ /高沢/
たかし /貴史/尚史/高志/喬/隆/孝/卓史/貴志/隆志/敬士/隆司/貴/恭士/敬/敬史/孝司/孝史/孝志/高士/尚/隆史/尚司/尚志/高史/岳史/貴司/洪/降/高/崇/崇史/大/高師/卓/隆資/貴士/高司/隆士/
たかしお /高潮/高汐/
たかしな /高品/高科/
たかしま /高嶋/高島/鷹島/
たかしまだいら /高島平/
たかしまだいらがわ /高島平側/
たかしまちょう /高島町/
たかしまや /高島屋/
たかしみず /高清水/
たかしろ /鷹城/
たかじょう /高城/
たかす /高須/高鷲/鷹栖/
たかすが /高須賀/
たかすぎ /高杉/
たかすぎしんさく /高杉晋作/
たかすみ /高住/
たかずみ /敬済/
たかせ /高瀬/
たかせい /多価性/
たかた /高田/田方/
たかたまゆこ /高田万由子/
たかだ /高田/
たかだい /高台/
たかだか /高々/
たかだかかさん /高々可算/
たかだし /高田市/
たかだて /高館/
たかだのばば /高田馬場/
たかだのばばえき /高田馬場駅/
たかだのばばしてん /高田馬場支店/
たかだのばばてん /高田馬場店/
たかだま /高玉/
たかちほ /高千穂/
たかちほかん /高千穂間/
たかちほきょう /高千穂峽/高千穂峡/
たかちほせん /高千穂線/
たかちほろんそう /高千穂論争/
たかっけい /多角形/
たかつ /高津/
たかつか /高塚/
たかつかこうこう /高塚高校/
たかつき /高槻/高月/
たかつきいとう /高槻以東/
たかつきし /高槻市/
たかつきしみん /高槻市民/
たかつきていしゃ /高槻停車/
たかつきてん /高槻店/
たかつく /高津区/
たかつぐ /高嗣/
たかとう /高遠/高藤/
たかとうりき /貴闘力/
たかとし /孝俊/隆俊/孝利/隆利/孝寿/
たかとび /高飛び/
たかとみ /孝富/高富/
たかとも /鷹友/
たかとり /高取/高鳥/
たかとりこうじょう /鷹取工場/
たかどの /楼/
たかな /高菜/
たかなお /高尚/高直/
たかなか /高中/
たかなし /高梨/
たかなべ /高鍋/
たかなみ /高波/高浪/
たかなわ /高輪/
たかなわぐち /高輪口/
たかに /高荷/
たかね /高値/高嶺/高根/
たかねきょうぞん /高値共存/
たかねざわ /高根沢/
たかの /高野/高乃/鷹野/
たかのがわ /高野川/
たかのす /鷹巣/
たかのせん /高野線/
たかのぞみ /高望み/
たかのつめ /鷹の爪/
たかのなみ /貴ノ浪/
たかのは /鷹羽/
たかのはな /貴ノ花/
たかのはら /高の原/
たかのばし /タカノ橋/
たかのふじ /孝乃富士/
たかのぶ /敬信/孝信/
たかのり /高徳/孝則/孝徳/隆則/孝憲/隆典/敬則/孝規/孝典/崇徳/
たかは /高羽/
たかはぎ /高萩/
たかはし /高橋/高梁/
たかはしけいこ /高橋恵子/
たかはしせいさくしょ /高橋製作所/
たかはしまりこ /高橋真梨子/
たかはしみちつな /高橋三千綱/
たかはた /高畑/高畠/
たかはたふどう /高幡不動/高畑不動/
たかはな /高鼻/
たかはなだ /貴花田/
たかはなだぜき /貴花田関/
たかはま /高浜/高濱/
たかはら /高原/
たかはる /高原/高春/
たかばたけ /高畠/
たかばやし /高林/
たかひこ /孝彦/貴彦/隆彦/高彦/
たかひさ /貴久/高尚/隆久/
たかひで /貴英/
たかひと /隆仁/隆人/貴仁/
たかひら /高比良/高平/
たかひろ /高宏/貴博/隆弘/孝広/貴広/貴裕/敬弘/高広/隆博/貴浩/孝浩/崇博/隆寛/隆宏/隆広/貴宏/隆啓/隆浩/孝宏/高裕/貴大/孝洋/
たかびしゃ /高飛車/
たかふみ /貴文/隆文/孝文/貴史/孝史/隆史/
たかべ /高部/
たかまがはら /高天原/
たかまさ /高政/隆政/隆征/孝昌/孝政/
たかまつ /高松/
たかまつえき /高松駅/
たかまつかん /高松間/
たかまつこう /高松港/
たかまつことひらてつどう /高松琴平鉄道/
たかまつし /高松市/
たかまつしない /高松市内/
たかまつしゅっしん /高松出身/
たかまつしょう /高松商/
たかまつじょう /高松城/
たかまつのみやはい /高松宮杯/高松宮盃/
たかまのはら /高天原/
たかまる /鷹丸/
たかみ /高見/孝美/
たかみさわ /高見沢/
たかみざわ /高見沢/
たかみす /高見州/
たかみすぎ /隆三杉/
たかみち /尊道/隆道/孝通/
たかみつ /貴光/隆充/
たかみね /高峰/嵩嶺/高嶺/
たかみねひでこ /高峰秀子/
たかみや /高宮/
たかむしろ /簟/
たかむね /高宗/
たかむら /高村/篁/
たかむらこうたろう /高村光太郎/
たかめ /高目/
たかもと /高本/
たかもり /高森/隆盛/鷹森/
たかもりかん /高森間/
たかや /隆也/高谷/隆弥/
たかやす /貴康/高安/
たかやなぎ /高柳/
たかやま /高山/鷹山/
たかやまかん /高山間/
たかやません /高山線/
たかやまちょう /高山町/
たかやまほうめん /高山方面/
たかやまほんせん /高山本線/
たかゆかしきえきしゃ /高床式駅舎/
たかゆき /高之/隆行/孝之/貴之/高行/孝行/隆之/孝幸/崇之/能之/隆幸/敬之/貴幸/尊之/崇行/高幸/貴行/
たかよし /孝義/隆吉/隆克/隆義/貴良/孝允/高好/高良/
たから /宝/寶/寳/財/
たからがいけ /宝が池/
たからくじ /宝くじ/
たからしゅぞう /宝酒造/寳酒造/
たからじま /宝島/
たからずか /宝塚/
たからずかきねんば /宝塚記念馬/
たからずかしょうじょかげき /宝塚少女歌劇/
たからずかだいげきじょう /宝塚大劇場/
たからだ /宝田/
たからだま /宝玉/
たからづか /宝塚/
たからづかおんせん /宝塚温泉/
たからづかかげき /宝塚歌劇/
たからづかきねん /宝塚記念/
たからづかきねんば /宝塚記念馬/
たからづかし /宝塚市/
たからづかしちょう /宝塚市長/
たからづかしょう /宝塚賞/
たからづかしょうじょかげき /宝塚少女歌劇/
たからづかせん /宝塚線/
たからづかせんぞい /宝塚線沿/
たからづかだいげきじょう /宝塚大劇場/
たからづかほうめん /宝塚方面/
たからづかみなみぐち /宝塚南口/
たからばこ /宝箱/
たからぶね /宝船/
たからべ /財部/
たからまち /宝町/
たからもと /宝本/
たからもの /宝物/
たかん /多感/多環/
たかんかくゆうごう /多感覚融合/
たかんきょうせい /多環境性/
たかんせだい /多感世代/
たかんせつ /多関節/
たかんちゅうしんちゅう /多環中心柱/
たが /多賀/箍/
たがい /互い/違い/互/
たがいしゃ /他会社/
たがいちがい /互い違い/
たがいに /互いに/
たがき /田垣/
たがぎ /高木/
たがく /多額/
たがくぶ /他学部/
たがじょう /多賀城/
たがじょうし /多賀城市/
たがじょうしやくしょ /多賀城市役所/
たがた /田方/
たがたぐん /田方郡/
たがっか /他学科/
たがね /鏨/
たがひ /違ひ/互/
たがみ /田上/
たがや /多賀谷/
たがりゅう /多賀竜/
たがわ /田川/多川/田河/
たがん /多眼/
たがんし /多眼視/
たがんしほう /多眼視法/
たき /滝/瀧/多岐/多紀/竜/瀑/多喜/多肢/
たきあせ /滝汗/
たきい /滝井/
たきいえき /滝井駅/
たきうち /瀧内/滝内/
たきお /滝尾/多喜夫/
たきかわ /滝川/瀧川/
たきかわえき /滝川駅/
たきかんけんきゅうしゃ /他機関研究者/
たきがわ /多岐川/滝川/瀧川/
たきぎ /薪/
たきぐち /瀧口/滝口/
たきさわ /滝澤/滝沢/
たきざわ /滝沢/滝澤/瀧沢/
たきざわりんどう /滝沢林道/
たきしーど /タキシード/
たきしゅ /他機種/多機種/
たきしゅよう /他機種用/
たきた /滝田/瀧田/
たきだ /瀧田/
たきだし /炊出し/炊き出し/
たきつぼ /滝壷/
たきとう /多気筒/
たきなみ /滝波/
たきね /滝根/
たきの /多喜乃/瀧野/滝野/
たきのう /多機能/他機能/
たきのうせい /多機能性/
たきのうでんわ /多機能電話/
たきのうぶんれつ /多機能分裂/
たきのがわ /瀧野川/
たきのがわじょがくえん /瀧野川女学園/
たきのがわじょしがくえん /瀧野川女子学園/
たきはら /滝原/
たきひろ /滝広/
たきび /焚火/焚き火/
たきもと /滝本/瀧本/
たきや /滝谷/
たきやま /瀧山/滝山/
たきゅう /田久/
たきゅうじょう /他球場/
たきゅうだん /他球団/
たきょう /他郷/田京/
たきょく /他局/多極/
たきょてん /他拠点/
たきれんたろう /滝廉太郎/
たぎ /多義/
たぎご /多義語/
たぎせい /多義性/
たぎてき /多義的/
たぎょう /タ行/
たぎょうしゅ /他業種/
たぎり /田切/
たく /濯/宅/託/拓/沢/琢/卓/鐸/択/啄/托/澤/倬/啅/戳/拆/擇/柝/謫/鈬/魄/柘/擢/度/
たくあき /卓明/
たくあん /沢庵/
たくい /宅井/
たくいつ /択一/
たくいつしき /択一式/
たくえつ /卓越/
たくお /卓雄/拓雄/卓夫/
たくき /琢己/
たくけい /磔刑/
たくさん /沢山/
たくし /卓史/拓志/
たくしー /タクシー/
たくしゅつ /卓出/
たくしょく /拓殖/
たくしょくだい /拓殖大/
たくしょくだいがく /拓殖大学/
たくしょくだいがくだいいちこうこう /拓殖大学第一高校/
たくしろう /卓四郎/
たくじ /卓治/託児/卓司/拓史/琢爾/卓爾/拓嗣/
たくじしせつ /託児施設/
たくじしょ /託児所/
たくじしょけん /託児所券/
たくじじょ /託児所/
たくじょう /卓上/
たくじょうがた /卓上型/
たくせつ /卓説/
たくせん /託宣/
たくせんしょ /託宣所/
たくぜつ /卓絶/
たくそう /託送/拓宋/
たくそうてにもつ /託送手荷物/
たくぞう /卓造/卓三/
たくだいいちこう /拓大一高/
たくち /宅地/
たくちなみかぜい /宅地並課税/
たくと /琢人/
たくないよう /宅内用/
たくはい /宅配/
たくはいきぼう /宅配希望/
たくはいそうりょうこみ /宅配送料込/
たくはいびん /宅配便/
たくはいびんぎょうしゃ /宅配便業者/
たくはいびんりょうきん /宅配便料金/
たくはつ /托鉢/
たくほん /拓本/
たくぼ /田窪/田久保/
たくぼく /啄木/
たくま /宅間/琢磨/託間/詫間/
たくまでんぱこうせん /詫間電波高専/
たくみ /匠/内匠/拓美/琢美/卓己/琢巳/巧/琢弥/
たくや /卓也/卓弥/拓也/琢也/拓哉/卓哉/
たくよう /托葉/
たくら /田倉/
たくろう /卓朗/拓郎/
たくわえ /蓄え/貯え/
たぐい /類/類い/疇/畴/
たぐす /田楠/
たぐち /田口/
たぐり /田栗/
たぐん /多群/
たけ /竹/茸/武/丈/健/岳/威/他家/毅/斌/雄/嶽/竹内/
たけい /武居/武井/多形/竹井/竹居/他系/
たけいし /武石/
たけいち /武市/武一/竹市/
たけいれつ /他系列/
たけうち /竹内/武内/
たけうちがいし /竹内外史/
たけうま /竹馬/
たけお /武雄/岳男/威雄/岳生/健夫/丈夫/竹生/竹男/竹尾/竹夫/竹雄/武男/武夫/毅雄/健郎/丈生/健生/武朗/
たけおおんせん /武雄温泉/
たけおか /竹岡/
たけおかせん /竹岡戦/
たけかず /丈和/
たけかわ /武川/竹川/
たけかんむり /竹冠/
たけがた /竹形/
たけがはら /竹ヶ原/
たけがり /茸狩/
たけがわ /竹河/
たけき /健樹/
たけくに /武邦/
たけぐち /竹口/
たけこし /竹腰/
たけさか /竹坂/
たけざわ /竹沢/竹澤/
たけし /猛/武志/毅/丈司/威/武/健/健志/剛/武司/岳史/剛史/武史/健史/竹志/武嗣/威志/英/岳/武士/剛志/武石/豪/丈史/
たけした /竹下/
たけしたけいこ /竹下景子/
たけしたのぼる /竹下登/
たけしば /竹芝/
たけしま /竹島/
たけしょぼう /竹書房/
たけじ /武治/
たけじろう /竹次郎/
たけすえ /武居/
たけぞえ /竹添/
たけぞの /竹園/
たけた /竹田/
たけたに /竹谷/
たけだ /武田/竹田/
たけだえき /竹田駅/
たけだけしい /猛々しい/
たけだけん /竹田研/
たけだし /竹田市/
たけだしんげん /武田信玄/
たけち /武智/武市/
たけつぐ /健嗣/
たけと /健人/丈人/岳人/竹人/
たけとし /武俊/壮聡/
たけとみ /武富/竹富/
たけとみじま /竹富島/
たけとも /斌友/
たけとよ /武豊/
たけとよせん /武豊線/
たけとよせんない /武豊線内/
たけとりものがたり /竹取物語/
たけなお /武直/
たけなか /竹中/武中/
たけなかこうむてん /竹中工務店/
たけなみ /竹並/
たけなり /丈成/雄成/
たけなわ /武縄/酣/闌/
たけの /竹野/武野/
たけのうち /竹之内/
たけのこ /竹の子/筍/笋/
たけのはま /竹野浜/
たけのぶ /健伸/武信/
たけのり /健雅/武憲/武範/
たけはし /竹橋/
たけはしかいかん /竹橋会館/
たけはな /竹花/
たけはら /竹原/武原/
たけはる /丈晴/毅治/
たけばし /竹橋/竹箸/
たけばやし /竹林/
たけひこ /武彦/竹彦/雄彦/建彦/剛彦/毅彦/
たけひご /竹籤/
たけひさ /竹久/武久/
たけひさゆめじ /竹久夢二/
たけひで /武英/武秀/
たけひと /武仁/武人/雄人/
たけひら /竹平/
たけひろ /雄洋/威裕/威博/竹広/武大/武裕/毅寛/
たけふ /武生/竹生/
たけふじ /武藤/
たけふみ /武文/
たけぶえ /竹笛/
たけべ /竹部/武部/建部/
たけぼうき /竹箒/
たけまえ /竹前/
たけまつ /竹松/
たけみ /武三/武見/
たけみつ /武満/竹光/
たけみや /武宮/竹宮/
たけむら /竹村/武村/
たけもち /威望/
たけもと /竹本/武本/武元/
たけもり /竹森/
たけや /武谷/竹屋/竹弥/
たけやぶ /竹薮/
たけやま /武山/竹山/
たけやり /竹槍/武鑓/
たけゆき /健幸/岳之/
たけよし /武吉/建美/
たけん /他県/
たけんきゅうしつ /他研究室/
たけんれん /他県連/
たげい /多芸/
たげいたさい /多芸多才/
たげん /多元/多言/他言/
たげんご /多言語/他言語/
たげんごたいおう /多言語対応/
たげんせい /多元性/
たげんてき /多元的/
たこ /蛸/凧/鮹/胝/胼胝/鱆/多古/
たこう /他校/多幸/多孔/多項/他行/
たこうかんれん /多項関連/
たこうしき /多項式/
たこうしきかいき /多項式回帰/
たこうしきかんすう /多項式関数/
たこうしきじかん /多項式時間/
たこうしきぶんるいき /多項式分類器/
たこうしつ /多孔質/
たこうしつざい /多孔質材/
たこうせい /他校生/
たこうせんこう /多孔穿孔/多孔せん孔/
たこうてい /多工程/
たこく /他国/
たこくご /多国語/
たこくごか /多国語化/
たこくごしよう /多国語使用/
たこくごたいおう /多国語対応/
たこくごばん /多国語版/
たこくごもじ /多国語文字/
たこくさん /他国産/
たこくせき /多国籍/他国籍/
たこくせききぎょう /多国籍企業/他国籍企業/
たこくせきぐん /多国籍軍/
たこくせきぐんがわ /多国籍軍側/
たこじま /蛸島/
たこのきもく /タコノキ目/Pandanales/
たこやき /蛸焼/
たご /田子/多湖/多胡/多語/
たごう /田郷;姓/
たごのうら /田子の浦/
たごん /他言/
たごんむよう /他言無用/
たさい /多彩/多才/
たさいと /他サイト/
たさいぼう /多細胞/
たさいぼうせいぶつ /多細胞生物/
たさいぼうもう /多細胞毛/
たさか /田坂/
たさき /田崎/
たさくひん /他作品/
たさつ /他殺/
たさん /多産/
たざき /田崎/
たざけ /田酒/
たざせき /多座席/
たざわ /田澤/田沢/
たざわこ /田沢湖/
たざわこせん /田沢湖線/
たざわこはん /田沢湖畔/
たざわぬま /田沢沼/
たざん /他山/
たし /足し/多肢/他紙/他誌/多指/
たしか /確か/
たしかに /確かに/
たしこむ /足し込む/
たしざん /足し算/足算/
たしせいせい /多士済済/
たしつ /多湿/咤叱/
たしてん /多視点/
たしま /田嶋/
たしゃ /他社/他者/他車/多謝/
たしゃかん /他社間/
たしゃく /他借/
たしゃせい /他社製/他者性/
たしゃせいひん /他社製品/
たしゃせん /他社線/
たしゃせんはっちゃく /他社線発着/
たしゃせんれんらく /他社線連絡/
たしゃびん /他社便/
たしゅ /多種/他種/
たしゅう /他州/
たしゅうだん /他集団/
たしゅたよう /多種多様/
たしゅたようたいりょう /多種多様大量/
たしゅつ /他出/
たしゅつりょく /多出力/
たしゅみ /多趣味/
たしゅるい /多種類/
たしょ /他所/他書/他諸/
たしょう /多少/他称/多祥/多生/
たしょうえいきょう /多少影響/
たしょうかいぜん /多少改善/
たしょうきょうみ /多少興味/
たしょうちんせいか /多少鎮静化/
たしょうてま /多少手間/
たしょうなん /多少難/
たしょうふあん /多少不安/
たしょうふぐあい /多少不具合/
たしょうふべん /多少不便/
たしょうむり /多少無理/
たしょうろうきゅうか /多少老朽化/
たしょく /多色/
たしょくか /多色化/
たしょくずり /他色刷/多色刷/
たしろ /田代/
たしろいりぐち /田代入口/
たしん /多芯/
たしんぎ /多進木/
たしんぴ /多心皮/
たしんぴるい /多心皮類/Polycarpicae/
たじ /他事/多事/
たじか /田近/
たじげん /多次元/
たじげんか /多次元化/
たじげんしゃくどこうせいほう /多次元尺度構成法/
たじげんてき /多次元的/
たじげんはいれつ /多次元配列/
たじつ /他日/
たじま /田島/田嶋/但馬/田嶌/
たじまちほう /但馬地方/
たじみ /多治見/
たじゅう /多重/
たじゅういみこうぞう /多重意味構造/
たじゅうおん /多重音/
たじゅうか /多重化/
たじゅうかいぞうどかいせき /多重解像度解析/
たじゅうがぞう /多重画像/
たじゅうがぞうしょり /多重画像処理/
たじゅうけいしょう /多重継承/
たじゅうけつごう /多重結合/
たじゅうこ /多重呼/
たじゅうさんらん /多重散乱/
たじゅうしてん /多重視点/
たじゅうしょり /多重処理/
たじゅうじんかく /多重人格/
たじゅうじんかくしゃ /多重人格者/
たじゅうせい /多重性/
たじゅうせきぶん /多重積分/
たじゅうたんし /多重端子/
たじゅうていぎ /多重定義/
たじゅうど /多重度/
たじゅうどきごう /多重度記号/
たじゅうは /多重波/
たじゅうひょうじ /多重表示/
たじゅうほうそう /多重放送/
たじゅうよびだし /多重呼出し/
たじゅうろくおん /多重録音/
たじゅうろこう /多重露光/
たじゅうろしゅつきこう /多重露出機構/
たじゆうど /多自由度/
たじょう /多情/
たじょうけん /他条件/
たじょうほう /他情報/
たじり /田尻/
たじん /多人/
たじんかくしゃ /多人格者/
たす /足す/＋/
たすいいき /他水域/
たすう /多数/
たすういけん /多数意見/
たすううんてん /多数運転/
たすうおうぼ /多数応募/
たすうか /多数花/
たすうかい /多数回/
たすうがわ /多数側/
たすうけつ /多数決/
たすうけつげんり /多数決原理/
たすうこ /多数個/
たすうごい /多数語彙/
たすうごおうぼ /多数御応募/
たすうさんか /多数参加/
たすうしゅう /多数集/
たすうしよう /多数使用/
たすうそんざい /多数存在/
たすうだい /多数台/
たすうてん /多数点/
たすうとう /多数党/
たすうとうろく /多数登録/
たすうは /多数派/
たすうはいび /多数配備/
たすうはこうさく /多数派工作/
たすうはっせい /多数発生/
たすうらんりつ /多数乱立/
たすき /襷/
たすきがけ /襷掛け/
たすきぞり /襷反り/
たすく /匡/相/輔/佑/弼/
たすけ /助け/太助/多助/
たすけあい /助け合い/
たせいぶん /多成分/
たせん /他薦/
たせんく /他線区/
たせんりゃくがくしゅう /多戦略学習/
たぜい /多勢/
たそーと /多ソート/
たそう /多相/多層/
たそうがた /多相型/
たそうきばん /多層基板/
たそうこうぞう /多層構造/
たそうこうぞうなべ /多層構造鍋/
たそうしき /多層式/
たそうせい /多相性/
たそうてき /多相的/
たそうなべ /多層鍋/
たそうひょうひ /多層表皮/
たそがれ /黄昏/
たそく /多足/
たそしき /他組織/
たぞえ /田添/
たた /多々/
たたい /多体/多態/田多井/田々井/
たたいいち /多対一/
たたいけい /多体系/
たたいた /多対多/
たたいもんだい /多体問題/
たたかい /戦い/
たたき /三和土/
たたきあげ /叩き上げ/
たたきだい /叩き台/
たたすく /他タスク/
たたど /多々戸/
たたに /田谷/
たたません /田玉線/
たたみ /疊/畳/疉/疂/
たたみこみ /畳み込み/
たたみじき /畳敷/
たたみはんぶん /畳半分/
たたみべや /畳部屋/
たたみま /畳間/
たたら /踏鞴;踏んで使うふいご。/多々良/多田羅/蹈鞴/タタラ/
たたり /祟/
たたん /他端/多端/
たたんし /多端子/
ただ /多田/只/唯/忠/正/惟/但/維/匡/無料/伊/
ただあき /理顕/忠明/
ただい /多大/他大/
ただいがく /他大学/
ただいま /只今/ただ今/唯今/
ただいまさんじょう /只今参上/
ただお /忠男/忠夫/忠雄/維男/
ただおか /忠岡/
ただおき /忠興/
ただき /只木/但木/
ただくま /只熊/
ただけん /只券/
ただごと /唯事/
ただし /但し/正/匡史/忠/忠司/忠志/直/貞/尚志/匡/忠史/理/惟史/禎/是/
ただしがき /但書/
ただしく /正しく/
ただす /匡/
ただせん /太多線/
ただたか /匡孝/
ただち /直/
ただちに /直ちに/
ただとし /忠利/正利/
ただなか /只中/
ただの /只野/唯野/
ただのぶ /忠信/
ただのり /忠則/匡孝/
ただはる /忠治/
ただひこ /忠彦/伊彦/
ただひさ /正久/
ただひとつ /唯一つ/
ただひとり /唯一人/
ただひら /忠平/
ただひろ /忠宏/忠浩/忠弘/忠博/忠広/
ただふみ /忠文/能文/
ただまさ /忠正/
ただみ /只見/只見線/
ただみせん /只見線/
ただみち /直道/忠道/
ただもと /忠元/
ただもの /只者/
ただや /多田屋/
ただゆき /忠行/忠幸/
ただよし /忠義/忠央/忠良/忠儀/
ただれいこ /多田麗子/
ただわか /唯若/
ただん /多段/
ただんかい /多段階/
ただんしよう /多段使用/
ただんたい /他団体/
ただんちょうり /多段調理/
ただんとう /多弾頭/
ただんれんさ /多段連鎖/
たち /達/立/舘/多値/太刀/館/逹/性質/質/城/大刀/
たちあい /立合/立ち会い/立会/立ち合い/
たちあいがわ /立会川/
たちあいにん /立会人/
たちあがり /立ち上がり/立上り/
たちあがりじかん /立ち上がり時間/
たちあげ /立ち上げ/
たちあらい /大刀洗/
たちい /立ち居/立居/起ち居/
たちいき /他地域/
たちいふるまい /立居振舞/
たちいり /立ち入り/立入る/立入/
たちいりきんし /立入禁止/
たちいりきんしばしょ /立入禁止場所/
たちいりけんさ /立入検査/
たちうお /太刀魚/
たちうち /太刀打ち/
たちうり /立売/
たちおうじょう /立往生/立ち往生/
たちかけ /太刀掛/太刃掛/
たちかわ /立川/太刀川/
たちかわいき /立川行/
たちかわえき /立川駅/
たちかわし /立川市/
たちかわじょし /立川女子/
たちかわぶんこ /立川文庫/
たちかわほうめん /立川方面/
たちかわゆき /立川行/
たちかんすう /多値関数/
たちがみ /舘上/
たちき /立木/
たちぎ /立木/
たちぎえ /立ち消え/
たちぎき /立ち聞き/
たちく /他地区/
たちぐい /立ち食い/
たちぐいそば /立ち食いそば/
たちさがり /立ち下がり/
たちざわ /立澤/立沢/
たちせきじょうしゃ /立席乗車/
たちせきとっきゅうけん /立席特急券/
たちてんつうしん /多地点通信/
たちはら /立原/
たちば /立場/
たちばじょう /立場上/
たちばじょうゆうり /立場上有利/
たちばな /橘/立花/
たちばなし /立ち話/
たちばなわん /橘湾/
たちひ /立飛/
たちまち /立町/立待ち/忽/怱ち/
たちみ /立ち見/立見/
たちみけん /立見券/
たちみせき /立見席/
たちもり /館盛/
たちや /達谷/
たちやく /立役/
たちよみ /立読み/
たちより /立ち寄り/
たちろんり /多値論理/
たっかん /達観/
たっきゅう /卓球/宅急/
たっきゅうびん /宅急便/
たっきゅうぶ /卓球部/
たっけい /磔刑/
たっけん /卓見/宅建/
たっけんぎょう /宅建業/
たっし /達し/
たっしゃ /達者/
たっせい /達成/
たっせいかのう /達成可能/
たっせいかん /達成感/
たっせいしゃ /達成者/
たっせいど /達成度/
たっせいりつ /達成率/
たった /立田/
たっち /タッチ/
たっちゅう /塔頭/
たっぴ /竜飛/
たっぴかいていえき /竜飛海底駅/
たっぴつ /達筆/
たっぴみさき /竜飛岬/
たつ /達/辰/龍/立/竜/逹/撻/燵/闥/韃/斬/立つ/
たつあき /達明/
たついち /辰一/
たつお /達夫/龍雄/達男/達雄/辰男/辰夫/辰雄/竜夫/竜雄/立雄/龍男/龍夫/竜生/達郎/
たつおか /龍岡/竜岡/立岡/
たつおかもん /竜岡門/龍岡門/
たつおき /辰興/
たつかわ /達川/立川/
たつき /立木/
たつきち /辰吉/
たつきよ /達清/
たつくち /辰口/
たつぐち /辰口/
たつごう /竜郷/
たつし /達志/辰史/達史/
たつしま /立嶋/
たつじ /達司/龍司/達治/辰司/辰二/
たつじん /達人/
たつた /龍田/立田/
たつたあげ /竜田揚げ/
たつたか /辰敬/
たつとし /達利/達俊/
たつどし /辰年/
たつなみ /立浪/
たつなみべや /立浪部屋/
たつなり /達就/
たつにしき /龍錦/
たつの /竜野/龍野/辰野/
たつのくち /辰口/竜ノ口/
たつのくちちょう /辰口町/
たつのくちまち /辰口町/
たつのちょう /辰野町/
たつのにし /竜野西/
たつのり /辰則/達就/辰徳/達徳/辰範/
たつひこ /達彦/龍彦/
たつひろ /達弘/
たつぶん /達文/
たつま /竜馬/辰馬/
たつまき /竜巻/
たつみ /巽/立見/辰爾/辰巳/辰己/竜実/
たつみしゅっぱん /辰巳出版/
たつや /達也/龍也/竜也/立矢/達哉/辰哉/辰也/立哉/
たつやま /龍山/竜山/
たつゆき /達行/達之/
たつるはま /田鶴浜/
たつろう /達郎/達朗/
たつんど /達人/
たづこ /田鶴子/
たづな /手綱/覊/
たて /縦/立/竪/│/盾/舘/館/楯/建/┃/縱/蓼/殺陣/
たてあき /賢明/
たていし /立石/建石/
たていしでんき /立石電機/
たていち /縦位置/
たていちよう /縦位置用/
たていちれつ /縦一列/
たていと /縦糸/經/
たていわ /館岩/
たてうち /館内/舘内/
たてうま /立馬/
たてうり /建売り/
たてお /建夫/建郎/
たておか /楯岡/
たておき /縦置/
たてかえ /立替/建替/
たてかえきん /立替金/
たてかた /立て方/
たてかわ /立川/
たてかん /立看/立て看/
たてかんばん /立看板/
たてがき /縦書き/
たてがた /縦型/
たてがたしんごう /縦形信号/
たてがたせいまいき /縦型精米機/
たてがみ /鬣/
たてがめん /縦画面/
たてき /建樹/
たてぎょうじ /立行司/
たてぐ /建具/
たてけい /縦系/
たてけいしき /縦形式/
たてこう /竪坑/
たてこし /館腰/
たてごと /竪琴/
たてさわ /立澤/
たてし /殺陣師/
たてしな /蓼科/立科/
たてしなやま /蓼科山/
たてしんどう /縦振動/
たてじく /縦軸/
たてじま /縦縞/
たてじょう /楯状/
たてじょうよう /楯状葉/
たてすじ /縦筋/
たてせん /縦線/｜/│/
たてつけ /立付け/建付/
たてつぼ /建坪/
たてなが /縦長/
たてなががめん /縦長画面/
たてながたんまつ /縦長端末/
たてながへんけいばん /縦長変形版/
たてながようし /縦長用紙/
たてなみ /縦波/
たての /立野/館野/舘野/
たてのだい /立野台/
たてはば /縦幅/
たてはら /立原/
たてばい /縦倍/
たてばいかく /縦倍角/
たてばやし /館林/
たてばやしし /館林市/
たてひこ /建彦/
たてふ /縦歩/
たてふだ /立札/立て札/
たてぶえ /縦笛/
たてべ /建部/
たてほうこう /縦方向/
たてほり /縦堀/
たてぼう /縦棒/｜/
たてまえ /建前/立前/
たてまえじょう /建前上/
たてまえろん /建前論/
たてまさ /建正/
たてまし /建増し/建て増し/
たてまち /立町/
たてまつ /立松/
たてむら /舘村/
たてめ /縦目/
たてもの /建物/
たてものじたい /建物自体/
たてものない /建物内/
たてものないぶ /建物内部/
たてもよう /縦模様/
たてや /建屋/
たてやくしゃ /立役者/
たてやない /建屋内/
たてやま /立山/館山/楯山/
たてやまさぼうてつどう /立山砂防鉄道/
たてやまさんろく /立山山麓/
たてやまでらおんせん /舘山寺温泉/
たてやまふきん /館山付近/
たてやまわん /館山湾/
たてよこ /縦横/
たてよここんざい /縦横混在/
たてよこひ /縦横比/
たてわき /帯刀/
たてわり /縦割り/
たてわりぎょうせい /縦割行政/
たてん /多点/他店/
たてんせいぎょ /多点制御/
たで /蓼/
たでか /タデ科/
たでもく /タデ目/Polygonales/
たとうしょうめい /多灯照明/
たとうすう /多頭数/
たとうはっこう /多灯発光/
たとえ /例え/喩え/譬え/
たとえば /例えば/
たとえばなし /例え話/
たとへば /例へば/
たとみ /田富/
たど /多度/
たどうし /他動詞/
たどうしもくてきご /他動詞目的語/
たどうてき /他動的/
たどうろ /他道路/
たどころ /田所/
たどつ /多度津/
たどつえき /多度津駅/
たどつかん /多度津間/
たどつこうじょう /多度津工場/
たどつふきん /多度津付近/
たどん /炭団/
たな /棚/柵/店/
たなあげ /棚上げ/
たなあみ /田名網/
たないた /棚板/
たなうえ /棚上/
たなえ /田苗/
たなおろし /棚卸し/
たなおろししさん /棚卸資産;流動資産の1つ/たな卸資産/
たなか /田中;姓/田仲;姓/
たなかかくえい /田中角栄;人名/
たなかきぬよ /田中絹代;人名/
たなかしゅしょう /田中首相/
たなかだて /田中館/
たなき /棚木/
たなくら /棚倉/
たなぐら /棚倉/
たなこ /店子/
たなごころ /掌/
たなざわ /棚沢/
たなし /田無/
たなだ /棚田/
たなはし /棚橋/
たなばた /七夕/
たなばたさま /七夕様/
たなばたしょう /七夕賞/
たなべ /田辺/田邉/
たなべせいやく /田辺製薬/
たなみ /棚見/
たなん /多難/
たに /谷/渓/溪/峪/谿/
たにあし /谷脚/
たにあしかじゅう /谷足加重/
たにい /谷井/溪井/
たにうち /谷内/
たにえ /谷江/
たにえき /谷駅/
たにおおつか /谷大塚/
たにおか /谷岡/
たにかわ /谷川/
たにかわしゅんたろう /谷川俊太郎/
たにがき /谷垣/
たにがみ /谷上/
たにがわ /谷川/谷側/谿/
たにがわごう /谷川号/
たにがわだけ /谷川岳/
たにがわだけてんじんだいら /谷川岳天神平/
たにく /多肉/
たにくけい /多肉茎/
たにくふじつかちょう /谷区藤塚町/
たにぐち /谷口/
たにぐみ /谷汲/
たにざき /谷崎/
たにざわ /谷沢/
たにし /田螺/
たにしげ /谷繁/
たにじま /谷島/
たにすじ /谷筋/
たにせ /谷瀬/
たにぞこ /谷底/
たにた /谷田/
たにだ /谷田/
たにの /谷野/
たにはら /谷原/
たにふじ /谷藤/
たにま /谷間/渓間/
たにまち /谷町/
たにまちきゅうちょうめ /谷町九丁目/
たにまちせん /谷町線/
たにむら /谷村/
たにむらしんじ /谷村新司/
たにむらゆみ /谷村有美/
たにもと /谷本/
たにやま /谷山/
たにゅうりょく /多入力/
たにわき /谷脇/
たにん /他人/
たにんぎょうぎ /他人行儀/
たにんごと /他人事/
たにんさま /他人様/
たにんしほん /他人資本;負債/
たにんずう /多人数/
たにんずうどうじ /多人数同時/
たにんずうよう /多人数用/
たにんどうし /他人同士/
たにんどん /他人丼/
たにんめいぎ /他人名義/
たぬき /狸/田貫/貍/
たぬきおしょう /狸和尚/
たぬきこうじ /狸小路/
たぬきざか /狸坂/
たぬきじる /狸汁/
たぬま /田沼/
たね /種/種子/多根/胤/
たねあかし /種明し/
たねあき /種明/
たねいち /種市/
たねうし /種牛/
たねうま /種馬/
たねおみ /種臣/
たねがしま /種子島/
たねぎれ /種切れ/
たねつけりょう /種付料/
たねとし /種敏/
たねび /種火/
たねほん /種本/
たねまき /種まき/種蒔き/
たねむら /種村/
たねん /多年/
たねんせい /多年性/
たねんせいそうほん /多年性草本/
たねんそう /多年草/
たの /多野/田野/他の/
たのう /多能/
たのうえ /田上/
たのうら /田浦/
たのしさ /愉しさ/
たのしそう /楽しそう/
たのしみ /楽しみ/愉しみ/
たのしみかた /楽しみ方/
たのなか /田野中/
たのはた /田野畑/
たはた /田畑/
たはつ /多発/
たはら /田原/
たば /束/田場/他馬/
たばい /多売/
たばいちょう /多倍長/
たばいちょうえんざん /多倍長演算/
たばいと /多バイト/
たばこ /煙草/タバコ/莨/
たばこきょうかい /煙草協会/
たばこしょうひりょう /煙草消費量/
たばこちゅうどく /煙草中毒/
たばこや /煙草屋/
たばた /田畑/田端/太幡/
たばたかん /田端間/
たばやま /丹波山/
たばら /田原/
たばる /田原/
たばるざか /田原坂/
たひら /田平/
たひんしゅ /多品種/
たひんど /多頻度/
たび /度/旅/足袋/
たびげいにん /旅芸人/
たびさき /旅先/
たびじ /旅路/
たびたび /度々/
たびだち /旅立ち/
たびびと /旅人/
たびょういん /他病院/
たびら /田平/
たふ /佗負/
たふけん /他府県/
たぶ /タブ/椨/他部/
たぶー /タブー/
たぶきょく /他部局/
たぶしょ /他部署/他部所/
たぶせ /田布施/
たぶち /田渕/田淵/
たぶふ /タブ譜/
たぶぶん /他部分/
たぶもん /他部門/
たぶん /多分/他聞/多聞/
たぶんか /他文化/
たぶんかい /多分解/
たぶんぎ /多分木/
たぶんだいじょうぶ /多分大丈夫/
たぶんむり /多分無理/
たぶんや /多分野/他分野/
たぶんわたし /多分私/
たへんすう /多変数/
たへんすうかいせき /多変数解析/
たへんすうかんすう /多変数関数/
たへんりょう /多変量/
たへんりょうかいせき /多変量解析/
たべ /多辺/田部/
たべかた /食べ方/
たべのこし /食べ残し/
たべほうだい /食べ放題/
たべもの /食べ物/食物/
たべん /多弁/
たほう /他方/多峰/
たほうめん /多方面/
たぼ /髱/
たぼう /多忙/
たぼうちゅう /多忙中/
たま /玉/多摩/弾/球/珠/珪/田万/彈/霊/靈/
たまい /玉井/
たまいれ /玉入れ/
たまえ /玉恵/
たまお /玉緒/
たまおき /玉置/
たまかし /玉柏/
たまかしき /玉貸機/
たまかず /玉数/
たまかずら /玉鬘/
たまかわ /玉川/
たまがわ /玉川/多摩川/田万川/
たまがわえん /多摩川園/
たまがわがくえん /玉川学園/
たまがわきょうりょう /多摩川橋梁/
たまがわぐち /玉川口/
たまがわさきこ /玉川沙巳子/
たまがわじぎょうしょ /多摩川事業所/
たまがわじょうすい /玉川上水/
たまがわせいがくいん /玉川聖学院/
たまがわせん /玉川線/多摩川線/
たまがわだい /玉川大/
たまがわだいがく /玉川大学/
たまがわだいこう /玉川大工/
たまがわてっきょう /多摩川鉄橋/
たまき /玉木/環/玉置/玉城/
たまきゅうりょう /多摩丘陵/
たまく /多摩区/
たまぐすく /玉城/
たまこし /玉越/
たまご /卵/玉子/
たまごがた /卵型/
たまごやき /卵焼/卵焼き/
たまごりょうり /卵料理/
たまさと /玉里/
たまさぶろう /玉三郎/
たまし /多摩市/
たましい /魂/
たましま /玉島/
たまじゃり /玉砂利/
たますじ /玉筋/球筋/
たません /多摩線/
たまたいしょう /玉大賞/
たまたま /偶々/偶/
たまだ /玉田/
たまだい /多摩大/
たまち /田町/
たまちいき /多摩地域/
たまちえき /田町駅/
たまちえきひがしぐち /田町駅東口/
たまちく /多摩地区/
たまちでんしゃく /田町電車区/
たまつき /玉突き/玉突/
たまつきてき /玉突的/
たまつくり /玉造/
たまつくりぐん /玉造郡/
たまつつみ /玉堤/
たまてばこ /玉手箱/
たまな /玉名/
たまなわ /玉縄/玉那覇/
たまねぎ /玉葱/タマネギ/
たまの /玉野/
たまのうら /玉之浦/
たまのお /玉の緒/
たまのこし /玉の輿/
たまのし /玉野市/
たまはら /玉原/
たまひめ /玉姫/
たまひめさま /玉姫様/
たまほ /玉穂/
たまほり /玉堀/
たままき /玉牧/
たまみ /珠美/
たまむし /玉虫/
たまむしいろ /玉虫色/
たまむら /玉村/
たまもと /玉本/
たまもの /賜物/賜/賚/
たまや /玉屋/
たまやま /玉山/
たまゆ /玉湯/
たまよ /多満代/たま代/
たまり /玉利/溜/澑/玉里/
たまりくうんきょく /多摩陸運局/
たまる /田丸/
たみ /民/多美/
たみあき /民朗/
たみえ /民江/
たみお /民男/民雄/民夫/
たみおか /民岡/
たみき /民喜/
たみくさ /民草/
たみこ /たみ子/
たみや /田宮/
たみやじろう /田宮二郎/
たみんぞく /多民族/
たむら /田村/田邑/
たむろ /屯/
ため /為/溜/澑/爲/
ためいき /溜息/ため息/溜め息/
ためいけ /溜め池/溜池/
ためいけえき /溜池駅/
ためいけかん /溜池間/
ためいけこうさてん /溜池交差点/
ためいけふきん /溜池付近/
ためうち /溜め撃ち/
ためきよ /為清/
ためぐち /タメ口/
ためし /試し/例/樣/
ためしげ /爲成/
ためす /試す/
ためひろ /為広/
ためん /多面/他面/
ためんせい /多面性/
ためんたい /多面体/
ためんてき /多面的/
たも /玉網/
たもがわ /田茂川/
たもくてき /多目的/
たもくてきこうしゅうしつ /多目的講習室/
たもくてきしつ /多目的室/
たもつ /保/
たもと /田本/袂/
たもやちだけ /田茂谷地岳/
たもり /タモリ/田森/田守/
たもん /多聞/大紋/
たや /田谷/多屋/
たやま /田山/
たゆ /斬/
たゆう /太夫/大夫/大輔/
たよう /多様/多用/
たようか /多様化/
たようがた /多様型/
たようせい /多様性/多用性/
たようたい /多様体/
たより /便り/
たら /鱈/膤/鰔/太良/
たらい /盥/
たらぎ /多良木/
たらこ /鱈子/
たらじる /鱈汁/
たらま /多良間/
たらみ /多良見/
たらみちょう /多良見町/
たりき /他力/
たりきほんがん /他力本願/
たりきほんがんじ /他力本願寺/
たりきほんがんてき /他力本願的/
たりつ /他律/
たりつてき /他律的/
たりゅうし /多粒子/
たりゅうど /多粒度/
たりょう /多量/
たりょういき /他領域/
たりんか /多輪花/
たる /樽/
たるい /垂井/
たるがた /樽型/
たるき /椽/榱/
たるなま /樽生/
たるほ /足穂/
たるみ /垂水/弛み/
たるみく /垂水区/
たるみず /垂水/
たるみずえき /垂水駅/
たるみずし /垂水市/
たれ /垂れ/誰/
たれいしき /他励式/
たれつ /多列/
たれつき /タレ付き/
たれつほうしゃそしき /多列放射組織/
たれまく /垂幕/垂れ幕/
たれみず /垂水/
たれんと /タレント/
たろう /太郎/太朗/太良/多郎/田老/
たろうかじゃ /太郎冠者/
たろせん /他路線/
たわ /嵶/
たわー /タワー/
たわい /他愛/
たわごと /戯言/
たわし /束子/
たわだいら /多和平/
たわむれ /戯/
たわら /俵/田原/太原/
たわらまち /俵万智/
たわらまちおおくさ /田原町大草/
たん /単/短/端/旦/誕/反/淡/鍛/丹/探/綻/担/胆/炭/蛋/耽/坦/箪/湛/歎/嘆/疸/亶/啖/啗/單/彖/慱/憚/憺/擔/摶/攤/槫/殫/毯/湍/潭/澹/猯/痰/眈/站/緞/膽/袒/襌/褝/覃/譚/賺/鄲/酖/靼/餤/檀/但/椴/堪/貪/
たん> /短/
たん? /短/
たんあな /単穴/
たんい /単位/單位/単為/
たんいえん /単位円/
たんいえんない /単位円内/
たんいえんばん /単位円板/
たんいかんきょう /単位環境/
たんいきゅう /単位球/
たんいぎょうれつ /単位行列/
たんいけい /単位系/
たんいげん /単位元/
たんいしつりょう /単位質量/
たんいしゃぞう /単位写像/
たんいじかん /単位時間/
たんいじかんない /単位時間内/
たんいじげん /単位次元/
たんいすう /単位数/
たんいせつ /単位節/
たんいたいせき /単位体積/
たんいち /単一/
たんいちかんでんち /単一乾電池/
たんいちでんち /単一電池/
たんいちょう /単位長/
たんいつ /単一/
たんいつか /単一化/
たんいつかし /単一化子/
たんいつけいしょう /単一継承/
たんいつけいちょう /単一茎頂/
たんいつさいぼう /単一細胞/
たんいつたい /単一体/
たんいつだいにゅう /単一代入/
たんいつだいにゅうそく /単一代入則/
たんいでんち /単位電池/
たんいにんてい /単位認定/
たんいはんぐん /単位半群/
たんいふ /単位符/
たんいふごう /単位符号/単位符合/
たんいめんせき /単位面積/
たんいようりょう /単位容量/
たんいりったいかく /単位立体角/
たんいりょう /単位量/
たんおん /単音/短音/
たんおんかい /短音階/
たんおんせつ /単音節/
たんおんせつめいりょうど /単音節明瞭度/
たんおんせつめいりょうどしけん /単音節明瞭度試験/
たんおんせつめいりょうどしけんけっか /単音節明瞭度試験結果/
たんか /単価/短歌/担架/炭化/啖呵/譚歌/単果/單價/
たんかー /タンカー/
たんかか /単花果/
たんかく /短角/
たんかだいがく /単科大学/
たんかひ /単花被/
たんかひるい /単花被類/Monochlamydeae/
たんかん /単漢/単館/胆管/
たんかんきょう /単環境/
たんかんじ /単漢字/
たんかんじじしょ /単漢字辞書/
たんかんじへんかん /単漢字変換/
たんかんじょうえい /単館上映/
たんがん /単眼/嘆願/歎願/
たんがんきょう /単眼鏡/
たんがんし /単眼視/
たんがんしほう /単眼視法/
たんがんしょ /嘆願書/
たんがんてき /単眼的/
たんき /短期/短気/単騎/単記/単機/
たんきかりいれきん /短期借入金/
たんきかん /短期間/
たんきかんじゅう /短機関銃/
たんききおく /短期記憶/
たんきぎょう /単企業/
たんきけっせん /短期決戦/
たんきこうげき /単機攻撃/
たんきしゅ /単機種/
たんきしゅうちゅう /短期集中/
たんきしゅうちゅうがた /短期集中型/
たんきしゅうちゅうこうざ /短期集中講座/
たんきしゅうちゅうれんさい /短期集中連載/
たんきじょうたつほう /短期上達法/
たんきせいけん /短期政権/
たんきたいざい /短期滞在/
たんきだいがく /短期大学/
たんきだいがくせい /短期大学生/
たんきだいがくぶ /短期大学部/
たんきてき /短期的/
たんきとう /単気筒/
たんきのう /単機能/
たんきひこうちゅう /単機飛行中/
たんきゃく /単脚/
たんきゅう /探究/探求/単球/
たんきゅうしゃ /探究者/探求者/
たんきゅうしん /探究心/
たんきょく /端局/単極/
たんきょり /短距離/単距離/
たんきょりけっとう /短距離血統/
たんきょりじょうしゃ /短距離乗車/
たんきょりせんもん /短距離専門/
たんきょりそうしゃ /短距離走者/
たんきょりば /短距離馬/
たんきょりらんなー /短距離ランナー/
たんきょりろせん /短距離路線/
たんきれんさい /短期連載/
たんきん /単金/
たんぎょく /単玉/
たんく /タンク/短躯/
たんくかん /短区間/
たんくかんしょり /短区間処理/
たんくかんしんぷく /短区間振幅/
たんくかんまど /短区間窓/
たんぐすてん /タングステン/
たんぐつ /単靴/
たんけい /短形/
たんけいこうへきいけいさいぼう /短形厚壁異形細胞/
たんけん /探検/探険/短剣/
たんけんたい /探険隊/探検隊/
たんけんちゅう /探検中/
たんけんてき /探検的/
たんけんふ /†/‡/短剣符/
たんけんぶ /探検部/
たんげ /丹下/
たんげい /端倪/
たんげん /単元/
たんげんしぶんし /単原子分子/
たんこう /単項/炭坑/単行/炭鉱/短光/炭鑛/鍛工/単孔/単溝/鍛鋼/単鉤/単向/
たんこうえんざん /単項演算/
たんこうえんざんし /単項演算子/
たんこうがた /単溝型/
たんこうしき /単項式/
たんこうてつどう /炭坑鉄道/
たんこうほんみしゅうろく /単行本未収録/
たんこうぼん /単行本/
たんこうぼんか /単行本化/
たんこうぼんけいしき /単行本形式/
たんこうぼんしゅうにゅう /単行本収入/
たんこうぼんみしゅうろく /単行本未収録/
たんこうるい /単孔類/
たんこうろうどうしゃ /炭鉱労働者/
たんころ /単コロ/
たんこんたい /担根体/
たんご /単語/丹後/端午/
たんごおんせい /単語音声/
たんごおんせいにんしき /単語音声認識/
たんごかん /単語間/
たんごかんくうはく /単語間空白/
たんごしゅう /単語集/
たんごすう /単語数/
たんごぜんたい /単語全体/
たんごたんい /単語単位/
たんごちく /丹後地区/
たんごちょう /単語帳/
たんごていぎ /単語定義/
たんごとうろく /単語登録/
たんごとうろくきどう /単語登録起動/
たんごない /単語内/
たんごにんしき /単語認識/
たんごにんしきりつ /単語認識率/
たんごはんとう /丹後半島/
たんごひょう /単語表/
たんごへんかん /単語変換/
たんごりょく /単語力/
たんさ /探査/
たんさい /淡彩/
たんさいぼう /単細胞/
たんさいぼうこうぼ /単細胞酵母/
たんさいぼうせいぶつ /単細胞生物/
たんさいぼうてき /単細胞的/
たんさいぼうもう /単細胞毛/
たんさき /探査機/
たんさく /探索/探策/
たんさくきのう /探索機能/
たんさくぎ /探索木/
たんさくくうかん /探索空間/
たんさくけいろ /探索経路/
たんさくこうりつ /探索効率/
たんさくせんりゃく /探索戦略/
たんさくてき /探索的/
たんさくはんい /探索範囲/
たんさくほう /探索法/
たんさくほうこう /探索方向/
たんさくほうしん /探索方針/
たんさくほうほう /探索方法/
たんさわこ /丹沢湖/
たんさん /炭酸/単三/
たんさんいり /炭酸入/
たんさんいんりょう /炭酸飲料/
たんさんえん /炭酸塩/
たんさんかり /炭酸カリ/
たんさんかんでんち /単三乾電池/
たんさんすい /炭酸水/
たんさんでんち /単三電池/
たんさんどおんてい /短三度音程/
たんさんわり /炭酸割り/
たんざ /端座/単座/
たんざがた /単座型/
たんざき /単座機/
たんざく /短冊/
たんざくがた /短冊型/
たんざわ /丹沢/
たんざわこほうめん /丹沢湖方面/
たんざん /湛山/
たんし /端子/譚詩/短枝/単子/
たんしかん /端子間/
たんしかんでんあつ /端子間電圧/
たんしき /単式/
たんしこしょう /箪食壷漿/箪食壺漿/
たんししゅつりょく /端子出力/
たんしすう /端子数/
たんしせつぞく /端子接続/
たんしぞくせい /端子属性/
たんしだい /端子台/
たんしでんあつ /端子電圧/
たんしばん /単篩板/
たんしゃ /単写/単車/単射/
たんしゃてき /単射的/
たんしゃれき /単車歴/
たんしゅく /短縮/
たんしゅくか /短縮化/
たんしゅくけい /短縮形/短縮茎/
たんしゅくこうか /短縮効果/
たんしゅくじかん /短縮時間/
たんしゅくばん /短縮版/
たんしゅくりつ /短縮率/
たんしゅん /探春/
たんしょ /短所/端緒/
たんしょう /単勝/短小/探勝/
たんしょうしき /単勝式/
たんしょうしじりつ /単勝支持率/
たんしょうそうひょうすう /単勝総票数/
たんしょうてん /単焦点/
たんしょうてんがわ /短焦点側/
たんしょうとう /探照燈/
たんしょうとうひょうすう /単勝投票数/
たんしょうはいとう /単勝配当/
たんしょうはんだん /単称判断/
たんしょうひょうすう /単勝票数/
たんしょうまんばけん /単勝万馬券/
たんしょく /単色/
たんしょくこう /単色光/
たんしょくし /探触子/
たんしよう /単子葉/
たんしようしょくぶつ /単子葉植物/
たんしようしょくぶつこう /単子葉植物綱/Monocotyledoneae/
たんしようるい /単子葉類/
たんしろん /単子論/
たんしん /単身/短針/
たんしんし /単振子/
たんしんしゃ /単身者/
たんしんどう /単振動/
たんしんふにん /単身赴任/
たんしんふにんしゃ /単身赴任者/
たんしんふにんぞく /単身赴任族/
たんしんふにんちゅう /単身赴任中/
たんじ /丹治/単耳/
たんじかん /短時間/
たんじかんけっちゃく /短時間決着/
たんじかんまど /短時間窓/
たんじかんろこう /短時間露光/
たんじき /単時期/
たんじきょく /単磁極/
たんじく /単軸/短軸/
たんじくじょう /単軸状/
たんじくじょうかじくぶんし /単軸状仮軸分枝/
たんじくぶんし /単軸分枝/
たんじじつ /短時日/
たんじつ /短日/
たんじつげつ /短日月/
たんじゅう /短銃/胆汁/
たんじゅみょう /短寿命/
たんじゅん /単純/単順/
たんじゅんおうふく /単純往復/
たんじゅんおん /単純音/
たんじゅんか /単純化/
たんじゅんけいさん /単純計算/
たんじゅんけいちょう /単純茎頂/
たんじゅんこう /単純項/
たんじゅんさぎょう /単純作業/
たんじゅんしじ /単純支持/
たんじゅんしょうせんきょく /単純小選挙区/
たんじゅんせい /単純性/
たんじゅんちょうぼいん /単純長母音/
たんじゅんどうさ /単純動作/
たんじゅんぶん /単純文/
たんじゅんへいきん /単純平均/
たんじゅんめいかい /単純明解/単純明快/
たんじゅんろん /単純論/
たんじょう /誕生/
たんじょうかい /誕生会/
たんじょうきねん /誕生記念/
たんじょうけん /端条件/
たんじょうご /誕生後/
たんじょうじ /誕生時/
たんじょうせき /誕生石/
たんじょうちょくご /誕生直後/
たんじょうつき /誕生月/
たんじょうねん /誕生年/
たんじょうび /誕生日/
たんじょうびきねん /誕生日記念/
たんじん /炭塵/
たんす /箪笥/
たんすい /淡水/
たんすいか /淡水化/
たんすいかぶつ /炭水化物/
たんすいぎょ /淡水魚/
たんすいこ /淡水湖/
たんすいせい /淡水性/
たんすいちゅう /淡水中/
たんすう /単数/
たんすうぐん /単数群/
たんすうけい /単数形/
たんすうふくすう /単数複数/
たんせい /丹精/丹青/単性/端正/嘆声/淡青/端整/
たんせいか /単性花/
たんせいど /単精度/
たんせき /胆石/
たんせん /単線/
たんせんうんてん /単線運転/
たんせんか /単線化/
たんせんくかん /単線区間/
たんせんこう /単穿孔/単せん孔/
たんせんじだい /単線時代/
たんせんりつ /単旋律/
たんせんりつおんがく /単旋律音楽/
たんぜん /丹前/
たんそ /炭素/炭疽/
たんそう /単層/単走/単相/単奏/
たんそうがた /単相型/
たんそうこうりゅう /単相交流/
たんそうさんせんしき /単相三線式/
たんそうひょうひ /単層表皮/
たんそうりょうか /単層量化/
たんそかん /炭素間/
たんそきん /炭疽菌/
たんそく /短足/嘆息/歎息/
たんそさ /炭素鎖/
たんそじゅんかん /炭素循環/
たんそせんい /炭素繊維/
たんそぼう /炭素棒/
たんぞう /鍛造/胆臓/
たんたい /単体/担体/
たんたいかかく /単体価格/
たんたいどうさ /単体動作/
たんたいはんばい /単体販売/
たんたいろしゅつけい /単体露出計/
たんたかばし /反高橋/
たんたん /淡々/淡淡/眈々/眈眈/
たんだ /単打/
たんだい /短大/
たんだいせい /短大生/
たんだいそつ /短大卒/
たんだすう /単打数/
たんち /探知/丹治/
たんちき /探知器/探知機/
たんちょ /単著/端緒/
たんちょう /単調/短調/単頂/
たんちょうかじょ /単頂花序/
たんちょうげんしょう /単調減少/
たんちょうこう /単調項/
たんちょうせい /単調性/
たんちょうぞうか /単調増加/
たんちょうろんり /単調論理/
たんつぼ /痰壷/
たんてい /探偵/端艇/単蹄/
たんていえいが /探偵映画/
たんていしつ /探偵室/
たんていしゃ /探偵社/
たんていしょうせつ /探偵小説/
たんていじむしょ /探偵事務所/
たんていだん /探偵団/
たんていちょう /探偵帖/
たんていもの /探偵物/
たんていやく /探偵役/
たんてき /端的/胆摘/
たんてん /端点/
たんでき /耽溺/
たんでん /炭田/
たんでんか /単電荷/
たんとう /担当/短刀/但東/
たんとうい /担当医/
たんとういし /担当医師/
たんとういん /担当員/
たんとううけつけ /担当受付/
たんとうか /担当課/
たんとうかかりかん /担当係官/
たんとうかしょ /担当箇所/
たんとうかもく /担当科目/
たんとうかん /担当官/
たんとうかんじ /担当幹事/
たんとうかんりにん /担当管理人/
たんとうがい /担当外/
たんとうがかりめい /担当係名/
たんとうけんさつかん /担当検察官/
たんとうこうし /担当講師/
たんとうしゃ /担当者/
たんとうしゃこじん /担当者個人/
たんとうしゃしめい /担当者氏名/
たんとうしょく /担当職/
たんとうちゅう /担当中/
たんとうちょくにゅう /単刀直入/
たんとうのうりょく /担当能力/
たんとうはんい /担当範囲/
たんとうび /担当日/
たんとうぶきょく /担当部局/
たんとうぶぶん /担当部分/
たんとうぶん /担当分/
たんとうぶんや /担当分野/
たんとうへんしゅう /担当編集/
たんとうへんしゅういいん /担当編集委員/
たんとうへんしゅうしゃ /担当編集者/
たんとうまどぐち /担当窓口/
たんとうろんぶん /担当論文/
たんとうわりあて /担当割り当て/
たんどう /胆道/
たんどく /単独/耽読/單獨/
たんどくこうえん /単独公演/
たんどくこうわ /単独講和/
たんどくしめい /単独指名/
たんどくしゅい /単独首位/
たんどくじこ /単独事故/
たんどくせいぎょ /単独制御/
たんどくそうこう /単独走行/
たんどくそくい /単独測位/
たんどくそんしょう /単独損傷/
たんどくとうこう /単独投稿/
たんどくとくてん /単独得点/
たんどくはんばい /単独販売/
たんどくへんせい /単独編成/
たんどくぼいん /単独母音/
たんどくらいにち /単独来日/
たんな /丹那/
たんなる /単なる/
たんなん /丹南/
たんに /歎異/単に/
たんにしょう /歎異抄/嘆異抄/
たんにゅうかん /単乳管/
たんにん /担任/
たんにんさん /タンニン酸/
たんねん /丹念/
たんねんどしゅぎ /単年度主義/
たんの /丹野/端野/
たんのう /堪能/胆嚢/
たんのうしゃ /堪能者/
たんのはら /旦野原/
たんはちょう /短波長/
たんはんげんき /短半減期/
たんば /丹羽/丹波/
たんばい /単売/
たんばいち /丹波市/
たんばぐち /丹波口/
たんばばし /丹波橋/
たんばら /丹原/
たんぱ /短波/
たんぱく /蛋白/淡白/タンパク/淡泊/
たんぱくげん /蛋白源/
たんぱくさいぼう /タンパク細胞/
たんぱくしつ /タンパク質/蛋白質/
たんぱしょう /短波賞/
たんぱじゅしんき /短波受信機/
たんぱつ /単発/短髪/
たんぱつてき /単発的/
たんぱつよみきり /単発読切/
たんぱほうそう /短波放送/
たんぱん /短パン/
たんび /耽美/
たんびてき /耽美的/
たんぴょう /短評/単票/
たんぴん /単品/
たんぴんゆそう /単品輸送/
たんふく /単複/
たんぶ /反歩/端部/
たんぶん /短文/単文/
たんぶんか /短文化/
たんぶんしょう /短文章/
たんぶんせつ /単文節/
たんぶんせつへんかん /単文節変換/
たんぷく /単複/
たんべんか /単弁花/
たんべんかるい /単弁花類/Monopetalae/
たんぺん /短編/短篇/短辺/
たんぺんけっさくしゅう /短編傑作集/
たんぺんしゅう /短篇集/短編集/
たんぺんしょうせつ /短編小説/短篇小説/
たんぺんせいか /短編成化/
たんほう /探訪/
たんほうかい /探訪会/
たんほうこう /単方向/
たんほうせい /単峰性/
たんぼ /田んぼ/田圃/
たんぼいん /単母音/
たんぼう /探訪/
たんぼく /単木/
たんぽ /担保/
たんまち /反町/
たんまちえき /反町駅/
たんまつ /端末/
たんまつか /端末化/
たんまつかん /端末間/
たんまつがわ /端末側/
たんまつき /端末機/
たんまつきき /端末機器/
たんまつきしつ /端末機室/
たんまつきょく /端末局/
たんまつけい /端末系/
たんまつしつ /端末室/
たんまつじょう /端末上/
たんまつせってい /端末設定/
たんまつせつび /端末設備/
たんまつそうさ /端末操作/
たんまつそうち /端末装置/
たんまつぞくせい /端末属性/
たんまつてじゅん /端末手順/
たんまつにゅうりょくじ /端末入力時/
たんまつひょうじ /端末表示/
たんまつまど /端末窓/
たんまつめい /端末名/
たんまつよう /端末用/
たんみつど /単密度/
たんみん /短眠/
たんむ /坦務/
たんめい /短命/
たんめん /湯麺/単面/
たんめんよう /単面葉/
たんもうしゅ /短毛種/
たんもの /反物/
たんよう /単葉/
たんよく /貪欲/
たんらく /短絡/
たんらくしこう /短絡思考/
たんらくせん /短絡線/
たんらくてき /短絡的/
たんらん /貪婪/
たんり /単利/単離/
たんりょ /短慮/
たんりょく /胆力/
たんれい /端麗/
たんれつ /単列/
たんれつほうしゃそしき /単列放射組織/
たんれん /鍛練/鍛錬/単連/
たんれんけつ /単連結/
たんれんちゅう /鍛錬中/
たんわく /単枠/
たんわくしてい /単枠指定/
たんわくしていば /単枠指定馬/
だ /駄/騨/打/田/陀/楕/舵/柁/妥/朶/堕/唾/惰/出/蛇/兌/墮/娜/懦/拏/拿/橢/沱/陏/駝/鴕/荼/佗/雫/
だい /第/大/台/代/題/内/醍/臺/迺/餒/戴/岱/弟/廼/梯/
だい# /第#1/第#0/第#3/第#2/第/
だい#い /第#1位/
だい#かい /第#1回/第#0回/第#2回/第 #0 回/第#3回/
だい#かいめ /第#1回目/第#0回目/
だい#かん /第#1巻/第#0巻/
だい#がくしょう /第#0楽章/
だい#き /第#0期/第#1期/
だい#きぼう /第#0希望/
だい#きょく /第#0局/第#1局/第#3局/
だい#ぎょう /第#3行/第#0行/
だい#こう /第#1項/第#0項/
だい#こうざ /第#3講座/
だい#こうほ /第 #0 候補/第#0候補/
だい#ごう /第#1号/第#0号/
だい#しゅ /第#3種/第#1種/
だい#しゅう /第#1週/第#0集/
だい#しょう /第#0章/第#1章/第#2章/
だい#じ /第#2次/第#0次/第#1次/第2次/
だい#じょう /第#3条/第#1条/第#2条/
だい#じん /第#1陣/
だい#すいじゅん /第#0水準/
だい#ず /第#4図/第#1図/
だい#せだい /第#1世代/第 #0 世代/
だい#せつ /第#0節/第#1節/
だい#せん /第#3線/第#戦/
だい#だいきゅうし /第#3大臼歯/
だい#だん /第#1弾/第#3弾/第#0段/第#3段/
だい#だん、 /第#0段/
だい#ちゅう /第#3中/
だい#にち /第#0日/
だい#はん /第#0版/第#1版/第#2版/第#1班/
だい#ばん /第#0版/第#1版/第#0番/第#2番/
だい#ばんめ /第#0番目/第#2番目/
だい#ぱん /第#0版/第#2版/
だい#ひきすう /第#0引数/第#1引数/
だい#びん /第#3便/
だい#ぶ /第#1部/第#0部/
だい#まく /第#3幕/
だい#めん /第#3面/
だい#や /第#3夜/
だい#れつ /第#3列/第#0列/
だい#わ /第#0話/
だい< /第/
だい> /第/大/
だい? /第/
だいあいじょう /大愛情/
だいあくま /大悪魔/
だいある /ダイアル/
だいあろぐ /ダイアログ/
だいあん /代案/
だいい /題意/大尉/代位/
だいいき /大域/
だいいきてき /大域的/
だいいせき /大遺跡/
だいいち /第一/第1/第１/ダイイチ/
だいいちい /第一位/
だいいちいんしょう /第一印象/
だいいちうちゅうそくど /第一宇宙速度/
だいいちおうよう /第一応用/
だいいちかいぎしつ /第一会議室/
だいいちかいそう /第一階層/
だいいちかいはつか /第一開発課/
だいいちかいはつしつ /第一開発室/
だいいちかいはつぶ /第一開発部/
だいいちかもつ /第一貨物/
だいいちかんぎょうぎんこう /第一勧業銀行/
だいいちかんぎん /第一勧銀/
だいいちがくしょう /第一楽章/
だいいちきぼう /第一希望/
だいいちぎ /第一義/
だいいちぎじゅつか /第一技術課/
だいいちぎじゅつぶ /第一技術部/
だいいちぎてき /第一義的/
だいいちけいひん /第一京浜/
だいいちけいひんこくどう /第一京浜国道/
だいいちけんきゅうしつ /第一研究室/
だいいちげんり /第一原理/
だいいちこう /第一項/
だいいちこうざ /第一講座/
だいいちこうしょう /第一興商/
だいいちこうほ /第一候補/第1候補/
だいいちごう /第１号/第一号/
だいいちざ /大一座/
だいいちしあい /第一試合/
だいいちしょうけん /第一證券/
だいいちしょうたい /第一小隊/
だいいちしんどうりょく /第一震動力/
だいいちじ /第一次/
だいいちじかいぎょうじ /第一次開業時/
だいいちじしめきり /第一次締切/
だいいちじたいせん /第一次大戦/
だいいちじょしこう /第一女子高/
だいいちじよせん /第一次予選/
だいいちじん /第一陣/
だいいちすいじゅん /第1水準/第一水準/
だいいちせいめい /第一生命/
だいいちせいやく /第一製薬/
だいいちせっけい /第一設計/
だいいちせっけいか /第一設計課/
だいいちせっけいしつ /第一設計室/
だいいちせっけいぶ /第一設計部/
だいいちせめんと /第一セメント/
だいいちだん /第１弾/第一段/第一弾/
だいいちだんかい /第1段階/第一段階/
だいいちちく /第一地区/
だいいちちょしゃ /第一著者/
だいいちとうじしゃ /第一当事者/
だいいちどうりん /第一動輪/
だいいちにち /第１日/第一日/
だいいちにちめ /第一日目/
だいいちにんしゃ /第一人者/
だいいちひきすう /第一引数/
だいいちびん /第一便/
だいいちぶ /第一部/
だいいちぶんがくぶ /第一文学部/
だいいちほうきかん /第一法規刊/
だいいちほうそく /第一法則/
だいいちほてる /第一ホテル/
だいいちほんごく /第一本国/
だいいちもくてきち /第一目的地/
だいいちもん /第一問/
だいいちゆうせん /第一優先/
だいいちよういん /第一要因/
だいいちようそ /第1要素/
だいいちれいきじょうたい /第一励起状態/
だいいちろう /大一郎/
だいいちわ /第一話/
だいいっか /第一課/
だいいっかい /第一回/第1回/第１回/第一階/
だいいっかいじゅしょうしゃ /第一回受賞者/
だいいっかいちょうさ /第一回調査/
だいいっかいはいほん /第一回配本/
だいいっかいめ /第１回目/第一回目/
だいいっかいろんり /第一階論理/
だいいっかん /第一巻/第一感/第一勘/第一款/
だいいっき /第一期/
だいいっきゅう /第一級/
だいいっこう /第一稿/第一項/
だいいっさく /第一作/
だいいっし /第一子/
だいいっししゅっさん /第一子出産/
だいいっしゅ /第1種/第一種/
だいいっしゅう /第一週/
だいいっしゅうめ /第一週目/
だいいっしょう /第一章/第1章/
だいいっせい /第一声/
だいいっせつ /第一節/
だいいっせん /第一戦/第一線/
だいいっせんきゅう /第一線級/
だいいってん /第一点/
だいいっぱ /第一波/
だいいっぱん /第1版/第一版/
だいいっぽ /第一歩/
だいいっぽう /第一報/
だいいとくみょうおう /大威徳明王/
だいいどう /大移動/
だいいん /代印/代員/
だいいんしん /大陰唇/
だいうちゅう /大宇宙/
だいうん /大運/
だいえー /ダイエー/
だいえい /大栄/大映/
だいえいだん /大英断/
だいえいていこく /大英帝国/
だいえいはくぶつかん /大英博物館/
だいえっと /ダイエット/
だいえん /大円/
だいえんかい /大宴会/
だいえんじょう /大円上/
だいえんぜつ /大演説/
だいおう /大王/
だいおうじょう /大往生/
だいおんきょう /大音響/
だいおんじょう /大音声/
だいおんせい /大音声/
だいおんりょう /大音量/
だいか /代価/
だいかあん /代価案/
だいかいぎしつ /大会議室/
だいかいしょう /大海嘯/
だいかいじゅう /大怪獣/
だいかいじょう /大会場/
だいかいせい /大改正/
だいかいせん /大海戦/
だいかいぞう /大改造/
だいかいぞうけいかく /大改造計画/
だいかいぞく /大海賊/
だいかいてい /大改訂/
だいかいてん /大回転/
だいかいれい /大海令/
だいかえ /代替/
だいかえあん /代替案/
だいかくじ /大覚寺/
だいかくめい /大革命/
だいかこ /大過去/
だいかぞく /大家族/
だいかっせん /大合戦/
だいかつ /大喝/
だいかつやく /大活躍/
だいかつやくちゅう /大活躍中/
だいかひん /代価品/
だいかぶつ /代価物/
だいかん /代官/大寒/大韓/
だいかんきょほう /大艦巨砲/
だいかんげい /大歓迎/
だいかんげいかい /大歓迎会/
だいかんげき /大感激/
だいかんこうくう /大韓航空/
だいかんこうくうき /大韓航空機/
だいかんごりん /大漢語林/
だいかんさま /代官様/
だいかんしゃ /大感謝/
だいかんしゅう /大観衆/
だいかんじょうせん /大環状線/
だいかんせい /大歓声/大喚声/
だいかんせん /大幹線/
だいかんそう /大観荘/
だいかんたいどうし /大艦隊同士/
だいかんどう /大感動/
だいかんのんぞう /大観音像/
だいかんみんこく /大韓民国/
だいかんみんこくじん /大韓民国人/
だいかんみんこくせき /大韓民国籍/
だいかんやま /代官山/
だいかんわ /大漢和/
だいかんわじてん /大漢和辞典/大漢和辭典/
だいがいしゃ /大会社/
だいがえ /代替/
だいがえくうこう /代替空港/
だいがえしゃ /代替車/
だいがえち /代替地/
だいがえゆそう /代替輸送/
だいがく /大学/大學/
だいがくいがい /大学以外/
だいがくいがくぶ /大学医学部/
だいがくいこう /大学以降/
だいがくいちねんせい /大学一年生/
だいがくいちねんていど /大学一年程度/
だいがくいん /大学院/
だいがくいんがくせい /大学院学生/
だいがくいんきょういく /大学院教育/
だいがくいんきょういくたいこう /大学院教育大綱/
だいがくいんきょうかんかいぎ /大学院教官会議/
だいがくいんざいがく /大学院在学/
だいがくいんしゅうりょうご /大学院修了後/
だいがくいんしんがくりつ /大学院進学率/
だいがくいんじゅうてんか /大学院重点化/
だいがくいんせい /大学院生/
だいがくいんせいたいかい /大学院生大会/
だいがくいんだいがく /大学院大学/
だいがくいんにゅうし /大学院入試/
だいがくうちゅうたんさきょうかい /大学宇宙探査協会/
だいがくかいかん /大学会館/
だいがくかん /大学間/
だいがくかんけい /大学関係/
だいがくかんけいしゃ /大学関係者/
だいがくがくぶ /大学学部/
だいがくがわ /大学側/
だいがくきかいほんやく /大学機械翻訳/
だいがくきそこうざ /大学基礎講座/
だいがくきょういく /大学教育/
だいがくきょういん /大学教員/
だいがくきょうかん /大学教官/
だいがくきょうじゅ /大学教授/
だいがくきょうよう /大学教養/
だいがくきょうようていど /大学教養程度/
だいがくきょうようぶ /大学教養部/
だいがくこうざ /大学講座/
だいがくこうない /大学構内/
だいがくごうかくりつ /大学合格率/
だいがくさい /大学祭/
だいがくさいちゅう /大学祭中/
だいがくざいがくちゅう /大学在学中/
だいがくしゅっしん /大学出身/
だいがくしょてん /大学書店/
だいがくしょねんじ /大学初年次/
だいがくしょりん /大学書林/
だいがくしんがく /大学進学/
だいがくじ /大学時/
だいがくじだい /大学時代/
だいがくじゅけん /大学受験/
だいがくじゅけんあんない /大学受験案内/
だいがくじゅんきょうじゅ /大学准教授/
だいがくじょしゅ /大学助手/
だいがくじん /大学人/
だいがくせい /大学生/
だいがくせいかつ /大学生活/
だいがくせいきょう /大学生協/
だいがくせいきょういがい /大学生協以外/
だいがくせいきょうしょくどう /大学生協食堂/
だいがくせいじだい /大学生時代/
だいがくせいじょし /大学生女子/
だいがくせいゆうり /大学生有利/
だいがくせん /大学戦/
だいがくせんしゅけん /大学選手権/
だいがくぜい /大学勢/
だいがくぜんたい /大学全体/
だいがくぜんぱん /大学全般/
だいがくそつ /大学卒/
だいがくそつぎょう /大学卒業/
だいがくそつぎょういらい /大学卒業以来/
だいがくそつぎょうしゃ /大学卒業者/
だいがくそつぎょうていど /大学卒業程度/
だいがくたいこう /大学対抗/
だいがくたいざいちゅう /大学滞在中/
だいがくてんもんれんめい /大学天文連盟/
だいがくで /大学出/
だいがくとしょかん /大学図書館/
だいがくない /大学内/
だいがくにほんいち /大学日本一/
だいがくにゅうがく /大学入学/
だいがくにゅうし /大学入試/
だいがくにゅうしもんだい /大学入試問題/
だいがくびょういん /大学病院/
だいがくびょういんまえ /大学病院前/
だいがくふんそう /大学紛争/
だいがくぶ /大学部/
だいがくまえ /大学前/
だいがくまんが /大学漫画/
だいがくめい /大学名/
だいがくやきゅう /大学野球/
だいがくやきゅうかい /大学野球界/
だいがくろうにんちゅう /大学浪人中/
だいがす /大ガス/
だいがっこう /大学校/
だいがっしょう /大合唱/
だいがめん /大画面/
だいがめんたいおう /大画面対応/
だいがんめん /大顔面/
だいき /代機/大機/
だいきぎょう /大企業/
だいきぎょうびょう /大企業病/
だいきち /大吉/
だいきぼ /大規模/
だいきぼか /大規模化/
だいきぼかんり /大規模管理/
だいきぼけいさん /大規模計算/
だいきぼこうぞう /大規模構造/
だいきぼすうちけいさん /大規模数値計算/
だいきぼちしき /大規模知識/
だいきぼてん /大規模店/
だいきぼとうし /大規模投資/
だいきぼはつでん /大規模発電/
だいきぼぶんさんこうぞう /大規模分散構造/
だいきぼへいれつ /大規模並列/
だいきぼへいれつねっとわあく /大規模並列ネットワーク/
だいきゅう /代休/
だいきゅうし /大臼歯/
だいきゅうじゅうごじょう /第九十五条/
だいきゅうじゅうななじょう /第九十七条/
だいきょう /大凶/大京/
だいきょうかい /大教会/
だいきょうかんこう /大京観光/
だいきょうこう /大恐慌/
だいきょうしつ /大教室/
だいきょうすう /大凶数/
だいきょうそう /大競走/
だいきょうちょう /大京町/
だいきょうまち /大京町/
だいきらい /大嫌い/
だいきん /代金/大金/
だいきんこうぎょう /ダイキン工業/
だいきんひきかえゆうびん /代金引換郵便/
だいきんぼし /大金星/
だいぎ /代議/
だいぎいん /代議員/
だいぎいんかい /代議員会/
だいぎいんたいかい /代議員大会/
だいぎし /代議士/
だいぎしすう /代議士数/
だいぎせい /代議制/
だいぎもん /大疑問/
だいぎゃくさつ /大虐殺/
だいぎゃくさつじけん /大虐殺事件/
だいぎゃくてん /大逆転/
だいぎゃくてんしょうり /大逆転勝利/
だいぎょうてん /大仰天/
だいぎん /大吟/
だいぎんこう /大銀行/
だいぎんじょう /大吟醸/
だいく /第九/大工/
だいくうこう /大空港/
だいくせん /大苦戦/
だいくまち /大工町/
だいぐうじ /大宮司/
だいぐさく /大愚作/
だいけい /大計/台形/大型計算機センター/大計センター/大型計算機/
だいけいかく /大計画/
だいけいそく /台形則/
だいけっさく /大傑作/
だいけん /大建/
だいけんい /大権威/
だいけんきゅう /大研究/
だいけんこうぎょう /大建工業/
だいけんしゅうしつ /大研修室/
だいけんとう /大健闘/
だいげきせん /大激戦/
だいげんかい /大言海/
だいげんすいへいか /大元帥陛下/
だいげんそく /大原則/
だいこう /代行/乃公/大幸/
だいこうかい /大公開/大航海/大後悔/
だいこうきょうきょく /大交響曲/
だいこうぎしつ /大講義室/
だいこうぎょう /代行業/
だいこうぎょうむ /代行業務/
だいこうけい /大口径/
だいこうけいぼうえん /大口径望遠/
だいこうけん /代行権/
だいこうこく /大広告/
だいこうざ /大講座/
だいこうしゃ /代行者/
だいこうしん /大行進/
だいこうじ /大工事/
だいこうずい /大洪水/
だいこうせい /大攻勢/
だいこうだいこう /大工大高/
だいこうてん /代行店/
だいこうどう /大講堂/
だいこうひょう /大好評/
だいこうふん /大興奮/
だいこうぶつ /大好物/
だいこうぼうせん /大攻防戦/
だいこうもく /大項目/
だいこうもくめい /大項目名/
だいこうや /代行屋/
だいこうゆそう /代行輸送/
だいこうりょう /大光量/
だいこく /大黒/
だいこくちょう /大国町/
だいこくどう /大黒堂/
だいこくばしら /大黒柱/
だいこん /大根/
だいこんおろし /大根下ろし/
だいこんざつ /大混雑/
だいこんせん /大混線/大混戦/
だいこんせんもよう /大混戦模様/
だいこんは /大根葉/
だいこんらん /大混乱/
だいこんらんじょうたい /大混乱状態/
だいご /醍醐/第五/第５/大吾/大悟/大子/
だいごい /大語彙/
だいごかい /第５回/大誤解/大語界/
だいごかん /第五巻/
だいごぎじゅつか /第五技術課/
だいごし /第五子/
だいごしあい /第五試合/
だいごしん /大誤審/
だいごじ /醍醐寺/
だいごせだい /第５世代/第五世代/
だいごせだいけいかく /第五世代計画/
だいごせつ /第五節/
だいごせん /第五戦/
だいごちく /醍醐地区/
だいごぶだいにか /第五部第二課/
だいごみ /醍醐味/
だいごらくえいが /大娯楽映画/
だいごわくせい /第五惑星/
だいさ /大佐/
だいさい /大祭/
だいさいがい /大災害/
だいさいなん /大災難/
だいさぎょう /大作業/
だいさく /大作/
だいさくせん /大作戦/
だいさつりく /大殺戮/
だいさぶろう /大三郎/
だいさん /第三/第３/第3/第III/
だいさんいんすう /第三引数/
だいさんおうよう /第三応用/
だいさんかい /第３回/
だいさんかいそう /第三階層/
だいさんかいはつか /第三開発課/
だいさんかいはつしつ /第三開発室/
だいさんかいはつぶ /第三開発部/
だいさんかん /第三巻/第三款/
だいさんがいこくご /第三外国語/
だいさんがくぐん /第三学群/
だいさんがくぐんまえ /第三学群前/
だいさんがくしょう /第三楽章/
だいさんき /第三期/
だいさんきぼう /第三希望/
だいさんけいひん /第三京浜/
だいさんけんきゅうしつ /第三研究室/
だいさんげん /大三元/
だいさんこう /第三項/
だいさんこうざ /第三講座/
だいさんごく /第三国/
だいさんざい /大散財/
だいさんしあい /第三試合/
だいさんしゃ /第三者/
だいさんしゃつうしん /第三者通信/
だいさんしゃてき /第三者的/
だいさんしゅ /第三種/
だいさんしょう /第三章/第3章/
だいさんしょかん /第三書館/
だいさんじ /大惨事/
だいさんじゅうごじょう /第三十五条/
だいさんじゅうじょう /第三十条/
だいさんじゅうななじょう /第三十七条/
だいさんじゅうにじょう /第三十二条/
だいさんじゅうろくじょう /第三十六条/
だいさんすいじゅん /第三水準/
だいさんせい /大賛成/
だいさんせいりょく /第三勢力/
だいさんせだい /第三世代/
だいさんせっけいか /第三設計課/
だいさんせつ /第三節/
だいさんせん /第三戦/
だいさんだん /第３段/第三弾/第３弾/
だいさんにち /第三日/
だいさんばん /第三版/
だいさんぶ /第三部/
だいさんぶたい /第三舞台/
だいさんわ /第三話/
だいざ /台座/
だいざい /題材/
だいざいじたい /題材自体/
だいざいちゅう /滞在中/
だいざいてき /題材的/
だいざえもん /大左衛門/
だいざんさつ /大惨殺/
だいざんぱい /大惨敗/
だいし /台紙/大師/第四/
だいしあい /大試合/
だいしきゅう /大至急/
だいしきょう /大司教/
だいしぎんこう /第四銀行/
だいしぜん /大自然/
だいしだい /大市大/
だいしっせいかん /大執政官/
だいしったい /大失態/
だいしっぱい /大失敗/
だいしどう /大師堂/
だいしへんけい /大四辺形/
だいしゃ /代車/台車/
だいしゃかん /台車間/
だいしゃこうかん /台車交換/
だいしゃっきん /大借金/
だいしゃない /台車内/
だいしゃふりかえ /台車振替/
だいしゃめん /大斜面/
だいしゃりん /大車輪/
だいしゃわく /台車枠/
だいしゅうかい /大集会/
だいしゅうかく /大収穫/
だいしゅうごう /大集合/
だいしゅうしゃ /大衆車/
だいしゅうだん /大集団/
だいしゅくしゃく /大縮尺/
だいしゅじゅつ /大手術/
だいしゅぞく /大種族/
だいしゅっせ /大出世/
だいしゅつげん /大出現/
だいしゅつりょく /大出力/
だいしゅつりょくきょく /大出力局/
だいしょ /代書/
だいしょう /大小/代償/大将/
だいしょうかんけい /大小関係/
だいしょうがい /大障害/
だいしょうくべつ /大小区別/
だいしょうぐん /大将軍/
だいしょうざん /大翔山/
だいしょうじ /大聖寺/
だいしょうだい /大商大/
だいしょうてん /大賞典/
だいしょうとつ /大衝突/
だいしょうひかく /大小比較/
だいしょうほう /大翔鳳/
だいしょうり /大勝利/大捷利/
だいしょうりろん /代償理論/
だいしょうわせいし /大昭和製紙/
だいしょくどう /大食堂/
だいしょてん /大書店/
だいしょや /代書屋/
だいしんさい /大震災/
だいしんでん /大神殿/
だいしんぱん /大信販/
だいしんぶん /大新聞/
だいしんゆう /大親友/
だいじ /大事/題字/大治/大弐/大字/
だいじぇすと /ダイジェスト/
だいじけん /大事件/
だいじげん /大字源/
だいじこ /大事故/
だいじしん /大地震/
だいじてん /大事典/大辞典/
だいじゃ /大蛇/
だいじゃたいじ /大蛇退治/
だいじゅういっこう /第十一項/
だいじゅうたい /大渋滞/
だいじゅんかん /大循環/
だいじょう /大丈/大嘗/
だいじょうさい /大嘗祭/
だいじょうだん /大上段/
だいじょうぶ /大丈夫/
だいじょうぶっきょう /大乗仏教/
だいじょきょく /大序曲/
だいじょゆう /大女優/
だいじりん /大辞林/
だいじろう /大二郎/
だいじん /大臣/大尽/大神/
だいじんぐう /大神宮/
だいじんぐうした /大神宮下/
だいじんどう /大仁堂/
だいじんぶつ /大人物/
だいす /台子/
だいすいがい /大水害/
だいすいせい /大彗星/
だいすう /台数/代数/大数/
だいすうかい /代数解/
だいすうかくだい /代数拡大/
だいすうかくほ /台数確保/
だいすうがく /代数学/
だいすうがくしゃ /大数学者/
だいすうきか /代数幾何/
だいすうきかがく /代数幾何学/
だいすうきかせんこう /代数幾何専攻/
だいすうきかてき /代数幾何的/
だいすうきょくせん /代数曲線/
だいすうけい /代数系/
だいすうけいとう /代数系統/
だいすうこうか /台数効果/
だいすうこうぞう /代数構造/
だいすうしき /代数式/
だいすうしよう /代数仕様/
だいすうたい /代数体/
だいすうたようたい /代数多様体/
だいすうち /代数値/
だいすうてき /代数的/
だいすうてきかい /代数的解/
だいすうてきしよう /代数的仕様/
だいすうほうていしき /代数方程式/
だいすうみてい /台数未定/
だいすき /大好き/
だいすけ /大介/大輔/大亮/大祐/大助/
だいず /大豆/
だいずかん /大図鑑/
だいせいうん /大星雲/
だいせいえん /大声援/
だいせいか /大成果/
だいせいかい /大正解/
だいせいきょう /大盛況/
だいせいこう /大成功/
だいせいどう /大聖堂/
だいせいりょく /大勢力/
だいせっきん /大接近/
だいせっけい /大雪渓/
だいせつ /大雪/
だいせつざん /大雪山/
だいせん /大山/
だいせんかん /大戦艦/
だいせんしゅ /大選手/
だいせんせい /大先生/
だいせんそう /大戦争/
だいせんだん /大船団/
だいせんでん /大宣伝/
だいせんぱい /大先輩/
だいせんぷう /大旋風/
だいせんりゃく /大戦略/
だいぜっきょう /大絶叫/
だいぜんしゅう /大全集/
だいぜんてい /大前提/
だいそう /代奏/代走/体操/
だいそうげん /大草原/
だいそうげんのちいさないえ /大草原の小さな家/
だいそうしょう /大僧正/
だいそうじょう /大僧上/
だいそしき /大組織/
だいそつ /大卒/
だいそつじょし /大卒女子/
だいそつだんし /大卒男子/
だいそんがい /大損害/
だいぞう /大蔵/
だいぞういん /大増員/
だいぞうかん /大増刊/
だいぞうかんごう /大増刊号/
だいぞうげん /大増減/
だいた /台田/代田/
だいたい /大体/代替/大腿/大隊/
だいたいあん /代替案/
だいたいいちねん /大体一年/
だいたいかいさい /代替開催/
だいたいき /代替機/
だいたいきかん /代替機関/
だいたいくうこう /代替空港/
だいたいけい /大腿頚/
だいたいこつ /大腿骨/
だいたいしゅだん /代替手段/
だいたいどうろ /代替道路/
だいたいねんりょう /代替燃料/
だいたいひょうき /代替表記/
だいたいひょうげん /代替表現/
だいたいひん /代替品/
だいたいぶ /大腿部/
だいたいぶつ /代替物/
だいたいぶひん /代替部品/
だいたいほう /代替法/
だいたいほうほう /代替方法/
だいたいろせん /代替路線/
だいたすう /大多数/
だいたばし /代田橋/
だいたろう /大太郎/
だいたん /大胆/
だいたんふてき /大胆不敵/
だいだ /代打/
だいだい /橙/大々/代々/
だいだいいろ /だいだい色/橙色/
だいだいてき /大々的/
だいだいひょう /大代表/
だいだいり /大内裏/
だいだげき /大打撃/
だいだじん /代打陣/
だいだっそう /大脱走/
だいだほんるいだ /代打本塁打/
だいだんあつじだい /大弾圧時代/
だいだんえん /大団円/大団圓/
だいだんそう /大断層/
だいち /大地/台地/大値/代地/
だいちえん /大遅延/
だいちぼしん /大地母神/
だいちまお /大地真央/
だいちゅう /大中/
だいちゅうおう /台中央/
だいちゅうしゃじょう /大駐車場/
だいちゅうしょう /大中小/
だいちゅうしょくかい /大昼食会/
だいちゅうだん /大中断/
だいちゅうぶんるい /大中分類/
だいちょう /台帳/大腸/
だいちょうかんり /台帳管理/
だいちょうきん /大腸菌/
だいちょうへん /大長編/
だいついせき /大追跡/
だいていこく /大帝国/
だいていたく /大邸宅/
だいていでん /大停電/
だいていり /大定理/
だいてつじん /大鉄人/
だいてん /題点/
だいてんかん /大転換/
だいてんさい /大天才/
だいてんし /大天使/大転子/
だいてんとう /大転倒/
だいてんもく /台天目/
だいでんつうだい /大電通大/
だいでんりゅう /大電流/
だいでんりょく /大電力/
だいと /大都/
だいとう /大東/
だいとうあ /大東亜/大東亞/
だいとうあきょうえいけん /大東亜共栄圏/
だいとうあせんそう /大東亜戦争/
だいとういつりろん /大統一理論/
だいとうがくえん /大東学園/
だいとうきょう /大東京/
だいとうきょうかさい /大東京火災/
だいとうし /大東市/
だいとうじん /大東陣/
だいとうぞく /大盗賊/
だいとうだい /大東大/
だいとうぶんか /大東文化/
だいとうぶんかだい /大東文化大/
だいとうぶんかだいがく /大東文化大学/
だいとうぼうしょく /大東紡織/
だいとうりょう /大統領/
だいとうりょうせんきょ /大統領選挙/
だいとうろん /大討論/
だいとかい /大都会/
だいとくい /大得意/
だいとくしゅう /大特集/
だいとくしゅうごう /大特集号/
だいとくじ /大徳寺/
だいとくじなっとう /大徳寺納豆/
だいとこうぎょう /大都工業/
だいとし /大都市/
だいとしかん /大都市間/
だいとしけん /大都市圏/
だいとしゃ /大都社/
だいとちしょゆう /大土地所有/
だいどう /大同/大道/
だいどうけおり /大同毛織/
だいどうげい /大道芸/
だいどうげいにん /大道芸人/
だいどうこうはん /大同鋼板/
だいどうしょうい /大同小異/
だいどうしょうにん /大道商人/
だいどうだんけつ /大同団結/
だいどうみゃく /大動脈/
だいどく /代読/
だいどころ /台所/
だいどころじじょう /台所事情/
だいどころせんざい /台所洗剤/
だいどころよう /台所用/
だいなごん /大納言/
だいなし /台無し/台無/
だいなな /第七/
だいななかい /第７回/
だいななきょく /第七局/
だいななげいじゅつげきじょう /第七芸術劇場/
だいななしあい /第七試合/
だいななじゅうはちじょう /第七十八条/
だいななせつ /第七節/
だいなみっくす /ダイナミックス/
だいなり /＞/
だいなりいこーる /≧/
だいなんかい /第何回/
だいなんしゅうめ /第何週目/
だいなんじょう /第何条/
だいなんわ /第何話/
だいに /第二/第２/第2/
だいにいんすう /第二引数/
だいにうちゅうそくど /第二宇宙速度/
だいにかい /第二回/第2回/第2階/
だいにかいはつか /第二開発課/
だいにかいはつしつ /第二開発室/
だいにかいはつぶ /第二開発部/
だいにかいめ /第二回目/
だいにかん /第二巻/第二款/
だいにがいこくご /第二外国語/
だいにがくしょう /第二楽章/
だいにきぼう /第二希望/
だいにきょく /第二局/
だいにぎじゅつか /第二技術課/
だいにぎじゅつぶ /第二技術部/
だいにぎていしょ /第二議定書/
だいにけいひん /第二京浜/
だいにけいひんこくどう /第二京浜国道/
だいにけんきゅうしつ /第二研究室/
だいにこう /第二項/
だいにこうざ /第二講座/
だいにこくどう /第二国道/
だいにごう /第二号/
だいにさく /第二作/
だいにしあい /第二試合/
だいにしゅ /第2種/第二種/
だいにしゅう /第2週/第二週/
だいにしゅげんつき /第二種原付/
だいにしょう /第2章/第二章/
だいにじ /第二次/第2次/
だいにじぎょうぶ /第二事業部/
だいにじさんぎょう /第二次産業/
だいにじせかいたいせん /第二次世界大戦/
だいにじたいせん /第二次大戦/
だいにじゅういちじょう /第二十一条/
だいにじゅうにじょう /第二十二条/
だいにじゅうはちじょう /第二十八条/
だいにじゅうろくじょう /第二十六条/第二六条/
だいにじょう /第二条/
だいにじょうばんせん /第二常磐線/
だいにすいじゅん /第2水準/第二水準/第２水準/
だいにすいじゅんかんじ /第二水準漢字/
だいにすいじゅんちゅう /第二水準中/
だいにせだい /第二世代/
だいにせっけい /第二設計/
だいにせっけいしつ /第二設計室/
だいにせつ /第二節/
だいにたいいくかん /第２体育館/
だいにだん /第二弾/
だいにだんかい /第2段階/
だいにち /大日/
だいにちざかり /大日盛/
だいにちだけ /大日岳/
だいにっぽん /大日本/
だいにっぽんいんさつ /大日本印刷/
だいにっぽんていこく /大日本帝国/
だいにてん /第二点/
だいにでんでん /第二電電/
だいにどうりん /第二動輪/
だいにはん /第二版/
だいにぶ /第二部/
だいにほうそく /第二法則/
だいにほん /大日本/
だいにほんいんさつ /大日本印刷/
だいにほんかいが /大日本絵画/
だいにほんていこく /大日本帝国/
だいにゅう /代入/
だいにゅうえんざん /代入演算/
だいにゅうえんざんし /代入演算子/
だいにゅうかのう /代入可能/
だいにゅうかのうせい /代入可能性/
だいにゅうきそく /代入規則/
だいにゅうげんご /代入言語/
だいにゅうそうさ /代入操作/
だいにゅうぶん /代入文/
だいにゅうぶんぽう /代入文法/
だいにゅうれい /代入例/
だいにようそ /第2要素/
だいにりょうしか /第二量子化/
だいにん /代人/
だいにんき /大人気/
だいにんずう /大人数/
だいねっきょう /大熱狂/
だいねっせん /大熱戦/
だいのう /大脳/代納/
だいのうかい /大納会/
だいのうはんきゅう /大脳半球/
だいのうひしつ /大脳皮質/
だいのうへんえん /大脳辺縁/
だいのおとこ /大の男/
だいのじ /大の字/
だいのはら /台原/
だいはいきりょう /大排気量/
だいはいきりょうしゃ /大排気量車/
だいはくしゅ /大拍手/
だいはくらんかい /大博覧会/
だいはくりょく /大迫力/
だいはちしあい /第八試合/
だいはちへんせい /第八編成/
だいはっかい /大発会/
だいはっけん /大発見/
だいはっせい /大発生/
だいはつこうぎょう /ダイハツ工業/
だいはつめい /大発明/
だいはどう /大波動/
だいはなびたいかい /大花火大会/
だいはらん /大波乱/
だいはんたい /大反対/
だいはんたいうんどう /大反対運動/
だいはんてん /大飯店/
だいはんもちゅう /大繁茂中/
だいば /台場/
だいばかり /台秤/
だいばくしょう /大爆笑/
だいばくはつ /大爆発/
だいばってき /大抜擢/
だいばめんせってい /大場面設定/
だいひきゅう /大飛球/
だいひっと /大ヒット/
だいひつ /代筆/
だいひつや /代筆屋/
だいひゃくじゅうにじょう /第百十二条/
だいひゃくじょう /第百条/
だいひゃっか /大百科/
だいひゃっかりようほう /大百科利用法/
だいひょう /代表/
だいひょういいんかい /代表委員会/
だいひょうかく /代表格/
だいひょうかんじ /代表幹事/
だいひょうきょく /代表曲/
だいひょうぐみ /代表組/
だいひょうけい /代表型/
だいひょうけん /代表権/
だいひょうげん /大氷原/代表元/
だいひょうこう /代表校/
だいひょうこうほ /代表候補/
だいひょうさく /代表作/
だいひょうさくひん /代表作品/
だいひょうさんこま /代表産駒/
だいひょうしかく /代表資格/
だいひょうしゃ /代表者/
だいひょうしゃかい /代表者会/
だいひょうしょく /代表色/
だいひょうせんしゅ /代表選手/
だいひょうだん /代表団/
だいひょうち /代表値/
だいひょうちょしゃ /代表著者/
だいひょうてき /代表的/
だいひょうてきさくひん /代表的作品/
だいひょうてきめいばん /代表的名盤/
だいひょうてん /代表点/
だいひょうでんわ /代表電話/
だいひょうでんわばんごう /代表電話番号/
だいひょうとりしまりやく /代表取締役/
だいひょうば /代表馬/
だいひょうばん /大評判/
だいひょうめい /代表名/
だいひょうりゅう /大漂流/
だいひょうれい /代表例/
だいひん /代品/
だいひんしゅく /大顰蹙/
だいひんみん /大貧民/
だいびき /代引き/代引/
だいびょういん /大病院/
だいびょうにん /大病人/
だいふぁん /大ファン/
だいふく /大福/
だいふくじ /大福寺/
だいふごう /大富豪/
だいふだ /台札/
だいふつか /第二日/
だいぶ /大部/大分/
だいぶいぜん /大分以前/
だいぶたい /大舞台/大部隊/
だいぶつ /大仏/
だいぶつかいがん /大仏開眼/
だいぶぶん /大部分/
だいぶまえ /大分前/
だいぶむかし /大分昔/
だいぶもん /大部門/
だいぶもんせい /大部門制/
だいぶん /大分/
だいぶんせつ /大文節/
だいぶんるい /大分類/
だいぶんるいか /大分類下/
だいへいげん /大平原/
だいへいれつ /大並列/
だいへん /代返/
だいへんかく /大変革/
だいへんこう /大変更/
だいへんせい /大編成/
だいへんたい /大編隊/
だいへんどう /大変動/
だいへんらく /大変楽/
だいべん /代弁/大便/
だいべんき /大便器/
だいべんしゃ /代弁者/
だいべんにん /代弁人/
だいほうけんせつ /大豊建設/
だいほうし /大法師/
だいほうしゅつ /大放出/
だいほうしゅつたいかい /大放出大会/
だいほん /台本/
だいほんえい /大本営/
だいほんえいはっぴょう /大本営発表/
だいほんめい /大本命/
だいぼう /大坊/
だいぼうけん /大冒険/
だいぼうそう /大暴走/
だいぼうどう /大暴動/
だいぼうねんかい /大忘年会/
だいぼくじょう /大牧場/
だいぼさつ /大菩薩/
だいぼしゅう /大募集/
だいま /大間/
だいまおう /大魔王/
だいまきょう /大魔境/
だいまじん /大魔人/大魔神/
だいまる /大丸/
だいまるうめだ /大丸梅田/
だいまるとうきょうてん /大丸東京店/
だいまるまえ /大丸前/
だいまんぞく /大満足/
だいみてい /題未定/
だいみょう /大名/
だいみょうぎょうれつ /大名行列/
だいみょうじゅうぞく /大名従属/
だいみょうじん /大明神/
だいみょうどうし /大名同士/
だいみょうりょこう /大名旅行/
だいみょうりょこうしゃ /大名旅行者/
だいみんていこく /大明帝国/
だいめ /台目/代目/
だいめい /題名/大明/
だいめいきゅう /大迷宮/
だいめいし /代名詞/
だいめいふめい /題名不明/
だいめいぶつ /大名物/
だいめいろ /大迷路/
だいめいわく /大迷惑/
だいめんせき /大面積/
だいもく /題目/
だいもくひょう /大目標/
だいもくひょうじ /題目表示/
だいもくみてい /題目未定/
だいもん /大門/代紋/大問/
だいもんじ /大文字/
だいもんじやま /大文字山/
だいもんだい /大問題/
だいや /ダイヤ/大谷/◆/◇/
だいやく /代役/
だいやくしん /大躍進/
だいやくまん /大役満/
だいやぐらむ /ダイヤグラム/
だいやもんど /ダイヤモンド/
だいやる /ダイヤル/
だいゆうかい /大誘拐/
だいゆうざんせん /大雄山線/
だいよう /代用/大葉/
だいようかい /大妖怪/
だいようかのう /代用可能/
だいようかんじ /代用漢字/
だいようさい /大要塞/
だいようひん /代用品/
だいようりょう /大容量/
だいようりょうか /大容量化/
だいようりょうしゅうでん /大容量集電/
だいよくじょう /大浴場/
だいよげん /大予言/
だいよそう /大予想/
だいよそく /大予測/
だいよっか /第四日/
だいよん /第四/第４/第4/
だいよんかい /第四回/
だいよんかいはつぶ /第四開発部/
だいよんかん /第四款/
だいよんかんひょうき /第四間氷期/
だいよんきがく /第四紀学/
だいよんきょうわせい /第四共和制/
だいよんこう /第四項/
だいよんしあい /第四試合/
だいよんしょう /第四章/第4章/
だいよんじゅういちじょう /第四十一条/
だいよんじゅうさんじょう /第四十三条/
だいよんじゅうななじょう /第四十七条/
だいよんじゅうにじょう /第四十二条/
だいよんせつ /第四節/
だいよんたんとう /第四担当/
だいよんばん /第四版/
だいよんぺん /第四辺/
だいよんわくせい /第四惑星/
だいら /平/
だいらく /大楽/
だいらくしょう /大楽勝/
だいらんこう /大乱交/
だいらんせん /大乱戦/
だいらんぶ /大乱舞/
だいり /代理/大利/内裏/
だいりくれい /大陸令/
だいりこうい /代理行為/
だいりしつもん /代理質問/
だいりせき /大理石/
だいりせんそう /代理戦争/
だいりそうごさよう /代理相互作用/
だいりてん /代理店/
だいりてんがわ /代理店側/
だいりてんけいゆ /代理店経由/
だいりてんけいゆう /代理店経由/
だいりてんてすうりょう /代理店手数料/
だいりてんてんとう /代理店店頭/
だいりとうこう /代理投稿/
だいりとうこうぶん /代理投稿分/
だいりとうひょう /代理投票/
だいりにん /代理人/
だいりびな /内裏雛/
だいりゅうけつ /大流血/
だいりゅうこう /大流行/
だいりょういき /大領域/
だいりょうはいきしゃかい /大量廃棄社会/
だいりょうふくせい /大量複製/
だいりょこう /大旅行/
だいれきしじけん /大歴史事件/
だいれん /大連/
だいれんあい /大恋愛/
だいれんけいゆ /大連経由/
だいれんけいゆう /大連経由/
だいれんごう /大連合/
だいれんさ /大連鎖/
だいれんらくきょう /大連絡橋/
だいれんらくばし /大連絡橋/
だいろうさ /大労作/
だいろく /第６/第六/
だいろくしあい /第六試合/
だいろくじゅうきゅうじょう /第六十九条/
だいろくせだい /第六世代/
だいろくせつ /第六節/
だいろっかい /第６回/第六回/
だいろっかん /第六感/
だいろっき /第六期/
だいろっきょく /第六局/
だいろまん /大浪漫/
だいろんぎ /大論議/
だいろんそう /大論争/
だいわ /大和/
だいわぎんこう /大和銀行/
だいわく /台枠/
だいわくじょう /台枠上/
だいわくせい /大惑星/
だいわしょうけん /大和証券/大和證券/
だいわだんち /大和団地/
だいわぼうせき /大和紡績/
だいわん /大彎/
だう /ダウ/
だうん /ダウン/
だうんひる /ダウンヒル/
だえき /唾液/
だえきせん /唾液腺/
だえん /楕円/橢円/橢圓/
だえんうんどう /楕円運動/
だえんがた /楕円型/
だえんきどう /楕円軌道/
だえんきどうじょう /楕円軌道上/
だえんけい /楕円形/楕円型/
だえんこ /楕円弧/
だえんじょう /楕円状/
だえんたい /楕円体/
だえんめん /楕円面/
だか /高/
だかい /打開/
だかいさく /打開策/
だかつ /蛇蝎/蛇蠍/
だかん /兌換/打感/
だかんけん /兌換券/
だかんしへい /兌換紙幣/
だがし /駄菓子/
だがしぎょうしゃ /駄菓子業者/
だがしや /駄菓子屋/
だがっき /打楽器/
だがっきせんもんてん /打楽器専門店/
だき /唾棄/
だきあわせ /抱き合わせ/
だきみょうが /抱茗荷/
だきゅう /打球/
だきゅうかん /打球感/
だきょう /妥協/
だきょうあん /妥協案/
だきょうがた /妥協型/
だきょうじょうけん /妥協条件/
だきょうていあん /妥協提案/
だきょうてん /妥協点/
だぎょう /ダ行/
だく /諾/濁/
だくおん /濁音/
だくおんにゅうりょくご /濁音入力後/
だくすい /濁水/
だくてん /゛/濁点/
だくと /ダクト/
だくひ /諾否/
だくりゅう /濁流/
だけ /岳/嶽/
だけつ /妥結/
だけん /打鍵/
だけんきょうじゃく /打鍵強弱/
だけんじ /打鍵時/
だけんすう /打鍵数/
だけんそくど /打鍵速度/
だげき /打撃/
だげきかんりょうご /打撃完了後/
だげきけい /打撃系/
だげきけっか /打撃結果/
だげきじん /打撃陣/
だげきせいせき /打撃成績/
だげきせん /打撃戦/
だげきとうしゅ /打撃投手/
だげきふしん /打撃不振/
だげきぶもん /打撃部門/
だげきめん /打撃面/
だげきりょく /打撃力/
だげきれんしゅう /打撃練習/
だげきわざ /打撃技/
だげん /打弦/
だこう /蛇行/
だこうとうてい /打高投低/
だこく /打刻/
ださ /打差/
ださく /駄作/
ださん /打算/
ださんてき /打算的/
だざい /太宰/
だざいおさむ /太宰治/
だざいふ /太宰府/
だざいふてんまんぐう /太宰府天満宮/
だし /山車/
だしいれ /出し入れ/
だしおしみ /出し惜しみ/
だしかた /出し方/
だしもの /出し物/
だしゃ /打者/
だしゃすう /打者数/
だしゃそうしゃ /打者走者/
だしん /打診/
だじゃれ /駄洒落/
だじゅん /打順/
だじょうかんれい /太政官令/
だすう /打数/
だせい /惰性/
だせいうんどう /惰性運動/
だせいしん /惰性心/
だせいそうこう /惰性走行/
だせき /打席/
だせきすう /打席数/
だせん /打線/
だそく /蛇足/
だそくへん /蛇足編/
だたい /堕胎/
だたいざい /堕胎罪/
だだ /駄々/
だだゆき /忠幸/
だち /達/逹/
だちょう /駝鳥/鴕鳥/
だちん /駄賃/
だっ /脱/
だっかい /脱会/奪回/
だっかいさくせん /奪回作戦/
だっかいせん /奪回戦/
だっかん /奪還/
だっき /妲己/妲妃/
だっきゃく /脱却/
だっきゅう /脱臼/
だっこ /抱っこ/
だっこう /脱稿/
だっこく /脱穀/
だっこくき /脱穀機/
だっし /脱脂/
だっしふんにゅう /脱脂粉乳/
だっしめん /脱脂綿/
だっしゅ /ダッシュ/奪取/
だっしゅう /脱臭/
だっしゅうき /脱臭器/
だっしゅうざい /脱臭剤/
だっしゅつ /脱出/
だっしゅつしゅだん /脱出手段/
だっしゅつじ /脱出時/
だっしゅつそくど /脱出速度/
だっしゅつちょくご /脱出直後/
だっしゅつふかのう /脱出不可能/
だっしゅつほう /脱出法/
だっしゅつほうほう /脱出方法/
だっしゅつりんかいてん /脱出臨界点/
だっしょく /脱色/
だっすい /脱水/
だっすいこうか /脱水効果/
だっすいしぼう /脱水死亡/
だっすいしゅうりょうじ /脱水終了時/
だっすいしょう /脱水症/
だっすいしょうじょう /脱水症状/
だっすいそう /脱水槽/
だっすいどうさ /脱水動作/
だっすいはんのう /脱水反応/
だっせん /脱線/
だっせんこうさ /脱線交差/
だっせんじこ /脱線事故/
だっせんわだい /脱線話題/
だっそう /脱走/
だったい /脱退/奪胎/
だったいご /脱退後/
だったいほうほう /脱退方法/
だったん /韃靼/
だっちゃく /脱着/
だっちゃくか /脱着可/
だっちょう /脱腸/脱調/
だっと /脱兎/
だっとう /脱党/
だっぴ /脱皮/
だっぴちゅう /脱皮中/
だっぷん /脱糞/
だっぽう /脱法/
だっぽうこうい /脱法行為/
だつ /脱/奪/妲/怛/獺/
だつい /脱衣/
だついしつ /脱衣室/
だついじょ /脱衣所/脱衣場/
だついじょう /脱衣場/
だつごく /脱獄/
だつさら /脱サラ/
だつさんしん /奪三振/
だつさんしんおう /奪三振王/
だつさんしんすう /奪三振数/
だつさんしんりつ /奪三振率/
だつしゅりつ /奪取率/
だつじ /脱字/
だつせぞくしゃかい /脱世俗社会/
だつぜい /脱税/
だつぞく /脱俗/
だつぶんか /脱分化/
だつほうこうい /脱法行為/
だつぼう /脱帽/
だつもう /脱毛/
だつもうほうほう /脱毛方法/
だつらく /脱落/
だつらくしゃ /脱落車/脱落者/
だつり /脱離/
だつりゃく /奪略/奪掠/
だつりゅう /脱硫/
だつりゅうか /脱硫化/
だつりょく /脱力/
だつりょくかん /脱力感/
だつりん /脱輪/
だて /館/伊達/舘/点/
だておとこ /伊達男/
だてがた /伊達方/
だてがわ /伊達川/
だてきみこ /伊達公子/
だてどの /伊達殿/
だてまさむね /伊達政宗/
だてもんべつ /伊達紋別/
だてん /打点/
だてんおう /打点王/
だてんし /堕天使/
だでん /打電/
だとう /妥当/打倒/
だとうしごく /妥当至極/
だとうせい /妥当性/
だな /棚/
だに /谷/壁蝨/
だは /打破/
だはく /打拍/
だひつ /惰筆/
だび /荼毘/
だびんぐ /ダビング/
だぶつ /陀仏/
だぶる /ダブル/
だぶるくりっく /ダブルクリック/
だぶん /駄文/
だほ /拿捕/
だほう /打法/
だぼう /打忘/
だぼく /打撲/
だま /玉/
だましうち /騙し討ち/
だみー /ダミー/
だみん /惰眠/
だむ /ダム/
だめ /駄目/ダメ/
だめーじ /ダメージ/
だめおし /駄目押し/
だらく /堕落/
だりつ /打率/
だりょく /惰力/
だりん /舵輪/
だるま /達磨/
だれ /誰/
だれあて /誰宛/
だれか /誰か/
だれかさん /誰かさん/
だれかば /誰カバ/
だれかれ /誰彼/
だれだれ /誰誰/誰々/
だれひとり /誰一人/
だん /段/談/弾/断/団/男/暖/檀/壇/團/彈/斷/煖/騨/旦/椴/灘/
だん< /団/
だん> /団/
だんあつ /弾圧/彈壓/
だんあつせいじ /弾圧政治/
だんい /段位/
だんいしゅとく /段位取得/
だんいにんていしょう /段位認定証/
だんいん /団員/
だんいんしかく /団員資格/
だんいんばんごう /団員番号/
だんおち /檀越/
だんおつ /檀越/
だんおんたい /暖温帯/
だんか /檀家/
だんかい /段階/団塊/
だんかいせだい /団塊世代/
だんかいてき /段階的/
だんかいてきしょうさいか /段階的詳細化/
だんかいろしゅつ /段階露出/
だんかん /段間/
だんがい /弾劾/断崖/彈劾/
だんがいぜっぺき /断崖絶壁/
だんがん /弾丸/彈丸/
だんがんとっきゅう /弾丸特急/
だんがんれっしゃ /弾丸列車/
だんき /暖機/暖気/団旗/
だんきうんてん /暖機運転/暖気運転/
だんきゅう /段丘/檀弓/段級/
だんきゅうい /段級位/
だんきろく /団鬼六/
だんきん /弾琴/断琴/断金/
だんぎ /談議/談義/
だんくみ /段組/
だんぐみ /段組/
だんけつ /団結/
だんけつけん /団結権/
だんけつりょく /団結力/
だんげん /断言/
だんこ /断固/断乎/
だんこう /断交/断行/団交/
だんこきょひ /断固拒否/
だんここうぎ /断固抗議/
だんこん /男根/弾痕/
だんご /団子/
だんごう /談合/
だんごうざか /談合坂/
だんごじょう /団子状/
だんごじょうたい /団子状態/
だんごばな /だんご鼻/
だんさ /段差/
だんさい /断裁/
だんざい /断罪/斬罪/
だんし /男子/弾指/談志/檀紙/
だんしがくせい /男子学生/
だんしけっしょう /男子決勝/
だんしこう /男子校/男子高/
だんしこうこう /男子高校/
だんししゃいん /男子社員/
だんしせいと /男子生徒/
だんしちゅうがくせい /男子中学生/
だんしどうよう /男子同様/
だんしはつ /男子初/
だんしめい /男子名/
だんしゃ /檀車/
だんしゃく /男爵/
だんしゃくふじん /男爵夫人/
だんしゅ /断種/断首/
だんしゅせいさく /断種政策/
だんしょう /談笑/断章/男娼/
だんしょく /暖色/男色/
だんしょくけい /暖色系/
だんしよう /男子用/
だんしようちえんじ /男子幼稚園児/
だんしりょう /男子寮/
だんしん /弾芯/
だんじ /男児/
だんじき /断食/
だんじく /段軸/
だんじくしき /段軸式/
だんじて /断じて/
だんじゅうろう /團十郎/団十郎/
だんじょ /男女/
だんじょいっしょ /男女一緒/
だんじょいったい /男女一体/
だんじょう /壇上/
だんじょかくさ /男女格差/
だんじょかん /男女間/
だんじょかんけい /男女関係/
だんじょくべつ /男女区別/
だんじょけっしょう /男女決勝/
だんじょけんよう /男女兼用/
だんじょこうさい /男女交際/
だんじょこんごう /男女混合/
だんじょこんざい /男女混在/
だんじょこんせい /男女混成/
だんじょさ /男女差/
だんじょさべつ /男女差別/
だんじょそうほうむき /男女双方向/
だんじょとも /男女共/
だんじょどういつちんぎん /男女同一賃金/
だんじょどうけん /男女同権/
だんじょひ /男女比/
だんじょびょうどう /男女平等/
だんじょべつ /男女別/
だんじょべつへんせい /男女別編成/
だんじょもんだい /男女問題/
だんじょりょうきんかくさ /男女料金格差/
だんす /ダンス/
だんすい /断水/
だんすう /弾数/段数/
だんせい /男性/男声/弾性/
だんせいか /男性化/
だんせいかしゅ /男性歌手/
だんせいがく /男性学/弾性学/
だんせいがた /男性形/
だんせいがっしょう /男声合唱/
だんせいがっしょうだん /男声合唱団/
だんせいがわ /男性側/
だんせいきつえんしゃ /男性喫煙者/
だんせいきゃく /男性客/
だんせいけい /弾性系/
だんせいけしょうひん /男性化粧品/
だんせいこういん /男性行員/
だんせいさいこん /男性再婚/
だんせいさっか /男性作家/
だんせいさべつ /男性差別/
だんせいさんらん /弾性散乱/
だんせいしゃいん /男性社員/
だんせいしゃかい /男性社会/
だんせいしゃしょう /男性車掌/
だんせいしゅたい /男性主体/
だんせいしょこん /男性初婚/
だんせいしょし /男性諸子/男性諸氏/
だんせいしんり /男性心理/
だんせいじん /男性陣/
だんせいせんよう /男性専用/
だんせいぞう /男性像/
だんせいたい /弾性体/
だんせいてき /男性的/
だんせいは /弾性波/
だんせいばん /弾性板/
だんせいひょう /男性票/
だんせいふたり /男性二人/
だんせいむけ /男性向/
だんせいめい /男性名/
だんせいよう /男性用/
だんせいようけしょうひん /男性用化粧品/
だんせいりょうきん /男性料金/
だんせいろん /弾性論/
だんせいわしゃ /男性話者/
だんせん /断線/
だんせんちてん /断線地点/
だんぜつ /断絶/
だんぜん /断然/
だんぜんかくじつ /断然確実/
だんぜんにんき /断然人気/
だんそう /断層/男装/弾倉/
だんそうさつえい /断層撮影/
だんそうしゃしん /断層写真/
だんそうほう /断層法/
だんそうめん /断層面/
だんそん /男尊/
だんそんじょひ /男尊女卑/
だんそんじょひしゅぎ /男尊女卑主義/
だんそんじょひしゅぎしゃ /男尊女卑主義者/
だんぞく /断続/
だんぞくさつえい /断続撮影/
だんぞくせっさく /断続切削/
だんぞくてき /断続的/
だんぞくへいこうせつ /断続平衡説/
だんたい /団体/弾帯/彈帶/暖帯/
だんたいうんちん /団体運賃/
だんたいえんぎ /団体演技/
だんたいかん /団体間/
だんたいきゃく /団体客/
だんたいきゃくよう /団体客用/
だんたいきょうぎ /団体競技/
だんたいけんきん /団体献金/
だんたいこうしょう /団体交渉/
だんたいこうどう /団体行動/
だんたいせん /団体戦/
だんたいせんよう /団体専用/
だんたいぜんたい /団体全体/
だんたいそうび /団体装備/
だんたいない /団体内/
だんたいめい /団体名/
だんたいよう /団体用/
だんたいよやく /団体予約/
だんたいりょうきん /団体料金/
だんたいりょこう /団体旅行/
だんたいりょこうきゃく /団体旅行客/
だんたいりよう /団体利用/
だんたいわく /団体枠/
だんたいわりびき /団体割引/
だんたにさんぎょう /段谷産業/
だんだ /段田/
だんだん /段々/
だんち /団地/暖地/
だんちゃく /弾着/彈着/
だんちょう /団長/断腸/
だんちょうだいり /団長代理/
だんてい /断定/
だんていちょう /断定調/
だんていてき /断定的/
だんと /檀徒/
だんとう /暖冬/弾頭/彈頭/
だんとうだい /断頭台/
だんとつ /断突/
だんどう /弾道/彈道/
だんどううんどう /弾道運動/
だんどうがく /弾道学/
だんどうひこう /弾道飛行/
だんどり /段取り/
だんな /旦那/
だんなさま /旦那様/
だんねつ /断熱/
だんねつざい /断熱材/
だんねつじっけん /断熱実験/
だんねつせい /断熱性/
だんねつせいのう /断熱性能/
だんねつふく /断熱服/
だんねん /断念/
だんのうら /壇ノ浦/
だんばん /檀板/
だんぱつ /断髪/
だんぱつしき /断髪式/
だんぱん /談判/
だんびら /段平/
だんぴつ /断筆/
だんふみ /壇ふみ/檀ふみ/
だんぷ /ダンプ/
だんぺん /断片/
だんぺんか /断片化/
だんぺんぐん /断片群/
だんぺんてき /断片的/
だんぺんてきちしき /断片的知識/
だんぼーる /段ボール/
だんぼう /暖房/煖房/
だんぼうかんり /暖房管理/
だんぼうき /暖房機/暖房器/
だんぼうちゅう /暖房中/
だんぼうひ /暖房費/
だんぼうよう /暖房用/
だんまく /弾幕/彈幕/
だんまつま /断末魔/断末摩/
だんみん /断眠/
だんめ /段目/
だんめん /断面/
だんめんず /断面図/
だんめんせき /断面積/
だんめんゆそうりょう /断面輸送量/
だんやく /弾薬/彈藥/
だんやくちょぞうこ /弾薬貯蔵庫/
だんゆう /男優/
だんらく /段落/談楽/
だんらくかん /段落間/
だんらくめ /段落目/
だんらくめい /段落名/
だんらくわく /段落枠/
だんらん /団欒/団らん/檀欒/
だんりゅう /暖流/
だんりょく /弾力/
だんりょくせい /弾力性/
だんりょくてき /弾力的/
だんりん /檀林/
だんれいぼう /暖冷房/
だんれいぼうひ /暖冷房費/
だんれつ /断裂/
だんろ /暖炉/煖爐/煖炉/
だんろんぽう /段論法/
だんわ /談話/
だんわかい /談話会/
だんわしつ /談話室/
だんわりかい /談話理解/
ち /値/地/知/恥/血/遅/致/置/智/家/馳/茅/蜘/千/痴/池/稚/弛/治/質/乳/魑/薙/緻/夂/夊/岻/癡/穉/笞/耻/胝/褫/踟/躓/輊/遲/黐/黹/
ちーず /チーズ/
ちーふ /チーフ/
ちーむ /チーム/
ちあき /千秋/千晶/千昌/千明/千章/千亜紀/
ちあゆ /稚鮎/
ちあん /治安/
ちあんいじ /治安維持/
ちあんいじほう /治安維持法/
ちあんかつどう /治安活動/
ちあんきょく /治安局/
ちあんじょう /治安上/
ちあんじょうきょう /治安状況/
ちあんじょうたい /治安状態/
ちい /地位/地衣/地異/
ちいき /地域/値域/
ちいきかいはつ /地域開発/
ちいきかいはつたんとう /地域開発担当/
ちいきかくさ /地域格差/
ちいきかん /地域間/
ちいきがい /地域外/
ちいきがた /地域型/
ちいきくぶん /地域区分/
ちいきけい /地域系/
ちいきげんてい /地域限定/
ちいきげんていはつばい /地域限定発売/
ちいきこゆう /地域固有/
ちいきご /地域語/
ちいきさ /地域差/
ちいきしゃかい /地域社会/
ちいきしょく /地域色/
ちいきじゅうみん /地域住民/
ちいきじょうほう /地域情報/
ちいきせい /地域性/
ちいきせいかつ /地域生活/
ちいきせいしん /地域精神/
ちいきそうごかん /地域相互間/
ちいきたんい /地域単位/
ちいきだいひょう /地域代表/
ちいきてき /地域的/
ちいきとくゆう /地域特有/
ちいきない /地域内/
ちいきばん /地域版/
ちいきぶん /地域分/
ちいきぶんか /地域文化/
ちいきぶんかつがた /地域分割型/
ちいきぶんぷ /地域分布/
ちいきぶんり /地域分離/
ちいきべつ /地域別/
ちいきみっちゃく /地域密着/
ちいきめい /地域名/
ちいく /知育/
ちいこうじょう /地位向上/
ちいこうじょういいん /地位向上委員/
ちいじょうはんてい /地上判定/
ちいといつ /七対子/
ちいほう /地和/
ちぇーん /チェーン/
ちぇあまん /チェアマン/
ちぇこすろばきあ /捷克/
ちぇす /チェス/
ちぇっかー /チェッカー/
ちぇっく /チェック/
ちぇんじ /チェンジ/
ちえ /知恵/千絵/知枝/智恵/知衣/千英/知江/知重/智慧/知惠/知慧/千枝/
ちえこ /千恵子/千枝子/知恵子/智恵子/
ちえねつ /知恵熱/
ちえぶくろ /知恵袋/
ちえみ /千絵美/智枝美/千恵美/智栄美/智恵美/
ちえり /智恵理/
ちえん /遅延/地縁/
ちえんかきこみ /遅延書きこみ/
ちえんじかん /遅延時間/
ちえんじょうきょう /遅延状況/
ちえんせん /遅延線/
ちえんは /遅延波/
ちえんひょうか /遅延評価/
ちえんめいれい /遅延命令/
ちえんりそく /遅延利息/
ちおりゅうさんしおるい /チオ硫酸塩類/
ちおんいん /知恩院/
ちか /地下/地価/近/知佳/知華/知夏/値化/知可/智香/治下/親/千夏/智加/智佳/
ちかい /地階/邇/近井/
ちかいっかい /地下一階/
ちかえき /地下駅/
ちかお /知馨夫/周夫/親雄/
ちかか /地下化/
ちかかいさつまえ /地下改札前/
ちかかこうじ /地下化工事/
ちかかすいしん /地下化推進/
ちかかつどう /地下活動/
ちかがい /地下街/
ちかきち /地下基地/
ちかきゅうこうせん /地下急行線/
ちかきょく /地下局/
ちかく /地殻/知覚/
ちかくうかん /地下空間/
ちかくかてい /知覚過程/
ちかくかん /地下区間/
ちかくきこう /知覚機構/
ちかくくうかん /知覚空間/
ちかくしゃくど /知覚尺度/
ちかくしょり /知覚処理/
ちかくしんりがく /知覚心理学/
ちかくじょう /知覚上/
ちかくせい /知覚性/
ちかくぞう /知覚像/
ちかくてき /知覚的/
ちかくないよう /知覚内容/
ちかくのうりょく /知覚能力/
ちかくへんどう /地殻変動/
ちかけい /地下茎/
ちかこ /千香子/智加子/ちか子/渠睦子/千嘉子/千賀子/智香子/知可子/千加子/睦子/
ちかごろ /近頃/
ちかざわ /近澤/
ちかし /迩/
ちかしげん /地下資源/
ちかしつ /地下室/
ちかしゃこ /地下車庫/
ちかしょくどう /地下食堂/
ちかじか /近々/
ちかすい /地下水/
ちかずみ /近角/
ちかせかい /地下世界/
ちかせん /地下線/
ちかせんよう /地下線用/
ちかそうこ /地下倉庫/
ちかそしき /地下組織/
ちかだ /近田/
ちかちゅうしゃじょう /地下駐車場/
ちかぢか /近々/
ちかつうろ /地下通路/
ちかてつ /地下鉄/
ちかてつあさしおばし /地下鉄朝潮橋/
ちかてついけぶくろえき /地下鉄池袋駅/
ちかてつえき /地下鉄駅/
ちかてつえんしん /地下鉄延伸/
ちかてつかくせん /地下鉄各線/
ちかてつきょうつう /地下鉄共通/
ちかてつぎんざせん /地下鉄銀座線/
ちかてつくかん /地下鉄区間/
ちかてつけんよう /地下鉄兼用/
ちかてつこうじ /地下鉄工事/
ちかてつしゃない /地下鉄車内/
ちかてつせん /地下鉄線/
ちかてつぜんくかん /地下鉄全区間/
ちかてつたにまちせん /地下鉄谷町線/
ちかてつつるまいせん /地下鉄鶴舞線/
ちかてつでんしゃ /地下鉄電車/
ちかてつとうざいせん /地下鉄東西線/
ちかてつないぶ /地下鉄内部/
ちかてつはくぶつかん /地下鉄博物館/
ちかてつひがしやません /地下鉄東山線/
ちかてつほうめん /地下鉄方面/
ちかてつめいじょうせん /地下鉄名城線/
ちかてつもう /地下鉄網/
ちかてつれんらくつうろ /地下鉄連絡通路/
ちかてつろせん /地下鉄路線/
ちかどう /地下道/
ちかどうくつ /地下洞窟/
ちかば /近場/
ちかひろ /近広/近廣/
ちかぶぶん /地下部分/
ちかま /近間/
ちかまつ /近松/
ちかみち /近道/
ちかやま /近山/
ちかよう /地下用/
ちかよくせい /地価抑制/
ちから /力/主税/千賀良/
ちからいがい /力以外/
ちからいっぱい /力一杯/
ちからいと /力糸/
ちからおとし /力落とし/
ちからかげん /力加減/
ちからかんけい /力関係/
ちからこぶ /力瘤/
ちからさ /力差/
ちからしごと /力仕事/
ちからじこく /力時刻/
ちからじまん /力自慢/
ちからせいぎょ /力制御/
ちからせいぶん /力成分/
ちからぞえ /力添え/
ちからてき /力的/
ちからぶそく /力不足/
ちからもち /力持ち/力餅/
ちからわざ /力技/
ちかれんらくつうろ /地下連絡通路/
ちかろう /地下牢/
ちかろせん /地下路線/
ちかん /置換/痴漢/置喚/弛緩/
ちかんぐん /置換群/
ちかんこうい /痴漢行為/
ちかんご /置換後/
ちかんし /置換子/
ちかんひょうげん /置換表現/
ちかんめい /置換名/
ちかんもじ /置換文字/
ちかんもじれつ /置換文字列/
ちが /違/千賀/
ちがい /違い/
ちがいほうけん /治外法権/
ちがく /地学/
ちがくざっし /地学雑誌/
ちがくしつ /地学室/
ちがくぶ /地学部/
ちがさき /茅ヶ崎/
ちがさきし /茅ヶ崎市/
ちがっか /地学科/
ちがや /茅/
ちき /知己/飭/稙/
ちきゅう /地球/恥丘/
ちきゅうおんだんか /地球温暖化/
ちきゅうかがく /地球科学/
ちきゅうかんきょう /地球環境/
ちきゅうかんきょうてき /地球環境的/
ちきゅうがい /地球外/
ちきゅうがいせいぶつ /地球外生物/
ちきゅうがいせいめい /地球外生命/
ちきゅうがた /地球型/
ちきゅうがわ /地球側/
ちきゅうきこう /地球紀行/
ちきゅうきどうじょう /地球軌道上/
ちきゅうきぼ /地球規模/
ちきゅうきょうつうご /地球共通語/
ちきゅうきんぺん /地球近辺/
ちきゅうぎ /地球儀/
ちきゅうぐん /地球軍/
ちきゅうけい /地球系/
ちきゅうけんきゅう /地球研究/
ちきゅうこく /地球国/
ちきゅうさいご /地球最後/
ちきゅうさいだい /地球最大/
ちきゅうしつてん /地球質点/
ちきゅうしつりょう /地球質量/
ちきゅうしゃ /地球社/
ちきゅうしんだん /地球診断/
ちきゅうしんにゅう /地球侵入/
ちきゅうしんりゃく /地球侵略/
ちきゅうじかん /地球時間/
ちきゅうじしん /地球自身/
ちきゅうじば /地球磁場/
ちきゅうじゆうしんどう /地球自由振動/
ちきゅうじょう /地球上/
ちきゅうじん /地球人/
ちきゅうじんどうし /地球人同士/
ちきゅうせい /地球製/
ちきゅうせいじん /地球星人/
ちきゅうせいふく /地球征服/
ちきゅうせいめい /地球生命/
ちきゅうせん /地球船/
ちきゅうぜんたい /地球全体/
ちきゅうたいき /地球大気/
ちきゅうちゅうしんかく /地球中心核/
ちきゅうていこく /地球帝国/
ちきゅうてき /地球的/
ちきゅうてきけんち /地球的見地/
ちきゅうでんじき /地球電磁気/
ちきゅうどけい /地球時計/
ちきゅうはつ /地球発/
ちきゅうはんけい /地球半径/
ちきゅうぶつり /地球物理/
ちきゅうぶつりがく /地球物理学/
ちきゅうぶつりがっか /地球物理学科/
ちきゅうぶつりや /地球物理屋/
ちきゅうぶつりよう /地球物理用/
ちきゅうほうこう /地球方向/
ちきゅうぼうえい /地球防衛/
ちきゅうぼうえいぐん /地球防衛軍/
ちきゅうみさき /地球岬/
ちきゅうりゅうたい /地球流体/
ちきゅうれんぽう /地球連邦/
ちきゅうれんぽうぐん /地球連邦軍/
ちきゅうわくせいぶつり /地球惑星物理/
ちきゅうわくせいぶつりがく /地球惑星物理学/
ちきゅうわくせいぶつりがくきょうしつ /地球惑星物理学教室/
ちきょう /地峡/
ちきん /チキン/
ちきんかつ /チキンカツ/
ちぎ /杠/
ちぎょ /稚魚/
ちぎょうち /知行地/
ちぎり /契/千切/
ちく /逐/地区/蓄/竹/筑/築/畜/矗/
ちくあん /竹安/
ちくい /築井/
ちくいち /逐一/
ちくおんき /蓄音機/
ちくかん /地区間/竹簡/
ちくきょう /地区協/
ちくご /逐語/筑後/築後/
ちくごがわ /筑後川/
ちくごてき /逐語的/
ちくごふくしまえき /筑後福島駅/
ちくごやく /逐語訳/
ちくさ /千種/
ちくさく /千種区/
ちくさつ /畜殺/
ちくさん /畜産/
ちくさんしけんじょう /畜産試験場/
ちくさんのうか /畜産農家/
ちくざい /蓄財/
ちくし /筑紫/
ちくしぐち /筑紫口/
ちくしじ /筑紫路/
ちくしてつや /筑紫哲也/
ちくしの /筑紫野/
ちくしゅい /地区首位/
ちくしょう /畜生/
ちくじ /逐次/
ちくじか /逐次化/
ちくじかんこうぶつ /逐次刊行物/
ちくじがた /逐次型/
ちくじがたすいろん /逐次型推論/
ちくじきんじ /逐次近似/
ちくじけいさん /逐次計算/
ちくじけいさんき /逐次計算機/
ちくじげんご /逐次言語/
ちくじこうひょう /逐次公表/
ちくじしょり /逐次処理/
ちくじじっこう /逐次実行/
ちくじじどうへんかん /逐次自動変換/
ちくじせい /逐次性/
ちくじてき /逐次的/
ちくじてきおうせいぎょ /逐次適応制御/
ちくじにゅうりょく /逐次入力/
ちくじひょうか /逐次評価/
ちくじへんかん /逐次変換/
ちくじょう /築上/築城/逐条/
ちくじれんらく /逐次連絡/
ちくせき /蓄積/
ちくせきがた /蓄積型/
ちくせきそうしん /蓄積送信/
ちくせきそうち /蓄積装置/
ちくせん /地区戦/
ちくぜん /竹善/筑前/
ちくぜんに /筑前煮/
ちくぞう /築造/
ちくたいかい /地区大会/
ちくだいひょう /地区代表/
ちくてん /逐電/
ちくでん /蓄電/逐電/
ちくでんち /蓄電池/
ちくない /地区内/
ちくなんねん /築何年/
ちくねつ /蓄熱/
ちくねつしき /蓄熱式/
ちくねん /逐年/
ちくのうしょう /蓄膿症/
ちくは /竹葉/
ちくはく /竹帛/
ちくば /竹馬/
ちくひ /竹扉/
ちくひせん /筑肥線/
ちくび /乳首/
ちくべつ /地区別/
ちくほ /筑穂/
ちくほう /筑豊/
ちくほうちほう /筑豊地方/
ちくほうでんてつ /筑豊電鉄/
ちくほうほんせん /筑豊本線/
ちくま /筑摩/
ちくまがわ /千曲川/
ちくましょぼう /筑摩書房/
ちくめい /地区名/
ちくゆうしょう /地区優勝/
ちくよせん /地区予選/
ちくら /千倉/
ちくりん /竹林/
ちくれいねつ /蓄冷熱/
ちくわ /竹輪/
ちくわふ /竹輪麩/
ちくん /治勲/
ちぐさ /千種/千草/
ちぐさく /千種区/
ちけい /地形/
ちけいがく /地形学/
ちけいこうか /地形効果/
ちけいず /地形図/
ちけいてき /地形的/
ちけっと /チケット/
ちけん /知見/地検/地圏/
ちけんしゃ /地権者/
ちこう /恥垢/地皇/
ちこうせい /遅効性/
ちこうふう /地衡風/
ちこうらんりゅう /地衡乱流/
ちこうりゅう /地衡流/
ちこく /遅刻/
ちこくげんきん /遅刻厳禁/
ちこくしどう /遅刻指導/
ちこくしゃ /遅刻者/
ちこくしゃたいさく /遅刻者対策/
ちこつ /恥骨/
ちこつけつごうえん /恥骨結合炎/
ちご /稚子/稚児/乳児/
ちさ /智佐/知砂/千沙/
ちさい /地裁/
ちさく /千咲/
ちさこ /知紗子/千佐子/
ちさと /千里/
ちさん /治山/地産/遅参/
ちざいけん /知財権/
ちざいぶ /知財部/
ちし /致死/致仕/智歯/地誌/
ちしお /血潮/
ちしき /知識/
ちしきいがい /知識以外/
ちしきかがく /知識科学/
ちしきぎじゅつしゃ /知識技術者/
ちしきぎのう /知識技能/
ちしきげん /知識源/
ちしきこうがく /知識工学/
ちしきこうがくしゃ /知識工学者/
ちしきこうがくてき /知識工学的/
ちしきこうぞう /知識構造/
ちしきさいりよう /知識再利用/
ちしきしっこうやくいん /知識執行役員/
ちしきしゅうやくてき /知識集約的/
ちしきしゅどうがた /知識主導型/
ちしきしょり /知識処理/
ちしきしょりこうがく /知識処理工学/
ちしきじたい /知識自体/
ちしきじょうほうこうがく /知識情報工学/
ちしきじょうほうしょり /知識情報処理/
ちしきじん /知識人/
ちしきすいじゅん /知識水準/
ちしきそう /知識層/
ちしきたいけい /知識体系/
ちしきたんとうやくいん /知識担当役員/
ちしきとう /知識等/
ちしきとうかつやくいん /知識統括役員/
ちしきひょうげん /知識表現/
ちしきひょうげんけいしき /知識表現形式/
ちしきひょうげんじょう /知識表現上/
ちしきぶそく /知識不足/
ちしきべーす /知識ベース/
ちしきほうふ /知識豊富/
ちしきよく /知識欲/
ちしきりょう /知識量/
ちしつ /地質/知悉/
ちしつがく /地質学/
ちしつがくてき /地質学的/
ちしつずさくいんず /地質図索引図/
ちしつちょうさしょ /地質調査所/
ちしてき /致死的/
ちしぶき /血飛沫/
ちしま /千島/
ちしまれっとう /千島列島/
ちしゃ /知者/苣/
ちしょ /地所/
ちしょう /知将/致傷/
ちしょうりょく /致傷力/
ちしりつ /致死率/
ちしりょう /致死量/
ちしりょうれんさ /致死量連鎖/
ちしろ /千代/
ちしん /地心/
ちじ /知事/
ちじき /地磁気/
ちじきかんそくしょ /地磁気観測所/
ちじく /地軸/
ちじせん /知事選/
ちじつ /遅日/
ちじゅんほう /置閏法/
ちじょう /地上/痴情/笞杖/
ちじょうえき /地上駅/
ちじょうかそくど /地上加速度/
ちじょうきちがわ /地上基地側/
ちじょうきょく /地上局/
ちじょうくかん /地上区間/
ちじょうけい /地上茎/
ちじょうけんちく /地上建築/
ちじょうこうげき /地上攻撃/
ちじょうこうげきよう /地上攻撃用/
ちじょうさいきょう /地上最強/
ちじょうさいだい /地上最大/
ちじょうさくてきのう /地上索敵能/
ちじょうしせつ /地上施設/
ちじょうしだん /地上師団/
ちじょうせつび /地上設備/
ちじょうせん /地上戦/地上線/
ちじょうせんとつにゅう /地上戦突入/
ちじょうそうこうしゃ /地上走行車/
ちじょうは /地上波/
ちじょうはほうそう /地上波放送/
ちじょうぶ /地上部/
ちじょうぶつ /地上物/
ちじょうぶぶん /地上部分/
ちじょうほうそう /地上放送/
ちじょうぼうえんきょう /地上望遠鏡/
ちじょうよう /地上用/
ちじょうわざ /地上技/
ちじょく /恥辱/
ちじん /知人/痴人/地人/
ちじんかんけい /知人関係/
ちじんけいゆ /知人経由/
ちじんたく /知人宅/
ちじんたくはく /知人宅泊/
ちじんたち /知人達/
ちすい /治水/
ちすいかふう /地水火風/
ちすじ /血筋/
ちすわ /千須和/
ちず /地図/千寿/智頭/
ちずか /地図化/
ちずきゅうこう /智頭急行/
ちずこ /千寿子/千鶴子/知寿子/
ちずしき /地図式/
ちずじょう /地図上/
ちずじょうほう /地図情報/
ちずせん /智頭線/
ちずちょう /地図帳/
ちずてき /地図的/
ちずてつどう /智頭鉄道/
ちずてん /地図店/
ちずばんじょう /地図板上/
ちずや /地図屋/
ちせ /知世/
ちせい /知性/治世/地勢/痴性/
ちせいか /知性化/
ちせいかせんそう /知性化戦争/
ちせいがく /地政学/
ちせいたい /知性体/
ちせいてき /知性的/
ちせいは /知性派/
ちせこ /智勢子/
ちせつ /稚拙/
ちそう /馳走/地層/
ちそく /遅速/
ちた /知多/
ちたい /地帯/遅滞/
ちたぐん /知多郡/
ちたし /知多市/
ちたね /千種/
ちたねく /千種区/
ちたはんとう /知多半島/
ちだ /千田/
ちだい /地代/
ちち /父/乳/遅々/義父/
ちちうえ /父上/
ちちうし /乳牛/
ちちおや /父親/
ちちおやさんかん /父親参観/
ちちおやじしん /父親自身/
ちちおやに /父親似/
ちちおやゆらい /父親由来/
ちちかた /父方/
ちちがた /父方/
ちちぎみ /父君/
ちちけんり /父権制/
ちちじま /父島/
ちちぶ /秩父/
ちちぶさん /秩父山/
ちちぶし /秩父市/
ちちぶてつどう /秩父鉄道/
ちちぶのみや /秩父宮/
ちちまつ /千々松/
ちちむすめ /父娘/
ちちゅう /地中/
ちちゅうかい /地中海/
ちちょう /地調/
ちぢ /千々/
ちぢみ /縮/
ちぢわ /千々石/
ちっきょ /蟄居/
ちっこう /築港/
ちっこうせん /築港線/
ちっそ /窒素/
ちっそく /窒息/
ちっそくし /窒息死/
ちっそこんごう /窒素混合/
ちっそさんかぶつ /窒素酸化物/
ちっそじゅうてん /窒素充填/
ちっそぶんあつ /窒素分圧/
ちっと /些と/
ちっとも /些とも/
ちっぷ /チップ/
ちっぷべつ /秩父別/
ちつ /秩/窒/膣/帙/腟/蟄/
ちつじょ /秩序/
ちつじょいじ /秩序維持/
ちつせん /膣栓/
ちつぶんぴつえき /膣分泌液/
ちつみ /千津美/
ちづ /地図/
ちづこ /千鶴子/
ちづる /千鶴/
ちてい /地底/
ちていこ /地底湖/
ちていじん /地底人/
ちてき /知的/
ちてきかつどう /知的活動/
ちてきかつどうしえん /知的活動支援/
ちてきかんきょうこうちく /知的環境構築/
ちてききょうみ /知的興味/
ちてきけいさんき /知的計算機/
ちてきけいさんきしつ /知的計算機室/
ちてきさぎょう /知的作業/
ちてきさぎょうのうりつ /知的作業能率/
ちてきざいさんけん /知的財産権/
ちてきしげき /知的刺激/
ちてきしゅうだん /知的集団/
ちてきしょうがい /知的障害/
ちてきしょうがいしゃ /知的障害者/
ちてきしょゆうけん /知的所有権/
ちてきしょり /知的処理/
ちてきしょりけいさんき /知的処理計算機/
ちてきしょりしすてむ /知的処理システム/
ちてきしんだん /知的診断/
ちてきじょうほうしょり /知的情報処理/
ちてきせいめい /知的生命/
ちてきせいめいたい /知的生命体/
ちてきたいしょう /知的対象/
ちてきたんきゅう /知的探求/
ちてきにんしき /知的認識/
ちてきのうりょく /知的能力/
ちてきび /知的美/
ちてきふごうか /知的符号化/
ちてきふごうかつうしん /知的符号化通信/
ちてつ /地鉄/
ちてん /地点/
ちてんかん /地点間/
ちてんじょう /血天井/
ちてんふきん /地点付近/
ちと /些と/少と/
ちとせ /千歳/千登世/
ちとせからすやま /千歳烏山/
ちとせせん /千歳線/
ちとせづる /千歳鶴/
ちとせばし /千登世橋/
ちとせふなばし /千歳船橋/
ちどうせつ /地動説/
ちどり /千鳥/鵆/
ちどりあし /千鳥足/
ちどりうんてん /千鳥運転/
ちどりがふち /千鳥ヶ淵/
ちどりそうこう /千鳥走行/
ちどりちょう /千鳥町/
ちどりばし /千鳥橋/
ちな /知名/
ちなつ /千夏/
ちなみ /因/
ちにちは /知日派/
ちねつ /地熱/
ちねん /知念/
ちの /茅野/千野/
ちのう /知能/智能/
ちのうか /知能化/
ちのうかがくせんこう /知能科学専攻/
ちのうかつどう /知能活動/
ちのうけい /知能系/
ちのうこうがくけんきゅう /知能工学研究/
ちのうこうがくこうざ /知能工学講座/
ちのうしすう /知能指数/
ちのうしょうがい /知能障害/
ちのうしょうがいしゃ /知能障害者/
ちのうじょうほう /知能情報/
ちのうじょうほうしょり /知能情報処理/
ちのうていど /知能程度/
ちのうてき /知能的/
ちのうてすと /知能テスト/
ちのうはん /知能犯/
ちのうひょうげん /知能表現/
ちのえき /茅野駅/
ちのけ /血の気/
ちのし /茅野市/
ちのね /茅根/
ちのり /血糊/
ちはい /遅配/
ちはつ /遅発/
ちはや /千早/
ちはら /茅原/千原/
ちはる /千春/智春/
ちば /千葉/地場/
ちばいえん /千葉以遠/
ちばいちりつ /千葉市立/
ちばいちりつこうこう /千葉市立高校/
ちばえき /千葉駅/
ちばかん /千葉間/
ちばがわ /千葉側/
ちばきゅうこう /千葉急行/
ちばきゅうこうせん /千葉急行線/
ちばけん /千葉県/
ちばけんいちかわし /千葉県市川市/
ちばけんいなげ /千葉県稲毛/
ちばけんえいてつどう /千葉県営鉄道/
ちばけんきゅうしょ /千葉研究所/
ちばけんさくらし /千葉県佐倉市/
ちばけんしゅうへん /千葉県周辺/
ちばけんじん /千葉県人/
ちばけんたいかい /千葉県大会/
ちばけんたてやまわん /千葉県館山湾/
ちばけんのだし /千葉県野田市/
ちばけんふなばしし /千葉県船橋市/
ちばけんみん /千葉県民/
ちばけんもばらし /千葉県茂原市/
ちばこうぎょうだいがく /千葉工業大学/
ちばこうだい /千葉工大/
ちばし /千葉市/
ちばししゃ /千葉支社/
ちばしみどりく /千葉市緑区/
ちばしゅっしん /千葉出身/
ちばたいかい /千葉大会/
ちばだい /千葉大/
ちばだいがく /千葉大学/
ちばだいりがくぶ /千葉大理学部/
ちばちゅうおう /千葉中央/
ちばつうか /千葉通過/
ちばな /知花/
ちばばん /千葉版/
ちばひがし /千葉東/
ちばひがしこうこう /千葉東高校/
ちばほうめん /千葉方面/
ちばん /地番/
ちひつ /遅筆/
ちひょう /地表/
ちひょうじょう /地表上/
ちひょうすい /地表水/
ちひょうは /地表波/
ちひょうふきん /地表付近/
ちひょうめん /地表面/
ちひろ /千尋/千紘/馳浩/千裕/知宏/
ちふみ /千文/
ちふゆ /千冬/
ちぶ /恥部/知夫/
ちぶくろ /血袋/
ちぶさ /乳房/
ちぶつ /地物/地球物理/
ちぶつけん /地物研/
ちへい /地平/
ちへいせん /地平線/
ちへいせんふきん /地平線付近/
ちへいふみきり /地平踏切/
ちへいめん /地平面/
ちへん /地変/
ちべん /智辯/
ちほ /千穂/智保/地歩/
ちほう /地方/痴呆/
ちほうえんせい /地方遠征/
ちほうか /痴呆化/
ちほうかいさい /地方開催/
ちほうかいじょう /地方会場/
ちほうがわ /地方側/
ちほうきゅうじょう /地方球場/
ちほうきょく /地方局/
ちほうぎょうせい /地方行政/
ちほうく /地方区/
ちほうくうこう /地方空港/
ちほうけいば /地方競馬/
ちほうこう /地方校/
ちほうこうきょうだんたい /地方公共団体/
ちほうこうぎょう /地方興行/
ちほうこうつうせん /地方交通線/
ちほうこうふぜい /地方交付税/
ちほうこうむいん /地方公務員/
ちほうこうむいんほう /地方公務員法/
ちほうこくりつだいがく /地方国立大学/
ちほうご /地方語/
ちほうごうぞく /地方豪族/
ちほうごと /地方毎/
ちほうさ /地方差/
ちほうざいじゅう /地方在住/
ちほうし /地方誌/地方紙/
ちほうしゅっしん /地方出身/
ちほうしょう /痴呆症/
ちほうしょうたい /地方招待/
ちほうしょうたいきょうそう /地方招待競走/
ちほうしょうたいば /地方招待馬/
ちほうしょく /地方色/
ちほうしんぶん /地方新聞/
ちほうしんぶんちょうかん /地方新聞朝刊/
ちほうじ /地方時/
ちほうじち /地方自治/
ちほうじちたい /地方自治体/
ちほうじょうたい /痴呆状態/
ちほうせん /地方線/
ちほうせんきょ /地方選挙/
ちほうぜい /地方税/
ちほうぜいりつ /地方税率/
ちほうたいかい /地方大会/
ちほうだいがく /地方大学/
ちほうだいひょう /地方代表/
ちほうつうしん /地方通信/
ちほうてき /地方的/
ちほうてつどう /地方鉄道/
ちほうてつどうほう /地方鉄道法/
ちほうとくさんひん /地方特産品/
ちほうとし /地方都市/
ちほうどう /地方道/
ちほうどくとく /地方独特/
ちほうば /地方馬/
ちほうばん /地方版/
ちほうぶん /地方分/
ちほうべつ /地方別/
ちほうめい /地方名/
ちほうめん /地方面/
ちほうりょこう /地方旅行/
ちほうれいかい /地方例会/
ちほうろせん /地方路線/
ちぼう /知謀/智謀/
ちぼつご /沈没後/
ちまき /粡/粽/
ちまた /巷/
ちまつり /血祭り/血祭/
ちまなこ /血眼/
ちみ /地味/魑魅/
ちみつ /緻密/
ちみもうりょう /魑魅魍魎/
ちむさーちょい /尖沙咀/
ちむら /地村/
ちめい /地名/致命/知名/
ちめいしょう /致命傷/
ちめいじてん /地名辞典/地名事典/
ちめいせっとうご /地名接頭語/
ちめいてき /致命的/
ちめいてきけっかん /致命的欠陥/
ちめいてきけってん /致命的欠点/
ちめいてきじゃくてん /致命的弱点/
ちめいど /知名度/
ちもう /恥毛/
ちもく /地目/
ちもよう /血模様/
ちゃ /茶/咤/
ちゃーしゅー /焼豚/叉焼/
ちゃーしゅーめん /叉焼麺/
ちゃーじ /チャージ/
ちゃーたー /チャーター/
ちゃーちすくえぁー /チャーチスクエァー/
ちゃーと /チャート/
ちゃーはん /炒飯/チャーハン/
ちゃあはん /炒飯/
ちゃいな /チャイナ/
ちゃいにーず /チャイニーズ/
ちゃいれ /茶入/
ちゃいろ /茶色/
ちゃいろじ /茶色地/
ちゃいろとそう /茶色塗装/
ちゃうけ /茶請け/
ちゃうす /茶臼/
ちゃうすやま /茶臼山/
ちゃお /チャオ/找/
ちゃおず /餃子/
ちゃか /茶化/茶菓/
ちゃかい /茶会/
ちゃかっしょく /茶褐色/
ちゃがし /茶菓子/
ちゃき /茶器/茶木/
ちゃきん /茶巾/
ちゃく /着/嫡/摘/
ちゃくい /着衣/
ちゃくえき /着駅/
ちゃくかくにん /着確認/
ちゃくがい /着外/
ちゃくがん /着眼/着岸/
ちゃくがんちゅう /着岸中/
ちゃくがんてん /着眼点/
ちゃくこう /着工/
ちゃくさ /着差/
ちゃくさいこうぞうが /着彩構造画/
ちゃくざ /着座/
ちゃくざいち /着座位置/
ちゃくし /嫡子/
ちゃくしつ /嫡室/
ちゃくしゅ /着手/
ちゃくしゅつ /嫡出/
ちゃくしょう /着床/
ちゃくしょく /着色/
ちゃくしょくずめん /着色図面/
ちゃくしょくよう /着色用/
ちゃくしょくりょう /着色料/
ちゃくしん /着信/
ちゃくしんかいせん /着信回線/
ちゃくしんがわ /着信側/
ちゃくしんしょり /着信処理/
ちゃくしんせってい /着信設定/
ちゃくしんにんばらい /着信人払い/
ちゃくじ /着磁/
ちゃくじこく /着時刻/
ちゃくじつ /着実/
ちゃくじつに /着実に/
ちゃくじゅん /着順/
ちゃくじゅんけいじばん /着順掲示板/
ちゃくじゅんはっぴょう /着順発表/
ちゃくすい /着水/
ちゃくせい /着生/
ちゃくせいこん /着生根/
ちゃくせき /着席/
ちゃくせきくぶん /着席区分/
ちゃくせきりつ /着席率/
ちゃくせつ /着雪/
ちゃくそう /着想/着装/
ちゃくだつ /着脱/
ちゃくだつかのう /着脱可能/
ちゃくだつじゅうたい /着脱渋滞/
ちゃくだん /着弾/着彈/
ちゃくだんごさ /着弾誤差/
ちゃくだんてん /着弾点/
ちゃくち /着地/
ちゃくちじ /着地時/
ちゃくちてん /着地点/
ちゃくちゃく /着々/着着/
ちゃくてい /着挺/
ちゃくでん /着電/
ちゃくにん /着任/
ちゃくにんじ /着任時/
ちゃくはつ /着発/
ちゃくば /着馬/
ちゃくばらい /着払/着払い/
ちゃくばらいたくはいびん /着払宅配便/
ちゃくひょう /着氷/
ちゃくふく /着服/
ちゃくみ /茶くみ/
ちゃくもく /着目/
ちゃくよう /着用/
ちゃくようぎむ /着用義務/
ちゃくようぎむか /着用義務化/
ちゃくようぎむてっぱい /着用義務撤廃/
ちゃくようしゃ /着用者/
ちゃくようふか /着用不可/
ちゃくようりつ /着用率/
ちゃくりく /着陸/
ちゃくりくしんにゅう /着陸進入/
ちゃくりくちょくぜん /着陸直前/
ちゃくりくてじゅん /着陸手順/
ちゃくりくふのう /着陸不能/
ちゃしつ /茶室/
ちゃしゃく /茶杓/
ちゃじ /茶事/
ちゃせき /茶席/
ちゃせん /茶筅/茶筌/茶せん/
ちゃたん /北谷/
ちゃだい /茶代/
ちゃちゃ /茶々/茶茶/
ちゃちゃまる /茶々丸/
ちゃっか /着火/
ちゃっかそうち /着火装置/
ちゃっかてん /着火点/
ちゃっかん /着艦/
ちゃっけん /着剣/
ちゃっこ /着呼/
ちゃっこう /着工/
ちゃっこうだんかい /着工段階/
ちゃづけ /茶漬/
ちゃづつ /茶筒/
ちゃどう /茶道/
ちゃどうぐ /茶道具/
ちゃない /茶内/
ちゃねる /チャネル/
ちゃのはら /茶之原/
ちゃのま /茶の間/
ちゃのみ /茶飲み/
ちゃばたけ /茶畑/茶畠/
ちゃばん /茶番/
ちゃばんげき /茶番劇/
ちゃぱつ /茶髪/
ちゃぶだい /卓袱台/茶袱台/
ちゃぺる /チャペル/
ちゃぼうず /茶坊主/
ちゃま /茶魔/
ちゃみ /茶美/茶見/
ちゃめ /茶目/
ちゃめっけ /茶目っ気/
ちゃや /茶屋/
ちゃやま /茶山/
ちゃやまだい /茶山台/
ちゃやまち /茶屋町/
ちゃやまちかん /茶屋町間/
ちゃやみち /茶屋道/
ちゃりてぃ /チャリティ/
ちゃれんじ /チャレンジ/
ちゃれんじゃー /チャレンジャー/
ちゃわん /茶碗/
ちゃわんむし /茶碗蒸/
ちゃんす /チャンス/
ちゃんすう /昌洙/
ちゃんねる /チャンネル/
ちやこ /千夜子/
ちゅ /丶/
ちゅーとりある /チュートリアル/
ちゅーな /チューナ/
ちゅーぶ /チューブ/
ちゅう /中/注/宙/昼/駐/虫/忠/註/柱/鋳/酎/抽/衷/仲/蟲/躊/※/沖/厨/儔/冑/冲/惆/晝/疇/畴/稠/籌/籀/紂/綢/胄/誅/鍮/鑄/廚/冢/寵/丑/紬/肘/紐/
ちゅう< /中/
ちゅう> /中/
ちゅうあつ /中厚/
ちゅうい /注意/中尉/中位/
ちゅういかんき /注意喚起/
ちゅういがき /注意書き/
ちゅういき /中域/
ちゅういきだっしゅつきこう /中域脱出機構/
ちゅういげんじ /注意現示/
ちゅういしょ /注意書/
ちゅういじこう /注意事項/
ちゅういち /中一/忠一/
ちゅういてん /注意点/
ちゅういてんとう /注意点等/
ちゅういひょうじ /注意表示/
ちゅういぶん /注意文/
ちゅういほう /注意報/
ちゅういほうかいじょ /注意報解除/
ちゅういほうほう /注意方法/
ちゅういりょく /注意力/
ちゅういりょくぶそく /注意力不足/
ちゅうえい /中衛/中映/
ちゅうえつせんそう /中越戦争/
ちゅうおう /中央/紂王/
ちゅうおういり /中央入/
ちゅうおうえき /中央駅/
ちゅうおうかいそくせん /中央快速線/
ちゅうおうかん /中央館/
ちゅうおうかんこうせん /中央緩行線/
ちゅうおうかんじょうせん /中央環状線/
ちゅうおうがい /中央街/
ちゅうおうがくいん /中央学院/
ちゅうおうがた /中央型/
ちゅうおうがわ /中央側/
ちゅうおうきげんてき /中央起源的/
ちゅうおうきょく /中央局/
ちゅうおうきんき /中央近畿/
ちゅうおうぎけん /中央技研/
ちゅうおうく /中央区/
ちゅうおうぐち /中央口/
ちゅうおうぐちてん /中央口店/
ちゅうおうぐん /中央軍/
ちゅうおうぐんい /中央軍委/
ちゅうおうけいば /中央競馬/
ちゅうおうけいばいがい /中央競馬以外/
ちゅうおうけいばかい /中央競馬会/
ちゅうおうけいばしょうたい /中央競馬招待/
ちゅうおうけいばじょう /中央競馬場/
ちゅうおうけん /中央研/
ちゅうおうけんきゅうしょ /中央研究所/
ちゅうおうけんきゅうじょ /中央研究所/
ちゅうおうけんきゅうじょまえ /中央研究所前/
ちゅうおうこうえん /中央公園/
ちゅうおうこうそく /中央高速/
ちゅうおうこうぞうせん /中央構造線/
ちゅうおうこうろん /中央公論/
ちゅうおうこうろんしゃ /中央公論社/
ちゅうおうさいせん /中央西線/
ちゅうおうした /中央下/
ちゅうおうしゃせん /中央車線/
ちゅうおうしゅういきげんてき /中央周囲起源的/
ちゅうおうしゅうけんたいせい /中央集権体制/
ちゅうおうしゅうけんてき /中央集権的/
ちゅうおうしゅうちゅうがた /中央集中型/
ちゅうおうしゅっぱん /中央出版/
ちゅうおうしょいん /中央書院/
ちゅうおうしょうぎょう /中央商業/
ちゅうおうしょうたい /中央招待/
ちゅうおうしょうめん /中央正面/
ちゅうおうしょくどう /中央食堂/
ちゅうおうしょりそうち /中央処理装置/
ちゅうおうしんかんせん /中央新幹線/
ちゅうおうじどうしゃどう /中央自動車道/
ちゅうおうじゅうてんそっこう /中央重点測光/
ちゅうおうせいぎょがた /中央制御型/
ちゅうおうせいふ /中央政府/
ちゅうおうせん /中央線/
ちゅうおうせんえんせん /中央線沿線/
ちゅうおうせんかいそく /中央線快速/
ちゅうおうせんない /中央線内/
ちゅうおうせんよう /中央線用/
ちゅうおうたい /中央帯/
ちゅうおうだい /中央大/
ちゅうおうだいがく /中央大学/
ちゅうおうだいがくすぎなみこうこう /中央大学杉並高校/
ちゅうおうち /中央値/
ちゅうおうちょう /中央町/
ちゅうおうつうろ /中央通路/
ちゅうおうでんし /中央電子/
ちゅうおうとしょかん /中央図書館/
ちゅうおうとっかい /中央特快/
ちゅうおうとっぱ /中央突破/
ちゅうおうどう /中央道/
ちゅうおうどうはちおうじ /中央道八王子/
ちゅうおうどうろ /中央道路/
ちゅうおうにっぽう /中央日報/
ちゅうおうはつでん /中央発電/
ちゅうおうば /中央馬/
ちゅうおうばし /中央橋/
ちゅうおうばしょ /中央場所/
ちゅうおうひがしせん /中央東線/
ちゅうおうひろば /中央広場/
ちゅうおうふきん /中央付近/
ちゅうおうぶ /中央部/
ちゅうおうぶぶん /中央部分/
ちゅうおうぶんりたい /中央分離帯/
ちゅうおうへいち /中央平地/
ちゅうおうほんせん /中央本線/
ちゅうおうみゃく /中央脈/
ちゅうおうゆうびんきょく /中央郵便局/
ちゅうおうよこ /中央横/
ちゅうおうよせ /中央寄せ/
ちゅうおうりん /中央輪/
ちゅうおうりんかん /中央林間/
ちゅうおうりんかんえき /中央林間駅/
ちゅうおん /中音/
ちゅうおんいき /中音域/
ちゅうか /中華/
ちゅうかい /仲介/注解/厨芥/
ちゅうかいぎしつ /中会議室/
ちゅうかいしゃ /仲介者/
ちゅうかいてすうりょう /仲介手数料/
ちゅうかいてんいき /中回転域/
ちゅうかいひょうげん /仲介表現/
ちゅうかいりょう /仲介料/
ちゅうかがい /中華街/
ちゅうかがし /中華菓子/
ちゅうかく /中核/中隔/
ちゅうかくは /中核派/
ちゅうかこうくう /中華航空/
ちゅうかこくみんせいふ /中華国民政府/
ちゅうかざいりょう /中華材料/
ちゅうかざんまい /中華三昧/
ちゅうかっこ /中括弧/中かっこ/
ちゅうかどん /中華丼/
ちゅうかなべ /中華鍋/
ちゅうかはん /中華飯/
ちゅうかひ /中果皮/
ちゅうかふう /中華風/
ちゅうかべんとう /中華弁当/
ちゅうかまんじゅう /中華饅頭/
ちゅうかみんこく /中華民國/
ちゅうかみんぞく /中華民族/
ちゅうかめん /中華麺/
ちゅうかや /中華屋/
ちゅうから /中辛/
ちゅうかりょうり /中華料理/
ちゅうかりょうりてん /中華料理店/
ちゅうかりょうりや /中華料理屋/
ちゅうかん /中間/昼間/中環/
ちゅうかんいち /中間位置/
ちゅうかんえき /中間駅/
ちゅうかんえきしはつ /中間駅始発/
ちゅうかんおん /中間音/
ちゅうかんかいきゅう /中間階級/
ちゅうかんかいさつ /中間改札/
ちゅうかんかいそう /中間階層/
ちゅうかんかいそく /昼間快速/
ちゅうかんかそく /中間加速/
ちゅうかんがいねん /中間概念/
ちゅうかんがくしょう /中間楽章/
ちゅうかんきほう /中間記法/
ちゅうかんぎ /中間木/
ちゅうかんけっか /中間結果/
ちゅうかんけん /中間圏/
ちゅうかんげんご /中間言語/
ちゅうかんこう /中間項/
ちゅうかんし /中間子/
ちゅうかんしけん /中間試験/
ちゅうかんしせつ /中間施設/
ちゅうかんしゃ /中間車/
ちゅうかんしゅうけい /中間集計/
ちゅうかんしゅうはすう /中間周波数/
ちゅうかんしゅうはすうぶ /中間周波数部/
ちゅうかんしょく /中間色/
ちゅうかんしんさ /中間審査/
ちゅうかんじゅつごろんり /中間述語論理/
ちゅうかんそう /中間層/
ちゅうかんそうすう /中間層数/
ちゅうかんたい /昼間帯/
ちゅうかんだいしゃ /中間台車/
ちゅうかんだな /中間棚/
ちゅうかんだんかい /中間段階/
ちゅうかんち /中間値/
ちゅうかんちてん /中間地点/
ちゅうかんちょう /中間調/
ちゅうかんていど /中間程度/
ちゅうかんてき /中間的/
ちゅうかんてん /中間点/
ちゅうかんてんふきん /中間点付近/
ちゅうかんとう /中間棟/
ちゅうかんとうしん /中間答申/
ちゅうかんとびら /中間扉/
ちゅうかんはいせん /中間配線/
ちゅうかんはっぴょう /中間発表/
ちゅうかんはっぴょうかい /中間発表会/
ちゅうかんひょうげん /中間表現/
ちゅうかんぶ /中間部/
ちゅうかんへんすう /中間変数/
ちゅうかんほうこく /中間報告/
ちゅうかんほうこくしょ /中間報告書/
ちゅうかんほうこくてき /中間報告的/
ちゅうかんめいだいろんり /中間命題論理/
ちゅうかんれべるがくしゅう /中間レベル学習/
ちゅうかんろんり /中間論理/
ちゅうがい /虫害/中外/
ちゅうがいいがくしゃ /中外医学社/
ちゅうがいせいやく /中外製薬/
ちゅうがえり /宙返り/
ちゅうがく /中学/
ちゅうがくいらい /中学以来/
ちゅうがくえいご /中学英語/
ちゅうがくきょうし /中学教師/
ちゅうがくくらい /中学位/
ちゅうがくこうこう /中学高校/
ちゅうがくこうこうじだい /中学高校時代/
ちゅうがくこうちょう /中学校長/
ちゅうがくじだい /中学時代/
ちゅうがくじゅけん /中学受験/
ちゅうがくせい /中学生/
ちゅうがくせいあいて /中学生相手/
ちゅうがくせいいじょう /中学生以上/
ちゅうがくせいいぜん /中学生以前/
ちゅうがくせいざっし /中学生雑誌/
ちゅうがくせいとかい /中学生徒会/
ちゅうがくせいばん /中学生版/
ちゅうがくそつぎょう /中学卒業/
ちゅうがくにゅうがくとうじ /中学入学当時/
ちゅうがくにゅうし /中学入試/
ちゅうがくにゅうしもんだい /中学入試問題/
ちゅうがた /中型/中形/
ちゅうがたいじょう /中型以上/
ちゅうがたか /中型化/
ちゅうがたき /中型機/
ちゅうがたぎょ /中型魚/
ちゅうがたけん /中型犬/
ちゅうがたげんてい /中型限定/
ちゅうがたしゃ /中型車/
ちゅうがたじゃぐちちょっけつ /中型蛇口直結/
ちゅうがたにりん /中型二輪/
ちゅうがたにりんめんきょ /中型二輪免許/
ちゅうがためんきょ /中型免許/
ちゅうがっこう /中学校/
ちゅうがっこういらい /中学校以来/
ちゅうがっこうしゅっしん /中学校出身/
ちゅうがっこうじだい /中学校時代/
ちゅうがっこうまで /中学校迄/
ちゅうき /中期/注記/駐機/中気/
ちゅうきさくひん /中期作品/
ちゅうきじょう /駐機場/
ちゅうきち /忠吉/
ちゅうきてき /中期的/
ちゅうきぼ /中規模/
ちゅうきぼうず /中規模渦/
ちゅうきゅう /中級/誅求/
ちゅうきゅうき /中級機/
ちゅうきゅうきていど /中級機程度/
ちゅうきゅうしゃ /中級者/
ちゅうきゅうしゃむけ /中級者向/
ちゅうきゅうしゃよう /中級者用/
ちゅうきゅうていど /中級程度/
ちゅうきゅうひん /中級品/
ちゅうきゅうへん /中級編/
ちゅうきょう /中京/中共/
ちゅうきょうかいさい /中京開催/
ちゅうきょうく /中京区/
ちゅうきょうけいばじょう /中京競馬場/
ちゅうきょうしば /中京芝/
ちゅうきょうじょしだいがく /中京女子大学/
ちゅうきょうだい /中京大/
ちゅうきょうだいがく /中京大学/
ちゅうきょうだいがくきょうじゅ /中京大学教授/
ちゅうきょうだいがくじょうほう /中京大学情報/
ちゅうきょうだいとよた /中京大豊田/
ちゅうきょうちく /中京地区/
ちゅうきょり /中距離/
ちゅうきょりいどう /中距離移動/
ちゅうきょりしゅもく /中距離種目/
ちゅうきょりだしゃ /中距離打者/
ちゅうきょりでんしゃ /中距離電車/
ちゅうきょりば /中距離馬/
ちゅうきん /駐禁/忠勤/
ちゅうきんとう /中近東/
ちゅうきんとうしょこく /中近東諸国/
ちゅうぎ /忠義/
ちゅうぎんじょう /中吟醸/
ちゅうくう /中空/宙空/
ちゅうくうこうぞう /中空構造/
ちゅうくうしまく /中空糸膜/
ちゅうくん /忠君/
ちゅうけい /中継/中繼/中計/
ちゅうけいき /中継器/
ちゅうけいきょく /中継局/
ちゅうけいきょくかん /中継局間/
ちゅうけいけい /中継系/
ちゅうけいけん /中継権/
ちゅうけいしゃ /中継者/
ちゅうけいしゅうりょう /中継終了/
ちゅうけいしんごうき /中継信号機/
ちゅうけいじ /中継時/
ちゅうけいじょ /中継所/
ちゅうけいち /中継地/
ちゅうけいちてん /中継地点/
ちゅうけいてん /中継点/
ちゅうけいは /中継波/
ちゅうけん /中研/中堅/忠犬/
ちゅうけんしゃいん /中堅社員/
ちゅうけんしゅ /中堅手/
ちゅうけんほ /駐建保/
ちゅうげん /中元/忠言/
ちゅうこ /中古/
ちゅうこう /中公/中興/中高/忠孝/中耕/昼行/鋳鋼/
ちゅうこうあいぞうばん /中公愛蔵版/
ちゅうこういき /中高域/
ちゅうこうおんいき /中高音域/
ちゅうこうきゅう /中高級/
ちゅうこうぎしつ /中講義室/
ちゅうこうしんしょ /中公新書/
ちゅうこうせい /中高生/鋳鋼製/
ちゅうこうそく /中高速/
ちゅうこうだいいん /中高大院/
ちゅうこうとっきゅうしゃ /昼行特急車/
ちゅうこうねん /中高年/
ちゅうこうびん /昼行便/
ちゅうこうぶんこ /中公文庫/
ちゅうこうもく /中項目/
ちゅうこうもくめい /中項目名/
ちゅうこうりね /中古売値/
ちゅうこうれっしゃ /昼行列車/
ちゅうこかかく /中古価格/
ちゅうこき /中古機/
ちゅうこぎょうしゃ /中古業者/
ちゅうこく /忠告/
ちゅうこくふぁんど /中国ファンド/
ちゅうここうにゅう /中古購入/
ちゅうこしじょう /中古市場/
ちゅうこしじょうかかく /中古市場価格/
ちゅうこしゃ /中古車/
ちゅうこしゃざっし /中古車雑誌/
ちゅうこしゃはんばいてん /中古車販売店/
ちゅうこしゃや /中古車屋/
ちゅうこしゃりょう /中古車両/
ちゅうこせんもんてん /中古専門店/
ちゅうこそうば /中古相場/
ちゅうこだい /中古台/
ちゅうこてん /中古店/
ちゅうこばん /中古盤/
ちゅうこばんや /中古盤屋/
ちゅうこひん /中古品/
ちゅうこぶひん /中古部品/
ちゅうこぶひんや /中古部品屋/
ちゅうこや /中古屋/
ちゅうごく /中国/中國/
ちゅうごくいがい /中国以外/
ちゅうごくうんなんしょう /中国雲南省/
ちゅうごくえいが /中国映画/
ちゅうごくえんせい /中国遠征/
ちゅうごくか /中国化/
ちゅうごくかがくいん /中国科学院/
ちゅうごくかんじ /中国漢字/
ちゅうごくかんたいじ /中国簡体字/
ちゅうごくがわ /中国側/
ちゅうごくき /中国旗/
ちゅうごくきし /中国棋士/
ちゅうごくきょうさんせいけん /中国共産政権/
ちゅうごくきょうさんとう /中国共産党/
ちゅうごくぎんこう /中国銀行/
ちゅうごくぐん /中国軍/
ちゅうごくぐんえい /中国軍営/
ちゅうごくぐんじんち /中国軍陣地/
ちゅうごくぐんみん /中国軍民/
ちゅうごくけい /中国系/
ちゅうごくけん /中国拳/
ちゅうごくこくない /中国国内/
ちゅうごくこくみん /中国国民/
ちゅうごくこくみんとう /中国国民党/
ちゅうごくこっきょう /中国国境/
ちゅうごくご /中国語/
ちゅうごくごがいろん /中国語概論/
ちゅうごくごしょしんしゃ /中国語初心者/
ちゅうごくごにゅうりょく /中国語入力/
ちゅうごくごばん /中国語版/
ちゅうごくごふう /中国語風/
ちゅうごくごぶぶん /中国語部分/
ちゅうごくごよう /中国語用/
ちゅうごくさん /中国産/
ちゅうごくさんち /中国山地/
ちゅうごくし /中国史/
ちゅうごくしき /中国式/
ちゅうごくしぶ /中国支部/
ちゅうごくしょ /中国書/
ちゅうごくしんぶん /中国新聞/
ちゅうごくしんりゃく /中国侵略/
ちゅうごくじどうしゃどう /中国自動車道/
ちゅうごくじゅうかんどう /中国縦貫道/
ちゅうごくじん /中国人/
ちゅうごくじんがくせい /中国人学生/
ちゅうごくじんがわ /中国人側/
ちゅうごくじんみん /中国人民/
ちゅうごくせい /中国製/
ちゅうごくせいいき /中国西域/
ちゅうごくせいねん /中国青年/
ちゅうごくせいふ /中国政府/
ちゅうごくせいふにんてい /中国政府認定/
ちゅうごくせいほう /中国西方/
ちゅうごくせき /中国籍/
ちゅうごくせんせいじゅつ /中国占星術/
ちゅうごくぜんど /中国全土/
ちゅうごくたいりく /中国大陸/
ちゅうごくちほう /中国地方/
ちゅうごくちゅうおうせいふ /中国中央政府/
ちゅうごくてき /中国的/
ちゅうごくでんりょく /中国電力/
ちゅうごくとうき /中国陶器/
ちゅうごくどう /中国道/
ちゅうごくどうけいゆ /中国道経由/
ちゅうごくどくりつ /中国独立/
ちゅうごくない /中国内/
ちゅうごくないぶ /中国内部/
ちゅうごくなんぶ /中国南部/
ちゅうごくのうみん /中国農民/
ちゅうごくはけんぐん /中国派遣軍/
ちゅうごくはっこう /中国発行/
ちゅうごくばん /中国版/
ちゅうごくびじん /中国美人/
ちゅうごくふう /中国風/
ちゅうごくぶっか /中国物価/
ちゅうごくぶっさんひんてん /中国物産品店/
ちゅうごくぶんか /中国文化/
ちゅうごくぶんがく /中国文学/
ちゅうごくぶんめいし /中国文明史/
ちゅうごくへい /中国兵/
ちゅうごくへん /中国編/
ちゅうごくほうそう /中国放送/
ちゅうごくほくぶ /中国北部/
ちゅうごくほんど /中国本土/
ちゅうごくまんが /中国漫画/
ちゅうごくみんかんじん /中国民間人/
ちゅうごくみんこう /中国民航/
ちゅうごくりゅう /中国流/
ちゅうごくりゅうがくせい /中国留学生/
ちゅうごくりょう /中国領/
ちゅうごくりょうり /中国料理/
ちゅうごくりょこうしゃ /中国旅行社/
ちゅうごし /中腰/
ちゅうごしっくたい /中ゴシック体/
ちゅうさ /中佐/
ちゅうさい /仲裁/
ちゅうさいにん /仲裁人/
ちゅうさかん /中属/
ちゅうさつ /駐箚/誅殺/
ちゅうさん /注参/昼餐/中三/
ちゅうざ /中座/
ちゅうざい /駐在/
ちゅうざいいん /駐在員/
ちゅうざいしょ /駐在所/
ちゅうし /中止/注視/
ちゅうしこく /中四国/
ちゅうしこくちほう /中四国地方/
ちゅうしじてん /注視時点/
ちゅうしてん /注視点/
ちゅうしゃ /駐車/注射/
ちゅうしゃいはん /駐車違反/
ちゅうしゃか /駐車可/
ちゅうしゃき /注射器/
ちゅうしゃきょかしょう /駐車許可証/
ちゅうしゃきんし /駐車禁止/
ちゅうしゃく /註釈/注釈/
ちゅうしゃくか /注釈化/
ちゅうしゃくぎょう /註釈行/
ちゅうしゃくじこう /注釈事項/
ちゅうしゃくつき /注釈付き/
ちゅうしゃくぶん /注釈文/
ちゅうしゃけん /駐車券/
ちゅうしゃしゃりょう /駐車車両/
ちゅうしゃじ /駐車時/
ちゅうしゃじょう /駐車場/
ちゅうしゃじょうあんない /駐車場案内/
ちゅうしゃじょうかくほ /駐車場確保/
ちゅうしゃじょうかんきょう /駐車場環境/
ちゅうしゃじょうきょう /駐車状況/
ちゅうしゃじょうした /駐車場下/
ちゅうしゃじょうだい /駐車場代/
ちゅうしゃじょうない /駐車場内/
ちゅうしゃじょうなど /駐車場等/
ちゅうしゃじょうりょうきん /駐車場料金/
ちゅうしゃたい /駐車帯/
ちゅうしゃだい /駐車代/
ちゅうしゃだいすう /駐車台数/
ちゅうしゃちゅう /駐車中/
ちゅうしゃとう /注射筒/
ちゅうしゃばしょ /駐車場所/
ちゅうしゃばり /注射針/
ちゅうしゃひょう /駐車票/
ちゅうしゃめん /中斜面/
ちゅうしゃもんだい /駐車問題/
ちゅうしゃりょう /駐車料/
ちゅうしゃりょうきん /駐車料金/
ちゅうしゃわく /駐車枠/
ちゅうしゅう /中周/中秋/仲秋/
ちゅうしゅつ /抽出/
ちゅうしゅつぶ /抽出部/
ちゅうしゅつぶつ /抽出物/
ちゅうしゅつほう /抽出法/
ちゅうしょ /中所/
ちゅうしょう /抽象/中傷/中小/中将/
ちゅうしょうか /抽象化/
ちゅうしょうかいしゃく /抽象解釈/
ちゅうしょうかんやく /抽象簡約/
ちゅうしょうが /抽象画/
ちゅうしょうがいねん /抽象概念/
ちゅうしょうがた /抽象型/
ちゅうしょうきかい /抽象機械/
ちゅうしょうきぎょう /中小企業/
ちゅうしょうきじ /中傷記事/
ちゅうしょうぎ /中将棋/
ちゅうしょうこうぶん /抽象構文/
ちゅうしょうこうぶんぎ /抽象構文木/
ちゅうしょうこく /中小国/
ちゅうしょうごめん /中傷御免/
ちゅうしょうしてつ /中小私鉄/
ちゅうしょうしょり /抽象処理/
ちゅうしょうすうがく /抽象数学/
ちゅうしょうせい /抽象性/
ちゅうしょうせかい /抽象世界/
ちゅうしょうつい /抽象対/
ちゅうしょうてき /抽象的/
ちゅうしょうてきがいねん /抽象的概念/
ちゅうしょうてきしこう /抽象的思考/
ちゅうしょうてきはんだん /抽象的判断/
ちゅうしょうでーたがた /抽象データ型/
ちゅうしょうとしょかん /中小図書館/
ちゅうしょうど /抽象度/
ちゅうしょうひぼう /中傷誹謗/
ちゅうしょうめいし /抽象名詞/
ちゅうしょうろん /抽象論/
ちゅうしょく /昼食/
ちゅうしょくかい /昼食会/
ちゅうしょくきゅうけい /昼食休憩/
ちゅうしょくご /昼食後/
ちゅうしょくじ /昼食時/
ちゅうしょくだい /昼食代/
ちゅうしょくどき /昼食時/
ちゅうしょくひ /昼食費/
ちゅうしょくべつ /昼食別/
ちゅうしょじま /中書島/
ちゅうしようきゅう /中止要求/
ちゅうしん /中心/衷心/忠臣/中震/注進/
ちゅうしんえき /中心駅/
ちゅうしんかく /中心角/中心格/
ちゅうしんがい /中心街/
ちゅうしんがた /中心型/
ちゅうしんぐら /忠臣蔵/
ちゅうしんさぶん /中心差分/
ちゅうしんしや /中心視野/
ちゅうしんしゅうはすう /中心周波数/
ちゅうしんしゅだい /中心主題/
ちゅうしんじく /中心軸/
ちゅうしんじんぶつ /中心人物/
ちゅうしんせい /中心性/
ちゅうしんせん /中心線/
ちゅうしんせんしゅ /中心選手/
ちゅうしんせんじょう /中心線上/
ちゅうしんせんほうこう /中心線方向/
ちゅうしんち /中心地/
ちゅうしんちゅう /中心柱/
ちゅうしんてき /中心的/
ちゅうしんてきかつどう /中心的活動/
ちゅうしんてききのう /中心的機能/
ちゅうしんてきそんざい /中心的存在/
ちゅうしんてん /中心点/
ちゅうしんでんきょく /中心電極/
ちゅうしんふきん /中心付近/
ちゅうしんぶ /中心部/
ちゅうしんぶいがい /中心部以外/
ちゅうしんぶいこう /中心部以降/
ちゅうしんほうこう /中心方向/
ちゅうしんりょく /中心力/
ちゅうじ /忠司/忠治/中耳/忠二/
ちゅうじえん /中耳炎/
ちゅうじく /中軸/
ちゅうじくたいざ /中軸胎座/
ちゅうじつ /忠実/
ちゅうじつど /忠実度/
ちゅうじつや /忠実屋/
ちゅうじてん /中辞典/
ちゅうじゅん /中旬/
ちゅうじゅんいこう /中旬以降/
ちゅうじゅんごろ /中旬頃/
ちゅうじゅんぶん /中旬分/
ちゅうじょ /中所/
ちゅうじょう /中條/中将/衷情/哀情/中条/
ちゅうじょうきゅうしゃ /中上級者/
ちゅうじょうきゅうしゃよう /中上級者用/
ちゅうじょうだん /中上段/
ちゅうじょっき /中ジョッキ/
ちゅうすい /注水/虫垂/
ちゅうすいえん /虫垂炎/
ちゅうすう /中枢/
ちゅうすうしんけい /中枢神経/
ちゅうすうしんけいけい /中枢神経系/
ちゅうすうせい /中枢性/
ちゅうすうぶ /中枢部/
ちゅうすけ /忠輔/
ちゅうず /中主/
ちゅうせい /中世/中性/忠誠/中正/
ちゅうせいおんがく /中世音楽/
ちゅうせいし /中性子/中性紙/
ちゅうせいしかじょうかく /中性子過剰核/
ちゅうせいしげん /中性子源/
ちゅうせいしすう /中性子数/
ちゅうせいしせい /中性子星/
ちゅうせいしせいじょう /中性子星上/
ちゅうせいしせん /中性子線/
ちゅうせいしそく /中性子束/
ちゅうせいしば /中性子場/
ちゅうせいしほうだん /中性子砲弾/
ちゅうせいしん /忠誠心/
ちゅうせいじょじし /中世叙事詩/
ちゅうせいせんざい /中性洗剤/
ちゅうせいそう /中性相/
ちゅうせいてき /中性的/中世的/
ちゅうせいど /忠誠度/
ちゅうせいびし /中性微子/
ちゅうせいふりょく /中性浮力/
ちゅうせいぶ /中西部/
ちゅうせき /沖積/柱石/
ちゅうせつ /忠節/
ちゅうせん /抽選/抽籤/
ちゅうせんかい /抽選会/
ちゅうせんきょく /中選挙区/
ちゅうせんきょくせい /中選挙区制/
ちゅうせんきょくせいど /中選挙区制度/
ちゅうせんけっか /抽選結果/
ちゅうせんけん /抽選券/
ちゅうせんご /抽選後/
ちゅうせんたいしょう /抽選対象/
ちゅうせんば /抽籤馬/
ちゅうせんび /抽選日/
ちゅうせんほうほう /抽選方法/
ちゅうぜい /中背/
ちゅうぜつ /中絶/
ちゅうぜつきんし /中絶禁止/
ちゅうぜんじ /中禅寺/
ちゅうぜんじこ /中禅寺湖/
ちゅうそ /註疏/
ちゅうそう /中層/抽送/
ちゅうそうすい /中層水/
ちゅうそく /中速/
ちゅうそくいき /中速域/
ちゅうそくしゃ /中速車/
ちゅうそつ /中卒/
ちゅうそんじ /中尊寺/
ちゅうぞう /忠三/鋳造/宙三/鑄像/
ちゅうぞうちゅう /鋳造中/
ちゅうぞうぶぶん /鋳造部分/
ちゅうた /宙太/
ちゅうたい /中退/中隊/柱体/
ちゅうたいちょう /中隊長/
ちゅうたんぺん /中短編/
ちゅうだい /中大/
ちゅうだいすぎなみ /中大杉並/
ちゅうだん /中断/中段/中団/
ちゅうだんご /中断後/
ちゅうだんじかん /中断時間/
ちゅうだんちゅう /中断中/
ちゅうち /中置/
ちゅうちきほう /中置記法/
ちゅうちゅうごくたいし /駐中国大使/
ちゅうちゅうたいし /駐中大使/
ちゅうちょ /躊躇/
ちゅうちょうきてき /中長期的/
ちゅうちょうきてきてんぼう /中長期的展望/
ちゅうちょうきょり /中長距離/
ちゅうちょうきょりろせん /中長距離路線/
ちゅうてい /中低/
ちゅうていいき /中低域/
ちゅうていおん /中低音/
ちゅうていしゃ /駐停車/
ちゅうていしゃきんし /駐停車禁止/
ちゅうていしゃちゅう /駐停車中/
ちゅうていそく /中低速/
ちゅうていど /中程度/
ちゅうてつ /鋳鉄/中鉄/
ちゅうてつしょ /鋳鉄所/
ちゅうてん /中点/・/宙天/沖点/冲点/
ちゅうてんれんけつていり /中点連結定理/
ちゅうでん /中電/中伝/
ちゅうでんかいちいき /中電界地域/
ちゅうでんりょく /中電力/
ちゅうと /中途/
ちゅうとう /中東/中等/仲冬/柱頭/
ちゅうとうきき /中東危機/
ちゅうとうきょういく /中等教育/
ちゅうとうじょうせい /中東情勢/
ちゅうとうせいさく /中東政策/
ちゅうとうせんそう /中東戦争/
ちゅうとうちいき /中東地域/
ちゅうとうど /中等度/
ちゅうとうぶ /中等部/
ちゅうとうもんだい /中東問題/
ちゅうとうわへい /中東和平/
ちゅうとうわへいかいぎ /中東和平会議/
ちゅうとさいよう /中途採用/
ちゅうとし /中都市/
ちゅうとしつめいしゃ /中途失明者/
ちゅうとはんぱ /中途半端/
ちゅうとん /駐屯/
ちゅうど /中度/
ちゅうどう /中道/中動/
ちゅうどうじ /中堂寺/
ちゅうどく /中毒/
ちゅうどくいき /中毒域/
ちゅうどくかんじゃ /中毒患者/
ちゅうどくしゃ /中毒者/
ちゅうどくしゃぞくしゅつ /中毒者続出/
ちゅうどくしょうじょう /中毒症状/
ちゅうどくせい /中毒性/
ちゅうどくてき /中毒的/
ちゅうなごん /中納言/
ちゅうなん /仲南/
ちゅうなんべい /中南米/
ちゅうなんべいしゅっしん /中南米出身/
ちゅうなんべいしょこく /中南米諸国/
ちゅうなんべいろせん /中南米路線/
ちゅうに /中２/
ちゅうにかい /中二階/
ちゅうにち /中日/駐日/
ちゅうにちしんぶん /中日新聞/
ちゅうにちせん /中日戦/
ちゅうにちりょうこく /中日両国/
ちゅうにゅう /注入/
ちゅうにゅうき /注入器/
ちゅうにゅうぐち /注入口/
ちゅうにゅうよう /注入用/
ちゅうねん /中年/
ちゅうねんいこう /中年以降/
ちゅうねんおとこ /中年男/
ちゅうねんしょうど /中燃焼度/
ちゅうねんしんし /中年紳士/
ちゅうねんだんせい /中年男性/
ちゅうのう /中脳/
ちゅうは /中波/
ちゅうはいじく /中胚軸/
ちゅうはいよう /中胚葉/
ちゅうはたい /中波帯/
ちゅうはほうそう /中波放送/
ちゅうばいか /虫媒花/
ちゅうばち /中鉢/
ちゅうばちけん /中鉢研/
ちゅうばん /中盤/中判/注番/
ちゅうばんいこう /中盤以降/
ちゅうばんいじょう /中判以上/
ちゅうばんせん /中盤戦/
ちゅうひ /中皮/
ちゅうび /中火/
ちゅうふく /中腹/
ちゅうぶ /中部/中風/
ちゅうぶう /中風/
ちゅうぶぜい /中部勢/
ちゅうぶだいがく /中部大学/
ちゅうぶちく /中部地区/
ちゅうぶちほう /中部地方/
ちゅうぶてんりゅう /中部天竜/
ちゅうぶでんりょく /中部電力/
ちゅうぶにっぽんほうそう /中部日本放送/
ちゅうぶにほんほうそう /中部日本放送/
ちゅうぶらりん /宙ぶらりん/
ちゅうぶん /中文/
ちゅうぶんるい /中分類/
ちゅうへん /中辺/中篇/中編/
ちゅうべい /中米/駐米/
ちゅうべいかくち /中米各地/
ちゅうべいほうめん /中米方面/
ちゅうぼう /厨房/
ちゅうぼうえん /中望遠/
ちゅうま /中馬/
ちゅうみつ /稠密/
ちゅうめん /柱面/中免/
ちゅうもく /注目/
ちゅうもくかぶ /注目株/
ちゅうもくさく /注目作/
ちゅうもくさくひん /注目作品/
ちゅうもくせんしゅ /注目選手/
ちゅうもくてん /注目点/
ちゅうもくど /注目度/
ちゅうもくひょう /中目標/
ちゅうもん /注文/中門/
ちゅうもんか /注文可/
ちゅうもんかのう /注文可能/
ちゅうもんしょ /注文書/
ちゅうもんせいさん /注文生産/
ちゅうもんせんよう /注文専用/
ちゅうもんちゅう /注文中/
ちゅうもんとり /注文取り/
ちゅうもんないよう /注文内容/
ちゅうもんぬし /注文主/
ちゅうもんばんごう /注文番号/
ちゅうもんひょう /注文票/注文表/
ちゅうもんひん /注文品/
ちゅうもんぶん /注文分/
ちゅうもんほうほう /注文方法/
ちゅうや /中也/昼夜/
ちゅうゆ /注油/
ちゅうゆう /忠勇/
ちゅうよう /中庸/中葉/
ちゅうりき /中力/
ちゅうりきこ /中力粉/
ちゅうりつ /中立/
ちゅうりつがわ /中立側/
ちゅうりつせい /中立性/
ちゅうりつせんげん /中立宣言/
ちゅうりつてき /中立的/
ちゅうりゃく /中略/
ちゅうりゅう /中流/駐留/
ちゅうりゅうど /中粒度/
ちゅうりょうゆそうきかん /中量輸送機関/
ちゅうりょく /注力/中力/
ちゅうりょくこ /中力粉/
ちゅうりん /駐輪/
ちゅうりんじょう /駐輪場/
ちゅうるい /忠類/
ちゅうれい /昼礼/
ちゅうれつ /中裂/
ちゅうろく /中肋/
ちゅうろくたいざ /中肋胎座/
ちゅうわ /中和/
ちゅうわざい /中和剤/
ちゅしょう /中小/
ちゅつ /黜/
ちゅん /中/
ちゅんりー /春麗/
ちゆ /治癒/
ちゆう /知友/
ちゆき /千幸/
ちゆこうか /治癒効果/
ちゆじゅつし /治癒術師/
ちゆじょうきょう /治癒状況/
ちょ /著/貯/猪/苧/瀦/樗/躇/儲/佇/墸/潴/竚/紵/豬/緒/箸/楮/
ちょーく /チョーク/
ちょう /長/超/帳/庁/調/町/重/張/弔/頂/腸/聴/鳥/兆/朝/肇/挑/潮/暢/徴/嘲/丁/蝶/銚/諜/跳/脹/喋/眺/牒/彫/懲/寵/帖/凋/稠/鬯/釣/趙/貼/佻/廳/廰/悵/昶/晁/楪/樢/漲/甼/疔/窕/糶/聽/膓/萇/誂/貂/輒/輙/迢/雕/髫/鵈/齠/澄/挺/澂/鼎/冢/蔦/微/吊/塚/鯛/
ちょう< /超/
ちょう> /超/
ちょうあい /寵愛/丁合/丁合い/帳合/帳合い/
ちょうあく /懲悪/
ちょうあつ /調圧/
ちょうあなうま /超穴馬/
ちょうあにき /超兄貴/
ちょうあまくち /超甘口/
ちょうあん /長安/
ちょうあんか /超安価/
ちょうい /弔意/弔慰/潮位/
ちょういき /町域/
ちょういち /長一/
ちょういちりゅう /超一流/
ちょういちりゅうば /超一流馬/
ちょういちりゅうひん /超一流品/
ちょういちりゅうほてる /超一流ホテル/
ちょういちりゅうりょかん /超一流旅館/
ちょういちろう /長一郎/
ちょういっきゅう /超一級/
ちょういん /調印/
ちょういんしき /調印式/
ちょううちゅう /超宇宙/
ちょうえい /町営/
ちょうえいきどう /町営軌道/
ちょうえいちゅうしゃじょう /町営駐車場/
ちょうえき /懲役/
ちょうえきけい /懲役刑/
ちょうえつ /超越/
ちょうえつしゃ /超越者/
ちょうえつせい /超越性/
ちょうえつそんざい /超越存在/
ちょうえつてき /超越的/
ちょうえつろんてきろんり /超越論的論理/
ちょうえん /兆円/腸炎/長円/
ちょうえんけい /長円形/
ちょうおおがた /超大型/
ちょうおおがたけいさん /超大型計算/
ちょうおおぐち /超大口/
ちょうおおぐちじぎょうしょ /超大口事業所/
ちょうおおて /超大手/
ちょうおおもの /超大物/
ちょうおん /長音/調音/聴音/ー/
ちょうおんか /長音化/
ちょうおんかい /長音階/
ちょうおんかぶぶん /長音化部分/
ちょうおんき /聴音機/
ちょうおんきごう /長音記号/
ちょうおんけつごう /調音結合/
ちょうおんそく /超音速/
ちょうおんそくせいのう /超音速性能/
ちょうおんてん /調音点/
ちょうおんてんへんか /調音点変化/
ちょうおんぱ /超音波/
ちょうおんぱしき /超音波式/
ちょうおんぱせんじょう /超音波洗浄/
ちょうおんぱつうしん /超音波通信/
ちょうおんぱつうしんこうがく /超音波通信工学/
ちょうおんぱはっせいき /超音波発生機/
ちょうおんぶ /調音部/聴音部/
ちょうおんぷ /長音符/
ちょうおんようしき /調音様式/
ちょうか /超過/釣果/長靴/
ちょうかい /懲戒/鳥海/朝会/潮解/町会/嘲詼/
ちょうかいけん /懲戒権/
ちょうかいけんしゃ /懲戒権者/
ちょうかいさん /鳥海山/
ちょうかいしょぶん /懲戒処分/
ちょうかいそく /超快速/
ちょうかいたいしょう /懲戒対象/
ちょうかいめんしょく /懲戒免職/
ちょうかいりょく /聴解力/
ちょうかがく /超科学/
ちょうかがくてき /超科学的/
ちょうかきんむてあて /超過勤務手当/
ちょうかく /聴覚/長角/
ちょうかくかてい /聴覚過程/
ちょうかくかん /聴覚感/
ちょうかくき /聴覚器/
ちょうかくきかん /聴覚器官/
ちょうかくきこう /聴覚機構/
ちょうかくきのう /聴覚機能/
ちょうかくけい /聴覚系/
ちょうかくけん /聴覚研/
ちょうかくけんきゅうしつ /聴覚研究室/
ちょうかくけんきゅうしゃ /聴覚研究者/
ちょうかくげんしょう /聴覚現象/
ちょうかくしょうがい /聴覚障害/
ちょうかくしょうがいしゃ /聴覚障害者/聴覚障碍者/
ちょうかくしょり /聴覚処理/
ちょうかくしょりきこう /聴覚処理機構/
ちょうかくしんけい /聴覚神経/
ちょうかくしんりがく /聴覚心理学/
ちょうかくじゅんのう /聴覚順応/
ちょうかくじょう /聴覚上/
ちょうかくじょうほうしょり /聴覚情報処理/
ちょうかくてき /聴覚的/
ちょうかくてきいんしょう /聴覚的印象/
ちょうかくてきしげき /聴覚的刺激/
ちょうかくとくせい /聴覚特性/
ちょうかくひろう /聴覚疲労/
ちょうかくまっしょうけい /聴覚末梢系/
ちょうかくやす /超格安/
ちょうかげき /超過激/
ちょうかそく /超加速/
ちょうかそくど /超過速度/
ちょうかていいん /超過定員/
ちょうかねもち /超金持ち/
ちょうかぶん /超過分/
ちょうからくち /超辛口/
ちょうかりじゅん /超過利潤/
ちょうかりょうきん /超過料金/
ちょうかん /長官/朝刊/聴感/鳥瞰/長巻/腸管/
ちょうかんかく /聴感覚/
ちょうかんけいゆう /腸管経由/
ちょうかんじゅんい /聴感順位/
ちょうかんじょう /聴感上/
ちょうかんすう /超関数/超函数/
ちょうかんすうろん /超関数論/
ちょうかんず /鳥瞰図/
ちょうかんたん /超簡単/
ちょうかんどう /超感動/
ちょうかんまく /腸間膜/
ちょうが /頂芽/
ちょうがい /鳥害/
ちょうがいさんかしゃ /町外参加者/
ちょうがゆうせい /頂芽優勢/
ちょうき /長期/寵姫/
ちょうきあんてい /長期安定/
ちょうきいどうちゅう /長期移動中/
ちょうきか /長期化/
ちょうきかりいれきん /長期借入金/
ちょうきかん /長期間/
ちょうきかんこうそく /長期間拘束/
ちょうきかんしよう /長期間使用/
ちょうきかんほうち /長期間放置/
ちょうきかんほぞん /長期間保存/
ちょうききおく /長期記憶/
ちょうききゅうか /長期休暇/
ちょうききゅうよう /長期休養/
ちょうききゅうようあけ /長期休養明/
ちょうききんぞく /長期勤続/
ちょうきけいかく /長期計画/
ちょうきけいやく /長期契約/
ちょうきけつじょう /長期欠場/
ちょうきこうはんい /長期広範囲/
ちょうきこうはんいしんごうけい /長期広範囲信号系/
ちょうきしゅっちょう /長期出張/
ちょうきしゅっちょうちゅう /長期出張中/
ちょうきせん /長期戦/
ちょうきたいざい /長期滞在/
ちょうきたいざいしゃ /長期滞在者/
ちょうきち /長吉/
ちょうきてき /長期的/
ちょうきてきみとおし /長期的見通し/
ちょうきにゅういん /長期入院/
ちょうきびょうけつ /長期病欠/
ちょうきふきょうか /長期不況下/
ちょうきふざい /長期不在/
ちょうきほぞん /長期保存/
ちょうきもくひょう /長期目標/
ちょうきゅう /超球/
ちょうきゅういんてき /超吸引的/
ちょうきゅうけいさつ /超級警察/
ちょうきょう /調教/
ちょうきょうし /調教師/
ちょうきょうちゅう /調教中/
ちょうきょうぶそく /調教不足/
ちょうきょうほう /調教法/
ちょうきょうりょく /超強力/
ちょうきょこう /超虚構/
ちょうきょだいうちゅう /超巨大宇宙/
ちょうきょだいせんしゃ /超巨大戦車/
ちょうきょり /長距離/
ちょうきょりうんてん /長距離運転/
ちょうきょりきっぷ /長距離切符/
ちょうきょりきゃく /長距離客/
ちょうきょりきろく /長距離記録/
ちょうきょりけい /長距離系/
ちょうきょりけっとう /長距離血統/
ちょうきょりこうそくどう /長距離高速道/
ちょうきょりこくさいせん /長距離国際線/
ちょうきょりしじょう /長距離試乗/
ちょうきょりじゅんこう /長距離巡行/
ちょうきょりせん /長距離戦/
ちょうきょりせんとうき /長距離戦闘機/
ちょうきょりせんもん /長距離専門/
ちょうきょりそうこう /長距離走行/
ちょうきょりそうしゃ /長距離走者/
ちょうきょりだしゃ /長距離打者/
ちょうきょりつうかきゃく /長距離通過客/
ちょうきょりつうきん /長距離通勤/
ちょうきょりでんわ /長距離電話/
ちょうきょりば /長距離馬/
ちょうきょりひこう /長距離飛行/
ちょうきょりびん /長距離便/
ちょうきょりふつう /長距離普通/
ちょうきょりほう /長距離砲/
ちょうきょりゆそう /長距離輸送/
ちょうきょりらんなー /長距離ランナー/
ちょうきょりりょうきん /長距離料金/
ちょうきょりりょこう /長距離旅行/
ちょうきょりれっしゃ /長距離列車/
ちょうきょりろせん /長距離路線/
ちょうきょりわりびき /長距離割引/
ちょうきよほう /長期予報/
ちょうきりょこう /長期旅行/
ちょうきれんきゅう /長期連休/
ちょうきれんさい /長期連載/
ちょうきれんさいさくひん /長期連載作品/
ちょうきん /超勤/彫金/
ちょうぎ /町議/嘲戯/
ちょうぎいん /町議員/
ちょうぎかい /町議会/
ちょうぎゃく /嘲謔/
ちょうくうかん /聴空間/超空間/
ちょうくうかんくどう /超空間駆動/
ちょうけい /長兄/蝶形/長形/
ちょうけいか /蝶形花/
ちょうけいこうへきいけいさいぼう /長形厚壁異形細胞/
ちょうけいりょう /超軽量/
ちょうけいりょうか /超軽量化/
ちょうけし /帳消し/
ちょうけつ /長欠/
ちょうけん /聴検/長剣/
ちょうげきせん /超激戦/
ちょうげん /超限/調弦/超弦/
ちょうげんきのうほう /超限帰納法/
ちょうげんじつてき /超現実的/
ちょうげんじつは /超現実派/
ちょうげんりろん /超弦理論/
ちょうこう /徴候/聴講/長考/超高/兆候/調光/長江/釣行/釣鉤/嘲詬/
ちょうこうかいてん /超高回転/
ちょうこうかいてんがた /超高回転型/
ちょうこうかく /超広角/
ちょうこうき /超広軌/
ちょうこうきぼう /聴講希望/
ちょうこうきゅう /超高級/
ちょうこうきゅうきしゅ /超高級機種/
ちょうこうきゅうりょうてい /超高級料亭/
ちょうこうこうきゅう /超高校級/
ちょうこうさんか /聴講参加/
ちょうこうし /超格子/
ちょうこうしゅうは /超高周波/
ちょうこうしゅうはつうしん /超高周波通信/
ちょうこうじゅんど /超高純度/
ちょうこうせいのう /超高性能/
ちょうこうぜつ /長広舌/
ちょうこうそう /超高層/
ちょうこうそく /超高速/超攻速/超光速/
ちょうこうそくおおがた /超高速大型/
ちょうこうそくかいてん /超高速回転/
ちょうこうそくくどう /超光速駆動/
ちょうこうそくこうこう /超光速航行/
ちょうこうそくこうほう /超光速航法/
ちょうこうそくだいようりょう /超高速大容量/
ちょうこうそくのうこう /超高速濃厚/
ちょうこうひんしつ /超高品質/
ちょうこうぶんし /超高分子/
ちょうこうみつど /超高密度/
ちょうこうむりょう /聴講無料/
ちょうこうりょう /聴講料/
ちょうこうれいかしゃかい /超高齢化社会/
ちょうこがた /超小型/
ちょうこく /彫刻/超克/
ちょうこくか /彫刻家/
ちょうこくとう /彫刻刀/
ちょうこだい /超古代/
ちょうこだいにほんご /超古代日本語/
ちょうこっかしゅぎ /超国家主義/
ちょうこつ /腸骨/
ちょうこんか /長恨歌/
ちょうこんざつ /超混雑/
ちょうご /長後/
ちょうごう /調合/
ちょうごうか /超豪華/
ちょうごうきん /超合金/
ちょうごうよう /調合用/
ちょうごえき /長後駅/
ちょうごくあく /超極悪/
ちょうさ /調査/潮差/
ちょうさい /兆載/
ちょうさいらい /調査依頼/
ちょうさいん /調査員/
ちょうさか /調査課/
ちょうさかい /調査会/
ちょうさかん /調査官/
ちょうさきかん /調査期間/調査機関/
ちょうさけっか /調査結果/
ちょうさけんきゅう /調査研究/
ちょうさこうもく /調査項目/
ちょうさしつ /調査室/
ちょうさしょ /調査書/
ちょうさしょもつ /調査書物/
ちょうさたい /調査隊/
ちょうさたいしょう /調査対象/
ちょうさだん /調査団/
ちょうさだんちょう /調査団長/
ちょうさちゅう /調査中/
ちょうさとうけいしりょう /調査統計資料/
ちょうさひ /調査費/
ちょうさひょう /調査票/調査表/
ちょうさふぜん /調査不全/
ちょうさぶ /調査部/
ちょうさぶそく /調査不足/
ちょうさほう /調査法/
ちょうさほうこく /調査報告/
ちょうさぼしゅう /調査募集/
ちょうさやく /調査役/
ちょうさよう /調査用/
ちょうさようし /調査用紙/
ちょうさんど /長三度/
ちょうさんぼし /朝三暮四/
ちょうさんわおん /長三和音/
ちょうざい /調剤/
ちょうざんこく /超残酷/
ちょうざんぞう /長残像/
ちょうし /調子/長子/銚子/聴視/冢祀/
ちょうしぎょこう /銚子漁港/
ちょうしし /銚子市/
ちょうししゃ /聴視者/
ちょうししょうぎょう /銚子商業/
ちょうしぜんがく /超自然学/
ちょうしなうす /超品薄/
ちょうしぶえ /調子笛/
ちょうしもの /調子者/
ちょうしゃ /庁舎/聴者/
ちょうしゃく /長尺/
ちょうしゃてい /長射程/
ちょうしゅ /聴取/
ちょうしゅいち /聴取位置/
ちょうしゅう /徴収/聴衆/長洲/長州/
ちょうしゅうかく /聴衆各/
ちょうしゅうがく /徴収額/
ちょうしゅうき /長周期/
ちょうしゅうきん /徴収金/
ちょうしゅうさんか /聴衆参加/
ちょうしゅうぜんいん /聴衆全員/
ちょうしゅくうかん /聴取空間/
ちょうしゅしゃ /聴取者/
ちょうしゅじ /聴取時/
ちょうしゅじっけん /聴取実験/
ちょうしゅほう /聴取法/
ちょうしゅりつちょうさ /聴取率調査/
ちょうしゅん /長春/
ちょうしょ /調書/長所/
ちょうしょう /嘲笑/弔鐘/
ちょうしょうすうは /超少数派/
ちょうしょく /朝食/調色/
ちょうしょくじ /朝食時/
ちょうしょくじかん /朝食時間/
ちょうしょくじゅんび /朝食準備/
ちょうしょくつき /朝食付/
ちょうしょくとりょう /調色塗料/
ちょうしょくよう /朝食用/
ちょうしょしんしゃ /超初心者/
ちょうしょたんしょ /長所短所/
ちょうしん /長身/聴診/長針/寵臣/
ちょうしんき /聴診器/
ちょうしんくう /超真空/
ちょうしんくうでんし /超真空電子/
ちょうしんけい /聴神経/
ちょうしんせい /超新星/
ちょうしんりがく /超心理学/
ちょうしんりがくしゃ /超心理学者/
ちょうしんりがっかい /超心理学会/
ちょうじ /長治/弔辞/寵児/
ちょうじかん /長時間/
ちょうじかんうんてん /長時間運転/
ちょうじかんさぎょう /長時間作業/
ちょうじかんさつえい /長時間撮影/
ちょうじかんしよう /長時間使用/
ちょうじかんそう /長時間走/
ちょうじかんていしゃ /長時間停車/
ちょうじかんでんわ /長時間電話/
ちょうじかんろこう /長時間露光/
ちょうじく /長軸/
ちょうじくうせんき /超時空戦記/
ちょうじくうようさい /超時空要塞/
ちょうじくほうこう /長軸方向/
ちょうじっすう /超実数/
ちょうじっすうろん /超実数論/
ちょうじつせい /超日性/
ちょうじゃ /長者/
ちょうじゃがさき /長者ヶ崎/
ちょうじゃくかん /長尺管/
ちょうじゅ /長寿/
ちょうじゅう /鳥獣/
ちょうじゅうぎが /鳥獣戯画/
ちょうじゅうせんしゃ /超重戦車/
ちょうじゅうりょくりろん /超重力理論/
ちょうじゅうろう /長十郎/
ちょうじゅしゃかい /長寿社会/
ちょうじゅしょうこうぐん /長寿症候群/
ちょうじゅせかいいち /長寿世界一/
ちょうじゅばんぐみ /長寿番組/
ちょうじゅみょう /長寿命/
ちょうじゅん /超準/
ちょうじゅんかいせき /超準解析/
ちょうじゅんすう /超準数/
ちょうじょ /長女/
ちょうじょう /長上/頂上/重畳/長城/超常/
ちょうじょうきゅう /超上級/
ちょうじょうきゅうしゃ /超上級者/
ちょうじょうげんしょう /超常現象/
ちょうじょうしゃ /長上者/
ちょうじょうのうりょく /超常能力/
ちょうじょうふきん /頂上付近/
ちょうじり /帳尻/
ちょうじろう /長次郎/
ちょうじん /超人/超神/鳥人/
ちょうじんてき /超人的/
ちょうじんてきよてい /超人的予定/
ちょうすうがく /超数学/
ちょうすうがくてき /超数学的/
ちょうすけ /長介/
ちょうず /手水/
ちょうずばち /手水鉢/
ちょうせあめ /朝鮮飴/
ちょうせい /調整/調性/長生/調製/長征/町政/調声/頂生/
ちょうせいおんがく /調性音楽/
ちょうせいかいせき /調性解析/
ちょうせいかん /調性感/
ちょうせいがく /調整額/
ちょうせいき /調整器/
ちょうせいきゅう /調整給/
ちょうせいご /調整後/
ちょうせいし /調整師/
ちょうせいしき /調整式/
ちょうせいしだい /調整次第/
ちょうせいしつ /調整室/
ちょうせいしゃ /調整者/
ちょうせいしゅだん /調整手段/
ちょうせいじょう /調整上/
ちょうせいじょうきょう /調整状況/
ちょうせいすう /調整数/
ちょうせいそく /超正則/
ちょうせいち /調整値/
ちょうせいちゅう /調整中/
ちょうせいのうりょく /調整能力/
ちょうせいはば /調整幅/
ちょうせいはんい /調整範囲/
ちょうせいぶ /調整部/
ちょうせいぶそく /調整不足/
ちょうせいほう /調整法/
ちょうせいほうほう /調整方法/
ちょうせいまえ /調整前/
ちょうせいめい /超生命/
ちょうせいやく /調整役/
ちょうせいよう /調整用/
ちょうせいりほう /超整理法/
ちょうせいりょう /調整料/
ちょうせき /長石/潮汐/
ちょうせきりょく /潮汐力/
ちょうせだい /超世代/
ちょうせつ /調節/
ちょうせついでんし /調節遺伝子/
ちょうせつかのう /調節可能/
ちょうせつきこう /調節機構/
ちょうせつきのう /調節機能/
ちょうせつほうほう /調節方法/
ちょうせん /挑戦/朝鮮/貂蝉;三国志演義に登場する美女/
ちょうせんいよく /挑戦意欲/
ちょうせんかんこくご /朝鮮韓国語/
ちょうせんき /挑戦記/
ちょうせんけい /朝鮮系/
ちょうせんけいいみん /朝鮮系移民/
ちょうせんご /朝鮮語/
ちょうせんし /超戦士/
ちょうせんしゃ /挑戦者/
ちょうせんしゃぐみ /挑戦者組/
ちょうせんしゃけってい /挑戦者決定/
ちょうせんしゃけっていせん /挑戦者決定戦/
ちょうせんしゅっしんしゃ /朝鮮出身者/
ちょうせんしんりゃく /朝鮮侵略/
ちょうせんじだい /朝鮮時代/
ちょうせんじょう /挑戦状/
ちょうせんじん /朝鮮人/
ちょうせんじんがっこう /朝鮮人学校/
ちょうせんじんさべつ /朝鮮人差別/
ちょうせんせい /朝鮮製/
ちょうせんせんそう /朝鮮戦争/
ちょうせんそうとくふ /朝鮮総督府/
ちょうせんだいがく /朝鮮大学/
ちょうせんだいがっこう /朝鮮大学校/
ちょうせんちゅう /挑戦中/
ちょうせんてき /挑戦的/
ちょうせんにっぽう /朝鮮日報/
ちょうせんにんじん /朝鮮人参/
ちょうせんはんとう /朝鮮半島/
ちょうせんはんとうなんぶ /朝鮮半島南部/
ちょうせんはんとうぶんだん /朝鮮半島分断/
ちょうせんへいごう /朝鮮併合/
ちょうせんもんか /超専門家/
ちょうぜい /徴税/町税/
ちょうぜつ /超絶/
ちょうぜつぎこう /超絶技巧/超絶技功/
ちょうぜつてき /超絶的/
ちょうぜつりんじん /超絶倫人/
ちょうぜん /超然/
ちょうそ /彫塑/
ちょうそかべ /長宗我部/
ちょうそがべ /長宗我部/
ちょうそく /長足/
ちょうそん /町村/
ちょうそんぶ /町村部/
ちょうそんめい /町村名/
ちょうぞう /長蔵/彫像/
ちょうぞうかん /超増感/
ちょうぞうかんしょり /超増感処理/
ちょうたいこく /超大国/
ちょうたいさく /超大作/
ちょうたいしょうせい /超対称性/
ちょうたいまん /超怠慢/
ちょうたきゃくき /超多客期/
ちょうただん /超多段/
ちょうたつ /調達/
ちょうたつご /調達後/
ちょうたつぶ /調達部/
ちょうたぼう /超多忙/
ちょうたろう /長太郎/
ちょうたん /長短/頂端/超短/
ちょうたんい /兆単位/
ちょうたんさいぼう /頂端細胞/
ちょうたんさいぼうがた /頂端細胞型/
ちょうたんさいぼうぐん /頂端細胞群/
ちょうたんさいぼうぐんがた /頂端細胞群型/
ちょうたんさいぼうせつ /頂端細胞説/
ちょうたんしげんさいぼう /頂端始原細胞/
ちょうたんしょ /長短所/
ちょうたんせいちょう /頂端生長/
ちょうたんはんてい /長短判定/
ちょうたんぱ /超短波/
ちょうたんぶんれつそしき /頂端分裂組織/
ちょうだ /長蛇/長打/
ちょうだい /長大/頂戴/朝大/鳥大/
ちょうだいか /長大化/
ちょうだいがめん /超大画面/
ちょうだいたん /超大胆/
ちょうだいへんせい /長大編成/
ちょうだえん /超楕円/
ちょうだりつ /長打率/
ちょうだりょく /長打力/
ちょうちかく /聴知覚/
ちょうちゃく /打擲/
ちょうちゅう /頂肘/
ちょうちょう /長調/町長/蝶々/蝶蝶/
ちょうちょうきょり /超長距離/
ちょうちょうは /超長波/
ちょうちょうはっし /丁々発止/
ちょうちん /提灯/
ちょうちんぴん /超珍品/
ちょうつがい /蝶番/
ちょうづめ /腸詰/
ちょうてい /調停/朝廷/超低/調定/
ちょうていおん /超低音/
ちょうていかかく /超低価格/
ちょうていくう /超低空/
ちょうていくうひこう /超低空飛行/
ちょうていしゃ /調停者/
ちょうていそく /超低速/
ちょうていぶんさん /超低分散/
ちょうていやく /調停役/
ちょうてき /朝敵/
ちょうてじゅん /長手順/
ちょうてすう /超手数/
ちょうてぬき /超手抜き/
ちょうてん /頂点/長点/
ちょうてんかん /頂点間/
ちょうてんすう /頂点数/
ちょうてんようそ /頂点要素/
ちょうてんれつ /頂点列/
ちょうでん /弔電/長電/
ちょうでんじ /超電磁/
ちょうでんじこうか /超電磁効果/
ちょうでんどう /超伝導/超電導/
ちょうでんどうじしゃく /超電導磁石/
ちょうでんどうでんじしゃく /超伝導電磁石/
ちょうと /長途/
ちょうとうは /超党派/
ちょうとくだい /超特大/
ちょうとっきゅう /超特急/
ちょうど /丁度/調度/
ちょうどう /町道/
ちょうどきゅう /超弩級/
ちょうどひん /調度品/
ちょうな /鐇/
ちょうない /町内/腸内/
ちょうないかい /町内会/
ちょうないかくしょ /町内各所/
ちょうなん /長男/長南/嘲難/
ちょうなんもん /超難問/
ちょうにがて /超苦手/
ちょうにゅうもん /超入門/
ちょうにん /町人/
ちょうにんき /超人気/
ちょうにんきぞく /町人貴族/
ちょうにんげん /超人間/
ちょうの /蝶野/
ちょうのうりょく /超能力/
ちょうのうりょくかいはつ /超能力開発/
ちょうのうりょくかいめい /超能力解明/
ちょうのうりょくしゃ /超能力者/超脳力者/
ちょうのうりょくばんぐみ /超能力番組/
ちょうのつぼ /町坪/
ちょうは /調波/長波/
ちょうはかく /超破格/
ちょうはちょう /長波長/
ちょうはつ /長髪/挑発/徴発/挑撥/調髪/
ちょうはつこうい /挑発行為/
ちょうはつてき /挑発的/
ちょうはつど /挑発度/
ちょうはんげんき /長半減期/
ちょうば /帳場/嘲罵/
ちょうばいか /鳥媒花/
ちょうばつ /懲罰/
ちょうひ /張飛;三国時代・蜀漢の武将/
ちょうひさん /超悲惨/
ちょうひっさつわざ /超必殺技/
ちょうひょう /帳表/帳票/
ちょうびさい /超微細/
ちょうびじん /超美人/
ちょうびふう /超微風/
ちょうびりゅうし /超微粒子/
ちょうびんぼう /超貧乏/
ちょうふ /調布/貼付/長府/
ちょうふえき /調布駅/
ちょうふかん /調布間/
ちょうふがおか /調布ヶ丘/
ちょうふがわ /調布側/
ちょうふく /重複/
ちょうふくぶん /重複分/
ちょうふこうこう /調布高校/
ちょうふさい /調布祭/
ちょうふし /調布市/
ちょうふしんせつ /超不親切/
ちょうふてん /調布店/
ちょうふにんきしゃ /超不人気車/
ちょうふふきん /調布付近/
ちょうぶ /頂部/
ちょうぶつ /長物/
ちょうぶん /長文/
ちょうぶんさん /超分散/
ちょうぶんし /超分子/
ちょうへい /徴兵/長平/
ちょうへいき /超兵器/
ちょうへいせい /徴兵制/
ちょうへいめん /超平面/
ちょうへいれつ /超並列/
ちょうへいれつがた /超並列型/
ちょうへいれつけいさん /超並列計算/
ちょうへいれつけいさんき /超並列計算機/
ちょうへいれつしょり /超並列処理/
ちょうへいれつよう /超並列用/
ちょうへき /腸壁/
ちょうへん /長編/長篇/長辺/
ちょうへんか /長編化/
ちょうへんしょうせつ /長編小説/
ちょうへんせい /長編成/
ちょうへんせいか /長編成化/
ちょうへんばん /長編版/
ちょうほ /調歩/
ちょうほう /重宝/諜報/長方/
ちょうほういん /諜報員/
ちょうほうきてき /超法規的/
ちょうほうけい /長方形/
ちょうほしゅしそう /超保守思想/
ちょうほしゅてき /超保守的/
ちょうほどうき /調歩同期/
ちょうほんにん /張本人/
ちょうぼ /帳簿/
ちょうぼいん /長母音/
ちょうぼう /眺望/
ちょうぼうえん /超望遠/
ちょうぼうえんよう /超望遠用/
ちょうぼじょう /帳簿上/
ちょうぼるい /帳簿類/
ちょうまじめ /超真面目/
ちょうまじゅつ /超魔術/
ちょうまる /朝丸/
ちょうまんいん /超満員/
ちょうまんばけん /超万馬券/
ちょうみ /調味/
ちょうみつ /稠密/
ちょうみつせい /稠密性/
ちょうみりょう /調味料/
ちょうみりょうだい /調味料代/
ちょうみりょうなど /調味料等/
ちょうみりょうひ /調味料費/
ちょうみん /町民/
ちょうみんよう /町民用/
ちょうむじゅん /超矛盾/
ちょうむち /超無知/
ちょうめ /丁目/
ちょうめい /町名/長命/澄明/
ちょうめいきょく /超名曲/
ちょうめいばん /超名盤/
ちょうめいもん /超名門/
ちょうめいれいご /長命令語/
ちょうめん /帳面/帖面/
ちょうめんづら /帳面面/
ちょうもく /鳥目/
ちょうもじ /超文字/
ちょうもん /弔問/長門/聴聞/
ちょうもんかい /聴聞会/
ちょうや /聴野/
ちょうやく /跳躍/超訳/
ちょうやくりょく /跳躍力/
ちょうゆう /町有/
ちょうゆうめい /超有名/
ちょうゆうめいじん /超有名人/
ちょうゆうめいてん /超有名店/
ちょうゆうめいばんぐみ /超有名番組/
ちょうよう /徴用/重陽/町陽/重用/
ちょうらく /凋落/
ちょうらくしょう /超楽勝/
ちょうり /調理/蝶理/嘲詈/
ちょうりき /調理器/
ちょうりきぐ /調理器具/調理機具/
ちょうりぎじゅつ /調理技術/
ちょうりし /調理師/
ちょうりじかん /調理時間/
ちょうりずみ /調理済み/
ちょうりちゅう /調理中/
ちょうりつ /調律/町立/
ちょうりつきょくせん /調律曲線/
ちょうりつし /調律師/
ちょうりつしきょうかい /調律師協会/
ちょうりつほう /調律法/
ちょうりつようちえん /町立幼稚園/
ちょうりなべ /調理鍋/
ちょうりにん /調理人/
ちょうりば /調理場/
ちょうりひん /調理品/
ちょうりほう /調理法/
ちょうりほうほう /調理方法/
ちょうりゅう /潮流/
ちょうりゅうどう /超流動/
ちょうりゅうまい /長粒米/
ちょうりょう /跳梁/
ちょうりょうばっこ /跳梁跋扈/
ちょうりょく /張力/聴力/
ちょうりょくきのう /聴力機能/
ちょうりよう /調理用/
ちょうりろん /超理論/
ちょうりんかいりゅうたい /超臨界流体/
ちょうるい /鳥類/
ちょうれい /朝礼/
ちょうれいか /張麗華/
ちょうれいぼかい /朝令暮改/
ちょうれん /長連/
ちょうろう /長老/嘲弄/
ちょうろうきしゃ /長老記者/
ちょうわ /調和/
ちょうわおん /長和音/
ちょうわしんどうし /調和振動子/
ちょうわへいきん /調和平均/
ちょきん /貯金/
ちょきんきょく /貯金局/
ちょきんしゃっきんひょう /貯金借金表/
ちょきんじむ /貯金事務/
ちょきんばこ /貯金箱/
ちょきんほうしき /貯金方式/
ちょきんりょう /貯金量/
ちょく /直/捗/勅/飭/敕/稙/躅/陟/
ちょくえい /直営/直衛/
ちょくえいてん /直営店/
ちょくえん /直掩/
ちょくおん /直音/
ちょくか /直下/
ちょくげき /直撃/
ちょくげきだん /直撃弾/
ちょくげん /直言/
ちょくこうりょうようでんしゃ /直交両用電車/
ちょくご /直後/勅語/
ちょくさいてき /直截的/
ちょくし /直視/勅使/勅旨/
ちょくしゃ /直射/
ちょくしゃにっこう /直射日光/
ちょくしゅつ /直出/
ちょくしょ /勅書/
ちょくしょう /勅詔/
ちょくしょうてん /直焦点/
ちょくしん /直進/
ちょくしんあんていせい /直進安定性/
ちょくしんうんどう /直進運動/
ちょくしんしゃ /直進車/
ちょくしんじ /直進時/
ちょくしんじどうにりん /直進自動二輪/
ちょくしんせい /直進性/
ちょくしんちゅう /直進中/
ちょくしんほうこう /直進方向/
ちょくじ /直示/
ちょくじょう /直上/直情/
ちょくせい /直生/
ちょくせいはいしゅ /直生胚珠/
ちょくせき /直積/
ちょくせつ /直接/直截/
ちょくせつあいて /直接相手/
ちょくせつえいきょう /直接影響/
ちょくせつおん /直接音/
ちょくせつかいじょう /直接会場/
ちょくせつかいせん /直接回線/
ちょくせつかいとう /直接回答/
ちょくせつかいにゅう /直接介入/
ちょくせつかくにん /直接確認/
ちょくせつかんせつ /直接間接/
ちょくせつがぞうしんごう /直接画像信号/
ちょくせつきじゅつ /直接記述/
ちょくせつきどう /直接起動/
ちょくせつけいやく /直接契約/
ちょくせつげんいん /直接原因/
ちょくせつこう /直接光/
ちょくせつこうげき /直接攻撃/
ちょくせつこうしょう /直接交渉/
ちょくせつこうにゅう /直接購入/
ちょくせつごうぎせい /直接合議制/
ちょくせつさぎょう /直接作業/
ちょくせつしょうめい /直接照明/
ちょくせつせいきゅう /直接請求/
ちょくせつせいきゅうけん /直接請求権/
ちょくせつせいぎょ /直接制御/
ちょくせつせっしゅ /直接摂取/
ちょくせつせつぞく /直接接続/
ちょくせつせん /直接戦/直接線/
ちょくせつせんきょせい /直接選挙制/
ちょくせつせんとう /直接戦闘/
ちょくせつぜい /直接税/
ちょくせつぜいふたん /直接税負担/
ちょくせつそうさ /直接操作/
ちょくせつそくてい /直接測定/
ちょくせつたいおう /直接対応/
ちょくせつたいけつ /直接対決/
ちょくせつちゅうもん /直接注文/
ちょくせつつうしん /直接通信/
ちょくせつていしゅつ /直接提出/
ちょくせつてき /直接的/
ちょくせつてきえいきょう /直接的影響/
ちょくせつてんそう /直接転送/
ちょくせつにゅうしゃ /直接入射/
ちょくせつにゅうしゅ /直接入手/
ちょくせつにゅうりょく /直接入力/
ちょくせつは /直接波/
ちょくせつはっちゅう /直接発注/
ちょくせつはんたい /直接反対/
ちょくせつはんばい /直接販売/
ちょくせつはんばいじぎょう /直接販売事業/
ちょくせつばち /直接鉢/
ちょくせつひ /直接費/
ちょくせつひかく /直接比較/
ちょくせつひかくけんとう /直接比較検討/
ちょくせつふつうせんきょ /直接普通選挙/
ちょくせつほう /直接法/直説法/
ちょくせつみんしゅしゅぎ /直接民主主義/
ちょくせつみんしゅせい /直接民主制/
ちょくせつゆにゅう /直接輸入/
ちょくせつりえき /直接利益/
ちょくせつりよう /直接利用/
ちょくせつれんらく /直接連絡/
ちょくせん /直線/勅撰/
ちょくせんいっき /直線一気/
ちょくせんうんどう /直線運動/
ちょくせんかいき /直線回帰/
ちょくせんかそく /直線加速/
ちょくせんかそくき /直線加速器/
ちょくせんがい /直線外/
ちょくせんがわ /直線側/
ちょくせんきょり /直線距離/
ちょくせんくかん /直線区間/
ちょくせんぐん /直線群/
ちょくせんしき /直線式/
ちょくせんしょうぶ /直線勝負/
ちょくせんじょう /直線上/直線状/
ちょくせんせい /直線性/
ちょくせんせんようき /直線専用機/
ちょくせんせんろ /直線線路/
ちょくせんてき /直線的/
ちょくせんどうろ /直線道路/
ちょくせんび /直線美/
ちょくせんふり /直線不利/
ちょくせんぶぶん /直線部分/
ちょくせんぶんし /直線分子/
ちょくせんへんこう /直線偏光/
ちょくせんほかん /直線補間/直線補完/
ちょくせんまえ /直線前/
ちょくせんりょうしか /直線量子化/
ちょくぜい /直税/
ちょくぜん /直前/
ちょくぜんゆそう /直前輸送/
ちょくそう /直送/
ちょくぞく /直属/
ちょくたつ /直達/
ちょくたつは /直達波/
ちょくちょう /直腸/
ちょくつう /直通/
ちょくつううんてん /直通運転/
ちょくつううんよう /直通運用/
ちょくつうかのう /直通可能/
ちょくつうかもつうんてん /直通貨物運転/
ちょくつうきゅうこう /直通急行/
ちょくつうじゅよう /直通需要/
ちょくつうじゅんきゅう /直通準急/
ちょくつうせん /直通線/
ちょくつうでんしゃ /直通電車/
ちょくつうとっきゅう /直通特急/
ちょくつうびん /直通便/
ちょくつうれっしゃ /直通列車/
ちょくつうろせん /直通路線/
ちょくで /直出/
ちょくとう /直答/勅答/
ちょくどう /直動/
ちょくどく /直読/
ちょくにゅう /直入/
ちょくにん /勅任/
ちょくはん /直販/
ちょくはんてん /直販店/
ちょくばい /直売/
ちょくばいてん /直売店/
ちょくふ /直付/
ちょくほう /直方/
ちょくほうたい /直方体/
ちょくめん /直面/
ちょくやく /直訳/
ちょくやくてき /直訳的/
ちょくゆ /直喩/
ちょくゆしゅつ /直輸出/
ちょくゆにゅう /直輸入/
ちょくゆにゅうばん /直輸入版/
ちょくりつ /直立/
ちょくりつけい /直立茎/
ちょくりつさいぼう /直立細胞/
ちょくりつし /直立枝/
ちょくりつしせい /直立姿勢/
ちょくりつじょうたい /直立状態/
ちょくりつせい /直立性/
ちょくりつほうしゃそしきさいぼう /直立放射組織細胞/
ちょくりつほこう /直立歩行/
ちょくりゅう /直流/
ちょくりゅうか /直流化/
ちょくりゅうがわでんあつ /直流側電圧/
ちょくりゅうき /直流機/
ちょくりゅうきかんしゃ /直流機関車/
ちょくりゅうくかん /直流区間/
ちょくりゅうしんごう /直流信号/
ちょくりゅうせいぶん /直流成分/
ちょくりゅうそうでん /直流送電/
ちょくりゅうたいおう /直流対応/
ちょくりゅうていこう /直流抵抗/
ちょくりゅうでんか /直流電化/
ちょくりゅうでんかくかん /直流電化区間/
ちょくりゅうでんきてつどう /直流電気鉄道/
ちょくりゅうでんしゃ /直流電車/
ちょくりゅうでんりゅう /直流電流/
ちょくりゅうはつでんき /直流発電機/
ちょくりゅうぶ /直流部/
ちょくりゅうほうしき /直流方式/
ちょくりゅうよう /直流用/
ちょくれい /勅令/直隷/
ちょくれつ /直列/
ちょくれつがた /直列型/
ちょくれつきごうしょりけい /直列記号処理系/
ちょくれつけい /直列系/
ちょくれつげんご /直列言語/
ちょくれつしき /直列式/
ちょくれつしよう /直列使用/
ちょくれつせつぞく /直列接続/
ちょくれつましん /直列マシン/
ちょくわ /直和/
ちょげん /緒言/
ちょこ /チョコ/猪口/
ちょこう /著効/
ちょこざい /猪口才/
ちょこれーと /チョコレート/貯古齢糖/
ちょさく /著作/
ちょさくぐん /著作群/
ちょさくけん /著作権/
ちょさくけんいはん /著作権違反/
ちょさくけんかんけい /著作権関係/
ちょさくけんきょうかい /著作権協会/
ちょさくけんしゃ /著作権者/
ちょさくけんしょゆうしゃ /著作権所有者/
ちょさくけんしようりょう /著作権使用料/
ちょさくけんしんがい /著作権侵害/
ちょさくけんじゃ /著作権者/
ちょさくけんじょう /著作権上/
ちょさくけんじょうもんだい /著作権上問題/
ちょさくけんせいど /著作権制度/
ちょさくけんたいしょう /著作権対象/
ちょさくけんだんたい /著作権団体/
ちょさくけんてき /著作権的/
ちょさくけんなど /著作権等/
ちょさくけんひょうじ /著作権表示/
ちょさくけんぶつ /著作権物/
ちょさくけんほう /著作権法/
ちょさくけんほうき /著作権放棄/
ちょさくけんほうきせい /著作権法規制/
ちょさくけんほうぜんぶん /著作権法全文/
ちょさくけんほご /著作権保護/
ちょさくけんぽうじょう /著作権法上/
ちょさくけんもんだい /著作権問題/
ちょさくけんりょう /著作権料/
ちょさくけんりょうさんてい /著作権料算定/
ちょさくけんりょうしはらい /著作権料支払/
ちょさくしゃ /著作者/
ちょさくしゃけん /著作者権/
ちょさくしゃざいさんけん /著作者財産権/
ちょさくしゃじんかくけん /著作者人格権/
ちょさくしゃべつ /著作者別/
ちょさくしゃめい /著作者名/
ちょさくちゅう /著作中/
ちょさくぶつ /著作物/
ちょさくぶつりゅうつう /著作物流通/
ちょさくりんせつけん /著作隣接権/
ちょさくりんせつけんしゃ /著作隣接権者/
ちょしゃ /著者/
ちょしゃあて /著者宛/
ちょしゃきごう /著者記号/
ちょしゃしょうかい /著者紹介/
ちょしゃじしん /著者自身/
ちょしゃたち /著者達/
ちょしゃめい /著者名/
ちょしゃめいじゅん /著者名順/
ちょしゃりゃくれき /著者略歴/
ちょしょ /著書/
ちょしょめい /著書名/
ちょじゅつ /著述/
ちょじゅつか /著述家/
ちょすい /貯水/
ちょすいそう /貯水槽/
ちょすいそしき /貯水組織/
ちょすいち /貯水池/
ちょすいよう /貯水用/
ちょすいりょう /貯水量/
ちょすかべ /長宗我部/
ちょせつけい /調節系/
ちょせん /緒戦/
ちょぞう /貯蔵/
ちょぞうこ /貯蔵庫/
ちょぞうこうぞう /貯蔵構造/
ちょぞうこん /貯蔵根/
ちょぞうしつ /貯蔵室/
ちょぞうしゅ /貯蔵酒/
ちょぞうじゅうそしき /貯蔵柔組織/
ちょぞうそしき /貯蔵組織/
ちょぞうひん /貯蔵品/
ちょちく /貯蓄/
ちょちくさいけん /貯蓄債券/
ちょちくほけん /貯蓄保険/
ちょっか /直下/
ちょっかい /直快/
ちょっかく /直覚/直角/
ちょっかくさんかっけい /直角三角形/
ちょっかくざひょう /直角座標/
ちょっかくほうこう /直角方向/
ちょっかっこう /直滑降/
ちょっかつ /直轄/
ちょっかん /直観/直感/直管/
ちょっかんしゅぎ /直観主義/直感主義/
ちょっかんしゅぎしゃ /直観主義者/
ちょっかんしゅぎじょう /直観主義上/
ちょっかんしゅぎすうがく /直観主義数学/
ちょっかんしゅぎてき /直観主義的/
ちょっかんしゅぎめいだいろんり /直観主義命題論理/
ちょっかんしゅぎろんり /直観主義論理/
ちょっかんせかい /直観世界/
ちょっかんてき /直感的/直観的/
ちょっかんてきほうほう /直感的方法/直観的方法/
ちょっかんないよう /直観内容/
ちょっかんひりつ /直間比率/
ちょっかんろんり /直観論理/
ちょっき /直帰/
ちょっきゅう /直球/
ちょっきょ /勅許/
ちょっきん /直近/
ちょっけい /直径/直系/
ちょっけいけつぞく /直系血族/
ちょっけいしそん /直系子孫/
ちょっけいぶぶん /直径部分/
ちょっけいやく /直径約/
ちょっけつ /直結/
ちょっけつしき /直結式/
ちょっこう /直交/直行/直航/
ちょっこうかんすう /直交関数/
ちょっこうかんすうけい /直交関数系/
ちょっこうがた /直交型/
ちょっこうがたきこう /直交型気孔/
ちょっこうきてい /直交基底/
ちょっこうきんじ /直交近似/
ちょっこうぎょうれつ /直交行列/
ちょっこうぐみ /直行組/
ちょっこうけい /直交系/
ちょっこうけいろ /直行経路/
ちょっこうざひょう /直交座標/
ちょっこうざひょうけい /直交座標系/
ちょっこうじく /直交軸/
ちょっこうせい /直交性/
ちょっこうちょくせんざひょう /直交直線座標/
ちょっこうちょっき /直行直帰/
ちょっこうびん /直行便/
ちょっこうぶんかい /直交分解/
ちょっこうわ /直交和/
ちょっと /一寸/
ちょとつ /猪突/
ちょとつもうしん /猪突猛進/
ちょはっかい /猪八戒/
ちょへん /著変/
ちょぼく /貯木/
ちょぼくじょう /貯木場/
ちょめい /著名/著明/
ちょめいさっか /著名作家/
ちょめいじん /著名人/
ちょめちょめ /××/
ちょりつ /佇立/
ちょりゅう /貯留/
ちょろん /緒論/
ちょんがけ /丁斧掛け/
ちょんぼ /チョンボ/錯和/
ちょんまげ /丁髷/
ちょんりま /千里馬/
ちよ /千代/
ちようだ /千代/
ちよかわ /千代川/
ちよくら /千代倉/
ちよこ /千代子/
ちよだ /千代田/
ちよだかこうけんせつ /千代田化工建設/
ちよだく /千代田区/
ちよだくこうじまち /千代田区麹町/
ちよだじょがくえん /千代田女学園/
ちよだせん /千代田線/
ちよだせんあかさか /千代田線赤坂/
ちよちょう /千代町/
ちよの /千代乃/
ちよまる /千代丸/
ちよろず /千万/
ちらく /地落/
ちらし /チラシ/
ちらん /知覧/
ちり /地理/塵/智利/
ちりあくた /塵芥/
ちりいん /地理院/
ちりがく /地理学/
ちりきょういく /地理教育/
ちりそーす /チリソース/
ちりてき /地理的/
ちりてきがいぶ /地理的外部/
ちりてきはいけい /地理的背景/
ちりてきぶんぷ /地理的分布/
ちりはま /千里浜/
ちりめん /縮緬/
ちりゃく /知略/智略/
ちりゅう /知立/
ちりゅうし /知立市/
ちりょう /治療/
ちりょうこうい /治療行為/
ちりょうこうか /治療効果/
ちりょうご /治療後/
ちりょうし /治療師/
ちりょうしつ /治療室/
ちりょうしゃ /治療者/
ちりょうじ /治療時/
ちりょうだい /治療代/
ちりょうちゅう /治療中/治寮中/
ちりょうはんい /治療範囲/
ちりょうひ /治療費/
ちりょうひかんけい /治療費関係/
ちりょうほう /治療法/
ちりょうほうほう /治療方法/
ちりょうやく /治療薬/
ちりょうよう /治療用/
ちりょうれい /治療例/
ちりょく /知力/地力/
ちれい /地霊/
ちわ /痴話/地和/
ちわく /地惑/
ちん /賃/陳/鎮/椿/沈/珍/朕/砧/チン/枕/抻/狆/珎/碪/趁/鎭/闖/鴆/
ちん> /珍/
ちんあげ /賃上げ/
ちんあつ /鎮圧/
ちんあん /珍案/
ちんか /沈下/鎮火/
ちんかきょう /沈下橋/
ちんがし /賃貸し/
ちんがり /賃借り/
ちんき /珍奇/丁幾/
ちんきゃく /珍客/
ちんきゅう /陳宮/
ちんきろく /珍記録/
ちんきん /沈金/
ちんぎん /賃金/
ちんぎんじょうしょう /賃金上昇/
ちんぎんすいじゅん /賃金水準/
ちんぎんたいけい /賃金体系/
ちんぎんどれいせい /賃金奴隷制/
ちんげい /珍芸/
ちんこう /沈降/沈香/
ちんこうせい /沈降性/
ちんこうちくせき /沈降蓄積/
ちんこん /鎮魂/
ちんこんか /鎮魂歌/
ちんさ /沈渣/
ちんさげ /賃下げ/
ちんざ /鎮座/
ちんざんそう /椿山荘/
ちんし /沈思/
ちんしもっこう /沈思黙考/
ちんしゃ /陳謝/
ちんしゃく /賃借/
ちんしゃくけん /賃借権/
ちんしゃくにん /賃借人/
ちんしゃくりょう /賃借料/
ちんしゃじょう /陳謝状/
ちんしゅ /珍種/珍手/
ちんじ /珍事/椿事/
ちんじゃく /賃借/
ちんじゅ /鎮守/
ちんじゅう /珍獣/珍重/
ちんじゅつ /陳述/
ちんじょう /陳情/
ちんすい /沈水/
ちんすいしょくぶつ /沈水植物/
ちんせい /鎮静/
ちんせいか /鎮静化/
ちんせき /珍石/枕席/
ちんせつ /珍説/
ちんせん /沈船/
ちんぜい /鎮西/
ちんたい /賃貸/沈滞/
ちんたいぎょう /賃貸業/
ちんたいけいやくしゃ /賃貸契約者/
ちんたいしゃく /賃貸借/
ちんたいじゅうたく /賃貸住宅/
ちんだん /沈檀/
ちんだんきだん /珍談奇談/
ちんちゃく /沈着/
ちんちゃくれいせい /沈着冷静/
ちんちょう /珍重/
ちんちょうげ /沈丁花/
ちんつう /鎮痛/
ちんつうざい /鎮痛剤/
ちんつうやく /鎮痛薬/
ちんてい /鎮定/
ちんでん /沈殿/沈澱/
ちんでんぶつ /沈殿物/
ちんとう /枕頭/
ちんとうびょう /沈頭鋲/
ちんどうしき /沈胴式/
ちんどうちゅう /珍道中/
ちんにゅう /闖入/
ちんねん /珍念/
ちんばめん /珍場面/
ちんばめんたいしょう /珍場面大賞/
ちんばん /珍盤/
ちんぱん /青幇/
ちんぴ /陳皮/
ちんぴん /珍品/
ちんぶ /鎮撫/
ちんぶん /珍聞/
ちんぷ /陳腐/
ちんぷか /陳腐化/
ちんぼつ /沈没/
ちんぼつかん /沈没艦/
ちんぼつせん /沈没船/
ちんぽう /珍宝/
ちんぽこ /似指/
ちんみ /珍味/
ちんみょう /珍妙/
ちんめい /珍名/
ちんめん /沈湎/
ちんもく /沈黙/
ちんりつ /賃率/
ちんりょう /賃料/
ちんりろん /珍理論/
ちんれつ /陳列/
ちんれつだな /陳列棚/
ぢ /痔/地/
ぢあけ /地上げ/
ぢか /近/直/
ぢくぢ /忸怩/
ぢぐち /地口/
ぢげ /地下/
ぢごく /地獄/
ぢさん /持参/
ぢざけ /地酒/
ぢしん /地震/
ぢぞく /持続/
ぢだい /地代/
ぢとり /地鶏/
ぢどり /地鶏/
ぢば /地場/
ぢばく /地縛/
ぢひびき /地響き/
ぢふぶき /地吹雪/
ぢみ /地味/
ぢみち /地道/
ぢめん /地面/
ぢもと /地元/
ぢゅう /中/
つ /津/都/付/積/晦/柘/
つーりすと /ツーリスト/
つーりんぐ /ツーリング/
つーる /ツール/
つあー /ツアー/
つい /対/追/鎚/椎/槌/墜/堆/遂/築/對/縋/
ついえ /毅/
ついおく /追憶/
ついか /追加/
ついかあんない /追加案内/
ついかかんさん /追加換算/
ついかかんざん /追加換算/
ついかがくしゅう /追加学習/
ついかきのう /追加機能/
ついかこうえん /追加公演/
ついかこうかい /追加公開/
ついかこうにゅう /追加購入/
ついかこうもく /追加項目/
ついかさくじょ /追加削除/
ついかさくひん /追加作品/
ついかしつもん /追加質問/
ついかしゅちょう /追加主張/
ついかじっそう /追加実装/
ついかじょうほう /追加情報/
ついかそうび /追加装備/
ついかちゅうもん /追加注文/
ついかてき /追加的/
ついかてん /追加点/
ついかとうりょくりょう /追加登録料/
ついかはいぶん /追加配分/
ついかはっちゅう /追加発注/
ついかはっぴょう /追加発表/
ついかはつばい /追加発売/
ついかばん /追加版/
ついかひょう /追加表/
ついかぶそう /追加武装/
ついかぶぶん /追加部分/
ついかぶん /追加分/
ついかぶんけん /追加文献/
ついかほうこく /追加報告/
ついかぼしゅうぶん /追加募集分/
ついかりょうきん /追加料金/
ついかれい /追加例/
ついかれっきょ /追加列挙/
ついかんばん /椎間板/
ついき /追記/立木/築城/
ついきえききんぺん /立木駅近辺/
ついきしき /追記式/
ついきじこう /追記事項/
ついきゅう /追及/追求/追究/追給/
ついきゅうしせい /追求姿勢/
ついきん /追金/
ついく /対句/
ついげき /追撃/
ついこうちゅう /遂行中/
ついこつ /椎骨/
ついご /対語/
ついし /追試/墜死/
ついしけん /追試験/
ついしけんしょう /追試検証/
ついしょう /追従/
ついしん /追伸/追信/P.S./
ついじっけん /追実験/
ついじゅう /追従/
ついじゅうせい /追従性/
ついじゅく /追熟/
ついすう /対数/
ついずい /追随/
ついずいせい /追随性/
ついせいせい /対生成/
ついせき /追跡/
ついせきがた /追跡型/
ついせきしゅざい /追跡取材/
ついせきちょうさ /追跡調査/
ついせきちょうさかのう /追跡調査可能/
ついせきほうどう /追跡報道/
ついせきほうほう /追跡方法/
ついそ /追訴/
ついそう /追走/追想/
ついたい /椎体/
ついたいけん /追体験/
ついたち /一日/1日/１日/朔日/
ついたて /衝立/
ついちょう /追徴/
ついちょうがく /追徴額/
ついちょうきん /追徴金/
ついで /序で/次いで/序/尋いで/
ついとう /追悼/
ついとうしき /追悼式/
ついとうじょうえい /追悼上映/
ついとうばんぐみ /追悼番組/
ついとつ /追突/
ついとつじこ /追突事故/
ついとつぼうし /追突防止/
ついに /終に/遂に/
ついにん /追認/
ついにんとうひょう /追認投票/
ついび /追尾/
ついびせいど /追尾精度/
ついびそうち /追尾装置/
ついふく /追復/
ついほ /追補/
ついほう /追放/
ついほうかいじょ /追放解除/
ついほばん /追補版/
ついぼ /追慕/
ついらく /墜落/
ついらくし /墜落死/
ついらくじこ /墜落事故/
ついろく /追録/
ついん /ツイン/
つう /通/痛/
つういいそう /字一色/
つういん /通院/痛飲/
つういんこうつうひ /通院交通費/
つういんしゃ /通院者/
つううん /通運/
つうえん /通園/
つうか /通過/通貨/
つうかい /痛快/通快/
つうかいき /通過域/
つうかうんてん /通過運転/
つうかえき /通過駅/
つうかえきそうごかん /通過駅相互間/
つうかかのう /通過可能/
つうかがた /通過型/
つうかきごう /通貨記号/
つうかきゃく /通過客/
つうかきんしえき /通過禁止駅/
つうかぎれい /通過儀礼/
つうかく /痛覚/
つうかけいろ /通過経路/
つうかこく /通過国/
つうかご /通過後/
つうかじ /通過時/
つうかじかん /通過時間/
つうかじこく /通過時刻/
つうかじどうしゃ /通過自動車/
つうかじゅんい /通過順位/
つうかじんいん /通過人員/
つうかせいげん /通過制限/
つうかせいげんひょう /通過制限表/
つうかせん /通過線/
つうかそくど /通過速度/
つうかたいいき /通過帯域/
つうかちゅう /通過中/
つうかてん /通過点/
つうかでんしゃ /通過電車/
つうかはんべつ /通過判別/
つうかほんすう /通過本数/
つうかりょきゃくすう /通過旅客数/
つうかれっしゃ /通過列車/
つうかれっしゃうんてん /通過列車運転/
つうかれっしゃせってい /通過列車設定/
つうかれっしゃどうし /通過列車同士/
つうかん /痛感/通関/通巻/
つうかんご /通関後/
つうかんじ /通関時/
つうがく /通学/
つうがくけいろ /通学経路/
つうがくさき /通学先/
つうがくしょうめいしょ /通学証明書/
つうがくじ /通学時/
つうがくじかん /通学時間/
つうがくじかんたい /通学時間帯/
つうがくせい /通学生/
つうがくゆそう /通学輸送/
つうがくよう /通学用/
つうがくろ /通学路/
つうがくろせん /通学路線/
つうき /通気/
つうきこう /通気口/通気孔/
つうきこうぞう /通気構造/
つうきせい /通気性/
つうきそしき /通気組織/
つうきん /通勤/
つうきんかいそく /通勤快速/
つうきんかいとく /通勤快特/
つうきんきゃく /通勤客/
つうきんけいろ /通勤経路/
つうきんけいろじょう /通勤経路上/
つうきんけん /通勤圏/
つうきんしゃ /通勤者/通勤車/
つうきんしゃりょう /通勤車両/
つうきんしんかいそく /通勤新快速/
つうきんじ /通勤時/
つうきんじかん /通勤時間/
つうきんじかんたい /通勤時間帯/
つうきんじごく /通勤地獄/
つうきんじじょう /通勤事情/
つうきんじゅよう /通勤需要/
つうきんせんく /通勤線区/
つうきんちゅう /通勤中/
つうきんつうがく /通勤通学/
つうきんていき /通勤定期/
つうきんていきだい /通勤定期代/
つうきんてつどう /通勤鉄道/
つうきんでんしゃ /通勤電車/
つうきんとくべつかいそく /通勤特別快速/
つうきんとちゅう /通勤途中/
つうきんとっかい /通勤特快/
つうきんとっきゅう /通勤特急/
つうきんひ /通勤費/
つうきんひほじょ /通勤費補助/
つうきんゆそう /通勤輸送/
つうきんよう /通勤用/
つうきんりゅうどう /通勤流動/
つうきんれっしゃ /通勤列車/
つうきんろ /通勤路/
つうきんろせん /通勤路線/
つうぎょう /通暁/
つうけん /通研/電気通信研究所/東北大学電気通信研究所/
つうけんこうかい /通研公開/
つうげき /痛撃/
つうげんごてき /通言語的/
つうこう /通行/通工/通交/通好/
つうこうか /通行可/
つうこうかのう /通行可能/
つうこうきょか /通行許可/
つうこうきんし /通行禁止/
つうこうきんしいはん /通行禁止違反/
つうこうくぶん /通行区分/
つうこうけん /通行券/
つうこうしゃ /通行車/
つうこうちゅう /通行中/
つうこうどめ /通行止/
つうこうにん /通行人/
つうこうふか /通行不可/
つうこうふのう /通行不能/
つうこうりょう /通行量/通行料/
つうこく /通告/
つうこん /痛恨/
つうごのみ /通好み/
つうさん /通産/通算/
つうさんきょく /通産局/
つうさんぎかん /通産技官/通商産業技官/
つうさんげつ /通算月/
つうさんしょう /通産省;2001年1月の中央省庁再編で経済産業省に再編された/通産相/通商産業省;2001年1月の中央省庁再編で経済産業省に再編された/
つうさんしょうこうぎいん /通産省工技院/
つうさんせいせき /通算成績/
つうさんだりつ /通算打率/
つうさんとくてん /通算得点/
つうさんねん /通算年/
つうし /通史/
つうしょう /通称/通商/
つうしょうかいぎ /通商会議/
つうしょうさんぎょうしょう /通商産業省;2001年1月の中央省庁再編で経済産業省に再編された/
つうしん /通信/
つうしんあいて /通信相手/
つうしんいん /通信員/
つうしんえいせい /通信衛星/
つうしんか /通信課/
つうしんかいせん /通信回線/
つうしんかいせんりろん /通信回線理論/
つうしんかいはつしつ /通信開発室/
つうしんかいはつぶ /通信開発部/
つうしんかくしゃ /通信各社/
つうしんかのう /通信可能/
つうしんかぶしきがいしゃ /通信株式会社/
つうしんかんきょう /通信環境/
つうしんかんけい /通信関係/
つうしんがいしゃ /通信会社/
つうしんがく /通信学/
つうしんがくぶ /通信学部/
つうしんがたじゅしんき /通信型受信機/
つうしんがっかい /通信学会/
つうしんき /通信機/
つうしんきかく /通信規格/
つうしんきこう /通信機構/
つうしんきのう /通信機能/
つうしんきょういく /通信教育/
つうしんきょういくきょうざい /通信教育教材/
つうしんきょり /通信距離/
つうしんぎじゅつ /通信技術/
つうしんぎじゅつぶ /通信技術部/
つうしんけいいっぱん /通信系一般/
つうしんけいろ /通信経路/
つうしんけんきゅうしょ /通信研究所/
つうしんけんきゅうぶ /通信研究部/
つうしんこうかん /通信交換/
つうしんこうがく /通信工学/
つうしんこうがくこうざ /通信工学講座/
つうしんこうがっか /通信工学科/
つうしんし /通信士/
つうしんしせつ /通信施設/
つうしんしゃ /通信社/
つうしんしゅだん /通信手段/
つうしんしょうがい /通信障害/
つうしんしょり /通信処理/
つうしんしんごう /通信信号/
つうしんじ /通信時/
つうしんじかん /通信時間/
つうしんじぎょうしゃ /通信事業者/
つうしんじじょう /通信事情/
つうしんじっぴ /通信実費/
つうしんじょう /通信上/
つうしんじょうけん /通信条件/
つうしんじょうほう /通信情報/
つうしんせいぎょけん /通信制御研/
つうしんせいのう /通信性能/
つうしんせつび /通信設備/
つうしんせん /通信線/
つうしんせんよう /通信専用/
つうしんそうけん /通信総研/
つうしんそうごうけん /通信総合研/
つうしんそうち /通信装置/
つうしんそうちけんきゅう /通信装置研究/
つうしんそくど /通信速度/
つうしんたいしょう /通信対象/
つうしんたんまつ /通信端末/
つうしんだい /通信代/
つうしんちゅう /通信中/
つうしんてじゅん /通信手順/
つうしんとぜつ /通信途絶/
つうしんないよう /通信内容/
つうしんのうりょく /通信能力/
つうしんはくしょ /通信白書/
つうしんはんばい /通信販売/
つうしんはんばいいがい /通信販売以外/
つうしんはんばいがいしゃ /通信販売会社/
つうしんはんばいてん /通信販売店/
つうしんばいたい /通信媒体/
つうしんひ /通信費/
つうしんひよう /通信費用/
つうしんぶん /通信文/
つうしんぶんや /通信分野/
つうしんへい /通信兵/
つうしんほう /通信法/
つうしんほうしき /通信方式/
つうしんほうほう /通信方法/
つうしんぼ /通信簿/
つうしんもう /通信網/
つうしんもうけんきゅうしょ /通信網研究所/
つうしんもくてき /通信目的/
つうしんよう /通信用/
つうしんようでんしぶつり /通信用電子物理/
つうしんようりょう /通信容量/
つうしんらん /通信欄/
つうしんりょう /通信量/通信料/
つうしんりょうきん /通信料金/
つうしんりろん /通信理論/
つうしんろ /通信路/
つうしんろん /通信論/
つうじ /通時/
つうじかい /通字解/
つうじてき /通時的/
つうじょう /通常/
つうじょううんちん /通常運賃/
つうじょううんてん /通常運転/
つうじょうえいぎょう /通常営業/
つうじょうおんいき /通常音域/
つうじょうかかく /通常価格/
つうじょうかやく /通常火薬/
つうじょうがた /通常型/
つうじょうがめん /通常画面/
つうじょうぎょうむ /通常業務/
つうじょうくうかん /通常空間/
つうじょうげんご /通常言語/
つうじょうこうかいてんいき /通常高回転域/
つうじょうこうげき /通常攻撃/
つうじょうこん /通常婚/
つうじょうさいせい /通常再生/
つうじょうさつえい /通常撮影/
つうじょうしよう /通常使用/
つうじょうじん /通常人/
つうじょうそうこう /通常走行/
つうじょうだん /通常弾/
つうじょうだんとう /通常弾頭/
つうじょうばん /通常版/通常盤/
つうじょうひょうじ /通常表示/
つうじょうぶん /通常文/
つうじょうへいき /通常兵器/
つうじょうほうしき /通常方式/
つうじょうほこう /通常歩行/
つうじょうりゅうにゅう /通常流入/
つうすい /通水/
つうすいようそ /通水要素/
つうせつ /通説/痛切/
つうせつどおり /通説通り/
つうそうけん /通総研/
つうそうていおん /通奏低音/
つうそく /通則/
つうぞく /通俗/
つうぞくかいせつしょ /通俗解説書/
つうぞくてき /通俗的/
つうぞくてきりかい /通俗的理解/
つうぞくどうとく /通俗道徳/
つうたつ /通達/
つうだ /痛打/
つうち /通知/
つうちしょ /通知書/
つうちじょう /通知状/
つうちょう /通帳/通牒/
つうちょうていき /通帳定期/
つうてん /痛点/
つうてんかく /通天閣/
つうでん /通電/
つうどう /通導/
つうどうこうぞう /通導構造/
つうどうそしき /通導組織/
つうどく /通読/
つうねん /通年/通念/
つうはん /通販/
つうはんぎょうしゃ /通販業者/
つうはんてん /通販店/通版店/
つうはんや /通販屋/
つうばん /通番/
つうぱい /字牌/
つうひ /通費/通臂/
つうふう /通風/痛風/
つうふうき /通風機/
つうふうこう /通風口/
つうぶん /通分/
つうほう /通報/
つうほうぎむ /通報義務/
つうほうしゃ /通報者/
つうめ /通目/
つうや /通夜/
つうやく /通訳/
つうやくかん /通訳官/
つうやくし /通訳氏/
つうやくしゃ /通訳者/
つうよう /通用/痛痒/
つうようきかん /通用期間/
つうようぐち /通用口/
つうようじたい /通用字体/
つうようど /通用度/
つうようもん /通用門/
つうらい /通来/
つうらん /通覧/
つうれい /通例/
つうれつ /痛烈/
つうろ /通路/
つうろがわ /通路側/
つうろはば /通路幅/
つうろふうさ /通路封鎖/
つうろん /通論/
つうわ /通話/
つうわじかん /通話時間/
つうわじょうたい /通話状態/
つうわせい /通話制/
つうわだい /通話代/
つうわないよう /通話内容/
つうわひょう /通話表/
つうわぼうじゅ /通話傍受/
つうわりょう /通話料/
つうわりょうきん /通話料金/
つえ /杖/拐/
つか /塚/束/柄/冢/
つかい /使い/
つかいかた /使い方/
つかいかって /使い勝手/
つかいがって /使い勝手/
つかいごこち /使い心地/
つかいすて /使い棄て/使い捨て/
つかいはしり /使い走り/
つかいま /使い魔/
つかいみち /使い道/使い途/
つかいもの /使いもの/使い物/
つかくち /塚口/
つかぐち /塚口/
つかこし /塚越/
つかごし /塚越/
つかさ /司/元/曹/
つかしま /塚島/
つかしん /ツカシン/
つかたに /塚谷/
つかだ /塚田/束田/
つかの /塚野/
つかのま /束の間/
つかのめ /塚目/
つかはら /束原/塚原/
つかみ /掴み/
つかみなげ /掴み投げ/
つかむ /搏/攫/
つかもと /塚本/
つかもとしょうじ /塚本商事/
つかれ /疲れ/
つかわれかた /使われ方/
つが /栂/都賀/
つがい /津飼/
つがいけ /栂池/
つがいけこうげん /栂池高原/
つがいけしゅうへん /栂池周辺/
つがる /津軽/
つがるかいきょう /津軽海峡/
つがるかいきょうせん /津軽海峡線/
つがるじゃみせん /津軽三味線/
つがるせん /津軽線/
つがるはんとう /津軽半島/
つがるべん /津軽弁/
つがるわん /津軽湾/
つがわ /津川/対川/
つき /月/付/槻/築/付き/欟/突き/憑き/
つきあい /付合/付き合い/
つきあう /付き合う/
つきあげ /突き上げ/
つきあげぐん /築上郡/
つきあたま /月頭/
つきいち /月一/
つきおか /月岡/
つきおとし /突き落とし/
つきおろしね /月卸値/
つきかいひ /月会費/
つきかげ /月影/
つきがけ /月掛け/
つきがせ /月ヶ瀬/
つきがた /月形/
つききち /月基地/
つきぎめ /月極め/
つきぎり /月限/
つきこ /月子/
つきこうはん /月後半/
つきごと /月毎/
つきさっぷ /月寒/
つきさむ /月寒/
つきしま /月島/
つきしょじゅん /月初旬/
つきじ /築地/
つきじぐち /築地口/
つきすう /月数/
つきすうかいくらい /月数回位/
つきずえ /月末/
つきせかい /月世界/
つきせかいりょこう /月世界旅行/
つきそい /付添/付添い/付き添い/
つきそいかんごひ /付添看護費/
つきたおし /突き倒し/
つきたて /月舘/
つきだし /突き出し/
つきだて /月舘/築館/
つきだてちょう /築館町/
つきづき /月々/
つきていど /月程度/
つきなみ /月並/槻並/月次/
つきなんにち /月何日/
つきの /月野/
つきのき /槻木/
つきのはら /月野原/
つきばらい /月払い/
つきひ /月日/
つきひめ /月姫/
つきびと /付き人/
つきへいきん /月平均/
つきべつ /月別/
つきぼし /月星/
つきみ /月見/
つきみそう /月見草/
つきみばし /月見橋/
つきもの /つき物/付き物/付物/憑き物/
つきやく /月役/
つきやま /築山/
つきよ /月夜/
つきよだ /月夜田/
つきよの /月夜野/
つきわり /月割/
つぎ /次/
つぎお /次男/次夫/次雄/
つぎき /継ぎ木/継木/接木/
つぎきれ /継切/
つぎつぎ /次々/
つぎて /継ぎ手/
つぎのすけ /継之助/
つぎめ /継目/
つく /筑/津久/
つくい /津久井/
つくいかん /津久井間/
つくいこ /津久井湖/
つくいはま /津久井浜/
つくえ /机/
つくえがた /机型/
つくし /筑紫/土筆/
つくしのうたかい /筑紫歌会/
つくだ /佃/附田/
つくだいびょういん /筑大病院/
つくだじま /佃島/
つくだに /佃煮/
つくだにふう /佃煮風/
つくづく /熟/
つくで /作手/
つくと /津久戸/
つくば /筑波/
つくばいいんかい /筑波委員会/
つくばえき /筑波駅/
つくばかがくはく /筑波科学博/
つくばぎじゅつたんだい /筑波技術短大/
つくばけん /筑波研/
つくばけんきゅう /筑波研究/
つくばけんきゅうしょ /筑波研究所/
つくばこうじょう /筑波工場/
つくばこうそく /筑波高速/
つくばさん /筑波山/
つくばし /筑波市/つくば市/
つくばしぶ /筑波支部/
つくばじっけんしつ /筑波実験室/
つくばじょうほう /筑波情報/
つくばだい /筑波大/
つくばだいかがく /筑波大化学/
つくばだいかがくけい /筑波大化学系/
つくばだいがく /筑波大学/
つくばだいがくいん /筑波大学院/
つくばだいがくじょうほう /筑波大学情報/
つくばだいがくせいぶつ /筑波大学生物/
つくばだいがくだい /筑波大学第/
つくばだいがくちゅうおう /筑波大学中央/
つくばだいがくでんし /筑波大学電子/
つくばだいこうがく /筑波大工学/
つくばだいしゃこう /筑波大社工/
つくばだいじょうほう /筑波大情報/
つくばだいすうちけん /筑波大数値研/
つくばだいせいぶつ /筑波大生物/
つくばだいちゅうおう /筑波大中央/
つくばだいでんし /筑波大電子/
つくばだいびょういん /筑波大病院/
つくばだいりこう /筑波大理工/
つくばちく /筑波地区/
つくばね /筑波嶺/
つくばはく /筑波博/
つくばばんぱく /筑波万博/
つくばまるぜん /筑波丸善/
つくみ /津久見/
つくも /九十九/
つくもがみ /付喪神/九十九髪/
つくもでんき /九十九電機/
つくよみ /月讀み/
つくり /作り/傍/旁/
つくりかた /作り方/
つくりこみ /作り込み/
つくりて /作り手/
つくろい /繕/
つぐ /嗣/津具/継/
つぐお /嗣雄/
つぐとし /次利/
つぐとも /嗣智/嗣朋/
つぐのぶ /嗣信/
つぐみ /鶫/
つぐも /津雲/
つけ /付/漬け/漬/
つけかえ /付替/
つけかた /付け方/
つけたし /付け足し/
つけち /付知/
つけづめ /付け爪/
つけね /付け根/
つけもの /漬物/漬け物/
つけものしょくにん /漬物職人/
つけものてん /漬物店/
つけやきば /付け焼刃/
つける /付ける/
つげ /柘/柘植/拓殖/都祁/
つげぐち /告げ口/
つごう /都合/
つごうしゅぎ /都合主義/
つごうじょう /都合上/
つさか /津坂/
つざき /津崎/
つし /津市/都志/
つしま /津島/対馬/津嶋/對馬/
つしまかなめ /津島要/
つしまく /津島区/
つしまなか /津島中/
つしまふくい /津島福居/
つじ /辻/
つじい /辻井/
つじうら /辻占/
つじうらない /辻占い/
つじおか /辻岡/
つじかわ /辻川/
つじがどう /辻ヶ堂/
つじぎみ /辻君/
つじさわ /辻沢/
つじした /辻下/
つじた /辻田/
つじつま /辻褄/
つじどう /辻堂/
つじの /辻野/
つじばしゃ /辻馬車/
つじむら /辻村/
つじもと /辻本/辻元/
つずき /都築/
つた /蔦/樢/
つたき /津滝/
つだ /津田/
つだじゅく /津田塾/
つだじゅくだい /津田塾大/
つだじゅくだいがく /津田塾大学/
つだぬま /津田沼/
つだぬまえき /津田沼駅/
つだぬまえきちょっか /津田沼駅直下/
つだぬまきんぺん /津田沼近辺/
つだぬましはつ /津田沼始発/
つち /土/槌/鎚/壌/椎/
つちい /土井/土居/
つちいろ /土色/
つちうら /土浦/
つちうらし /土浦市/
つちうらにこう /土浦二高/
つちうらにちだい /土浦日大/
つちかべ /土壁/
つちかわ /土川/
つちくれ /土くれ/土塊/
つちぐも /蝪/
つちけいろ /土気色/
つちけむり /土煙/
つちこ /土子/
つちた /土田/
つちだ /土田/槌田/
つちとい /土樋/
つちとりもちもく /ツチトリモチ目/Balanophorales/
つちのえ /戊/
つちのえいぬ /戊戌/
つちのえうま /戊午/
つちのえさる /戊申/
つちのえたつ /戊辰/
つちのえとら /戊寅/
つちのえね /戊子/
つちのと /己/
つちのとい /己亥/
つちのとう /己卯/
つちのとうし /己丑/
つちのととり /己酉/
つちのとひつじ /己未/
つちのとみ /己巳/
つちはし /土橋/
つちへん /埃/圦/
つちぼこり /土埃/
つちもと /土本/
つちや /土屋/土家/土谷/
つちやま /土山/
つちゆ /土湯/
つっけんどん /突慳貪/
つっこみ /突込み/
つつ /筒/砲/
つつい /筒井/
つついやすたか /筒井康隆/
つつが /恙/筒賀/
つつがむし /恙虫/
つつぐち /筒口/
つつしんで /謹んで/
つつじ /榴/躑躅/
つつじがおか /榴岡/榴ヶ岡/つつじヶ丘/
つつじもく /ツツジ目/Ericales/
つつじょう /筒状/
つつなか /筒中/
つつみ /提/筒見/包/堤/恙/愼/
つつみがみ /包み紙/
つつみまち /堤町/
つつみむし /包み蒸し/
つつみやき /包み焼き/
つつもたせ /美人局/
つづ /通津/
つづき /続き/綴喜/都築/
つづみ /皷/鼓/
つづらおり /九十九折り/
つづらふじか /ツヅラフジ科/Menispermaceae/
つづり /綴/
つづりかたきょうしつ /綴方教室/
つづりじ /綴り字/
つて /伝手/
つと /衝と/
つとに /夙に/
つとむ /務/勉/努/勤/力/
つとめ /勤め/
つとめさき /勤め先/
つとめて /努めて/
つど /都度/津戸/
つどい /集/
つどけってい /都度決定/
つな /綱/津名/
つなお /綱男/
つなぎ /繋/津奈木/
つなしま /綱島/綱嶋/
つなみ /津波/
つなみけいほう /津波警報/
つなみじょうほう /津波情報/
つなみちゅういほう /津波注意報/
つなみよほう /津波予報/
つなわたり /綱渡り/綱渡/
つなん /津南/
つね /常/恒/典/恆/経/桓/
つねあき /常明/
つねお /恒男/恒夫/恒雄/常男/常夫/常雄/
つねかわ /恒川/
つねきち /常吉/
つねきよ /経清/
つねこ /恒子/
つねじ /常次/
つねずみ /常澄/
つねたけ /恒毅/典武/
つねづね /常々/
つねとう /恒藤/恒任/
つねとし /恒敏/種敏/
つねとよ /常豊/
つねなが /常長/
つねに /常に/
つねのり /恒憲/
つねはる /常晴/
つねひこ /恒彦/
つねひごろ /常日頃/
つねひら /恒平/
つねひろ /恒宏/恒博/常廣/常広/
つねまさ /恒正/
つねもり /常森/
つねやす /常安/経康/
つねゆき /恒行/常幸/
つねよ /常与/
つねよし /恒吉/恒美/常吉/
つの /角/都濃/津野/都農/
つのお /角尾/
つのおか /角岡/
つのがい /角皆/
つのごろう /角五郎/
つのだ /角田/
つのぶえ /角笛/
つはもの /兵/
つはら /津原/
つば /鍔/唾/鐔/
つばい /椿井/
つばき /椿/
つばきい /椿井/
つばきか /ツバキ科/Theaceae/
つばきさんじゅうろう /椿三十郎/
つばきしゅぞう /椿酒造/
つばきはら /椿原/
つばきひめ /椿姫/
つばきもとちえいん /椿本チエイン/
つばきやま /椿山/
つばさ /翼/翅/
つばた /津幡/
つばめ /燕/
つばめざわ /燕沢/
つひに /終に/遂に/
つぶ /粒/
つぶさき /粒崎/
つぶさに /具に/悉に/備に/
つぶす /潰/
つぶて /礫/
つぶやき /呟き/
つぶら /円/
つぶらや /円谷/
つべつ /津別/
つぼ /壷/坪/壺/
つぼい /坪井/壷井/
つぼうち /坪内/
つぼうちけん /坪内研/
つぼかわ /坪川/
つぼくら /坪倉/
つぼさき /坪崎/
つぼすう /坪数/
つぼた /坪田/
つぼだけ /坪岳/
つぼね /局/
つぼはち /つぼ八/
つぼみ /蕾/莟/
つま /妻/嬬/褄/都万/
つまい /妻井/
つまお /妻夫/
つまご /妻籠/
つまごい /つま恋/嬬恋/妻恋/
つまさき /爪先/つま先/
つまどり /褄取り/
つまびき /爪弾き/
つまびらか /詳らか/審らか/
つまみぐい /つまみ食い/撮み食い/摘み食い/
つみ /罪/辟/詰み/
つみあげ /積み上げ/
つみいしき /罪意識/
つみかえ /積み替え/
つみかさね /積み重ね/
つみき /積木/
つみきん /積み金/
つみこみ /積み込み/
つみたて /積立/積立て/
つみたてきん /積立金/
つみに /積荷/積み荷/
つみほろぼし /罪滅ぼし/
つむ /錘/
つむがり /都牟刈/
つむぎ /紬/紡木/紡/
つむじかぜ /旋風/
つむら /津村/
つめ /爪/詰/詰め/爭/爬/爰/爲/
つめあわせ /詰合せ/
つめえり /詰襟/
つめかえ /詰め替え/
つめご /詰碁/
つめさき /爪先/
つめしょ /詰所/
つめしょうぎ /詰将棋/詰め将棋/
つめしょうぎかい /詰将棋界/
つめすじ /詰筋/
つめもの /詰め物/
つも /模/
つもあがり /自模和了/
つもほう /自模和/
つもり /津守/
つや /通夜/艶/艷/
つやけし /艶消/
つやざき /津屋崎/
つやだし /艶出/
つやま /津山/
つやません /津山線/
つゆ /梅雨/露/
つゆあけ /梅雨明/
つゆいこう /梅雨以降/
つゆいり /梅雨入/
つゆき /露木/
つゆくさもく /ツユクサ目/Commelinales/
つゆこ /露子/
つゆごろ /梅雨頃/
つゆぞら /梅雨空/
つゆどき /梅雨時/
つゆはし /露橋/
つゆはらい /露払い/
つよき /強気/
つよさ /強さ/
つよし /毅/剛/強/剛士/毅師/津義/幹/
つよび /強火/
つよみ /強味/
つら /面/
つらがまえ /面構え/
つらなり /連なり/
つらゆき /貫之/
つらら /氷柱/
つり /釣/吊/
つりー /ツリー/
つりあい /釣合/釣り合い/
つりいと /釣糸/
つりおとし /吊り落とし/
つりかた /釣り方/
つりかわ /吊り皮/吊革/釣り革/
つりかんけいしゃ /釣関係者/
つりがき /釣書/
つりがけでんしゃ /釣掛電車/
つりがね /釣り鐘/釣鐘/
つりがねがた /釣鐘形/
つりぐ /釣り具/釣具/
つりぐかんけい /釣具関係/
つりぐてん /釣具店/
つりぐや /釣具屋/
つりこうこく /吊り広告/
つりざお /釣竿/
つりしょ /釣書/
つりせん /釣銭/
つりたに /釣谷/
つりだし /吊り出し/
つりば /釣り場/
つりばし /吊橋/
つりびと /釣り人/釣人/
つりぶね /釣船/
つりほう /釣法/
つりぼり /釣堀/
つる /鶴/弦/都留/蔓/寉/敦/
つるい /鶴居/
つるいち /鶴一/
つるえ /鶴枝/鶴江/
つるおか /鶴岡/
つるおかし /鶴岡市/
つるかめ /鶴亀/
つるかめざん /鶴亀算/
つるかわ /鶴川/
つるかわこうこう /鶴川高校/
つるが /敦賀/鶴賀/鶴我/
つるがおか /鶴岡/
つるがおかはちまんぐう /鶴岡八幡宮/
つるがかん /敦賀間/
つるがこう /敦賀港/
つるがしま /鶴ヶ島/
つるがみね /鶴ヶ峰/
つるがや /鶴ヶ谷/
つるきえき /鶴来駅/
つるぎ /剣/鶴来/劍/劔/劒/剱/釼/
つるぎざき /剣崎/
つるこう /鶴光/
つるさき /鶴崎/
つるしま /鶴島/
つるじろう /鶴次郎/
つるぞう /鶴蔵/
つるた /鶴田/
つるたろう /鶴太郎/
つるだ /鶴田/
つるはぎ /鶴脛/
つるはし /鶴橋/鶴嘴/
つるふじ /鶴藤/
つるべ /釣瓶/鶴瓶;人名。笑福亭鶴瓶/
つるま /鶴間/
つるまい /鶴舞/
つるまいえき /鶴舞駅/
つるまいこうえん /鶴舞公園/
つるまいせん /鶴舞線/
つるまき /鶴巻/
つるまきおんせん /鶴巻温泉/
つるみ /鶴見/
つるみく /鶴見区/
つるみず /鶴水/
つるみせん /鶴見線/
つるや /鶴谷/鶴屋/
つるやま /鶴山/
つれ /連れ/
つれづれ /徒然/
つれづれぐさ /徒然草/
つわの /津和野/
つわもの /強者/兵/
つんどく /積讀/積ん読/
つんぼ /聾/
づ /図/津/
づか /塚/冢/
づかい /使い/
づくえ /机/
づくし /尽くし/
づくり /作り/
づけ /付/付け/
づつう /頭痛/
づのう /頭腦/
づま /妻/
づみ /詰み/
づめ /詰/詰め/
づれ /連れ/
て /手/弖/〒/
てーぶる /テーブル/
てーぷ /テープ/
てーま /テーマ/
てあい /手合/
てあか /手垢/
てあし /手足/
てあしくちびょう /手足口病/
てあたりしだい /手当たり次第/
てあて /手当/手当て/
てあぶり /手焙り/
てあみ /手編/手編み/
てあら /手荒/
てあらい /手洗い/手洗/
てぃー /ティー/
てぃあ /ティア/
てぃしゅ /ティシュ/
てぃしゅー /ティシュー/
てぃじろ /Ｔ字路/
てぃっしゅ /ティッシュ/
てい /低/定/邸/程/艇/締/訂/提/諦/鼎/釘/逓/蹄/鄭/抵/弟/底/停/袋/帝/庭/廷/堤/呈/挺/禎/梯/碇/汀/貞/悌/亭/剃/偵/丁/掟/体/第/薙/酊/叮/啼/嚔/嚏/幀/柢/棣/楴/涕/渟/牴/眤/睇/碵/羝/觝/詆/躰/軆/逞/遉/遞/酲/騁/體/綴/鵜/滞/
てい> /低/
ていあつ /低圧/
ていあつちょくりゅう /低圧直流/
ていあつよう /低圧用/
ていあん /提案/
ていあんいけん /提案意見/
ていあんがわ /提案側/
ていあんきじ /提案記事/
ていあんご /提案後/
ていあんしゃ /提案者/
ていあんしょ /提案書/
ていあんないよう /提案内容/
ていあんふび /提案不備/
ていあんほうほう /提案方法/
ていあんりゆうせつめい /提案理由説明/
ていい /定位/低位/
ていいかん /定位感/
ていいき /低域/
ていいきこう /定位機構/
ていいきつうか /低域通過/
ていいきとうか /低域透過/
ていいきのう /定位機能/
ていいきぶ /低域部/
ていいち /貞一/禎一/定位置/
ていいど /低緯度/
ていいのうりょく /定位能力/
ていいん /定員/
ていいんいっぱい /定員一杯/
ていいんがい /定員外/
ていいんさんしゅつほう /定員算出法/
ていいんじょうしゃ /定員乗車/
ていいんせいかいそく /定員制快速/
ていいんわれ /定員割/
ていうん /低運/
ていうんてんだいしゃ /低運転台車/
ていえん /庭園/定演/
ていえんびじゅつかん /庭園美術館/
ていおう /帝王/
ていおうしょう /帝王賞/
ていおん /低温/低音/定温/
ていおんいき /低音域/
ていおんか /低温下/
ていおんかん /低音感/
ていおんがわ /低温側/低音側/
ていおんけん /低温研/
ていおんこうがくかい /低温工学会/
ていおんじ /低温時/
ていおんぶ /低音部/
ていおんよう /低温用/
ていか /低下/定価/定價/
ていかい /低徊/
ていかいか /定価以下/
ていかいじょう /定価以上/
ていかいぞうど /低解像度/
ていかいてん /低回転/
ていかいてんいき /低回転域/
ていかいてんがた /低回転型/
ていかかく /低価格/
ていかかくか /低価格化/
ていかかくきょうそう /低価格競争/
ていかかくしゃ /低価格車/
ていかかくせいひん /低価格製品/
ていかかくひん /低価格品/
ていかかくろせん /低価格路線/
ていかく /定格/
ていかくかいてんすう /定格回転数/
ていかくしゅつりょく /定格出力/
ていかくそくど /定格速度/
ていかくでんあつ /定格電圧/
ていかくでんりゅう /定格電流/
ていかくりつ /低確率/
ていかごうけい /定価合計/
ていかそくしゃりょう /低加速車両/
ていかはんばい /定価販売/
ていかひょう /定価表/
ていかみまん /定価未満/
ていかん /定款/定感/帝冠/
ていかんかく /定間隔/
ていかんし /定冠詞/
ていかんど /低感度/
ていが /定芽/
ていがく /停学/定額/低額/
ていがくこがわせ /定額小為替/
ていがくねん /低学年/
ていがくほう /定額法/
ていき /定期/提起/定気/
ていきあつ /低気圧/
ていきいれ /定期入/
ていきえんそうかい /定期演奏会/
ていきかいいん /定期会員/
ていきかいいんけん /定期会員券/
ていきかいさい /定期開催/
ていきかんこう /定期観光/
ていきかんこうぶつ /定期刊行物/
ていききゃく /定期客/
ていきけん /定期券/
ていきけんうりば /定期券売場/
ていきけんくかん /定期券区間/
ていきけんしん /定期検診/
ていきこうどく /定期購読/定期講読/
ていきざっし /定期雑誌/
ていきしけん /定期試験/
ていきしょうきゅう /定期昇給/
ていきじょうしゃけん /定期乗車券/
ていきせん /定期戦/
ていきだい /定期代/
ていきつえんしゃ /定喫煙者/
ていきてき /定期的/
ていきてんけん /定期点検/
ていきてんけんぼ /定期点検簿/
ていきとうこう /定期投稿/
ていきとっきゅう /定期特急/
ていきど /低輝度/
ていきどう /低軌道/
ていきのう /低機能/
ていきびん /定期便/
ていきほうえい /定期放映/
ていきほうこく /定期報告/
ていきほしゅ /定期保守/
ていきほしゅび /定期保守日/
ていきゅう /低級/庭球/定休/
ていきゅうび /定休日/
ていきょう /提供/帝京/貞享/提共/
ていきょうかのう /提供可能/
ていきょうきょく /提供曲/
ていきょうぎじゅつかがくだいがく /帝京技術科学大学/
ていきょうこうこう /帝京高校/
ていきょうしゃ /提供者/
ていきょうしゃがわ /提供者側/
ていきょうだい /帝京大/
ていきょうだいがく /帝京大学/
ていきょうちゅう /提供中/
ていきょうはちおうじ /帝京八王子/
ていきょうばんぐみ /提供番組/
ていきょうほうほう /提供方法/
ていきょうもと /提供元/
ていきょじゅう /挺拳銃/
ていきよきん /定期預金/
ていきりよう /定期利用/
ていきれっしゃ /定期列車/
ていきんり /低金利/
ていきんりじだい /低金利時代/
ていぎ /定義/提議/
ていぎいき /定義域/
ていぎいきぜんたい /定義域全体/
ていぎかのう /定義可能/
ていぎくうかん /定義空間/
ていぎぐん /定義群/
ていぎしき /定義式/
ていぎじたい /定義自体/
ていぎじょう /定義上/
ていぎせつ /定義節/
ていぎたい /定義体/
ていぎちゅう /定義中/
ていぎちょう /定義長/
ていぎづけ /定義付け/
ていぎないよう /定義内容/
ていぎぶ /定義部/
ていぎぶぶん /定義部分/
ていぎぶん /定義文/
ていぎほう /定義法/
ていぎほうほう /定義方法/
ていぎもじ /定義文字/
ていぎもんだい /定義問題/
ていぎん /帝銀/
ていくう /低空/
ていけい /提携/定型/定形/梯形/
ていけいかいしょう /提携解消/
ていけいがい /定型外/
ていけいさき /提携先/
ていけいしょり /定型処理/
ていけいてき /定型的/
ていけいふうとう /定型封筒/
ていけいぶん /定型文/
ていけつ /締結/挺傑/
ていけつあつ /低血圧/
ていけん /定検/定見/
ていげん /提言/低減/低限/低弦/
ていげんか /低減化/
ていげんめいほう /定言命法/
ていこ /貞子/挺庫/艇庫/
ていこう /抵抗/定項/低高/
ていこうかねつ /抵抗加熱/
ていこうかん /抵抗感/
ていこうがい /低公害/
ていこうがいしゃ /低公害車/
ていこうき /抵抗器/
ていこうせい /抵抗性/
ていこうせいぎょ /抵抗制御/
ていこうせいぎょしゃ /抵抗制御車/
ていこうせいぶん /抵抗成分/
ていこうち /抵抗値/
ていこうていてい /低高低低/
ていこうふか /抵抗負荷/
ていこうりつ /抵抗率/
ていこうりょく /抵抗力/
ていこうるい /抵抗類/
ていこく /帝国/定刻/帝國/
ていこくかいぐん /帝國海軍/
ていこくぎかい /帝国議会/
ていこくぎんこう /帝國銀行/
ていこくぐん /帝国軍/
ていこくげきじょう /帝国劇場/
ていこくさんぎょう /帝国産業/
ていこくしゅぎ /帝国主義/
ていこくしゅぎしゃ /帝国主義者/
ていこくしゅぎだんかい /帝国主義段階/
ていこくしゅと /帝国首都/
ていこくせきゆ /帝国石油/
ていこくせんい /帝国繊維/
ていこくばん /帝国版/
ていこくほてる /帝国ホテル/
ていこくりくぐん /帝國陸軍/
ていこすと /低コスト/
ていさい /体裁/
ていさく /定朔/
ていさつ /偵察/
ていさついん /偵察員/
ていさつえいせい /偵察衛星/
ていさつき /偵察機/
ていさつよういん /偵察要員/
ていさん /帝産/
ていさんだい /帝産台/
ていざいは /定在波/
ていざいはひ /定在波比/
ていざいはほう /定在波法/
ていざん /低山/定残/
ていざんぎょう /定残業/
ていざんけい /定山溪/
ていし /停止/定詞/手石/
ていしいち /停止位置/
ていしえき /停止液/
ていしき /定式/程式/
ていしきか /定式化/
ていしきかん /停止期間/
ていしきょり /停止距離/
ていしげき /低刺激/
ていしげきせい /低刺激性/
ていしげんしょう /停止現象/
ていししょぶん /停止処分/
ていししんごう /停止信号/
ていしじ /停止時/
ていしじかん /停止時間/
ていしじょうけん /停止条件/
ていしじょうたい /停止状態/
ていしすんぜん /停止寸前/
ていしせい /停止性/低姿勢/
ていしせいはんてい /停止性判定/
ていしせん /停止線/
ていしちゅう /停止中/
ていしちょくぜん /停止直前/
ていしつ /低湿/低質/廷叱/
ていしつごしょうてん /帝室御賞典/
ていしつど /低湿度/
ていしのうりょく /停止能力/
ていしほうほう /停止方法/
ていしもんだい /停止問題/
ていしゃ /停車/
ていしゃいち /停車位置/
ていしゃえき /停車駅/
ていしゃえきあんない /停車駅案内/
ていしゃえきさくげん /停車駅削減/
ていしゃえきぜんぶ /停車駅全部/
ていしゃえきひょうじ /停車駅表示/
ていしゃかいすう /停車回数/
ていしゃかのう /停車可能/
ていしゃかんかく /停車間隔/
ていしゃきょり /停車距離/
ていしゃご /停車後/
ていしゃしゃりょう /停車車両/
ていしゃじ /停車時/
ていしゃじかん /停車時間/
ていしゃじふん /停車時分/
ていしゃじょうたい /停車状態/
ていしゃちえん /停車遅延/
ていしゃちゅう /停車中/
ていしゃちょくぜん /停車直前/
ていしゃでんしゃ /停車電車/
ていしゃまえ /停車前/
ていしゃれっしゃ /停車列車/
ていしゅ /亭主/
ていしゅう /挺秀/
ていしゅうにゅう /定収入/
ていしゅうは /低周波/
ていしゅうはしゅつりょく /低周波出力/
ていしゅうはしんどう /低周波振動/
ていしゅうはすう /低周波数/低周波数域/
ていしゅうはすういき /低周波数域/
ていしゅうはでんか /低周波電化/
ていしゅうはぶぶん /低周波部分/
ていしゅく /貞淑/
ていしゅつ /提出/挺出/
ていしゅつきげん /提出期限/
ていしゅつさき /提出先/
ていしゅつしめきり /提出締切/
ていしゅつしゃ /提出者/
ていしゅつしょるい /提出書類/
ていしゅつじょ /提出所/
ていしゅつび /提出日/
ていしゅつぶつ /提出物/
ていしゅつぶんしょ /提出文書/
ていしゅつよう /提出用/低出葉/
ていしゅつようし /提出用紙/
ていしゅつりつ /提出率/
ていしゅつりょくこうひんしつ /低出力高品質/
ていしょ /低所/
ていしょう /提唱/
ていしょうしゃ /提唱者/
ていしょうちゅう /提唱中/
ていしょうど /低照度/
ていしょうひ /低消費/
ていしょうひでんりょく /低消費電力/
ていしょく /抵触/定食/定職/停職/牴触/
ていしょくや /定食屋/
ていしょとく /低所得/
ていしょとくしゃ /低所得者/
ていしょとくそう /低所得層/
ていしよてい /停止予定/
ていしろう /偵四郎/
ていしん /定進/挺身/逓信/挺進/遞信/
ていしんしゅうてき /低侵襲的/
ていしんらい /低信頼/
ていじ /提示/定時/呈示/低次/貞次/貞治/貞二/悌二/禎治/禎二/丁字/
ていじうんこう /定時運行/
ていじおん /提示音/
ていじかいすう /提示回数/
ていじかかく /提示価格/
ていじげん /低次元/
ていじげんぶんかい /低次元分解/
ていじご /定時後/
ていじごと /定時毎/
ていじじかん /提示時間/
ていじじこく /提示時刻/呈示時刻/
ていじじゅんじょ /提示順序/
ていじじょうけん /提示条件/
ていじすう /提示数/
ていじせい /定時制/
ていじそうかい /定時総会/
ていじそうち /呈示装置/
ていじにゅうこうしゃ /定時入校者/
ていじぶ /提示部/
ていじほう /提示法/
ていじゅう /定住/
ていじゅうしん /低重心/
ていじゅうしんか /低重心化/
ていじゅんど /低純度/
ていじょ /貞女/
ていじょう /定常/呈上/堤上/
ていじょううちゅうろん /定常宇宙論/
ていじょうおん /定常音/
ていじょうかくりつ /定常確率/
ていじょうかんきょうか /定常環境下/
ていじょうぎょうむ /定常業務/
ていじょうこう /定常光/
ていじょうさいさうんどう /定常才差運動/
ていじょうじけいれつ /定常時系列/
ていじょうじょうたい /定常状態/
ていじょうせい /定常性/
ていじょうたい /定常態/
ていじょうてき /定常的/
ていじょうは /定常波/
ていじょうぶ /定常部/
ていじょうぶんぷ /定常分布/
ていじん /帝人/
ていすいじゅん /低水準/
ていすう /定数/艇数/
ていすうかいせいあん /定数改正案/
ていすうかくさ /定数格差/
ていすうかくさぜせい /定数格差是正/
ていすうかしゅほう /定式化手法/
ていすうきごう /定数記号/
ていすうけいさん /定数計算/
ていすうけいすう /定数係数/
ていすうこう /定数項/
ていすうしき /定数式/
ていすうぜせい /定数是正/
ていすうち /定数値/
ていすうばい /定数倍/
ていすうぶん /定数文/
ていせい /訂正/定性/貞静/帝政/低声/帝制/
ていせいいん /訂正印/
ていせいかしょ /訂正箇所/
ていせいかのう /訂正可能/
ていせいがくえん /貞静学園/
ていせいきじ /訂正記事/
ていせいきのう /訂正機能/
ていせいご /訂正後/
ていせいしてき /訂正指摘/
ていせいすいろん /定性推論/
ていせいちょう /低成長/
ていせいてき /定性的/
ていせいてん /訂正点/
ていせいとうこう /訂正投稿/
ていせいのう /低性能/
ていせいのうりょく /訂正能力/
ていせいばん /訂正版/
ていせいふごう /訂正符号/訂正符合/
ていせいほうほう /訂正方法/
ていせいよう /訂正用/
ていせいりつ /訂正率/
ていせき /定石/艇積/
ていせきぶん /定積分/
ていせつ /定説/貞節/挺節/
ていせん /停戦/停船/
ていせんきょうぎ /停戦協議/
ていせんきょうていいはん /停戦協定違反/
ていせんこうさく /停戦工作/
ていせんりょう /低線量/
ていぜん /挺然/
ていそ /提訴/
ていそう /貞操/低層/底層/
ていそうたい /貞操帯/
ていそうりゅう /底層流/
ていそく /低速/
ていそくいき /低速域/
ていそくか /低速化/
ていそくかいせん /低速回線/
ていそくかいせんじょう /低速回線上/
ていそくかいてん /低速回転/定速回転/
ていそくがわ /低速側/
ていそくしゃ /低速車/
ていそくじ /定速時/低速時/
ていそくすう /定足数/
ていそくそうこう /定速走行/
ていそくたんまつ /低速端末/
ていそくつうしんじ /低速通信時/
ていそくど /定速度/低速度/
ていそしき /定礎式/
ていそすんぜん /提訴寸前/
ていそんしつ /低損失/
ていそんしつせんろ /低損失線路/
ていぞう /貞蔵/
ていぞく /低俗/
ていぞくせい /低俗性/
ていたい /停滞/堤体/定退/
ていたいいき /低帯域/
ていたいぐみ /停滞組/
ていたいび /停滞日/定退日/
ていたく /邸宅/
ていたらく /為体/
ていだい /帝大/提題/
ていだいけい /帝大系/
ていだん /鼎談/
ていち /低地/定置/定値/
ていちあみ /定置網/
ていちしき /定置式/
ていちそうこうねんぴ /定地走行燃費/
ていちゃく /定着/
ていちゃくえき /定着液/
ていちゃくか /定着化/
ていちゃくしょりじかん /定着処理時間/
ていちゃくじかん /定着時間/
ていちゃくせい /定着性/
ていちゃくふりょう /定着不良/
ていちゃくりつ /定着率/
ていちゅうそく /低中速/
ていちょう /低調/丁重/低潮/鄭重/
ていちょく /挺直/
ていちんぎん /低賃金/
ていっぱい /手一杯/
ていてつ /蹄鉄/
ていてん /定点/
ていてんしき /定点式/
ていでん /停電/遞傳/
ていでんあつ /低電圧/定電圧/
ていでんあつか /低電圧化/
ていでんあつげん /定電圧源/
ていでんあつてんとう /低電圧点灯/
ていでんあつひん /低電圧品/
ていでんじこ /停電事故/
ていでんりゅう /定電流/
ていでんりゅうげん /定電流源/
ていでんりゅうじゅうでん /定電流充電/
ていでんりょくふか /定電力負荷/
ていと /帝都/
ていとう /抵当/提灯/低頭/
ていとうかかく /抵当価格/
ていとうけん /抵当権/
ていとく /提督/
ていとくてん /低得点/
ていとでんてつ /帝都電鉄/
ていとものがたり /帝都物語/
ていど /程度/
ていどくせい /低毒性/
ていどひつよう /程度必要/
ていどもんだい /程度問題/
ていどよそく /程度予測/
ていどりかい /程度理解/
ていね /手稲/
ていねい /丁寧/
ていねいご /丁寧語/
ていねこうざん /手稲砿山/
ていねん /停年/定年/
ていねんご /停年後/
ていねんごろ /定年頃/
ていねんせい /定年制/
ていねんたいかん /定年退官/
ていねんたいしょく /停年退職/定年退職/
ていねんぴ /低燃費/
ていねんれい /低年齢/
ていねんれいか /低年齢化/
ていねんれいそう /低年齢層/
ていのう /低能/
ていのうしゅく /低濃縮/
ていはく /停泊/碇泊/
ていはくち /停泊地/
ていはつ /剃髪/
ていばいき /逓倍器/
ていばいりつ /低倍率/
ていばつ /挺抜/
ていばん /定番/定版/
ていひょう /定評/
ていひんしつ /低品質/
ていふか /低負荷/
ていぶ /底部/
ていぶんかいのう /低分解能/
ていぶんさん /低分散/
ていへん /底辺/
ていほん /定本/底本/
ていぼう /堤防/
ていぼく /低木/
ていまい /弟妹/
ていみつど /低密度/
ていめい /低迷/
ていめいぎみ /低迷気味/
ていめいじだい /低迷時代/
ていめん /底面/
ていもう /剃毛/
ていや /悌也/
ていやく /締約/
ていやねしゃ /低屋根車/
ていゆうせん /艇優先/
ていよう /提要/定容/
ていよく /低翼/
ていよくき /低翼機/
ていよさん /低予算/
ていらく /低落/
ていり /定理/低利/
ていりき /禎力/
ていりしょうめい /定理証明/
ていりしょうめいき /定理証明機/定理証明器/
ていりしょうめいけい /定理証明系/
ていりじたい /定理自体/
ていりつ /定立/低率/定率/鼎立/挺立/
ていりつほう /定率法/
ていりゅう /停留/底流/
ていりゅうしょ /停留所/
ていりゅうじかん /停留時間/
ていりゅうじょ /停留所/
ていりゅうじょいがい /停留所以外/
ていりゅうじょう /停留場/
ていりゅうじょかん /停留所間/
ていりゅうじょめい /停留所名/
ていりょう /定量/
ていりょうか /定量化/
ていりょうきん /低料金/
ていりょうせい /定量性/
ていりょうせん /定量戦/
ていりょうてき /定量的/
ていりょうてきけいさん /定量的計算/
ていりょうてきしひょう /定量的指標/
ていりょうてきひょうかち /定量的評価値/
ていれ /手入れ/
ていれい /定例/
ていれいかい /定例会/
ていれいきょうじゅかい /定例教授会/
ていれべる /低レベル/
てうす /手薄/
てうち /手打/
ておくれ /手遅れ/
ておち /手落ち/
ておの /手斧/
ており /手織/
てかげん /手加減/
てかず /手数/
てかせ /手枷/
てが /手賀/
てがかり /手がかり/手掛り/
てがき /手書/手書き/
てがきすうじ /手書き数字/
てがきすうじにんしき /手書き数字認識/
てがきすうじにんしきもんだい /手書き数字認識問題/
てがきもじ /手書き文字/
てがきもじにんしき /手書き文字認識/
てがた /手形/
てがたな /手刀/
てがぬま /手賀沼/
てがみ /手紙/
てがら /手柄/
てがる /手軽/
てがわ /手側/
てき /的/適/敵/鏑/滴/笛/擢/摘/俶/剔/廸/彳/擲/狄/糴/覿/躑/迪/逖/嫡/荻/
てきあいて /敵相手/
てきい /敵意/
てきえい /敵影/
てきおう /適応/
てきおうか /適応化/
てきおうかのう /適応可能/
てきおうがくしゅう /適応学習/
てきおうがた /適応型/
てきおうきょうめい /適応共鳴/
てきおうきょうめいりろん /適応共鳴理論/
てきおうけい /適応系/
てきおうしんごうしょり /適応信号処理/
てきおうせい /適応性/
てきおうせいぎょ /適応制御/
てきおうせんりゃく /適応戦略/
てきおうてき /適応的/
てきおうど /適応度/
てきおうはんい /適応範囲/
てきおうふくぶんかつ /適応副分割/
てきおうぶんかつ /適応分割/
てきおうほう /適応法/
てきおうりょうしか /適応量子化/
てきおうりょく /適応力/
てきおん /適温/
てきか /適価/滴下/
てきかく /的確/適格/適確/
てきかくしゃ /適格者/
てきかくせい /適格性/
てきかた /敵方/
てきかん /敵艦/
てきかんたい /敵艦隊/
てきがいしん /敵愾心/
てきがわ /敵側/
てきき /敵機/適期/
てききしゅうらい /敵機襲来/
てききどうへいき /敵機動兵器/
てききょてん /敵拠点/
てきぎ /適宜/
てきぎついか /適宜追加/
てきぎはんだん /適宜判断/
てきぎへんこう /適宜変更/
てきぐん /敵軍/
てきこく /敵国/
てきごう /適合/
てきごうか /適合化/
てきごうかんすう /適合関数/
てきごうしゃ /適合車/
てきごうせい /適合性/
てきごうど /適合度/
てきごうにんてい /適合認定/
てきごうほあんぶひん /適合保安部品/
てきざい /適材/
てきざいてきしょ /適材適所/
てきし /敵視/
てきしゃ /適者/敵車/
てきしゃせいぞん /適者生存/
てきしゅつ /摘出/剔出/
てきしゅつしゅじゅつ /摘出手術/
てきしょ /適所/
てきしょく /適職/
てきしょてきざい /適所適材/
てきじ /適時/
てきじだ /適時打/
てきじにるいだ /適時二塁打/
てきじょ /摘除/滌除/
てきじょうしさつ /敵状視察/
てきじん /敵陣/
てきじんがわ /敵陣側/
てきじんない /敵陣内/
てきすと /テキスト/
てきせい /適正/適性/敵性/
てきせいか /適正化/
てきせいかかく /適正価格/
てきせいきあつ /適正気圧/
てきせいぎのう /適正技能/
てきせいけんさ /適性検査/
てきせいこうりょう /適正光量/
てきせいしようりょう /適正使用量/
てきせいしんだん /適性診断/
てきせいすう /適正数/
てきせいち /適正値/
てきせいりょく /適正力/
てきせいろこう /適正露光/
てきせいろしゅつ /適正露出/適性露出/
てきせつ /適切/
てきせつふてきせつ /適切不適切/
てきせんしゃ /敵戦車/
てきせんとうき /敵戦闘機/
てきぜんとうぼう /敵前逃亡/
てきそん /劇村/
てきたい /敵対/
てきたいいしき /敵対意識/
てきたいかんけい /敵対関係/
てきたいこうい /敵対行為/
てきたいこうどう /敵対行動/
てきたいし /敵対視/
てきたいしゃ /敵対者/
てきたいてき /敵対的/
てきだん /敵弾/擲弾/擲彈/
てきち /適地/敵地/
てきちゅう /的中/適中/
てきちゅうりつ /的中率/
てきちょく /躑躅/
てきてい /滴定/
てきとう /適当/
てきとうせい /適当性/
てきど /適度/
てきどうし /敵同士/
てきにん /適任/適人/
てきにんしゃ /適任者/適人者/
てきはかいりつ /敵破壊率/
てきはつ /摘発/
てきはつきこう /摘発機構/
てきはつじけん /摘発事件/
てきばくげきき /敵爆撃機/
てきひ /適否/
てきふてき /適不適/
てきへい /敵兵/
てきほう /適法/
てきほうこうい /適法行為/
てきほんきょち /敵本拠地/
てきめん /覿面/
てきやく /適役/敵役/適訳/
てきよう /適用/摘要/
てきようかのう /適用可能/
てきようがい /適用外/
てきようきかい /適用機会/
てきようきせいないよう /適用規制内容/
てきようきそく /適用規則/
てきようぎょうむ /適用業務/
てきようけっか /適用結果/
てきようげんかい /適用限界/
てきようこうか /適用効果/
てきようご /適用後/
てきようじ /適用時/
てきようじゅんじょ /適用順序/
てきようじょうけん /適用条件/
てきようじょがい /適用除外/
てきようじれい /適用事例/
てきようずみ /適用済/
てきようせい /適用性/
てきようたいしょう /適用対象/
てきようたいしょうがい /適用対象外/
てきようはんい /適用範囲/
てきようはんいがい /適用範囲外/
てきようふかのう /適用不可能/
てきようぶ /適用部/
てきようへんこう /適用変更/
てきようほう /適用法/
てきようまえ /適用前/
てきようれい /適用例/
てきりょう /適量/
てきれい /適齢/適例/
てきれいき /適齢期/
てぎれ /手切れ/
てぎわ /手際/
てくせ /手くせ/
てくだ /手管/
てくにっく /テクニック/
てくの /テクノ/
てくのろじー /テクノロジー/
てくび /手首/
てくびこっせつ /手首骨折/
てぐ /手具/
てぐさり /手鎖/
てぐすね /手具脛/
てぐち /手口/
てけいさん /手計算/
てこ /梃/挺子/梃子/
てこいれ /梃入れ/
てこう /手甲/
てごたえ /手応え/
てごま /手駒/
てごめ /手籠/
てごろ /手頃/手ごろ/
てさき /手先/
てさぎょう /手作業/
てさぐり /手探り/
てさげ /手下げ/手提/
てさし /手差し/
てざいく /手細工/
てざき /手崎/
てざし /手差し/
てざわり /手触り/
てしお /手塩/天塩/
てしおなかがわ /天塩中川/
てしかが /弟子屈/
てしがわら /勅使河原/
てしくつちょう /弟子屈町/
てした /手下/
てしば /手柴/
てしま /手島/手嶋/
てしゅうせい /手修正/
てしろぎ /手代木/
てじか /手近/
てじな /手品/
てじなし /手品師/
てじま /手島/手嶋/
てじめ /手締め/
てじゅん /手順/
てじゅんしょ /手順書/
てじょう /手錠/
てすう /手数/
てすうりょう /手数料/
てすうりょうていど /手数料程度/
てすうりょうむりょう /手数料無料/
てすじ /手筋/
てすじしゅう /手筋集/
てすと /テスト/
てすとしようしょ /テスト仕様書/
てすり /手摺り/
てずか /手塚/
てせい /手製/
てぜま /手狭/
てぜんたい /手全体/
てそう /手相/
てぞん /手損/
てたれ /手タレ/
てだし /手出し/
てだすけ /手助け/
てだて /手立て/
てだま /手玉/
てだれ /手練/
てちがい /手違い/
てちょう /手帳/手帖/
てぢか /手近/
てっ /徹/
てっかい /撤回/
てっかいようきゅう /撤回要求/
てっかめん /鉄仮面/
てっかん /鉄管/
てっき /鉄器/敵機/適期/
てっきゅう /鉄球/
てっきょ /撤去/剔去/
てっきょう /鉄橋/
てっきょうした /鉄橋下/
てっきょかのう /撤去可能/
てっきょご /撤去後/
てっきん /鉄筋/鉄琴/
てっけん /鉄拳/鉄建/
てっこう /鉄鋼/鉄鉱/鉄工/鐵工/鐵鉱/鐵鋼/手甲/
てっこうぎょう /鉄鋼業/
てっこうしょ /鉄工所/鉄鉱所/鉄鋼所/鐵工所/鐵綱所/鐵鉱所/
てっこうじょ /鉄工所/鐵工所/
てっこうじょう /鉄工場/
てっこうせき /鉄鉱石/
てっこうせん /鉄甲船/
てっこうだん /徹甲弾/
てっこつ /鉄骨/
てっこついんりょう /鉄骨飲料/
てっさく /鉄柵/
てっしゅう /撤収/撤收/
てっしゅうじゅんび /撤収準備/
てっしょう /哲章/鉄漿/
てっせい /鉄製/哲西/
てっせん /鉄線/
てっそく /鉄則/
てったい /撤退/
てったいきげん /撤退期限/
てったいじょうけん /撤退条件/
てったいちゅう /撤退中/
てっちゅう /鉄柱/
てっちゅうこうげき /鉄柱攻撃/
てっつい /鉄槌/鉄鎚/
てってい /徹底/
てっていか /徹底化/
てっていかいせき /徹底解析/
てっていかいぞう /徹底改造/
てっていかいめい /徹底解明/
てっていぎろんは /徹底議論派/
てっていこうかい /徹底公開/
てっていついせき /徹底追跡/
てっていてき /徹底的/
てっていひかく /徹底比較/
てっとう /鉄塔/
てっぱい /撤廃/
てっぱん /鉄板/鉄鈑/
てっぱんやき /鉄板焼/
てっぴ /鉄扉/
てっぴつ /鉄筆/
てっぷん /鉄紛/鉄粉/
てっぺい /撤兵/鉄平/
てっぺき /鉄璧/鉄壁/
てっぺん /天辺/
てっぽう /鉄砲/
てっぽうすう /鉄砲数/
てっぽうだま /鉄砲玉/
てつ /鉄/哲/徹/轍/撤/迭/鐵/綴/姪/咥/垤/屮/耋/跌/輟/銕/鐡/餮/
てつあき /哲明/
てついち /鉄一/
てつお /哲雄/哲夫/哲男/鉄男/鉄夫/鉄雄/哲生/哲郎/徹男/哲臣/
てつか /手塚/
てつかいしょく /鉄灰色/
てつかず /手着かず/
てつがく /哲学/
てつがくか /哲学科/
てつがくかい /哲学会/
てつがくきょういく /哲学教育/
てつがくきょうじゅ /哲学教授/
てつがくしゃ /哲学者/
てつがくしゃたち /哲学者達/
てつがくしゅっぱん /哲学出版/
てつがくしょ /哲学書/
てつがくじょう /哲学上/
てつがくだんぎ /哲学談義/
てつがくてき /哲学的/
てつがくてきがいねん /哲学的概念/
てつがくてきけんち /哲学的見地/
てつがくばたけ /哲学畑/
てつがくろん /哲学論/哲学的/
てつがくろんぎ /哲学論議/
てつがくろんそう /哲学論争/
てつき /手付/哲樹/
てつきどう /鉄軌道/
てつくず /鉄屑/
てつけ /手付け/
てつけいたい /鉄警隊/
てつけきん /手付金/
てつけん /鉄研/
てつこ /徹子/哲子/
てつごうし /鉄格子/
てつざい /鉄材/
てつし /哲史/哲士/哲資/
てつしゃりん /鉄車輪/
てつしん /鉄芯/
てつじ /哲司/哲二/哲嗣/哲志/哲至/轍次/哲士/哲史/
てつじょうぎ /鉄定規/
てつじょうもう /鉄条網/
てつじろう /哲治郎/
てつじん /鉄人/哲人/
てつせい /鉄製/
てつせいひん /鉄製品/
てつた /哲多/
てつたろう /鉄太郎/哲太郎/
てつだい /手伝い/
てつづき /手続き/手続/
てつづきかん /手続き間/
てつづきがた /手続型/手続き型/
てつづきがたげんご /手続き型言語/手続型言語/
てつづきじょう /手続き上/
てつづきち /手続き値/
てつづきてき /手続的/
てつづきない /手続き内/
てつづち /鉄鎚/
てつどう /鉄道/鐵道/
てつどうあいこうか /鉄道愛好家/
てつどういがい /鉄道以外/
てつどういっぱん /鉄道一般/
てつどういん /鉄道員/
てつどうえいぎょうほう /鉄道営業法/
てつどうえき /鉄道駅/
てつどうえんちょう /鉄道延長/
てつどうおう /鉄道王/
てつどうかい /鉄道界/
てつどうかくし /鉄道各誌/
てつどうかもつ /鉄道貨物/
てつどうかんけい /鉄道関係/
てつどうかんけいしゃ /鉄道関係者/
てつどうかんれん /鉄道関連/
てつどうがいしゃ /鉄道会社/
てつどうがわ /鉄道側/
てつどうきねんかん /鉄道記念館/
てつどうきねんび /鉄道記念日/
てつどうきやく /鉄道規約/
てつどうぎじゅつ /鉄道技術/
てつどうぎょう /鉄道業/
てつどうけい /鉄道系/
てつどうけいえい /鉄道経営/
てつどうけいさつたい /鉄道警察隊/
てつどうけん /鉄道研/
てつどうけんきゅうかい /鉄道研究会/
てつどうけんせつこうだん /鉄道建設公団/
てつどうけんちくぶつ /鉄道建築物/
てつどうこうあん /鉄道公安/
てつどうこうあんかん /鉄道公安官/
てつどうこうがく /鉄道工学/
てつどうこうそくか /鉄道高速化/
てつどうこくゆうか /鉄道国有化/
てつどうざっし /鉄道雑誌/
てつどうしがっかい /鉄道史学会/
てつどうしゃしん /鉄道写真/
てつどうしゃりょう /鉄道車両/
てつどうしゃりょうもけい /鉄道車両模型/
てつどうしゅみ /鉄道趣味/
てつどうしょう /鉄道省/
てつどうしょうか /鉄道唱歌/
てつどうしょくいん /鉄道職員/
てつどうじぎょう /鉄道事業/
てつどうじぎょうしゃ /鉄道事業者/
てつどうじぎょうめんきょ /鉄道事業免許/
てつどうじぎょうようち /鉄道事業用地/
てつどうじこ /鉄道事故/
てつどうじこくひょう /鉄道時刻表/
てつどうじじょう /鉄道事情/
てつどうじょうほう /鉄道情報/
てつどうせいび /鉄道整備/
てつどうせいびききん /鉄道整備基金/
てつどうせいびぜい /鉄道整備税/
てつどうせん /鉄道線/
てつどうせんろ /鉄道線路/
てつどうそうけん /鉄道総研/
てつどうたんてい /鉄道探偵/
てつどうたんていだん /鉄道探偵団/
てつどうだいこう /鉄道代行/
てつどうでんか /鉄道電化/
てつどうとう /鉄道等/
てつどうない /鉄道内/
てつどうはくぶつかん /鉄道博物館/
てつどうふっけん /鉄道復建/
てつどうぶもん /鉄道部門/
てつどうまんが /鉄道漫画/
てつどうめい /鉄道名/
てつどうもけい /鉄道模型/
てつどうもけいしゅみ /鉄道模型趣味/
てつどうもけいよう /鉄道模型用/
てつどうゆうびん /鉄道郵便/
てつどうゆそう /鉄道輸送/
てつどうようご /鉄道用語/
てつどうようらん /鉄道要覧/
てつどうりょうきん /鉄道料金/
てつどうりょこう /鉄道旅行/
てつどうりょこうじゅつ /鉄道旅行術/
てつどうろばん /鉄道路盤/
てつなべ /鉄鍋/
てつのり /哲憲/
てつひと /鉄一/鉄人/
てつひろ /哲弘/哲宏/
てつびん /鉄瓶/
てつぶろ /鉄風炉/
てつぶん /鉄分/
てつぶんか /鉄文化/
てつぶんほきゅう /鉄分補給/
てつぼう /鉄棒/
てつまど /鉄窓/
てつまん /徹マン/
てつみ /哲美/
てつめん /鉄面/
てつめんぴ /鉄面皮/
てつや /徹夜/哲也/哲弥/哲哉/鉄也/鉄弥/徹也/
てつやぐみ /徹夜組/
てつゆき /徹之/徹行/
てつり /哲理/
てつろ /鉄路/
てつろう /哲郎/哲朗/徹郎/鉄郎/
てつわん /鉄腕/鉄椀/
てづか /手塚/
てづかおさむ /手塚治虫/
てづかさとみ /手塚理美/
てづかみ /手掴み/
てづくり /手作り/
てづまり /手詰り/
てづめ /手詰/
てづる /手蔓/
てとりす /テトリス/
てどうさ /手動作/
てどり /手取り/手取/
てどりがわ /手取川/
てなおし /手直し/
てなみ /手並み/
てならい /手習い/手習/
てにす /テニス/
てにもつ /手荷物/
てにもつけんさ /手荷物検査/
てにもつけんさじょう /手荷物検査場/
てにもつよう /手荷物用/
てにゅうりょく /手入力/
てにをは /天爾遠波/
てぬき /手抜き/
てぬぐい /手ぬぐい/手拭い/
てのひら /掌/手の平/
てはい /手配/手牌/
てはいしょ /手配書/
てはいりょこう /手配旅行/
てはじめ /手始め/
てはず /手筈/
てはら /手原/
てばさき /手羽先/
てばた /手旗/
てびき /手引/手引き/
てびきあん /手引案/
てびきしょ /手引書/
てびきだい /手引第/
てびきだいいっぱん /手引第一版/
てびょうし /手拍子/
てびろ /手広/
てふだ /手札/
てぶくろ /手袋/
てぶり /手振/
てべんとう /手弁当/
てほどき /手解き/
てほん /手本/
てほんびき /手本引き/
てま /手間/
てまえ /手前/点前/
てまえがわ /手前側/
てまえみそ /手前味噌/
てまき /手巻/
てまくら /手枕/
てまちん /手間賃/
てまね /手真似/
てまねき /手招き/
てまひま /手間暇/
てまり /手毬/手鞠/
てまりうた /手毬唄/手鞠唄/手鞠歌/
てまわし /手回し/
てみじか /手短/
てみやげ /手土産/
てもち /手持ち/手持/
てもちぶさた /手持ち無沙汰/
てもと /手元/手許/
てやき /手焼/
てゆび /手指/
てら /寺/地球/
てらい /寺井/
てらうち /寺内/
てらお /寺尾/
てらおか /寺岡/
てらおかせいこう /寺岡精工/
てらおとこ /寺男/
てらかわ /寺川/
てらがいと /寺垣内/
てらがわ /寺側/
てらくら /寺倉/
てらこや /寺子屋/
てらごや /寺小屋/
てらさか /寺坂/
てらさき /寺崎/
てらさわ /寺沢/寺澤/
てらした /寺下/
てらしま /寺島/寺嶋/
てらしょう /寺庄/
てらじま /寺島/
てらそま /寺杣/
てらだ /寺田/
てらどまり /寺泊/
てらにし /寺西/
てらの /寺野/
てらまえ /寺前/
てらまち /寺町/
てらまちしゅうへん /寺町周辺/
てらまちじいんぐん /寺町寺院群/
てらまちどおり /寺町通/
てらむら /寺村/
てらもと /寺本/寺元/
てらやま /寺山/
てらやましゅうじ /寺山修司/
てり /輝/
てりかえし /照り返し/
てりやき /照り焼き/
てりやす /輝泰/
てりょうり /手料理/
てる /輝/照/テル/晃/瑛/
てるあき /輝明/
てるい /照井/
てるお /輝男/晃央/輝雄/輝夫/照男/照夫/照雄/光男/晃夫/
てるき /輝樹/
てるこ /輝子/照子/てる子/
てるたか /照貴/
てると /照人/
てるのぶ /輝暢/晧史/照信/
てるのり /照則/
てるひこ /照比古/輝彦/照彦/
てるひさ /照久/
てるひろ /照洋/
てるみ /輝美/照美/
てるみな /テルミナ/
てるもと /輝元/
てるやす /輝泰/
てるゆき /輝之/輝幸/
てれあさ /テレ朝/
てれっくす /テレックス/
てれぱしー /テレパシー/
てれび /テレビ/電視/
てれびきょく /テレビ局/
てれびじょん /テレビジョン/
てれや /照れ屋/
てれん /手練/
てわけ /手分け/
てわざ /手技/
てわたし /手渡し/
てん /点/・/店/天/転/典/展/．/顛/添/甜/填/殿/纏/、/…/丶/，/テン/辿/囀/壥/奠/巓/廛/忝/恬/梃/殄/癲/碾/篆/纒/腆/覘/諂/貂/躔/輾/轉/霑/靦/鷆/鷏/點/貼/槙/・・・/
てんあんもん /天安門/
てんあんもんじけん /天安門事件/
てんあんもんひろば /天安門広場/
てんあんもんひろばまえ /天安門広場前/
てんい /転移/転位/典韋;三国時代・曹操配下の巨漢/
てんいおんど /転移温度/
てんいがい /点以外/
てんいち /天一/
てんいへんかん /転移変換/
てんいむほう /天衣無縫/
てんいり /点入/
てんいん /店員/転院/
てんいんきょういく /店員教育/
てんえい /天栄/
てんおう /天王/
てんおんげん /点音源/
てんか /転嫁/天下/点火/添加/転化/転訛/転科/
てんかい /展開/天海/転回/天界/
てんかいかんすう /展開関数/
てんかいきぼう /展開希望/
てんかいけい /展開形/
てんかいけいすう /展開係数/
てんかいこうげき /展開攻撃/
てんかいご /展開後/
てんかいしき /展開式/
てんかいしゅほう /展開手法/
てんかいじ /展開時/
てんかいじたい /展開自体/
てんかいじょうたい /展開状態/
てんかいず /展開図/
てんかいそくど /展開速度/
てんかいち /天下市/
てんかいちぶどうかい /天下一武道会/
てんかいちゅう /展開中/
てんかいっぴん /天下一品/
てんかいてき /展開的/
てんかいてん /転回点/
てんかいどうよう /展開同様/
てんかいばん /展開版/
てんかいぶ /展開部/
てんかいぶぶん /展開部分/
てんかいまえ /展開前/
てんかいゆうり /展開有利/
てんかけい /点火系/
てんかけいしき /点火形式/
てんかご /添加後/
てんかごめん /天下御免/
てんかざい /添加剤/
てんかしん /点加振/
てんかじき /点火時期/
てんかす /天滓/
てんかたいへい /天下泰平/
てんかてい /点過程/
てんかとういつ /天下統一/
てんかびと /天下人/
てんかふん /天花粉/
てんかぶつ /添加物/
てんかぶつなど /添加物等/
てんかまえ /点火前/
てんかむてき /天下無敵/
てんかれいじ /添加励磁/
てんかわ /添川/
てんかん /転換/点間/癲癇/
てんかんき /転換器/転換期/
てんかんしゃさい /転換社債/
てんかんじ /転換時/
てんが /典雅/天下/
てんがい /天外/天蓋/
てんがいこどく /天涯孤独/
てんがいまきょう /天外魔境/
てんがくぶ /転学部/
てんがじゃやかん /天下茶屋間/
てんがん /点眼/
てんがんえき /点眼液/
てんがんやく /点眼薬/
てんき /天気/転記/転機/天氣/
てんきー /テンキー/
てんきあめ /天気雨/
てんきず /天気図/
てんきそうだんしょ /天気相談所/
てんきそうだんじょ /天気相談所/
てんきばんぐみ /天気番組/
てんきぼ /点鬼簿;鬼籍/
てんきや /天気屋/
てんきゅう /天球/
てんきゅうぎ /天球儀/
てんきょ /転居/典拠/
てんきょう /癲狂/
てんきょさき /転居先/
てんきょつうち /転居通知/
てんきよほう /天気予報/
てんきよほうし /天気予報士/
てんきん /転勤/
てんきんさき /転勤先/
てんきんひ /転勤費/
てんぎく /天菊/
てんぎょう /転業/
てんくう /天空/
てんくうじょう /天空城/
てんぐ /天狗/
てんぐう /天宮/
てんぐだいら /天狗平/
てんぐばし /天狗橋/
てんぐまい /天狗舞/
てんぐやま /天狗山/
てんけい /典型/天啓/
てんけいち /典型値/
てんけいてき /典型的/
てんけいれい /典型例/
てんけつ /点穴/
てんけつごう /点結合/
てんけん /点検/
てんけんこうもく /点検項目/
てんけんじこう /点検事項/
てんけんせいび /点検整備/
てんげん /点源/
てんげんだい /天元台/
てんこ /点呼/
てんこう /天候/転校/転向/天功/典孝/
てんこうぐみ /転向組/
てんこうげん /点光源/
てんこうさき /転校先/
てんこうしだい /天候次第/
てんこうしょにち /転校初日/
てんこうせい /転校生/
てんこうふじゅん /天候不順/
てんこうりつ /点効率/
てんこうりょく /転向力/
てんこく /転告/篆刻/
てんご /点５/
てんごく /天国/
てんごくきぶん /天国気分/
てんごくゆき /天国行/
てんさ /点差/
てんさい /転載/天才/天災/甜菜/
てんさいいらい /転載依頼/
てんさいか /転載可/
てんさいかいし /転載開始/
てんさいかがくしゃ /天才科学者/
てんさいかのう /転載可能/
てんさいきさい /天才奇才/
てんさいきじ /転載記事/
てんさいきょか /転載許可/
てんさいきんし /転載禁止/
てんさいけん /転載権/
てんさいご /転載後/
てんさいしゃ /転載者/
てんさいしょうじょ /天才少女/
てんさいしょうねん /天才少年/
てんさいじ /転載時/天才児/
てんさいじゆう /転載自由/
てんさいじょう /点差以上/
てんさいじょうけん /転載条件/
てんさいせい /天才性/
てんさいせいとう /甜菜製糖/
てんさいせきにんしゃ /転載責任者/
てんさいたいしょう /天才大賞/
てんさいてき /天才的/
てんさいはながた /天才花形/
てんさいふう /天才風/
てんさいふか /転載不可/
てんさいもと /転載元/
てんさいろん /天才論/
てんさく /添削/
てんさくしどう /添削指導/
てんざい /点在/
てんざん /天山/
てんし /天使/覘視/天子/
てんしき /点式/
てんしげ /天繁/
てんしじ /点支持/
てんしじかん /天使時間/
てんしたち /天使達/
てんしちょう /天使長/
てんしゃ /転写/転社/
てんしゃく /転借/
てんしゃだい /転車台/
てんしやく /天使役/
てんしゅ /店主/
てんしゅうごう /点集合/
てんしゅかく /天守閣/
てんしゅつ /転出/
てんしゅつこう /転出校/
てんしゅつしょうめい /転出証明/
てんしゅどう /天主堂/
てんしょ /添書/篆書/典書/転所/
てんしょう /転生/天昇/
てんしょうどう /天賞堂/
てんしょく /転職/天職/
てんしょくご /転職後/
てんしょくさき /転職先/
てんしょくまえ /転職前/
てんしん /転身/転進/天津/点心/
てんしんこう /天津港/
てんしんしはんだいがく /天津師範大学/
てんしんはん /天津飯/
てんしんらんまん /天真爛漫/
てんじ /展示/点字/添字/
てんじいん /展示員/
てんじいんさつ /点字印刷/
てんじえいわじてん /点字英和辞典/
てんじかい /展示会/
てんじかいしゅさいしゃ /展示会主催者/
てんじかいじょう /展示会場/
てんじかん /展示館/
てんじかんけい /点字関係/
てんじきき /展示機器/
てんじく /天竺/
てんじしつ /展示室/
てんじしゃ /展示車/
てんじじょう /展示場/
てんじせつめいかい /展示説明会/
てんじそくばい /展示即売/
てんじそくばいかい /展示即売会/
てんじたんとうしゃ /展示担当者/
てんじつ /天日/
てんじつえん /天日塩/
てんじひこう /展示飛行/
てんじひょうじぶ /点字表示部/
てんじひん /展示品/
てんじぶつ /展示物/
てんじぶんしょう /点字文章/
てんじほう /展示法/
てんじゅ /天寿/
てんじょう /天井/点状/天上/天壌/天壤/添乗/纏繞/殿上/
てんじょういん /添乗員/
てんじょういんよう /添乗員用/
てんじょううら /天井裏/
てんじょうかい /天上界/
てんじょうけい /纏繞茎/
てんじょうさじき /天井桟敷/
てんじょうせっちがた /天井設置型/
てんじょうつり /天井吊/
てんじょうてんか /天上天下/
てんじょうびと /殿上人/
てんじょうむきゅう /天壌無窮/天壤無窮/
てんじょうめん /天井面/
てんじよう /点字用/
てんじん /天神/
てんじんいわたや /天神岩田屋/
てんじんだいら /天神平/
てんじんはつ /天神発/
てんじんばし /天神橋/
てんじんまつり /天神祭/
てんじんや /天神屋/
てんじんゆき /天神行/
てんすい /天水/
てんすう /点数/
てんすうけいさん /点数計算/
てんすうせい /点数制/
てんすうせいど /点数制度/
てんすうちょうせい /点数調整/
てんすうはいぶん /点数配分/
てんせい /天性/転生/転成/
てんせいご /転生後/
てんせいじんご /天声人語/
てんせいまえ /転生前/
てんせいりんね /転生輪廻/
てんせき /転籍/転石/
てんせっしょく /点接触/
てんせん /点線/転戦/転線/
てんせんげん /点線源/
てんぜん /恬然/
てんそう /転送/
てんそうかのう /転送可能/
てんそうがわ /転送側/
てんそうき /転送機/
てんそうきかん /転送期間/
てんそうきこう /転送機構/
てんそうきのう /転送機能/
てんそうこうりつ /転送効率/
てんそうさき /転送先/
てんそうしつ /転送室/
てんそうしゃ /転送者/
てんそうしゅうよう /転送収容/
てんそうしゅうりょう /転送終了/
てんそうしょり /転送処理/
てんそうじ /転送時/
てんそうじかん /転送時間/
てんそうじっけん /転送実験/
てんそうじょうげん /転送上限/
てんそうせいのう /転送性能/
てんそうそうち /転送装置/
てんそうそくど /転送速度/
てんそうちゅう /転送中/
てんそうとちゅう /転送途中/
てんそうのうりょく /転送能力/
てんそうはば /転送幅/
てんそうほうほう /転送方法/
てんそうもと /転送元/
てんそうよう /転送用/
てんそうようきゅう /転送要求/
てんそうようりょう /転送容量/
てんそうりょう /転送量/転送料/
てんそうろ /転送路/
てんそく /天測/纒足/典則/纏足/
てんそば /天蕎麦/
てんそる /テンソル/
てんそんこうりん /天孫降臨/
てんぞう /点像/
てんぞく /転属/
てんたい /天体/転貸/
てんたいうちゅうぶつり /天体宇宙物理/
てんたいかんそく /天体観測/
てんたいがぞう /天体画像/
てんたいしゃく /転貸借/
てんたいしゃしん /天体写真/
てんたいしゃしんか /天体写真家/
てんたいしょう /点対称/
てんたいぶつりがく /天体物理学/
てんたいぶつりてき /天体物理的/
てんたいぶつりや /天体物理屋/
てんたいぼうえんきょう /天体望遠鏡/
てんたいや /天体屋/
てんたいよう /天体用/
てんたん /恬淡/
てんだい /天台/
てんだいしゅう /天台宗/
てんち /天地/転地/転置/
てんちぎゃくてん /天地逆転/
てんちぎょうれつ /転置行列/
てんちそうぞう /天地創造/
てんちちりょう /転地治療/
てんちむよう /天地無用/
てんちゅう /天誅/天諌/
てんちゅうさつ /天中殺/
てんちょう /転調/店長/天頂/
てんちょうさき /転調先/
てんつい /点対/
てんてき /天敵/点滴/
てんてきちゅう /点的中/
てんてん /転々/…/・・・/‥/点々/．．．/短点/：/……/
てんてんてん /・・・/
てんてんはんそく /輾転反側/
てんでんか /点電荷/
てんと /テント/
てんとう /店頭/点灯/転倒/点燈/顛倒/天道/
てんとうかかく /店頭価格/
てんとうきせい /点灯規制/
てんとうしょぶんひん /店頭処分品/
てんとうじ /転倒時/点灯時/
てんとうちゅう /点灯中/
てんとうはんばい /店頭販売/
てんとうひん /店頭品/
てんとうむし /てんとう虫/
てんどう /天童/天道/天動/
てんどうこうげん /天童高原/
てんどうし /天童市/
てんどうせつ /天動説/
てんどうぼうし /転動防止/
てんどん /天丼/
てんない /店内/
てんないせんよう /店内専用/
てんに /点２/
てんにゅう /転入/
てんにゅうせい /転入生/
てんにゅうてんしゅつ /転入転出/
てんにゅうとどけ /転入届/
てんにょ /天女/
てんにん /転任/天人/
てんにんさき /転任先/
てんねん /天然/
てんねんかじゅう /天然果汁/
てんねんがき /天然牡蠣/
てんねんきねんぶつ /天然記念物/
てんねんしば /天然芝/
てんねんしょく /天然色/
てんねんすい /天然水/
てんねんせっけん /天然石鹸/
てんねんせんりょう /天然染料/
てんねんとう /天然痘/
てんねんほうしゃせん /天然放射線/
てんねんもの /天然物/
てんねんゆき /天然雪/
てんねんりん /天然林/
てんのう /天皇/天王/
てんのうきかんせつ /天皇機関説/
てんのうけ /天皇家/
てんのうこうごう /天皇皇后/
てんのうざん /天王山/
てんのうしゅけん /天皇主権/
てんのうしょう /天皇賞/
てんのうしょうあき /天皇賞秋/
てんのうしょうかんじ /天皇賞幹事/
てんのうしょうきょうそう /天皇賞競走/
てんのうしょうぐみ /天皇賞組/
てんのうしょうはる /天皇賞春/
てんのうしょうば /天皇賞馬/
てんのうしんぽうしゃ /天皇信奉者/
てんのうじ /天王寺/
てんのうじえき /天王寺駅/
てんのうじしん /天皇自身/
てんのうじすいぞっかん /天王寺水族館/
てんのうじどうぶつえん /天王寺動物園/
てんのうず /天王州/
てんのうせい /天皇制/天王星/
てんのうせいど /天皇制度/
てんのうせいひはん /天皇制批判/
てんのうせいろん /天皇制論/
てんのうそくいご /天皇即位後/
てんのうたんじょうび /天皇誕生日/
てんのうだい /天王台/
てんのうちょう /天王町/
てんのうちょうかん /天王町間/
てんのうはい /天皇杯/
てんのうはいけっしょう /天皇杯決勝/
てんのうはいじゅんけっしょう /天皇杯準決勝/
てんのうはいよせん /天皇杯予選/
てんのうひはん /天皇批判/
てんのうへいか /天皇陛下/
てんのうほうぎょ /天皇崩御/
てんのうほうちゅう /天皇訪中/
てんのうほうどう /天皇報道/
てんのうゆうざいろん /天皇有罪論/
てんのうようご /天皇擁護/
てんのうようごはつげん /天皇擁護発言/
てんはいれつ /点配列/
てんはく /天白/
てんはくく /天白区/
てんばい /転売/
てんばつ /天罰/
てんばん /天板/
てんばんごう /店番号/
てんぱい /聴牌/顛沛/
てんぱく /天白/天伯/
てんぱん /典範/天板/
てんびき /天引き/
てんびょう /点描/
てんびん /天秤/
てんびんざ /天秤座/
てんぴ /天火/天日/
てんぴじお /天日塩/
てんぴょう /天平/
てんぴん /天稟/
てんぶ /転部/
てんぶん /天分/
てんぷ /添付/天賦/貼付/
てんぷかのう /添付可能/
てんぷく /転覆/
てんぷしょるい /添付書類/
てんぷしりょう /添付資料/
てんぷちずさんしょう /添付地図参照/
てんぷら /天ぷら/天麩羅/
てんぷらや /天麩羅屋/
てんぷれーと /テンプレート/
てんべつ /点別/
てんぺん /転変/天変/
てんぺんちい /天変地異/
てんほう /天和/
てんほくせん /天北線/
てんぼう /展望/点棒/
てんぼうしゃ /展望車/
てんぼうせき /展望席/
てんぼうだい /展望台/
てんぼうとう /展望塔/
てんぽ /店舗/テンポ/
てんぽう /天保/天方/
てんぽうさん /天保山/
てんぽうざん /天保山/
てんぽめんせき /店舗面積/
てんぽらり /テンポラリ/
てんま /天満/天馬/天魔/
てんまがわ /天満川/
てんまく /天幕/
てんません /伝馬船/
てんまちょう /伝馬町/
てんまつ /顛末/天松/
てんまつき /顛末記/
てんまど /天窓/
てんまばし /天満橋/
てんまばやし /天間林/
てんまや /天満屋/
てんまん /天満/
てんまんぐう /天満宮/
てんまんてん /点満点/
てんむす /天むす/
てんめ /点目/
てんめい /天命/店名/天明/
てんめいふめい /店名不明/
てんめつ /点滅/
てんめつおん /点滅音/
てんめつじょうたい /点滅状態/
てんめん /纏綿/
てんめんじゃん /甜麺醤/
てんもう /天網/
てんもうかいかい /天網恢恢/
てんもん /天文/
てんもんか /天文家/
てんもんかん /天文館/
てんもんかんけい /天文関係/
てんもんがく /天文学/
てんもんがくしゃ /天文学者/
てんもんがくじょうほう /天文学情報/
てんもんがくてき /天文学的/
てんもんがっか /天文学科/
てんもんがっかい /天文学会/
てんもんがっかいし /天文学会誌/
てんもんけい /天文系/
てんもんけいさん /天文計算/
てんもんげっぽう /天文月報/
てんもんげんしょう /天文現象/
てんもんざっし /天文雑誌/
てんもんしゃしん /天文写真/
てんもんしょうねん /天文少年/
てんもんせんもんし /天文専門誌/
てんもんだい /天文台/
てんもんどうこうかい /天文同好会/
てんもんねんかん /天文年鑑/
てんもんぶ /天文部/
てんもんや /天文屋/
てんや /店屋/
てんやく /点訳/
てんやくへんかん /点訳変換/
てんやもの /店屋物/
てんゆう /天佑/
てんゆうしんじょ /天佑神助/
てんよう /転用/
てんようさき /転用先/
てんらい /天来/
てんらく /転落/
てんらん /展覧/天覧/
てんらんかい /展覧会/
てんらんかいじょう /展覧会場/
てんり /天理/
てんりこうこう /天理高校/
てんりし /天理市/
てんりせん /天理線/
てんりだい /天理大/
てんりちく /天理地区/
てんりひがし /天理東/
てんりゅう /天竜/天龍/点流/
てんりゅうがわ /天竜川/
てんりゅうがわかこう /天竜川河口/
てんりゅうきょう /天龍峡/
てんりゅうほうめん /天竜方面/
てんりょう /転寮/
てんりんおう /轉輪王/転輪王/
てんれつ /点列/
てんれんけつ /点連結/
てんろうせい /天狼星/
てんろく /天六/
で /出/弟/
でーた /データ/
でーたがた /データ型/
でーたてんそう /データ転送/
でーと /デート/
でーもん /デーモン/
であい /出会い/出合い/
であし /出足/
でぃーりんぐ /ディーリング/
でぃくす /ディクス/
でぃじたる /ディジタル/
でぃすかっしょん /ディスカッション/
でぃすく /ディスク/
でぃすこ /ディスコ/
でぃっしゅ /ディッシュ/
でぃなー /ディナー/
でぃれくた /ディレクタ/
でぃれくとり /ディレクトリ/
でい /泥/禰/
でいすい /泥酔/泥水/
でいたん /泥炭/
でいど /泥土/
でいねい /泥濘/
でいり /出入り/
でいりぐち /出入口/出入り口/
でいりゅう /泥流/
でか /刑事/
でかぐらむ /瓧/
でかせぎ /出稼ぎ/
でかた /出方/出かた/
でかたしだい /出方次第/
でかめーとる /籵/
でかりっとる /竍/
でがわ /出川/
でき /出来/溺/
できあい /溺愛/
できあがり /出来上がり/
できごころ /出来心/
できごと /出来事/
できし /溺死/
できしだい /出来次第/
できじたい /出来自体/
できだか /出来高/
できね /出来値/
できばえ /出来栄え/
できふでき /出来不出来/
できぼし /出来星/
でく /木偶/
でくにんぎょう /木偶人形/
でくのぼう /木偶の坊/
でぐあい /出具合/
でぐち /出口/
でぐちちょうさ /出口調査/
でぐちちょくぜん /出口直前/
でぐちふきん /出口付近/
でげねりあか /デゲネリア科/Degeneriaceae/
でこーど /デコード/
でこぼこ /凸凹/
でこぼこみち /凸凹道/
でさき /出先/
でざーと /デザート/
でざいな /デザイナ/
でざいなーず /デザイナーズ/
でざいん /デザイン/
でざき /出崎/
でざわ /出沢/
でし /弟子/
でしいり /弟子入り/
でしお /出汐/
でしぐらむ /瓰/
でしたち /弟子達/
でしりっとる /竕/
でじたる /デジタル/
でじたるか /デジタル化/
でじたるしんごう /デジタル信号/
でじま /出島/
でじる /出汁/
ですく /デスク/
でぞめしき /出初式/
でた /出た/
でたに /出谷/
でたらめ /出鱈目/
でだし /出出し/
でだま /出玉/
でだまじょうきょう /出玉状況/
でだますう /出玉数/
でだますうじたい /出玉数自体/
でだまりつ /出玉率/
でっき /デッキ/
でっち /丁稚/
でっちり /出っ尻/
でっぱ /出っ歯/
でつ /捏/
でつぞう /捏造/
でづっぱり /出突っ張り/
でづら /出面/
でどころ /出所/出処/
ではいり /出入り/
ではじめ /出始め/
でば /出刃/
でばいす /デバイス/
でばっく /デバック/
でばな /出鼻/
でばぼうちょう /出刃包丁/出刃庖丁/出歯包丁/
でばん /出番/
でぱーと /デパート/
でびゅー /デビュー/
でふぉると /デフォルト/
でふぉるとち /デフォルト値/
でふね /出船/
でふれ /デフレ/
でぶ /デブ/
でぶしょう /出不精/
でぶち /出淵/
でま /デマ/手間/
でまえ /出前/
でまち /出待ち/出町/
でまちやなぎ /出町柳/
でまちやなぎえき /出町柳駅/
でまちやなぎはつ /出町柳発/
でまちやなぎほうめん /出町柳方面/
でまちやまぎ /出町柳/
でまど /出窓/
でみず /出水/
でみせ /出店/
でむかえ /出迎え/
でむら /出村/
でめ /出目/
でめとく /出目徳/
でも /デモ/
でもと /出本/
でもの /出物/
でもばん /デモ版/
でもん /出門/
でもんすとれーしょん /デモンストレーション/
でやしき /出屋敷/
でら /寺/
でらっくす /デラックス/
でる /出る/
でるた /デルタ/Δ/δ/
でわ /出羽/出葉/
でわざくら /出羽桜/
でわにしき /出羽錦/
でわのうみ /出羽海/
でわのうみべや /出羽海部屋/
でん /電/田/伝/殿/澱/鈿/臀/傳/甸/畋/棯/沺/黏/佃/淀/
でんあつ /電圧/
でんあつけい /電圧計/
でんあつげん /電圧源/
でんあつこうか /電圧降下/
でんあつていか /電圧低下/
でんあつへんどう /電圧変動/
でんい /電位/
でんいさ /電位差/
でんえもん /伝衛門/
でんえん /田園/
でんえんこうきょうきょく /田園交響曲/
でんえんちょうふ /田園調布/
でんえんちょうふえき /田園調布駅/
でんえんちょうふせん /田園調布線/
でんえんちょうふふたば /田園調布双葉/田園調布雙葉/
でんえんとし /田園都市/
でんえんとしせん /田園都市線/
でんえんとしせんぞい /田園都市線沿/
でんえんふうけい /田園風景/
でんおん /伝音/
でんおんけい /伝音系/
でんおんけいなんちょう /伝音系難聴/
でんか /殿下/電化/伝家/電荷/
でんかい /電解/電界/
でんかいかいせき /電界解析/
でんかいきょうど /電界強度/
でんかいしつ /電解質/
でんかいない /電界内/
でんかかいぎょう /電化開業/
でんかかんせい /電化完成/
でんかかんせいご /電化完成後/
でんかくかん /電化区間/
でんかけいかく /電化計画/
でんかご /電化後/
でんかせいひん /電化製品/
でんかぶんぷ /電荷分布/
でんかほうしき /電化方式/
でんかまえ /電化前/
でんかみつど /電荷密度/
でんかもくてき /電化目的/
でんかりょう /電荷量/
でんかん /電管/電環/
でんがく /電楽/田楽/
でんき /電気/電機/伝記/電器/伝奇/傳綺/
でんきあつりょくなべ /電気圧力鍋/
でんきえいが /伝記映画/
でんきえいどう /電気泳動/
でんきおよびつうしんこうがくせんこう /電気及通信工学専攻/
でんきおんきょう /電気音響/
でんきおんきょうがく /電気音響学/
でんきおんきょうけんきゅうかい /電気音響研究会/
でんきおんすいき /電気温水器/
でんきか /電気科/電気化/
でんきかいろ /電気回路/
でんきかいろぶぶん /電気回路部分/
でんきかがく /電気化学/
でんきかぶしきがいしゃ /電気株式会社/
でんきかんけい /電気関係/
でんきかんりし /電気管理士/
でんきがい /電気街/電器街/
でんきがっか /電気学科/
でんきがっかい /電気学会/
でんきがっかいぎほう /電気学会技報/
でんきがっかいせいいん /電気学会正員/
でんきがっき /電気楽器/
でんきがま /電器釜/電気釜/
でんきき /電機器/
でんききかい /電気機械/
でんききかんしゃ /電気機関車/電機機関車/
でんききき /電気機器/
でんきききこうがく /電気機器工学/
でんきききせいさく /電気機器製作/
でんききそこうざ /電気基礎講座/
でんきくどう /電気駆動/
でんきけい /電気系/
でんきけいがっか /電気系学科/
でんきけいじ /電気計時/
でんきけいそくがく /電気計測学/
でんきけいとう /電気系統/
でんきけんそくしゃ /電気検測車/
でんきけんていきょうかい /電気検定協会/
でんきこうがく /電気工学/
でんきこうがくか /電気工学科/
でんきこうがくけい /電気工学系/
でんきこうがくしゃ /電気工学者/
でんきこうがくじっけん /電気工学実験/
でんきこうがくせんこう /電気工学専攻/
でんきこうがくだいに /電気工学第二/
でんきこうがっか /電気工学科/
でんきこうぎょう /電気工業/
でんきこうじ /電気工事/
でんきこうじし /電気工事士/
でんきさんぎょう /電器産業/
でんきしき /電気式/
でんきしきちくおんき /電気式蓄音機/
でんきしげき /電気刺激/
でんきしゃ /電気車/
でんきしゅうじんき /電気集塵器/
でんきしょうせつ /伝奇小説/
でんきしようりょう /電気使用量/
でんきしんごう /電気信号/
でんきじかけ /電気仕掛/
でんきじきがく /電気磁気学/
でんきじぎょう /電気事業/
でんきじぎょうほう /電気事業法/
でんきじどうしゃ /電気自動車/
でんきじょうほう /電気情報/
でんきじょうほうけい /電気情報系/
でんきじょうほうこうがく /電気情報工学/
でんきじょうほうこうがっか /電気情報工学科/
でんきすいはんき /電気炊飯器/
でんきせい /電器製/電機製/
でんきせいぎょ /電気制御/
でんきせいひん /電気製品/電器製品/
でんきせいひんいっぱん /電気製品一般/
でんきせつび /電気設備/
でんきそうじき /電気掃除機/
でんきそうち /電気装置/
でんきだい /電機大/電気代/
でんきだいがく /電機大学/
でんきだいなど /電気代等/
でんきつうしん /電気通信/
でんきつうしんがくぶ /電気通信学部/
でんきつうしんけんきゅうしょ /電気通信研究所/
でんきつうしんけんきゅうじょ /電気通信研究所/
でんきつうしんざいりょう /電気通信材料/
でんきつうしんざいりょうがく /電気通信材料学/
でんきつうしんじぎょう /電気通信事業/
でんきつうしんだい /電気通信大/
でんきつうしんだいがく /電気通信大学/
でんきつうしんほうしき /電気通信方式/
でんきていこう /電気抵抗/
でんきてき /電気的/伝記的/
でんきてきかいろ /電気的回路/
でんきてきかつどう /電気的活動/
でんきてきしょうげき /電気的衝撃/
でんきてきとくせい /電気的特性/
でんきてつどう /電気鉄道/
でんきてん /電器店/
でんきでんし /電気電子/
でんきでんしぶんや /電気電子分野/
でんきでんどうど /電気伝導度/
でんきとう /電気棟/
でんきどうりょく /電気動力/
でんきなべ /電気鍋/
でんきひつじ /電気羊/
でんきふきゅうざいだん /電気普及財団/
でんきぶ /電気部/
でんきぶんかい /電気分解/
でんきほうしき /電気方式/
でんきほせい /電気補正/
でんきもうふ /電気毛布/
でんきもの /伝奇物/電気物/
でんきや /電気屋/電器屋/電機屋/
でんきゅう /電球/
でんきょうしゃ /電響社/
でんきょく /電極/
でんきょくひん /電極品/
でんきようりょう /電気容量/
でんきりきがく /電気力学/
でんきりょう /電気量/
でんきりょうきん /電気料金/
でんきりようしゃ /電気利用者/
でんきりろん /電気理論/
でんきれいぞうこ /電気冷蔵庫/
でんきれんけつき /電気連結器/
でんきろ /電気炉/
でんきろうれん /電気労連/
でんきろくおん /電気録音/
でんぎ /電技/
でんぎょう /電業/
でんけい /電計/
でんけん /電顕/電検/
でんけんさんしゅ /電験三種/
でんげき /電撃/
でんげきおう /電撃王/
でんげきてき /電撃的/
でんげん /電源/
でんげんいがい /電源以外/
でんげんいり /電源入/
でんげんかいはつ /電源開発/
でんげんかいろ /電源回路/
でんげんかんけい /電源関係/
でんげんがわ /電源側/
でんげんきょうきゅう /電源供給/
でんげんけんよう /電源兼用/
でんげんこうじ /電源工事/
でんげんしゃ /電源車/
でんげんしゅうはすう /電源周波数/
でんげんしゅつりょく /電源出力/
でんげんせつび /電源設備/
でんげんせん /電源線/
でんげんたんし /電源端子/
でんげんつき /電源付/
でんげんでんあつ /電源電圧/
でんげんとうにゅう /電源投入/
でんげんとうにゅうご /電源投入後/
でんげんとうにゅうじ /電源投入時/
でんげんとうにゅうちょくご /電源投入直後/
でんげんないぞう /電源内蔵/
でんげんばん /電源板/
でんげんふよう /電源不要/
でんげんぶ /電源部/
でんげんよう /電源用/
でんげんようりょう /電源容量/電原容量/
でんこう /電工/電光/
でんこうかぶしきがいしゃ /電工株式会社/
でんこうけいじ /電光掲示/
でんこうけいじばん /電光掲示板/電光掲示盤/電光掲示版/
でんこうしき /電光式/
でんこうせっか /電光石火/
でんこうばん /電光板/
でんこうひょうじ /電光表示/
でんこうひょうじばん /電光表示板/
でんこうほうしゃ /電光放射/
でんごん /伝言/
でんごんばん /伝言板/
でんさん /電算/電産/
でんさんか /電算課/電算化/
でんさんき /電算機/
でんさんきしつ /電算機室/
でんさんしつ /電算室/
でんさんしゃしょく /電算写植/
でんさんしょり /電算処理/
でんさんぶ /電算部/
でんざい /電材/
でんし /電子/
でんしおん /電子音/
でんしおんがく /電子音楽/
でんしおんきょう /電子音響/
でんしか /電子化/電子科/
でんしかいぎ /電子会議/
でんしかいぎしつ /電子会議室/
でんしかいろ /電子回路/
でんしかいろがく /電子回路学/
でんしかんけい /電子関係/
でんしがく /電子学/
でんしがっき /電子楽器/
でんしきかい /電子機械/
でんしきき /電子機器/
でんしききじぎょうぶ /電子機器事業部/
でんしききぶ /電子機器部/
でんしききるい /電子機器類/
でんしきそぶ /電子基礎部/
でんしきていじょうたい /電子基底状態/
でんしきどう /電子軌道/
でんしきょう /電子協/電子工業振興協会/
でんしぎじゅつ /電子技術/
でんしぎじゅつかんけい /電子技術関係/
でんしぎじゅつしゃ /電子技術者/
でんしぎじゅつそうごうけんきゅうしょ /電子技術総合研究所/
でんしぎじゅつぶんや /電子技術分野/
でんしぎじゅつや /電子技術屋/
でんしけい /電子系/
でんしけいさん /電子計算/
でんしけいさんき /電子計算機/
でんしけいさんきしつ /電子計算機室/
でんしけいじばん /電子掲示板/電子掲示版/
でんしけん /電子研/
でんしけんきゅうしょ /電子研究所/
でんしけんびきょう /電子顕微鏡/
でんしこう /電子工/
でんしこうがく /電子工学/
でんしこうがくか /電子工学科/
でんしこうがくきょうしつ /電子工学教室/
でんしこうがくせんこう /電子工学専攻/
でんしこうがっか /電子工学科/
でんしこうぎょう /電子工業/
でんしこうさく /電子工作/
でんしこうさくよう /電子工作用/
でんしざいりょう /電子材料/
でんししき /電子式/
でんししゅっぱん /電子出版/
でんししゅっぱんきょく /電子出版局/
でんしじゅう /電子銃/
でんしじょうたい /電子状態/
でんしじょうほう /電子情報/
でんしじょうほうがっか /電子情報学科/
でんしじょうほうけい /電子情報系/
でんしじょうほうけいしすてむこうがくせんこう /電子情報系システム工学専攻/
でんしじょうほうこうがく /電子情報工学/
でんしじょうほうこうがくせんこう /電子情報工学専攻/
でんしじょうほうつう /電子情報通/
でんしじょうほうつうしんがっかい /電子情報通信学会/
でんしせいき /電子精機/
でんしせいぎょ /電子制御/
でんしせいぎょか /電子制御化/
でんしせいぎょきかい /電子制御機械/
でんしせいふ /電子政府/
でんしせってん /電子接点/
でんしせん /電子線/
でんしせんい /電子遷移/
でんしせんこう /電子専攻/
でんしそうちぶ /電子装置部/
でんしだい /電視台/
でんしちゃっか /電子着火/
でんしつい /電子対/
でんしつうしん /電子通信/
でんしつうしんがく /電子通信学/
でんしつうしんがっか /電子通信学科/
でんしつうしんがっかい /電子通信学会/
でんしつうしんじだい /電子通信時代/
でんしてき /電子的/
でんしてきじょうほうげん /電子的情報源/
でんしてきへんしゅう /電子的編集/
でんしてちょう /電子手帳/
でんしとうろん /電子討論/
でんしとしょかん /電子図書館/
でんしは /電子波/
でんしはいち /電子配置/
でんしばいたい /電子媒体/
でんしばいたいじょう /電子媒体上/
でんしばん /電子版/
でんしぴあの /電子ピアノ/
でんしぶっせい /電子物性/
でんしぶつり /電子物理/
でんしぶひん /電子部品/
でんしぶんぷ /電子分布/
でんしめーる /電子メール/
でんしめいる /電子メイル/
でんしもじ /電子文字/
でんしゃ /電車/伝者/
でんしゃいがい /電車以外/
でんしゃうんちん /電車運賃/
でんしゃえき /電車駅/
でんしゃか /電車化/
でんしゃきゅうこう /電車急行/
でんしゃく /電車区/
でんしゃせん /電車線/
でんしゃせんせつび /電車線設備/
でんしゃせんでんあつ /電車線電圧/
でんしゃせんよう /電車専用/
でんしゃだい /電車代/
でんしゃちん /電車賃/
でんしゃつうがく /電車通学/
でんしゃつうきん /電車通勤/
でんしゃつうきんしゃ /電車通勤者/
でんしゃとくていくかん /電車特定区間/
でんしゃとっきゅう /電車特急/
でんしゃない /電車内/
でんしゃへんせい /電車編成/
でんしゃみち /電車道/
でんしゃよう /電車用/
でんしゃりよう /電車利用/
でんしゆうびん /電子郵便/
でんしゆそう /電子輸送/
でんしょ /伝書/
でんしょう /伝承/
でんしょうきょく /伝承曲/
でんしょうしゃ /伝承者/
でんしょうじょじし /伝承叙事詩/
でんしょうぶんがく /伝承文学/
でんしょく /電飾/
でんしょくこう /電色光/
でんしょばと /伝書鳩/
でんしりょうし /電子量子/
でんしりれい /電子リレー/
でんしれいき /電子励起/
でんしれいきじょうたい /電子励起状態/
でんしれいきゃく /電子冷却/
でんしれんじ /電子レンジ/
でんしわおん /電子和音/
でんしん /電信/伝信/
でんしんき /電信機/
でんしんきゅう /電信級/
でんしんでんわ /電信電話/
でんしんでんわがいしゃ /電信電話会社/
でんしんばしら /電信柱/
でんじ /電磁/
でんじかい /電磁界/
でんじかんきょう /電磁環境/
でんじき /電磁気/
でんじきえんしゅう /電磁気演習/
でんじきがく /電磁気学/
でんじきりろん /電磁気理論/
でんじげんしょう /電磁現象/
でんじしき /電磁式/
でんじしゃく /電磁石/
でんじしょうがい /電磁障害/
でんじそうおん /電磁騒音/
でんじちょうり /電磁調理/
でんじちょうりき /電磁調理器/電磁調理機/
でんじてき /電磁的/
でんじてききろく /電磁的記録/
でんじは /電磁波/
でんじはこうがく /電磁波工学/
でんじはざんりゅう /電磁波残留/
でんじば /電磁場/
でんじほうていしき /電磁方程式/
でんじゅ /伝授/
でんじゆうどう /電磁誘導/
でんじょう /電情/
でんじょうつう /電情通/
でんじょうはいこう /電場配向/
でんじりきがく /電磁力学/
でんじりゅうたい /電磁流体/
でんじりょく /電磁力/
でんじん /電人/
でんすけ /電助/
でんせいかん /伝声管/
でんせつ /伝説/電設/
でんせつしゅう /伝説集/
でんせつじょう /伝説上/
でんせつてき /伝説的/
でんせつぶつ /伝説物/
でんせん /電線/伝染/電専/伝線/
でんせんおんど /電線音頭/
でんせんちちゅうか /電線地中化/
でんせんひき /電線引/
でんせんびょう /伝染病/
でんそう /伝送/電装/電送/
でんそうかいじょしゃ /電装解除車/
でんそうかんけい /電装関係/
でんそうけい /電装系/伝送系/
でんそうけいろ /伝送経路/
でんそうけん /電総研/電子技術総合研究所/伝送研/
でんそうしき /電送式/
でんそうしゅだん /伝送手段/
でんそうしょり /電送処理/
でんそうせいぎょ /伝送制御/
でんそうそくど /伝送速度/
でんそうたいいき /伝送帯域/
でんそうだい /電総大/
でんそうちゅう /伝送中/
でんそうとくせい /伝送特性/
でんそうないよう /伝送内容/
でんそうばいたい /伝送媒体/
でんそうひん /電装品/
でんそうぶ /電送部/
でんそうりょう /伝送量/
でんそうろ /伝送路/
でんそく /電束/
でんたく /電卓/
でんたくかたて /電卓片手/
でんたくがた /電卓型/
でんたくきのう /電卓機能/
でんたつ /伝達/
でんたつかんすう /伝達関数/
でんたつかんすうしょり /伝達関数処理/
でんたつかんすうもぎ /伝達関数模擬/
でんたつけい /伝達系/
でんたつけいしき /伝達形式/
でんたつけいろ /伝達経路/
でんたつけん /伝達権/
でんたつげーと /伝達ゲート/
でんたつこうりつ /伝達効率/
でんたつしゃ /伝達者/
でんたつしゅだん /伝達手段/
でんたつそしき /伝達組織/
でんたつとくせい /伝達特性/
でんたつぶっしつ /伝達物質/
でんたつほうしき /伝達方式/
でんたつりつ /伝達率/
でんたつろ /伝達路/
でんたん /電探/
でんだ /伝田/
でんだい /電大/
でんち /電池/
でんちく /電蓄/
でんちくどう /電池駆動/
でんちこうかん /電池交換/
でんちざんりょうけい /電池残量計/
でんちしき /電池式/
でんちしきでんげん /電池式電源/
でんちせいぞう /電池製造/
でんちだい /電池代/
でんちないぞう /電池内蔵/
でんちふよう /電池不要/
でんちぶぶん /電池部分/
でんちゅう /電柱/
でんちゅうけん /電中研/
でんちようりょう /電池容量/
でんつう /電通/
でんつうけん /電通研/
でんつうこくさいじょうほう /電通国際情報/
でんつうだい /電通大/電気通信大学/
でんつうだいいん /電通大院/
でんつうだいだいがくいん /電通大大学院/
でんてい /電停/
でんてつ /電鉄/
でんてついずもし /電鉄出雲市/
でんてつがいしゃ /電鉄会社/
でんてつひめじ /電鉄姫路/
でんてつりようきゃく /電鉄利用客/
でんでん /電電/電々/
でんでんこうしゃ /電電公社/
でんでんりつ /導電率/
でんとう /伝統/電灯/電燈/
でんとうげいのう /伝統芸能/
でんとうこう /伝統校/
でんとうこうげい /伝統工芸/
でんとうしゅうかん /伝統習慣/
でんとうせん /電灯線/
でんとうてき /伝統的/
でんとうてきしゅうかん /伝統的習慣/
でんとうてきせいど /伝統的制度/
でんとうりょうり /伝統料理/
でんどう /伝道/伝導/電動/殿堂/電導/伝動/
でんどうあわたてき /電動泡立て器/
でんどうき /電動機/
でんどうけい /伝導系/
でんどうし /伝道師/伝導師/
でんどうしき /電動式/
でんどうしゃ /電動車/
でんどうせい /電導性/
でんどうたい /伝導体/
でんどうはみがき /電動歯磨/
でんどうば /殿堂馬/
でんどうりつ /伝導率/
でんねつ /電熱/
でんねつかんけい /伝熱関係/
でんねつき /電熱器/
でんねつせん /電熱線/
でんのう /電脳/
でんのうか /電脳化/
でんのうかしゃかい /電脳化社会/
でんのうがい /電脳街/
でんのうがろう /電脳画廊/
でんのうくうかん /電脳空間/
でんのうくらぶ /電脳倶楽部/
でんのうけんちくがく /電脳建築学/
でんのうしゃかい /電脳社会/
でんのうじしょ /電脳辞書/
でんのうせんし /電脳戦士/
でんのうづくえ /電脳机/
でんのうとし /電脳都市/
でんのうどうぐばこ /電脳道具箱/
でんのうぶ /電脳部/
でんのうゆうえんち /電脳遊園地/
でんば /電場/
でんばた /田畑/
でんばほうれいしゅう /電波法令集/
でんぱ /電波/伝播/
でんぱかんすう /伝播関数/
でんぱかんりきょく /電波管理局/
でんぱきゅうしゅうざい /電波吸収材/
でんぱきゅうしゅうたい /電波吸収体/
でんぱぎょうせい /電波行政/
でんぱけい /電波系/
でんぱけいしき /電波形式/
でんぱけん /電波研/
でんぱこうせん /電波高専/
でんぱし /電波子/
でんぱしょうねん /電波少年/
でんぱしようりょう /電波使用料/
でんぱしんぶん /電波新聞/
でんぱしんぶんしゃ /電波新聞社/
でんぱじょうきょう /電波状況/
でんぱぜい /電波税/
でんぱた /田畑/
でんぱち /伝八/
でんぱつうしんがっか /電波通信学科/
でんぱてきあくじょうけん /電波的悪条件/
でんぱてんたい /電波天体/
でんぱてんもんがく /電波天文学/
でんぱでんそう /電波電送/電波伝送/
でんぱでんぱん /電波伝搬/
でんぱとう /電波塔/
でんぱどけい /電波時計/
でんぱばいたい /電波媒体/
でんぱぶつり /電波物理/
でんぱほう /電波法/
でんぱほうき /電波法規/
でんぱほうれいしょうろく /電波法令抄録/
でんぱぼうがい /電波妨害/
でんぱむきょうしつ /電波無響室/
でんぱりよう /電波利用/
でんぱりようぜい /電波利用税/
でんぱりようりょう /電波利用料/
でんぱん /伝播/伝搬/
でんぱんきこう /伝播機構/
でんぱんけい /伝搬系/
でんぱんけいろ /伝搬経路/
でんぱんこう /伝搬項/
でんぱんじかん /伝搬時間/
でんぱんじかんさ /伝搬時間差/
でんぱんじかんとう /伝搬時間等/
でんぱんそくど /伝搬速度/
でんぱんは /伝搬波/
でんぱんはせいぶん /伝搬波成分/
でんぱんろ /伝搬路/
でんぴょう /伝票/
でんぴょうしょり /伝票処理/
でんぶ /臀部/田麩/
でんぶん /伝聞/伝文/電文/
でんぶんけいしき /伝聞形式/
でんぶんしゃ /伝聞者/
でんぶんじょうほう /伝聞情報/
でんぶんちょう /伝聞調/
でんぶんてき /伝聞的/
でんぷん /澱粉/
でんぽ /田圃/
でんぽう /電報/伝法/
でんぽうきょく /電報局/
でんぽうぶん /電報文/
でんまーく /丁抹/
でんまちょう /伝馬町/
でんらい /伝来/
でんらん /電纜/
でんり /電離/
でんりく /電リク/
でんりけん /電離圏/
でんりしょうとつ /電離衝突/
でんりせい /電離性/
でんりそう /電離層/
でんりそんしつ /電離損失/
でんりど /電離度/
でんりばこ /電離箱/
でんりゅう /電流/
でんりゅういってい /電流一定/
でんりゅうけい /電流計/
でんりゅうげん /電流源/
でんりゅうせん /電留線/
でんりゅうち /電流値/
でんりゅうつうか /電流通過/
でんりゅうばくは /電流爆破/
でんりゅうへんか /電流変化/
でんりゅうみつど /電流密度/
でんりゅうようりょう /電流容量/
でんりゅうりょう /電流量/
でんりょく /電力/
でんりょくかんけい /電力関係/
でんりょくがいしゃ /電力会社/
でんりょくきょうきゅう /電力供給/
でんりょくきょうきゅうりょく /電力供給力/
でんりょくぎょうかい /電力業界/
でんりょくけいとう /電力系統/
でんりょくけいとうこうがく /電力系統工学/
でんりょくしせつ /電力施設/
でんりょくしょうひ /電力消費/
でんりょくしょうひりょう /電力消費量/
でんりょくじゅよう /電力需要/
でんりょくせん /電力線/
でんりょくちょぞうしゅだん /電力貯蔵手段/
でんりょくでんし /電力電子/
でんりょくはいせん /電力配線/
でんりょくへんかんき /電力変換器/
でんりょくもう /電力網/
でんりょくりょう /電力量/
でんれい /伝令/電鈴/
でんわ /電話/
でんわあんない /電話案内/
でんわいっぽん /電話一本/
でんわかいせん /電話回線/
でんわかいせんけいゆう /電話回線経由/
でんわかんれん /電話関連/
でんわがいしゃ /電話会社/
でんわき /電話機/電話器/
でんわきのう /電話機能/
でんわきほんたい /電話機本体/
でんわきゅう /電話級/
でんわきょく /電話局/
でんわぎょう /電話業/
でんわぐち /電話口/
でんわけんり /電話権利/
でんわこうかんきょく /電話交換局/
でんわしつ /電話室/
でんわしようけんり /電話使用権利/
でんわじじょう /電話事情/
でんわせん /電話線/
でんわせんけいゆ /電話線経由/
でんわそうだん /電話相談/
でんわたんまつ /電話端末/
でんわだい /電話代/電話台/
でんわだいせつやく /電話代節約/
でんわちゅう /電話中/
でんわちょう /電話帳/
でんわちょうさ /電話調査/
でんわとうひょう /電話投票/
でんわばん /電話番/
でんわばんごう /電話番号/
でんわばんごうあんない /電話番号案内/
でんわばんごうかくにん /電話番号確認/
でんわばんごうひょう /電話番号表/
でんわもう /電話網/
でんわや /電話屋/
でんわよう /電話用/
でんわよやく /電話予約/
でんわよやくうけつけ /電話予約受付/
でんわよやくかいし /電話予約開始/
でんわりょう /電話料/
でんわりょうきん /電話料金/
でんわりようしゃ /電話利用者/
でんわれんらく /電話連絡/
でんわれんらくもう /電話連絡網/
と /都/登/途/吐/土/戸/賭/渡/徒/杜/十/冨/砺/砥/鍍/富/斗/妬/人/塗/兎/図/菟/屠/堵/度/闘/兔/圖/汢/睹/礪/肚/荼/莵/蚪/蠹/蠧/覩/跿/砿/外/
とーたる /トータル/
とーれ /東レ/
とあみ /投網/
とい /問/戸井/土肥/樋/桶/
といあわせ /問い合わせ/問合/問合せ/
といあわせさき /問い合わせ先/
といき /吐息/
といし /砥石/礪/
といた /戸板/
といたがくえん /戸板学園/
といたじょし /戸板女子/
といたとうげ /戸板峠/
といつ /対子/
といとい /対々/
といみさき /都井岬/
といめん /対面/
といれ /トイレ/
といれっと /トイレット/
とう /等/当/頭/東/投/逃/透/闘/盗/冬/討/藤/答/董/陶/統/到/棟/灯/糖/筒/島/謄/騰/燈/鐙/祷/痘/党/蕩/塔/踏/豆/唐/湯/父/凍/倒/刀/淘/套/搭/涛/梼/桃/嶋/悼/宕/塘/韜/當/通/登/篤/読/道/納/十/任/橈/疼/盪/籐/撓/亠/偸/儻/剳/叨/夲/嶌/嶝/帑/幢/抖/掏/掉/搗/搨/擣/朸/档/檮/棹/棠/榻/橦/櫂/盜/濤/淌/滔/滕/溏/潼/蘯/磴/礑/竇/籘/綯/縢/纛/罩/荅/螳/蟷/讀/蹈/迯/酘/釖/閙/陦/鞜/鞳/饕/骰/鬥/鬪/黨/鼕/疾う/稻/撞/桶/稲/兜/桐/沓/諮/訊/逗/萄/樋/訪/吋/橙/
とう< /当/
とう> /当/
とうあ /東亜/東亞/
とうあがくえん /東亜学園/
とうあけんせつ /東亜建設/
とうあつ /等圧/
とうあつめん /等圧面/
とうあぺいんと /東亜ペイント/
とうあぼうしょく /東亜紡織/
とうあれんめい /東亜連盟/
とうあん /答案/
とうい /等位/東夷/糖衣/当為/陶猗/
とういいんかい /当委員会/
とういく /陶育/
とういじょう /糖衣錠/
とういす /籐椅子/
とういそうめん /等位相面/
とういち /東一/
とういつ /統一/
とういつおうじゃ /統一王者/
とういつか /統一化/
とういつかん /統一感/
とういつきかく /統一規格/
とういつきょうかい /統一教会/統一協会/
とういつけんかい /統一見解/
とういつげんご /統一言語/
とういつこうどう /統一行動/
とういつこっか /統一国家/
とういつしき /統一指揮/
とういつせい /統一性/
とういつせん /統一戦/
とういつたい /統一体/
とういつてき /統一的/
とういつてききじゅつ /統一的記述/
とういつば /統一場/
とういつばりろん /統一場理論/
とういつひょうき /統一表記/
とういつほうしき /統一方式/
とういつりろん /統一理論/
とういてき /等位的/
とういん /党員/桐蔭/登院/当院/頭韻/東員/
とういんがくえん /桐蔭学園/
とううつ /陶鬱/
とうえい /投影/東映/東永/東栄/
とうえいえいが /東映映画/
とうえいき /投影機/
とうえいぎじゅつ /投影技術/
とうえいけんさ /投影検査/
とうえいず /投影図/
とうえいぞう /投影像/
とうえいどうが /東映動画/
とうえいないよう /投影内容/
とうえいばん /東映版/
とうえいほう /投影法/
とうえいほうこう /投影方向/
とうえいめん /投影面/
とうえいりったいかく /投影立体角/
とうえん /遠縁/登園/
とうえんめい /陶淵明/
とうおう /東欧/陶泓/
とうおうけいゆう /東欧経由/
とうおうしゃかいたいせい /東欧社会体制/
とうおうしょこく /東欧諸国/
とうおん /唐音/等温/
とうおんせん /等温線/
とうおんたいき /等温大気/
とうか /等価/透過/十日/当課/10日/燈火/投下/１０日/灯火/等化/桃花/燈下/糖化/豆果/橙火/陶化/陶家/橙/
とうかい /東海/韜晦/倒壊/当会/倒潰/
とうかいいとう /東海以東/
とうかいいん /当会員/
とうかいおき /東海沖/
とうかいかーぼん /東海カーボン/
とうかいかんこう /東海観光/
とうかいがくせい /東海学生/
とうかいきせん /東海汽船/
とうかいぎんこう /東海銀行/
とうかいこうえい /東海公営/
とうかいこうぎょう /東海興業/東海鋼業/
とうかいし /東海市/
とうかいしぜんほどう /東海自然歩道/
とうかいしぶ /東海支部/
とうかいじしん /東海地震/
とうかいじどうしゃどう /東海自動車道/
とうかいじょしだいがく /東海女子大学/
とうかいだい /東海大/
とうかいだいかいはつこう /東海大開発工/
とうかいだいがく /東海大学/
とうかいだいがくまえ /東海大学前/
とうかいだいこうふ /東海大甲府/
とうかいだいさがみ /東海大相模/
とうかいだいひょう /東海代表/
とうかいだいぶつり /東海大物理/
とうかいだいよん /東海大四/
とうかいちいき /東海地域/
とうかいちく /東海地区/
とうかいちば /東海千葉/
とうかいちほう /東海地方/
とうかいどう /東海道/
とうかいどういち /東海道一/
とうかいどうかもつせん /東海道貨物線/
とうかいどうくかん /東海道区間/
とうかいどうぐち /東海道口/
とうかいどうしんかんせん /東海道新幹線/
とうかいどうせん /東海道線/
とうかいどうせんえんせん /東海道線沿線/
とうかいどうせんぞい /東海道線沿/
とうかいどうせんとつか /東海道線戸塚/
とうかいどうせんのぼり /東海道線上り/
とうかいどうせんふつう /東海道線不通/
とうかいどうほんせん /東海道本線/
とうかいぱるぷ /東海パルプ/
とうかいほうめん /東海方面/
とうかいむら /東海村/
とうかいりん /東海林/
とうかおん /透過音/
とうかかいてんけい /等価回転系/
とうかかいろ /等価回路/
とうかかく /当価格/等価格/
とうかかくそくど /等価角速度/
とうかかん /十日間/
とうかかんけい /等価関係/
とうかがた /透過型/
とうかがたでんけん /透過型電顕/
とうかき /等化器/
とうかく /当確/頭角/等角/倒閣/等覚/
とうかくしゃぞう /等角写像/
とうかくりつ /等確率/
とうかげん /桃花源/
とうかげんり /等価原理/
とうかこう /透過光/
とうかこうかん /等価交換/
とうかしほんかいしゅう /投下資本回収/
とうかじょうたい /等価状態/
とうかせい /等価性/透過性/
とうかせいはんてい /等価性判定/
とうかせいはんていもんだい /等価性判定問題/
とうかせる /等価セル/
とうかそうおん /等価騒音/
とうかそうおんれべる /等価騒音レベル/
とうかそくどうんどう /等加速度運動/
とうかそんしつ /透過損失/
とうかつ /統轄/統括/
とうかつしてん /統括支店/
とうかつじぎょうぶ /統括事業部/統轄事業部/
とうかつはん /統括班/
とうかつぶ /統括部/統轄部/
とうかつぶちょう /統括部長/
とうかつほんぶ /統括本部/
とうかてき /透過的/等価的/
とうかてん /等価点/
とうかへんかん /等価変換/
とうかまち /十日町/
とうかめん /透過面/
とうかりつ /透過率/
とうかりょく /透過力/
とうかん /投函/等閑/当館/
とうかんかく /等間隔/
とうかんけいゆ /東関経由/
とうかんし /等閑視/
とうが /陶瓦/冬芽/
とうがい /当該/頭外/等外/頭蓋/頭骸/
とうがいあいてかた /当該相手方/
とうがいえいが /当該映画/
とうがいえん /等外延/
とうがいかくごう /当該各号/
とうがいかしょ /当該箇所/
とうがいきじ /当該記事/
とうがいきゅうだん /当該球団/
とうがいきょだく /当該許諾/
とうがいくかん /当該区間/
とうがいけんきゅうかい /当該研究会/
とうがいこういしゃ /当該行為者/
とうがいこく /当該国/
とうがいこつ /頭蓋骨/
とうがいしちょうそん /当該市町村/
とうがいしゅっぱんけん /当該出版権/
とうがいしょうぎょうよう /当該商業用/
とうがいしょうひん /当該商品/
とうがいじつえん /当該実演/
とうがいじどう /当該児童/
とうがいだんたい /当該団体/
とうがいちいき /当該地域/
とうがいちょさくけん /当該著作権/
とうがいちょさくぶつ /当該著作物/
とうがいていい /頭外定位/
とうがいふくせいぶつ /当該複製物/
とうがっか /当学科/
とうがった /遠刈田/
とうがね /東金/
とうがらし /唐辛子/
とうがん /冬瓜/東岸/
とうき /冬季/冬期/頭記/投棄/登記/当期/当機/陶器/騰貴/投機/闘鬼/党旗/
とうきかいいんけん /冬季会員券/
とうきかく /当企画/
とうききゅうか /冬期休暇/
とうきぎむしゃ /登記義務者/
とうきげんてい /冬季限定/
とうきしょ /登記所/登記書/
とうきしんせい /登記申請/
とうきじ /当記事/
とうきすじ /投機筋/
とうきずみしょ /登記済書/
とうきせい /投機性/陶器製/
とうきち /藤吉/
とうきちろう /藤吉郎/
とうきはくぶつかん /陶器博物館/
とうきび /唐黍/
とうきぶつ /投棄物/
とうきへいさ /冬期閉鎖/冬季閉鎖/
とうきぼ /登記簿/
とうきぼとうほん /登記簿謄本/
とうきゅう /東急/投球/等級/
とうきゅういけがみせん /東急池上線/
とうきゅうえんせんじゅうみん /東急沿線住民/
とうきゅうおおいまちえき /東急大井町駅/
とうきゅうおおいまちせん /東急大井町線/
とうきゅうかいすう /投球回数/
とうきゅうかんこう /東急観光/
とうきゅうがわ /東急側/
とうきゅうけんせつ /東急建設/
とうきゅうさんげんじゃや /東急三軒茶屋/
とうきゅうしゃりょう /東急車両/
とうきゅうしんたまがわせん /東急新玉川線/
とうきゅうじ /投球時/
とうきゅうせん /東急線/
とうきゅうせんえんせん /東急線沿線/
とうきゅうたたません /東急田玉線/
とうきゅうでんてつ /東急電鉄/
とうきゅうとうよこ /東急東横/
とうきゅうとうよこせん /東急東横線/
とうきゅうとうよこてん /東急東横店/
とうきゅうどうさ /投球動作/
とうきゅうないよう /投球内容/
とうきゅうはんず /東急ハンズ/
とうきゅうひゃっかてん /東急百貨店/
とうきゅうひゃっかてんまえ /東急百貨店前/
とうきゅうふどうさん /東急不動産/
とうきゅうぶんかむら /東急文化村/
とうきゅうほてる /東急ホテル/
とうきゅうほんかん /東急本館/
とうきゅうほんてん /東急本店/
とうきゅうまえ /東急前/投球前/
とうきゅうめかません /東急目蒲線/
とうきょう /東京/東教/
とうきょうあきはばら /東京秋葉原/
とうきょういがい /東京以外/
とうきょういき /東京行/
とうきょういけぶくろ /東京池袋/
とうきょういち /東京一/
とうきょううえの /東京上野/
とうきょうえき /東京駅/
とうきょうえきだいまる /東京駅大丸/
とうきょうえきちか /東京駅地下/
とうきょうえきちゃく /東京駅着/
とうきょうえきみなみぐち /東京駅南口/
とうきょうおうふく /東京往復/
とうきょうおおさかかん /東京大阪間/
とうきょうおおつか /東京大塚/
とうきょうおんだい /東京音大/
とうきょうおんど /東京音頭/
とうきょうかい /当協会/
とうきょうかいかん /東京会舘/
とうきょうかいさい /東京開催/
とうきょうかいじょう /東京海上/東京会場/
とうきょうかいはつ /東京開発/
とうきょうかいらく /東京快楽/
とうきょうかいわい /東京界隈/
とうきょうかがくどうじん /東京化学同人/
とうきょうかせい /東京化成/
とうきょうかせいだい /東京家政大/
とうきょうかせいだいがく /東京家政大学/
とうきょうかながわ /東京神奈川/
とうきょうかんない /東京管内/
とうきょうが /東京画/
とうきょうがくげいだい /東京学芸大/
とうきょうがくげいだいがく /東京学芸大学/
とうきょうがす /東京ガス/東京瓦斯/
とうきょうがわ /東京側/
とうきょうきかんく /東京機関区/
とうきょうきそけん /東京基礎研/
とうきょうきゅうこう /東京急行/
とうきょうきゅうこうてつどう /東京急行電鉄/
とうきょうきゅうじょう /東京球場/
とうきょうきんこう /東京近郊/
とうきょうきんこうまで /東京近郊迄/
とうきょうきんぺん /東京近辺/
とうきょうきんむ /東京勤務/
とうきょうぎじゅつかいはつ /東京技術開発/
とうきょうぎんこう /東京銀行/
とうきょうくらぶ /東京倶楽部/
とうきょうぐち /東京口/
とうきょうけい /東京系/
とうきょうけいき /東京計器/
とうきょうけいばじょう /東京競馬場/
とうきょうけいゆ /東京経由/
とうきょうけいゆう /東京経由/
とうきょうけいれつ /東京系列/
とうきょうけん /東京圏/
とうきょうけんきゅうしょ /東京研究所/
とうきょうけんきゅうじょ /東京研究所/
とうきょうげいじゅつげきじょう /東京芸術劇場/
とうきょうこう /東京校/東京港/
とうきょうこうえん /東京公演/
とうきょうこうか /東京工科/
とうきょうこうかだい /東京工科大/
とうきょうこうかだいがく /東京工科大学/
とうきょうこうきょうがくだん /東京交響楽団/
とうきょうこうぎょうだい /東京工業大/
とうきょうこうぎょうだいがく /東京工業大学/
とうきょうこうげいだいがく /東京工芸大学/
とうきょうこうこう /東京高校/
とうきょうこうじょう /東京工場/
とうきょうこうせいねんきん /東京厚生年金/
とうきょうこうせん /東京高専/
とうきょうこうだい /東京工大/
とうきょうこくさい /東京国際/
とうきょうこくさいくうこう /東京国際空港/
とうきょうこくさいだいがく /東京国際大学/
とうきょうご /東京語/
とうきょうさいばん /東京裁判/
とうきょうざいじゅう /東京在住/
とうきょうしき /東京式/
とうきょうししゃ /東京支社/
とうきょうしじょう /東京市場/
とうきょうしたまち /東京下町/
とうきょうしば /東京芝/
とうきょうしぶ /東京支部/
とうきょうしゅうへん /東京周辺/
とうきょうしゅっしん /東京出身/
とうきょうしゅっちょう /東京出張/
とうきょうしょうがいとくべつ /東京障害特別/
とうきょうしょうせんだいがく /東京商船大学/
とうきょうしょせき /東京書籍/
とうきょうしょせきいんさつ /東京書籍印刷/
とうきょうしんがくだいがく /東京神学大学/
とうきょうしんじゅく /東京新宿/
とうきょうしんじゅくいき /東京新宿行/
とうきょうしんじゅくゆき /東京新宿行/
とうきょうしんぶん /東京新聞/
とうきょうしんぶんはい /東京新聞杯/
とうきょうじぎょうしょ /東京事業所/
とうきょうじむしょ /東京事務所/
とうきょうじょうほう /東京情報/
とうきょうじょがっかん /東京女学館/
とうきょうじょし /東京女子/
とうきょうじょしがくいん /東京女子学院/
とうきょうじょしだいがく /東京女子大学/
とうきょうじん /東京人/
とうきょうすいさんだい /東京水産大/
とうきょうすがお /東京菅生/
とうきょうすたいる /東京スタイル/
とうきょうせいかつ /東京生活/
とうきょうせいこう /東京製鋼/
とうきょうせいてつ /東京製鐵/
とうきょうせたがや /東京世田谷/
とうきょうせん /東京戦/
とうきょうぜいかん /東京税関/
とうきょうぜんたい /東京全体/
とうきょうそうげんしゃ /東京創元社/
とうきょうたいいくかん /東京体育館/
とうきょうたいかい /東京大会/
とうきょうたいざいじかん /東京滞在時間/
とうきょうたんけん /東京探検/
とうきょうたんていだん /東京探偵団/
とうきょうだい /東教大/東京大/
とうきょうだいがく /東京大学/
とうきょうだいがくしゅうし /東京大学修士/
とうきょうだいがくしゅっぱんかい /東京大学出版会/
とうきょうだいがくせい /東京大学生/
とうきょうだいがくせいきょう /東京大学生協/
とうきょうだいがくせいさん /東京大学生産/
とうきょうだいがくてんもん /東京大学天文/
とうきょうだいがくほんごう /東京大学本郷/
とうきょうだいがくものがたり /東京大学物語/
とうきょうだいがくりか /東京大学理科/
とうきょうだいくうしゅう /東京大空襲/
とうきょうちかえき /東京地下駅/
とうきょうちく /東京地区/
とうきょうちほう /東京地方/
とうきょうちほうじん /東京地方人/
とうきょうちゅうおうぶ /東京中央部/
とうきょうちゅうしん /東京中心/
とうきょうちゅうしんぶ /東京中心部/
とうきょうちゅうにち /東京中日/
とうきょうちょっこうびん /東京直行便/
とうきょうてあとる /東京テアトル/
とうきょうてっこう /東京鐵鋼/
とうきょうてん /東京店/
とうきょうてんもんだい /東京天文台/
とうきょうでんかん /東京電環/
とうきょうでんき /東京電気/
とうきょうでんきだい /東京電機大/
とうきょうでんきだいがく /東京電機大学/
とうきょうでんしせっけい /東京電子設計/
とうきょうでんりょく /東京電力/
とうきょうと /東京都/
とうきょうといたばしく /東京都板橋区/
とうきょうとうぼうしゃ /東京逃亡者/
とうきょうとおおたく /東京都太田区/東京都大田区/
とうきょうときたく /東京都北区/
とうきょうとくない /東京都区内/
とうきょうとくないはつ /東京都区内発/
とうきょうとくぶ /東京都区部/
とうきょうとこうつうきょく /東京都交通局/
とうきょうとこだいらし /東京都小平市/
とうきょうとざいじゅう /東京都在住/
とうきょうとしゅっしん /東京都出身/
とうきょうとしょ /東京図書/
とうきょうとしょうとうし /東京都昭島市/
とうきょうとしょくいん /東京都職員/
とうきょうとしんじゅくく /東京都新宿区/
とうきょうとすいどうきょく /東京都水道局/
とうきょうとすぎなみく /東京都杉並区/
とうきょうとちょう /東京都庁/
とうきょうとない /東京都内/
とうきょうとなかのく /東京都中野区/
とうきょうとねりまく /東京都練馬区/
とうきょうとひのし /東京都日野市/
とうきょうとふちゅうし /東京都府中市/
とうきょうとほうやし /東京都保谷市/
とうきょうとまちだし /東京都町田市/
とうきょうとみたかし /東京都三鷹市/
とうきょうとみなとくしば /東京都港区芝/
とうきょうとみん /東京都民/
とうきょうとめぐろく /東京都目黒区/
とうきょうとりつ /東京都立/
とうきょうとりつだい /東京都立大/
とうきょうとりつだいがく /東京都立大学/
とうきょうどう /東京堂/
とうきょうどうしゅっぱん /東京堂出版/
とうきょうなんせいぶ /東京南西部/
とうきょうにちにちしんぶん /東京日日新聞/
とうきょうにっさん /東京日産/
とうきょうのうぎょうだいがく /東京農業大学/
とうきょうのうこうだい /東京農工大/
とうきょうのうこうだいがく /東京農工大学/
とうきょうのりいれ /東京乗入/
とうきょうはちおうじ /東京八王子/
とうきょうはつ /東京発/
とうきょうはつそくたつ /東京発速達/
とうきょうはるみ /東京晴海/
とうきょうばん /東京版/
とうきょうびん /東京便/
とうきょうふきん /東京付近/
とうきょうぶんか /東京文化/
とうきょうぶんかかいかん /東京文化会館/東京文化会舘/
とうきょうぶんかけん /東京文化圏/
とうきょうぶんかこうこう /東京文化高校/
とうきょうへん /東京篇/
とうきょうべいえぬけーほーる /東京ベイＮＫホール/
とうきょうべん /東京弁/
とうきょうほうげん /東京方言/
とうきょうほうしき /東京方式/
とうきょうほうそう /東京放送/
とうきょうほうめん /東京方面/
とうきょうほか /東京他/
とうきょうほんしゃ /東京本社/
とうきょうみやげ /東京土産/
とうきょうめいか /東京銘菓/
とうきょうやまのてせんない /東京山手線内/
とうきょうゆうがたはつ /東京夕方発/
とうきょうゆうしゅん /東京優駿/
とうきょうよみうりきょじんぐん /東京読売巨人軍/
とうきょうりかだい /東京理科大/
とうきょうりかだいがく /東京理科大学/
とうきょうりっしょう /東京立正/
とうきょうりっしょうこうこう /東京立正高校/
とうきょうりゅう /東京流/
とうきょうりゅうつう /東京流通/
とうきょうわん /東京湾/
とうきょうわんいっしゅう /東京湾一周/
とうきょうわんがん /東京湾岸/
とうきょうわんぐち /東京湾口/
とうきょうわんない /東京湾内/
とうきょく /当局/
とうきょくしゃ /当局者/
とうきょり /等距離/
とうきりえき /当期利益/
とうきん /陶鈞/
とうきんせん /東金線/
とうぎ /討議/東儀/闘技/
とうぎじこう /討議事項/
とうぎじょう /闘技場/
とうぎゅう /闘牛/
とうぎゅうし /闘牛士/
とうぎょ /統御/
とうぎょう /陶業/
とうぎり /当限/
とうくつ /盗掘/
とうぐう /東宮/
とうけい /統計/東経/闘鶏/
とうけいえんざん /統計演算/
とうけいかいせき /統計解析/
とうけいかいせきよう /統計解析用/
とうけいがく /統計学/
とうけいがくてき /統計学的/
とうけいがくてきもでる /統計学的モデル/
とうけいけいさん /統計計算/
とうけいけっか /統計結果/
とうけいごさ /統計誤差/
とうけいしゅほう /統計手法/
とうけいしょり /統計処理/
とうけいしょりよう /統計処理用/
とうけいしりょう /統計資料/
とうけいじょうほう /統計情報/
とうけいすうがく /統計数学/
とうけいすうじ /統計数字/
とうけいせいど /統計精度/
とうけいち /統計値/
とうけいちょうさ /統計調査/
とうけいてき /統計的/
とうけいてきかいき /統計的回帰/
とうけいてきかんかく /統計的感覚/
とうけいてきけっか /統計的結果/
とうけいてきしゅほう /統計的手法/
とうけいてきしりょう /統計的資料/
とうけいてきすうち /統計的数値/
とうけいてきせいしつ /統計的性質/
とうけいてきていじょう /統計的定常/
とうけいてきぱたあん /統計的パターン/
とうけいてきぱたあんにんしき /統計的パターン認識/
とうけいてきぱたあんぶんるい /統計的パターン分類/
とうけいてきほうそく /統計的法則/
とうけいてきゆういせい /統計的有意性/
とうけいねつりきがく /統計熱力学/
とうけいひょう /統計表/
とうけいぶ /頭頸部/
とうけいぶつり /統計物理/
とうけいぶんせき /統計分析/
とうけいぶんぷ /統計分布/
とうけいぶんぷてきかてい /統計分布的仮定/
とうけいよう /統計用/
とうけいりきがく /統計力学/
とうけいりきがくけい /統計力学系/
とうけいりょう /統計量/
とうけつ /凍結/盗血/
とうけつじゅせいらん /凍結受精卵/
とうけつじょうきょう /凍結状況/
とうけつどうろ /凍結道路/
とうけつぼうし /凍結防止/
とうけつぼうしざい /凍結防止剤/
とうけつぼうしよう /凍結防止用/
とうけつまえ /凍結前/
とうけつろ /凍結路/
とうけん /当権/闘犬/刀剣/東建/陶甄/
とうけんきゅうかい /当研究会/
とうけんきゅうしつ /当研究室/
とうけんきゅうしょ /当研究所/
とうげ /峠/
とうげい /陶芸/
とうげいか /陶芸家/
とうげえき /峠駅/
とうげこう /登下校/
とうげこうじ /登下校時/
とうげこうちゅう /登下校中/
とうげごえ /峠越/
とうげぞく /峠族/
とうげつ /当月/
とうげつざん /当月残/
とうげつぶん /当月分/
とうげみち /峠道/
とうげん /桃源/
とうげんきょう /桃源郷/
とうこ /東子/
とうこう /投稿/等高/登校/投降/陶工/東光/東工/東耕/
とうこういしき /投稿意識/
とうこういと /投稿意図/
とうこういらい /投稿依頼/
とうこうかいすう /投稿回数/
とうこうかのう /投稿可能/
とうこうかんきょう /投稿環境/
とうこうがわ /投稿側/
とうこうきじ /投稿記事/
とうこうきじすう /投稿記事数/
とうこうきじちゅう /投稿記事中/
とうこうきてい /投稿規定/
とうこうきみつ /投稿機密/
とうこうきょひ /登校拒否/
とうこうきんし /投稿禁止/
とうこうけいけん /投稿経験/
とうこうけんき /東航研機/
とうこうげんこう /投稿原稿/
とうこうこうい /投稿行為/
とうこうご /投稿後/
とうこうさき /投稿先/
とうこうさくひん /投稿作品/
とうこうしかく /投稿資格/
とうこうしけん /投稿試験/
とうこうしつもん /投稿質問/
とうこうしめきり /投稿締切/
とうこうしゃ /投稿者/
とうこうしゃしん /投稿写真/
とうこうしゃじしん /投稿者自身/
とうこうしゃすう /投稿者数/
とうこうしゃぜんいん /投稿者全員/
とうこうしゃそうすう /投稿者総数/
とうこうしゃどうし /投稿者同士/
とうこうしゃべつ /投稿者別/
とうこうしゃほんにん /投稿者本人/
とうこうしゃめい /投稿者名/
とうこうじ /投稿時/登校時/
とうこうじかん /投稿時間/
とうこうじたい /投稿自体/
とうこうじっせき /投稿実績/
とうこうじてん /投稿時点/
とうこうじゅんび /投稿準備/
とうこうすう /投稿数/
とうこうずみ /投稿済/
とうこうせいげん /投稿制限/
とうこうせいげんとう /投稿制限等/
とうこうせきにん /投稿責任/
とうこうせん /等高線/
とうこうせんさくせい /等高線作成/
とうこうせんず /等高線図/
とうこうせんぱく /東工船舶/
とうこうそうすう /投稿総数/
とうこうたいど /投稿態度/
とうこうだい /東工大/東京工業大学/
とうこうだいこう /東工大高/
とうこうだいしゅうし /東工大修士/
とうこうだいじょうこう /東工大情工/
とうこうだいすうがっか /東工大数学科/
とうこうだいすうり /東工大数理/
とうこうだいないぶ /東工大内部/
とうこうだいながつだ /東工大長津田/
とうこうだいぶつり /東工大物理/
とうこうちゅう /投稿中/
とうこうちゅうどく /投稿中毒/
とうこうちょうさ /投稿調査/
とうこうてじゅん /投稿手順/
とうこうないよう /投稿内容/
とうこうなみ /投稿並/
とうこうにん /党公認/
とうこうはんい /投稿範囲/
とうこうばしょ /投稿場所/
とうこうひんど /投稿頻度/
とうこうぶん /投稿文/
とうこうへい /投降兵/
とうこうほうしき /投稿方式/
とうこうほうほう /投稿方法/
とうこうまえ /投稿前/
とうこうよう /投稿用/
とうこうりょう /投稿量/
とうこうりょうちょうさ /投稿量調査/
とうこうれき /投稿歴/
とうこうろんぶん /投稿論文/
とうこうろんぶんいがい /投稿論文以外/
とうこうろんぶんよう /投稿論文用/
とうこつ /橈骨/頭骨/
とうこん /闘魂/当今/
とうこんさんじゅうし /闘魂三銃士/
とうご /統語/頭語/東児/
とうごう /統合/等号/東郷/＝/投合/
とうごうあん /統合案/
とうごういちがたしき /統合一型式/
とうごうか /統合化/
とうごうかいはつかんきょう /統合開発環境/
とうごうかしゅほう /統合化手法/
とうごうかじょうほう /統合化情報/
とうごうかのうせい /統合可能性/
とうごうかんきょう /統合環境/
とうごうかんけい /等号関係/
とうごうがた /統合型/
とうごうき /統合器/
とうごうきょういく /統合教育/
とうごうきょういくもんだい /統合教育問題/
とうごうぎじゅつ /統合技術/
とうごうしっちょうしょう /統合失調症/
とうごうしょり /統合処理/
とうごうせい /等号性/統合性/
とうごうていあん /統合提案/
とうごうてき /統合的/
とうごうてきけんきゅう /統合的研究/
とうごうばん /統合版/
とうごうひかく /等号比較/
とうごうほう /統合法/
とうごうりつ /統合率/
とうごうろんり /等号論理/
とうごかいせき /統語解析/
とうごく /投獄/東国/
とうごけい /頭語系/
とうごじょう /統語上/
とうごてき /統語的/
とうごはんちゅう /統語範疇/
とうごろん /統語論/
とうさ /踏査/等差/
とうさい /搭載/登載/
とうさいいち /搭載位置/
とうさいうお /当歳魚/
とうさいかのう /搭載可能/
とうさいかん /搭載艦/
とうさいき /搭載機/
とうさいきすう /搭載機数/
とうさいぎょ /当歳魚/
とうさいしゃ /搭載車/
とうさいと /当サイト/
とうさいば /当歳馬/
とうさく /倒錯/盗作/東作/
とうさくしゃ /倒錯者/
とうさすうれつ /等差数列/
とうさつ /盗撮/
とうさま /父様/
とうさん /父さん/倒産/東讃/
とうさんご /倒産後/
とうさんさい /唐三彩/
とうさんほうしゅつひん /倒産放出品/
とうざ /当座/
とうざい /東西/
とうざいかくさ /東西格差/
とうざいこくない /東西国内/
とうざいごうりゅう /東西合流/
とうざいしゅうききょうかいじょうけん /東西周期境界条件/
とうざいじゆうつうろ /東西自由通路/
とうざいじょうもんじん /東西縄文人/
とうざいせん /東西線/
とうざいせんかいそく /東西線快速/
とうざいせんちょくつう /東西線直通/
とうざいせんない /東西線内/
とうざいせんりようしゃ /東西線利用者/
とうざいたいけつ /東西対決/
とうざいとういつ /東西統一/
とうざいなんぼく /東西南北/
とうざいべつけいとう /東西別系統/
とうざいほうこう /東西方向/
とうざいりょうよこづな /東西両横綱/
とうざしさん /当座資産;流動資産の一種。預金、受取手形、売掛金、有価証券の4つからなる/
とうざん /頭山/
とうし /投資/透視/凍死/闘士/闘志/骰子/祷祀/祷祠/
とうしか /投資家/
とうしがく /投資額/
とうしき /等式/
とうしきかくていせつ /等式確定節/
とうしきろんり /等式論理/
とうしけいかく /投資計画/
とうしこうか /投資効果/
とうししゃえい /透視射影/
とうししんたく /投資信託/
とうししんたくがいしゃ /投資信託会社/
とうしじゅつ /透視術/
とうしじょうほう /投資情報/
とうしたんい /投資単位/
とうしつ /等質/糖質/
とうしつせい /等質性/透湿性/
とうしつりょう /等質量/
とうしとう /投資等/
とうしど /透視度/
とうしはいぶん /投資配分/
とうしば /東芝/
とうしばえいぞう /東芝映像/
とうしばえいぞうけん /東芝映像研/
とうしばかんさいけん /東芝関西研/
とうしばきかい /東芝機械/
とうしばぐち /東芝口/
とうしばけい /東芝系/
とうしばけんきゅうかいはつ /東芝研究開発/
とうしばじゅんせい /東芝純正/
とうしばじょうほう /東芝情報/
とうしばせい /東芝製/
とうしばそうけん /東芝総研/
とうしばちゅうぶ /東芝中部/
とうしばちょう /東芝町/
とうしばなす /東芝那須/
とうしばばん /東芝版/
とうしばふちゅう /東芝府中/
とうしへんかん /透視変換/
とうしゃ /当社/投射/謄写/透写/謄寫/
とうしゃせいひん /当社製品/
とうしゃばん /謄写版/
とうしゃひ /当社比/
とうしゅ /投手/党首/当主/頭首/陶鋳/
とうしゅう /踏襲/東周/等終/
とうしゅきよう /投手起用/
とうしゅきようほう /投手起用法/
とうしゅじん /投手陣/
とうしゅせいめい /投手生命/
とうしゅせん /投手戦/
とうしゅぶもん /投手部門/
とうしゅめい /投手名/
とうしゅりょく /投手力/
とうしょ /当初/投書/当所/島嶼/当処/頭書/
とうしょう /闘将/東証/闘翔/凍傷/
とうしょうぐう /東照宮/
とうしょきたい /当初期待/
とうしょく /東食/
とうしょけいかく /当初計画/
とうしょばこ /投書箱/
とうしょよそう /当初予想/
とうしょよてい /当初予定/
とうしょらん /投書欄/
とうしりょく /透視力/
とうしれいしつ /塔指令室/
とうしん /等親/答申/頭身/等身/投身/東進/刀身/投信/東伸/闘神/
とうしんだい /等身大/
とうしんてつどう /東清鉄道/
とうじ /当時/答辞/統辞/湯治/冬至/田路/杜氏/東寺/藤治/刀自/当寺/当事/悼辞/統治/蕩児/田牛/等時/
とうじいん /等持院/
とうじき /陶磁器/
とうじこうこうせい /当時高校生/
とうじこく /当事国/
とうじさい /冬至祭/
とうじしゃ /当事者/
とうじしゃいしき /当時者意識/
とうじしゃかん /当事者間/当時者間/
とうじしゃてきかく /当事者適格/
とうじしょうがくせい /当時小学生/
とうじせい /等時性/
とうじちゅうがくせい /当時中学生/
とうじつ /当日/
とうじつあさ /当日朝/
とうじつうけつけ /当日受付/
とうじつかいじょう /当日会場/
とうじつかいじょうまえ /当日会場前/
とうじつけん /当日券/
とうじつけんまどぐち /当日券窓口/
とうじつさんか /当日参加/
とうじつしてい /当日指定/
とうじつじさん /当日持参/
とうじつじゅんび /当日準備/
とうじつちゅう /当日中/
とうじつとうちゃくぶん /当日到着分/
とうじつはっこう /当日発行/
とうじつはっぴょう /当日発表/
とうじつぶん /当日分/
とうじつりょうきん /当日料金/
とうじば /湯治場/
とうじぶんき /等時分岐/
とうじゅ /東樹/
とうじゅうろう /藤十郎/
とうじゆうめい /当時有名/
とうじょ /唐書/
とうじょう /登場/搭乗/東條/東条/棟上/東上/塔乗/頭状/東城/筒状/
とうじょういぜん /登場以前/
とうじょういらい /登場以来/
とうじょういん /搭乗員/
とうじょうか /頭状花/
とうじょうかいかん /東條會舘/
とうじょうかじょ /頭状花序/
とうじょうきゃく /搭乗客/
とうじょうきょり /搭乗距離/
とうじょうぐち /搭乗口/
とうじょうけん /搭乗券/
とうじょうご /登場後/
とうじょうしゃ /搭乗者/
とうじょうしゃほけん /搭乗者保険/
とうじょうじ /塔乗時/登場時/
とうじょうじっせき /搭乗実績/
とうじょうじんぶつ /登場人物/
とうじょうじんぶつたち /登場人物達/
とうじょうじんぶつめい /登場人物名/
とうじょうせいけん /東条政権/
とうじょうせん /東上線/
とうじょうせんけいとう /東上線系統/
とうじょうちょくぜん /搭乗直前/
とうじょうてつどう /東上鉄道/
とうじょうとうじ /登場当時/
とうじょうばめん /登場場面/
とうじょうばんぐみ /登場番組/
とうじょうび /塔乗日/搭乗日/
とうじょうびん /搭乗便/
とうじょうまえ /登場前/搭乗前/
とうじょうよてい /登場予定/搭乗予定/
とうじょうよていび /搭乗予定日/
とうじょうりつ /搭乗率/
とうじょたいだい /東女体大/
とうじりつ /透磁率/
とうじろう /藤治郎/
とうじん /蕩尽/陶人/唐人/
とうじんぼう /東尋坊/
とうすい /陶酔/統帥/
とうすいけん /統帥権/
とうすいだい /東水大/
とうすう /頭数/
とうすうけん /統計数理研究所/統数研/
とうすけ /藤輔/東介/
とうすぽ /東スポ/
とうせい /当世/統制/陶製/東征/籐製/倒生/
とうせいがくえん /東星学園/
とうせいは /統制派/
とうせいはいしゅ /倒生胚珠/
とうせいふう /当世風/
とうせいれんしょうたんしき /頭制連勝単式/
とうせき /投石/透析/等積/
とうせきかいし /透析開始/
とうせきかいろ /透析回路/
とうせきかんじゃ /透析患者/
とうせきき /透析機/
とうせきしつ /透析室/
とうせきじ /透析時/
とうせきそうち /透析装置/
とうせきちゅう /透析中/
とうせきどうにゅう /透析導入/
とうせきりょうほう /透析療法/
とうせん /当選/頭線/盗泉/陶染/東線/
とうせんかいすう /当選回数/
とうせんかくじつ /当選確実/
とうせんかくりつ /当選確率/当選確立/
とうせんけってい /当選決定/
とうせんご /当選後/
とうせんしゃ /当選者/
とうせんばんごう /当選番号/
とうぜん /当然/陶然/當然/当前/
とうぜんそんざい /当然存在/
とうそう /闘争/党争/逃走/鬪爭/
とうそうおん /唐宋音/
とうそうけいろ /逃走経路/
とうそうしん /闘争心/
とうそうせん /東早戦/
とうそうほうほう /闘争方法/逃走方法/
とうそく /等速/頭側/
とうそくうんどう /等速運動/
とうそくえんうんどう /等速円運動/
とうそくちょくせんうんどう /等速直線運動/
とうそくど /等速度/
とうそくどうんどう /等速度運動/
とうそしき /当組織/
とうそつ /統率/
とうそつせい /統率性/
とうそつりょく /統率力/
とうそん /藤村/
とうぞく /盗賊/
とうぞくかぎょう /盗賊家業/
とうぞくけい /盗賊系/
とうぞくだん /盗賊団/
とうぞくなど /盗賊等/
とうた /淘汰/
とうたく /董卓;後漢末期の群雄/
とうたつ /到達/
とうたつかのう /到達可能/
とうたつかのうせい /到達可能性/
とうたつきょり /到達距離/
とうたつけんかい /到達見解/
とうたつじかん /到達時間/
とうたつじかんさ /到達時間差/
とうたつせい /到達性/
とうたつてん /到達点/
とうたつど /到達度/
とうたつは /到達波/
とうたつはんい /到達範囲/
とうたつふかのう /到達不可能/
とうたつもくひょう /到達目標/
とうたん /東端/
とうだ /頭打/
とうだい /東大/燈台/東京大学/当代/灯台/
とうだいいかけん /東大医科研/
とうだいいがくぶ /東大医学部/
とうだいいん /東大院/
とうだいうら /東大裏/
とうだいおうか /東大応化/
とうだいかいぼう /東大解剖/
とうだいかいようけん /東大海洋研/
とうだいかがく /東大化学/
とうだいがく /当大学/
とうだいがくない /東大学内/
とうだいがわ /東大側/
とうだいきかい /東大機械/
とうだいきこう /東大気候/
とうだいきょういく /東大教育/
とうだいきょういくしんり /東大教育心理/
とうだいきょうじゅ /東大教授/
とうだいきょうよう /東大教養/
とうだいきょうようぶつり /東大教養物理/
とうだいきんぞく /東大金属/
とうだいきんぺん /東大近辺/
とうだいぐさもく /トウダイグサ目/Euphorbiales/
とうだいぐさもくぐん /トウダイグサ目群/
とうだいけいざい /東大経済/
とうだいけいざいがくぶ /東大経済学部/
とうだいけいすう /東大計数/
とうだいげんしりょく /東大原子力/
とうだいこう /東大工/
とうだいこうか /東大工化/
とうだいこうがくぶ /東大工学部/
とうだいこうきんぞく /東大工金属/
とうだいこうない /東大構内/
とうだいこまば /東大駒場/
とうだいごうかくしゃ /東大合格者/
とうだいごうかくしゃすう /東大合格者数/
とうだいざいりょう /東大材料/
とうだいしゅさい /東大主催/
とうだいしゅっしんしゃ /東大出身者/
とうだいしゅっぱんかい /東大出版会/
とうだいしんり /東大心理/
とうだいじ /東大寺/
とうだいじしんけん /東大地震研/
とうだいじょうか /東大情科/
とうだいじょうこう /東大情工/
とうだいじょうほう /東大情報/
とうだいじょうほうかがく /東大情報科学/
とうだいじょうほうこう /東大情報工/
とうだいじょうほうこうがく /東大情報工学/
とうだいじんぶん /東大人文/
とうだいすうがく /東大数学/
とうだいすうがっか /東大数学科/
とうだいすうりかがく /東大数理科学/
とうだいせい /東大生/
とうだいせいけん /東大生研/
とうだいせいさん /東大生産/
とうだいせいさんけん /東大生産研/
とうだいせいみつ /東大精密/
とうだいせんたんけん /東大先端研/
とうだいせんぱく /東大船舶/
とうだいせんぱくかいよう /東大船舶海洋/
とうだいぜんたい /東大全体/
とうだいそけん /東大素研/
とうだいだいけい /東大大型/
とうだいちぶつ /東大地物/
とうだいでんき /東大電気/
とうだいでんし /東大電子/
とうだいでんしこうがく /東大電子工学/
とうだいのう /東大農/
とうだいのうがくぶ /東大農学部/
とうだいびょういん /東大病院/
とうだいぶっせいけん /東大物性研/
とうだいぶつり /東大物理/
とうだいぶんがくぶ /東大文学部/
とうだいほう /東大法/
とうだいほうがくぶ /東大法学部/
とうだいほうめん /東大方面/
とうだいほんごう /東大本郷/
とうだいまえ /東大前/
とうだいめいよきょうじゅ /東大名誉教授/
とうだいやく /東大薬/
とうだいり /東大理/
とうだいりいち /東大理一/
とうだいりかにるい /東大理科二類/
とうだいりがくぶ /東大理学部/
とうだいりじょうほう /東大理情報/
とうだん /登壇/当団/
とうだんしゃ /登壇者/
とうだんたい /当団体/
とうち /当地/倒置/統治/等値/投地/
とうちか /統治下/
とうちぎょうれつ /倒置行列/
とうちく /東筑/
とうちこうい /統治行為/
とうちしき /倒置式/
とうちしゃ /統治者/
とうちせん /等値線/
とうちせんかんかく /等値線間隔/
とうちゃく /到着/
とうちゃくかくりつ /到着確率/
とうちゃくかんかく /到着間隔/
とうちゃくき /到着機/
とうちゃくきゃく /到着客/
とうちゃくご /到着後/
とうちゃくごすうにち /到着後数日/
とうちゃくしだい /到着次第/
とうちゃくじ /到着時/
とうちゃくじかん /到着時間/
とうちゃくじこく /到着時刻/
とうちゃくじこくじゅん /到着時刻順/
とうちゃくじゅん /到着順/
とうちゃくじゅんじょ /到着順序/
とうちゃくち /到着地/
とうちゃくとし /到着都市/
とうちゃくび /到着日/
とうちゃくぶん /到着分/
とうちゃくぶんまで /到着分迄/
とうちゃくりつ /到着率/
とうちゃくれっしゃかんかく /到着列車間隔/
とうちゃん /父ちゃん/
とうちゅう /頭注/陶鋳/
とうちゅうかそう /冬虫夏草/
とうちょう /盗聴/登頂/登庁/唐朝/頭頂/等張/
とうちょうき /盗聴器/
とうちょうじけん /盗聴事件/
とうちょうないよう /盗聴内容/
とうちょうぶ /頭頂部/
とうちょうぼうし /盗聴防止/
とうちょうぼうしきのう /盗聴防止機能/
とうちょうぼうしたいさく /盗聴防止対策/
とうちょく /当直/
とうつう /疼痛/東通/
とうつうさんぎょう /東通産業/
とうつき /当月/
とうてい /到底/
とうていふかのう /到底不可能/
とうていむり /到底無理/
とうてき /投擲/
とうてつ /透徹/饕餮/
とうてつこうぎょう /東鉄工業/
とうてん /読点/当店/東天/
とうてんこう /東天紅/
とうで /遠出/
とうでん /東電/
とうでんがわ /東電側/
とうとう /等々/東陶/到頭/陶陶/丁丁/東塔/偸盗/登登/滔/蕩蕩/トウトウ/鼕鼕/トウ鞳/疾う疾う/等等/滔々/滔滔/
とうとうきき /東陶機器/
とうとうみ /遠江/
とうとすいさん /東都水産/
とうとつ /唐突/頭突/
とうど /糖度/凍土/
とうどう /藤堂/
とうどく /東独/
とうどり /頭取/
とうない /頭内/党内/東内/
とうないだいぎし /党内代議士/
とうないていい /頭内定位/
とうなん /東南/盗難/
とうなんあじあ /東南アジア/
とうなんげき /盗難劇/
とうなんこうい /盗難行為/
とうなんしゃ /盗難車/
とうなんしょうめい /盗難証明/
とうなんたいさく /盗難対策/
とうなんたはつ /盗難多発/
とうなんとう /東南東/
とうなんほけん /盗難保険/
とうなんほしょう /盗難補償/
とうなんぼうし /盗難防止/
とうなんぼうしよう /盗難防止用/
とうにち /東日/
とうにゅう /投入/豆乳/刀入/
とうにゅうきんがく /投入金額/
とうにゅうぐち /投入口/
とうにゅうご /投入後/
とうにゅうじ /投入時/
とうにゅうひりつ /投入比率/
とうにゅうよてい /投入予定/
とうにゅうりょう /投入量/
とうにょう /糖尿/
とうにょうびょう /糖尿病/
とうにん /当人/
とうにんいがい /当人以外/
とうにんたち /当人達/
とうにんどうし /当人同士/
とうねん /当年/
とうの /統乃/遠野/東野/
とうのうだい /東農大/
とうのしょう /東庄/
とうは /党派/踏破/
とうはいごう /統廃合/
とうはく /東伯/
とうはつ /頭髪/
とうはてきにんげん /党派的人間/
とうはと /東鳩/
とうはば /等幅/
とうはん /東販/東版/登攀/登坂/東阪/
とうはんじ /登坂時/
とうばい /当倍/等倍/
とうばいとうりつぞう /当倍倒立像/
とうばく /掏摸/
とうばつ /倒伐/討伐/
とうばつたい /討伐隊/
とうばん /当番/登板/
とうばんかた /登板過多/
とうばんぐみ /当番組/
とうばんこう /当番校/
とうばんじゃん /豆板醤/豆瓣醤/
とうばんせい /当番制/
とうばんちょう /当番町/
とうひ /逃避/当否/等比/頭皮/討匪/
とうひかつどう /逃避活動/
とうひこう /討匪行/逃避行/逃飛行/
とうひこうどう /逃避行動/
とうひすうれつ /等比数列/
とうひちゅう /逃避中/
とうひょう /投票/
とうひょうかいし /投票開始/
とうひょうかんり /投票管理/
とうひょうかんりきかん /投票管理機関/
とうひょうがく /投票額/
とうひょうきかん /投票期間/
とうひょうきかんちゅう /投票期間中/
とうひょうきじ /投票記事/
とうひょうきそく /投票規則/
とうひょうきょひ /投票拒否/
とうひょうきょひうんどう /投票拒否運動/
とうひょうきんがく /投票金額/
とうひょうけいしき /投票形式/
とうひょうけっか /投票結果/
とうひょうけっかどおり /投票結果通り/
とうひょうけん /投票権/投票券/
とうひょうけんだい /投票券代/
とうひょうこうどう /投票行動/
とうひょうご /投票後/
とうひょうさ /投票差/
とうひょうさき /投票先/
とうひょうさぎょう /投票作業/
とうひょうさんかしゃ /投票参加者/
とうひょうさんせいは /投票賛成派/
とうひょうしかく /投票資格/
とうひょうしゃ /投票者/
とうひょうしゃあて /投票者宛/
とうひょうしゃいちらん /投票者一覧/
とうひょうしゃかくこじん /投票者各個人/
とうひょうしゃかん /投票者間/
とうひょうしゃすう /投票者数/
とうひょうしゃぜんいん /投票者全員/
とうひょうしゃめい /投票者名/
とうひょうしゅうけい /投票集計/
とうひょうしゅうりょう /投票終了/
とうひょうしゅうりょうご /投票終了後/
とうひょうしゅうりょうしゃ /投票終了者/
とうひょうしゅうりょうまえ /投票終了前/
とうひょうしゅだん /投票手段/
とうひょうしゅほう /投票手法/
とうひょうしょない /投票所内/
とうひょうじたい /投票自体/
とうひょうじっし /投票実施/
とうひょうじっしまえ /投票実施前/
とうひょうじてん /投票時点/
とうひょうじゅうし /投票重視/
とうひょうじゅんい /投票順位/
とうひょうじょ /投票所/
とうひょうじょう /投票場/
とうひょうじょうい /投票上位/
とうひょうじょういば /投票上位馬/
とうひょうじょうけん /投票条件/
とうひょうじょない /投票所内/
とうひょうすう /投票数/
とうひょうせい /投票制/
とうひょうせいど /投票制度/
とうひょうせいりつ /投票成立/
とうひょうせんしゅつ /投票選出/
とうひょうぜんすう /投票全数/
とうひょうぜんたい /投票全体/
とうひょうそうすう /投票総数/
とうひょうたいしょう /投票対象/
とうひょうちゅう /投票中/
とうひょうないよう /投票内容/
とうひょうないようじたい /投票内容自体/
とうひょうにんずう /投票人数/
とうひょうはっぴょう /投票発表/
とうひょうはんたい /投票反対/
とうひょうはんたいしゃ /投票反対者/
とうひょうはんたいは /投票反対派/
とうひょうはんたいひょう /投票反対票/
とうひょうばこ /投票箱/
とうひょうひょうかきじゅん /投票評価基準/
とうひょうび /投票日/
とうひょうびとうじつ /投票日当日/
とうひょうぶぶん /投票部分/
とうひょうぶん /投票分/
とうひょうほうしき /投票方式/
とうひょうほうほう /投票方法/
とうひょうむこう /投票無効/
とうひょうよう /投票用/
とうひょうようし /投票用紙/
とうひょうらん /投票欄/
とうひょうりつ /投票率/
とうひょうりゆう /投票理由/
とうひょうれい /投票例/
とうひん /盗品/
とうびょう /闘病/投錨/
とうびょうせいかつ /闘病生活/
とうびょうせいかつちゅう /闘病生活中/
とうふ /豆腐/■/
とうふく /東福/
とうふくじ /東福寺/
とうふくじえき /東福寺駅/
とうふくじのりかえ /東福寺乗換/
とうふなべ /豆腐鍋/
とうふや /豆腐屋/
とうぶ /東武/東部/頭部/当部/
とうぶあさくさ /東武浅草/
とうぶいせざきせん /東武伊勢崎線/
とうぶえんせん /東武沿線/
とうぶおんきょうでんたつかんすう /頭部音響伝達関数/
とうぶかいてん /頭部回転/
とうぶきょうだ /頭部強打/
とうぶきょく /当部局/
とうぶけいゆ /東武経由/
とうぶせんけいゆ /東武線経由/
とうぶせんけいゆう /東武線経由/
とうぶせんせん /東部戦線/
とうぶせんない /東武線内/
とうぶそうちゃく /頭部装着/
とうぶてつどう /東武鉄道/
とうぶでんしゃ /東武電車/
とうぶでんたつかんすう /頭部伝達関数/
とうぶとうじょうせん /東武東上線/
とうぶとっきゅう /東武特急/
とうぶどうぶつこうえん /東武動物公園/
とうぶなつじかん /東部夏時間/
とうぶにっこう /東武日光/
とうぶにっこうえき /東武日光駅/
とうぶにっこうせん /東武日光線/
とうぶのだ /東武野田/
とうぶはくぶつかん /東武博物館/
とうぶふきん /頭部付近/
とうぶほんしゃ /東武本社/
とうぶん /当分/等分/糖分/
とうぶんあんたい /当分安泰/
とうぶんかつ /等分割/
とうぶんさき /当分先/
とうぶんしょ /当文書/
とうぶんせん /等分線/
とうぶんぷ /等分布/
とうぶんへいきんりつ /等分平均率/
とうへい /東平/
とうへき /盗癖/東壁/
とうへん /等辺/陶片/
とうへんぼく /唐変木/
とうべつ /当別/
とうべん /答弁/
とうほう /当方/東邦/東宝/東方/桐朋/等方/投法/
とうほうあん /当法案/
とうほうおき /東方沖/
とうほうおんだい /桐朋音大/東邦音大/
とうほうがくえん /桐朋学園/
とうほうがくえんたんだい /東邦学園短大/
とうほうがくえんだいがく /桐朋学園大学/
とうほうがす /東邦瓦斯/
とうほうぎんこう /東邦銀行/
とうほうけい /東宝系/
とうほうけいげきじょう /東宝系劇場/
とうほうこう /等方向/
とうほうさんらん /等方散乱/
とうほうしてい /当方指定/
とうほうしんれき /東方新暦/
とうほうじじょう /当方事情/
とうほうじたく /当方自宅/
とうほうじょし /桐朋女子/
とうほうじょしこうこう /桐朋女子高校/
とうほうせい /等方性/
とうほうせいざい /等方性材/
とうほうせいめい /東邦生命/
とうほうだいがく /東邦大学/
とうほうだいがくいん /東邦大学院/
とうほうてき /等方的/
とうほうとくさつえいが /東宝特撮映画/
とうほうふたん /当方負担/
とうほうぶんぷ /等方分布/
とうほうれーよん /東邦レーヨン/
とうほく /東北/
とうほくかもつせん /東北貨物線/
とうほくかんない /東北管内/
とうほくがくいん /東北学院/
とうほくがくいんだい /東北学院大/
とうほくがくいんだいがく /東北学院大学/
とうほくぐんばつ /東北軍閥/
とうほくけいとう /東北系統/
とうほくけんない /東北圏内/
とうほくこうぎょうだい /東北工業大/
とうほくこうぎょうだいがく /東北工業大学/
とうほくさわ /東北沢/
とうほくししゃ /東北支社/
とうほくしてん /東北支店/
とうほくしぶ /東北支部/
とうほくしぶちょう /東北支部長/
とうほくしゅっしん /東北出身/
とうほくしょく /東北色/
とうほくしんかんせん /東北新幹線/
とうほくしんしゃ /東北新社/
とうほくじどうしゃどう /東北自動車道/
とうほくじん /東北人/
とうほくせん /東北線/東北戦/
とうほくせんうえのぐち /東北線上野口/
とうほくせんくかん /東北線区間/
とうほくせんけいゆ /東北線経由/
とうほくせんけいゆう /東北線経由/
とうほくたいかい /東北大会/
とうほくだい /東北大/東北大学/
とうほくだいがく /東北大学/東北大學/
とうほくだいがくこうがくぶ /東北大学工学部/
とうほくだいがくしんさ /東北大学審査/
とうほくだいがくせいきょう /東北大学生協/
とうほくだいがくつうけん /東北大学通研/
とうほくだいがくでんきつうしんけんきゅうじょ /東北大学電気通信研究所/
とうほくだいがくびょういん /東北大学病院/
とうほくだいがくぶんがくぶ /東北大学文学部/
とうほくだいこう /東北大工/
とうほくだいしゅっしん /東北大出身/
とうほくだいじょうほう /東北大情報/
とうほくだいすうがく /東北大数学/
とうほくだいせい /東北大生/
とうほくだいせいみつ /東北大精密/
とうほくちいき /東北地域/
とうほくちく /東北地区/
とうほくちほう /東北地方/
とうほくちほうけいゆ /東北地方経由/
とうほくでんりょく /東北電力/
とうほくとう /東北東/
とうほくとっきゅう /東北特急/
とうほくどう /東北道/
とうほくひりょう /東北肥料/
とうほくふくしだい /東北福祉大/
とうほくべん /東北弁/
とうほくほうげん /東北方言/
とうほくほうそう /東北放送/
とうほくほうめん /東北方面/
とうほくほんせん /東北本線/
とうほくやっかだい /東北薬科大/
とうほくよう /東北用/
とうほくりょこう /東北旅行/
とうほん /謄本/
とうほんせいそう /東奔西走/
とうほんにん /当本人/
とうぼう /逃亡/
とうぼうしゃ /逃亡者/
とうぼうはん /逃亡犯/
とうぼく /倒木/冬木/透木/
とうま /藤間/當麻/当間/当麻/討魔/冬馬/東馬/
とうみつ /糖蜜/
とうみつど /等密度/
とうみょう /灯明/燈明/
とうみん /冬眠/
とうみんじょうたい /冬眠状態/
とうみんまえ /冬眠前/
とうむら /東村/
とうめい /東名/透明/
とうめいかわさき /東名川崎/
とうめいかん /透明感/東名間/
とうめいこうそく /東名高速/
とうめいこうそくせん /東名高速線/
とうめいこうそくどうろ /東名高速道路/
とうめいごたんば /東名御殿場/
とうめいごてんば /東名御殿場/
とうめいし /透明視/
とうめいしずおか /東名静岡/
とうめいじどうしゃどう /東名自動車道/
とうめいせい /透明性/
とうめいたい /透明体/
とうめいど /透明度/
とうめいにんげん /透明人間/
とうめいはままつにし /東名浜松西/
とうめいはん /東名阪/
とうめいばす /東名バス/
とうめいばん /透明盤/
とうめいぶぶん /透明部分/
とうめいよこはま /東名横浜/
とうめいよこはまほうめん /東名横浜方面/
とうめん /当面/等面/
とうめんよう /等面葉/
とうもう /投網/
とうもろこし /玉蜀黍/
とうや /当夜/陶冶/洞爺/
とうやく /投薬/
とうやこ /洞爺湖/
とうやま /当山/遠山/當山/
とうやまはい /遠山灰/
とうゆ /灯油/
とうゆうし /投融資/
とうよ /投与/
とうよう /東洋/盗用/東陽/登用/当用/頭葉/投用/陶俑/陶遥/
とうよういがく /東洋医学/
とうよういがくしゃ /東洋医学者/
とうようえいわ /東洋英和/
とうようかがく /東洋化学/
とうようかん /東洋館/
とうようかんじ /当用漢字/
とうようかんじひょう /当用漢字表/
とうようがく /東洋学/
とうようけい /東洋系/
とうようけいざい /東洋経済/
とうようこうぎょう /東洋工業/
とうようこうそく /東葉高速/
とうようこうそくてつどう /東葉高速鉄道/
とうようこうはん /東洋鋼板/
とうようさんぎょう /東洋産業/
とうようさんそ /東洋酸素/
とうようし /東洋史/
とうようしそう /東洋思想/
とうようしそういっぱん /東洋思想一般/
とうようしゅぎ /東洋主義/
とうようじょうぞう /東洋醸造/
とうようじょうほう /東洋情報/
とうようじょし /東洋女子/
とうようじん /東洋人/
とうようすいさん /東洋水産/
とうようせいかん /東洋製罐/
とうようせいとう /東洋精糖/
とうようだいがく /東洋大学/
とうようだいひめじ /東洋大姫路/
とうようちょう /東陽町/
とうようてき /東洋的/
とうようてつがく /東洋哲学/
とうようでんき /東洋電機/東洋電器/
とうようでんきせいぞう /東洋電機製造/
とうようふう /東洋風/
とうようふとう /東洋埠頭/
とうようぶんこ /東洋文庫/
とうようぼうせき /東洋紡績/
とうよく /東翼/
とうよこ /東横/
とうよこがくえん /東横学園/
とうよこせん /東横線/
とうよこせんかいさつ /東横線改札/
とうよこせんきくなえき /東横線菊名駅/
とうよこせんしぶや /東横線渋谷/
とうよこせんしぶやえき /東横線渋谷駅/
とうよこせんぜんせん /東横線全線/
とうよこせんでぐち /東横線出口/
とうよこせんれんらく /東横線連絡/
とうよこてん /東横店/
とうよりょう /投与量/
とうらい /到来/
とうらいおん /到来音/
とうらいほうこう /到来方向/
とうらうどねす /等ラウドネス/
とうらく /当落/騰落/
とうらくせんじょう /当落線上/
とうり /桃李/党利/通/
とうりだい /東理大/
とうりつ /倒立/頭立/
とうりつしんし /倒立振子/
とうりつぞう /倒立像/
とうりつりょく /統率力/
とうりとく /等利得/
とうりふげん /桃李不言/
とうりゅう /刀流/逗留/闘竜/
とうりゅうもん /登竜門/
とうりょう /統領/等量/棟梁/投了/当量/頭領/
とうる /透/徹/
とうるい /盗塁/糖類/
とうるいおう /盗塁王/
とうるいすう /盗塁数/
とうれ /東レ/
とうれい /答礼/
とうろう /灯籠/燈篭/蟐螂/螳螂/蟷螂/燈籠/
とうろく /登録/
とうろくいらい /登録依頼/
とうろくうけつけ /登録受付/
とうろくうけつけぎょうむ /登録受付業務/
とうろくおんせい /登録音声/
とうろくかいじょ /登録解除/
とうろくかくにん /登録確認/
とうろくかんりょう /登録完了/
とうろくかんりょうば /登録完了馬/
とうろくきせい /登録規制/
とうろくきのう /登録機能/
とうろくきぼうしゃ /登録希望者/
とうろくぎむしゃ /登録義務者/
とうろくくぶん /登録区分/
とうろくけんすう /登録件数/
とうろくご /登録語/
とうろくごすう /登録語数/
とうろくさき /登録先/
とうろくさぎょう /登録作業/
とうろくしゃ /登録者/
とうろくしゃすう /登録者数/
とうろくしゃめい /登録者名/
とうろくしょ /登録書/
とうろくしょう /登録証/
とうろくしょうしょ /登録証書/
とうろくしょうひょう /登録商標/
とうろくしょひよう /登録諸費用/
とうろくしんせい /登録申請/
とうろくじ /登録時/
とうろくじしょめい /登録辞書名/
とうろくじどうしゃ /登録自動車/
とうろくじゅり /登録受理/
とうろくじょう /登録上/
とうろくじょうほう /登録情報/
とうろくすう /登録数/
とうろくずみ /登録済/
とうろくせいど /登録制度/
とうろくせんしゅ /登録選手/
とうろくそうさ /登録操作/
とうろくたんごすう /登録単語数/
とうろくちゅう /登録中/
とうろくてづづき /登録手続/
とうろくないよう /登録内容/
とうろくはがき /登録葉書/
とうろくば /登録馬/
とうろくばん /登録版/
とうろくばんごう /登録番号/
とうろくひ /登録費/
とうろくひょう /登録票/登録表/
とうろくび /登録日/
とうろくへんこう /登録変更/
とうろくほうほう /登録方法/
とうろくぼ /登録簿/
とうろくまえ /登録前/
とうろくまっしょう /登録抹消/
とうろくめい /登録名/
とうろくめいぼ /登録名簿/
とうろくもうしこみようし /登録申込用紙/
とうろくよう /登録用/
とうろくようきゅう /登録要求/
とうろくりつ /登録率/
とうろくりょう /登録料/
とうろくわしゃ /登録話者/
とうろくわしゃすう /登録話者数/
とうろん /討論/闘論/
とうろんかい /討論会/
とうろんけいしき /討論形式/
とうろんしゃ /討論者/
とうろんないよう /討論内容/
とうろんばんぐみ /討論番組/
とうわ /十和/東倭/東和/
とうわく /当惑/
とえ /十重/
とえい /都営/渡英/
とえいあさくさせん /都営浅草線/
とえいいがい /都営以外/
とえいうんちん /都営運賃/
とえいこうつう /都営交通/
とえいしゃ /都営車/
とえいしんじゅくせん /都営新宿線/
とえいせん /都営線/
とえいせんない /都営線内/
とえいちかてつ /都営地下鉄/
とえいちょくつうれっしゃ /都営直通列車/
とえいみたせん /都営三田線/
とえはたえ /十重二十重/
とお /十/遠/通/
とおあさ /遠浅/
とおい /遠井/
とおう /渡欧/
とおか /十日/10日/
とおかいち /十日市/
とおかった /遠刈田/
とおかまち /十日町/
とおがった /遠刈田/
とおしばんごう /通し番号/
とおだ /遠田/
とおちか /遠近/
とおで /遠出/
とおとうみ /遠江/
とおの /遠野/
とおのものがたり /遠野物語/
とおのり /遠乗り/
とおぼえ /遠吠/
とおま /遠間/
とおまき /遠巻き/
とおまわし /遠回し/
とおまわり /遠回り/
とおみ /遠見/
とおみづか /遠見塚/
とおめ /遠目/
とおやま /遠山/
とおやまざくら /遠山桜/
とおり /通り/通/
とおりぬけ /通り抜け/
とおりみち /通り道/
とおる /徹/透/亨/達/融/逹/理/享/
とおわ /十和/
とか /都下/渡河/徒過;むだに時をすごす/
とかい /都会/渡海/
とかいか /都会化/
とかいじん /都会人/
とかいそだち /都会育ち/
とかいてき /都会的/
とかいは /都会派/
とかげ /蜥蜴/石竜子/
とかしき /渡嘉敷/
とかち /十勝/
とかちがわ /十勝川/
とかちへいや /十勝平野/
とが /咎/科/利賀/
とがうち /戸河内/
とがき /ト書き/
とがくし /戸隠/
とがし /富樫/冨樫/
とがのお /栂尾/
とがみ /戸上/
とがめ /咎め/
とがり /戸狩/戸苅/
とがわ /戸川/外川/
とき /時/鴇/土岐/刻/朱鷺/常/鴾/時間/秋/鬨/辰/穐/
ときいらい /時以来/
ときえだ /時枝/
ときお /時男/時夫/時雄/登紀夫/時郎/時生/
ときおか /時岡/
ときおり /時折/時おり/
ときかた /解き方/
ときがわ /都幾川/
ときこ /時空子/登紀子/時子/
ときさだ /時貞/
ときじろう /時次郎/
ときた /時田/
ときだ /時田/
ときち /十吉/
ときつ /時津/
ときつかぜ /時津風/
ときとう /時任/
ときどき /時々/時時/
ときね /十樹根/
ときひろ /時広/
ときぶんかつ /時分割/
ときまさ /常正/
ときめく /時めく/
ときょう /都響/
ときょうそう /徒競走/
ときわ /常盤/常葉/常磐/
ときわざ /常盤座/
ときわじゅ /常盤樹/
ときわだい /常盤台/
ときわまつ /トキワ松/
ときわまつがくえん /トキワ松学園/
とぎ /都議/砥/伽/富来/
とぎかい /都議会/
とぎし /砥師/
とぎせん /都議選/
とぎつ /時津/
とぎばなし /伽話/伽噺/
とぎまち /富来町/
とぎれる /途切れ/
とぎん /都銀/
とく /特/得/徳/督/篤/禿/涜/匿/読/悳/慝/牘/犢/讀/黷/疾く/
とくい /得意/特異/
とくいきゃく /得意客/
とくいく /徳育/
とくいげ /得意気/
とくいげんしょう /特異現象/
とくいさき /得意先/
とくいせい /特異性/
とくいせきぶん /特異積分/
とくいたいしつ /特異体質/
とくいち /徳一/特異値/
とくいちぶんかい /特異値分解/
とくいてき /特異的/
とくいてきていこうりょく /特異的抵抗力/
とくいてん /特異点/
とくいび /特異日/
とくいふとくい /得意不得意/
とくいぶんや /得意分野/
とくいわざ /得意技/
とくえ /徳衛/
とくえい /徳衛/
とくお /徳雄/十九夫/徳男/
とくおか /徳岡/
とくか /特化/
とくがき /徳垣/
とくがわ /徳川/
とくがわいえやす /徳川家康/
とくがわき /徳川期/
とくがわけ /徳川家/
とくがわけいき /徳川慶喜/
とくがわしょうぐんけ /徳川将軍家/
とくがわぶげいちょう /徳川武芸帳/
とくがわよしのぶ /徳川慶喜/
とくき /特記/
とくきじこう /特記事項/
とくぎ /特技/
とくこ /徳子/
とくこう /特高/
とくさ /木賊/
とくさく /得策/
とくさつ /特撮/
とくさつえいが /特撮映画/
とくさつぎじゅつ /特撮技術/
とくさつしつ /特撮室/
とくさつもの /特撮物/
とくさつよう /特撮用/
とくさぶろう /徳三郎/
とくさわ /徳沢/
とくさん /特産/
とくさんひん /特産品/
とくさんぶつ /特産物/
とくし /得之/特使/
とくしか /篤志家/
とくしってん /得失点/
とくしってんさ /得失点差/
とくしつ /特質/得失/
とくしま /徳島/
とくしまかん /徳島間/
とくしまくうこう /徳島空港/
とくしまけん /徳島県/
とくしまけんきょう /徳島県境/
とくしません /徳島線/
とくしまだい /徳島大/
とくしまだいがく /徳島大学/
とくしまちく /徳島地区/
とくしゃ /特車/特赦/
とくしゃたい /特車隊/
とくしゅ /特殊/特種/
とくしゅう /特集/
とくしゅうきじ /特集記事/
とくしゅうごう /特集号/
とくしゅうちゅう /特集中/
とくしゅうばんぐみ /特集番組/
とくしゅか /特殊化/
とくしゅかい /特殊解/
とくしゅかいきゅう /特殊階級/
とくしゅかんすう /特殊関数/
とくしゅがっきゅう /特殊学級/
とくしゅがっこう /特殊学校/
とくしゅきごう /特殊記号/
とくしゅきのう /特殊機能/
とくしゅきんいつくかん /特殊均一区間/
とくしゅぎのう /特殊技能/
とくしゅくうかん /特殊空間/
とくしゅけい /特殊形/
とくしゅけいしき /特殊形式/
とくしゅけいじょう /特殊形状/
とくしゅこう /特殊鋼/
とくしゅこうか /特殊効果/
とくしゅこうぎ /特殊講義/
とくしゅこうぐ /特殊工具/
とくしゅこうげき /特殊攻撃/
とくしゅさいせい /特殊再生/
とくしゅさいのう /特殊才能/
とくしゅさつえい /特殊撮影/
とくしゅしゃりょう /特殊車両/
とくしゅしょうひん /特殊賞品/
とくしゅじじょう /特殊事情/
とくしゅじどうしゃ /特種自動車/
とくしゅじゅうだん /特殊銃弾/
とくしゅせい /特殊性/
とくしゅそうたいろん /特殊相対論/
とくしゅそうたいろんてき /特殊相対論的/
とくしゅのうりょく /特殊能力/
とくしゅはいれつ /特殊配列/
とくしゅぶき /特殊武器/
とくしゅぶたい /特殊部隊/
とくしゅぶつ /特殊物/
とくしゅぶらく /特殊部落/
とくしゅへいき /特殊兵器/
とくしゅへんすう /特殊変数/
とくしゅほうじん /特殊法人/
とくしゅほそう /特殊舗装/
とくしゅむせんぎし /特殊無線技師/
とくしゅもくてき /特殊目的/
とくしゅもじ /特殊文字/
とくしゅようと /特殊用途/特種用途/
とくしゅよくじょう /特殊浴場/
とくしゅれい /特殊例/
とくしゅろせん /特殊路線/
とくしょう /特賞/∃/特称/
とくしょく /特色/
とくしん /得心/特進/涜神/得真/
とくじ /徳治/徳次/徳地/
とくじゅ /特需/
とくじゅけいき /特需景気/
とくじょう /特上/
とくじろう /徳次郎/
とくせい /特性/特製/
とくせいきょくせん /特性曲線/
とくせいきょくせんぐん /特性曲線群/
とくせいさ /特性差/
とくせいすうち /特性数値/
とくせいち /特性値/
とくせいてき /特性的/
とくせいひょう /特性表/
とくせいひん /特製品/
とくせいびょう /特性病/
とくせいれっか /特性劣化/
とくせつ /特設/
とくせつかいじょう /特設会場/
とくせん /特選/特専/特撰/
とくせんがい /特選街/
とくせんたい /特戦隊/
とくせんたいたいいん /特戦隊隊員/
とくせんひょうじゅんまい /特選標準米/
とくせんひん /特選品/
とくそう /特捜/特装/
とくそうけいじ /特捜刑事/
とくそうたい /特捜隊/
とくそうぶ /特捜部/
とくそく /督促/
とくそくじょう /督促状/
とくぞう /徳蔵/
とくたいせい /特待生/
とくたろう /徳太郎/
とくだ /徳田/得田/
とくだい /特大/
とくだいごう /特大号/
とくだいじ /徳大寺/
とくだね /特種/
とくだん /特段/
とくちゅう /特注/
とくちゅうひん /特注品/
とくちょう /特徴/特長/
とくちょういちらん /特徴一覧/
とくちょうか /特徴化/
とくちょうかんすう /特徴関数/
とくちょうがくしゅう /特徴学習/
とくちょうくうかん /特徴空間/
とくちょうしゅうはすう /特徴周波数/
とくちょうちゅうしゅつ /特徴抽出/
とくちょうづけ /特徴付け/
とくちょうてき /特徴的/
とくちょうてききのう /特徴的機能/
とくちょうてん /特徴点/
とくちょうぶつ /特徴物/
とくちょうめん /特徴面/
とくちょうりょう /特徴量/
とくてい /特定/
とくていうんちん /特定運賃/
とくていうんちんくかん /特定運賃区間/
とくていか /特定化/
とくていかいせん /特定回線/
とくていきしゅじょう /特定機種上/
とくていきしゅべつ /特定機種別/
とくていきゅうだん /特定球団/
とくていくかん /特定区間/
とくていけいしきき /特定形式機/
とくていげんごけん /特定言語圏/
とくていこじん /特定個人/
とくていこじんよう /特定個人用/
とくていざいげん /特定財源/
とくていしゃりょう /特定車両/
とくていしょうすう /特定少数/
とくていしょうでんりょく /特定小電力/
とくていしょこくいがい /特定諸国以外/
とくていじんぶつ /特定人物/
とくていせつび /特定設備/
とくていせんく /特定線区/
とくていせんしゅ /特定選手/
とくていたすう /特定多数/
とくていち /特定値/
とくていちいき /特定地域/
とくていちいきいがい /特定地域以外/
とくていちいきがい /特定地域外/
とくていとうこうしゃ /特定投稿者/
とくていとくしない /特定都区市内/
とくていふのう /特定不能/
とくていぶぶん /特定部分/
とくていぶんや /特定分野/
とくていようと /特定用途/
とくていわしゃ /特定話者/
とくてん /得点/特典/特点/
とくてんおう /得点王/
とくてんき /得点機/
とくてんけいか /得点経過/
とくてんけいさん /得点計算/
とくてんけいさんしき /得点計算式/
とくてんけんだりつ /得点圏打率/
とくてんこうくうけん /特典航空券/
とくてんさ /得点差/
とくてんしゃ /得点者/
とくてんすう /得点数/
とくてんちゅう /得点中/
とくてんつき /得点付/
とくてんはいぶん /得点配分/
とくてんはんい /得点範囲/
とくてんばめん /得点場面/
とくてんひょう /得点表/特典表/
とくてんひりつ /得点比率/
とくてんぶんぷ /得点分布/
とくてんほうほう /得点方法/
とくてんりつ /得点率/
とくてんりょく /得点力/
とくてんりょこう /特典旅行/
とくでん /特電/
とくとう /特等/禿頭/
とくとうせき /特等席/
とくとみ /徳富/徳冨/
とくない /都区内/
とくないはつ /都区内発/
とくなが /徳永/
とくに /特に/
とくのう /篤農/
とくのうか /篤農家/
とくのしま /徳之島/
とくは /特派/
とくはい /特配/
とくはいん /特派員/
とくはいんほうこく /特派員報告/
とくはし /徳橋/
とくはつ /特発/
とくはつせい /特発性/
とくはら /徳原/
とくばい /特売/
とくばいび /特売日/
とくばいびかかく /特売日価格/
とくばん /特番/
とくひさ /徳久/
とくひつ /特筆/
とくひょう /得票/
とくひょうさ /得票差/
とくひょうじゅんい /得票順位/
とくひょうすう /得票数/
とくひょうりつ /得票率/
とくひら /徳平/
とくひろ /徳弘/
とくへい /徳平/
とくべつ /特別/
とくべつあつかい /特別扱い/
とくべつうんちん /特別運賃/
とくべつえんそうかい /特別演奏会/
とくべつか /特別化/
とくべつかいいん /特別会員/
とくべつかいけい /特別会計/
とくべつかいじょう /特別会場/
とくべつかいそく /特別快速/
とくべつかいはつしつ /特別開発室/
とくべつかいひ /特別会費/
とくべつかかく /特別価格/
とくべつかさんうんちん /特別加算運賃/
とくべつかてん /特別加点/
とくべつかんらんせき /特別観覧席/
とくべつき /特別機/
とくべつきかく /特別企画/
とくべつきごう /特別記号/
とくべつきてい /特別規定/
とくべつきゅうか /特別休暇/
とくべつきゅうこう /特別急行/
とくべつきゅうこうれっしゃ /特別急行列車/
とくべつきょうそう /特別競争/特別競走/
とくべつきょうてい /特別協定/
とくべつくかん /特別区間/
とくべつけんきゅう /特別研究/
とくべつけんきゅういん /特別研究員/
とくべつけんきゅうがくせい /特別研究学生/
とくべつけんきゅうしつ /特別研究室/
とくべつこうえん /特別講演/
とくべつこうえんかい /特別講演会/
とくべつこうぎ /特別講義/
とくべつこうとうけいさつ /特別高等警察/
とくべつこうろうしょう /特別功労賞/
とくべつこんなん /特別困難/
とくべつごう /特別号/
とくべつさんか /特別参加/
とくべつし /特別視/
とくべつしつ /特別室/
とくべつしてい /特別指定/
とくべつしていせき /特別指定席/
とくべつしゃりょう /特別車両/
とくべつしゅつえん /特別出演/
とくべつしょう /特別賞/
とくべつしょく /特別職/特別食/特別色/
とくべつしょち /特別処置/
とくべつしようしゃ /特別仕様車/
とくべつじあい /特別試合/
とくべつすいしんけんきゅう /特別推進研究/
とくべつせい /特別製/
とくべつせき /特別席/
とくべつせつびひ /特別設備費/
とくべつせん /特別戦/
とくべつせんしつ /特別船室/
とくべつせんばつ /特別選抜/
とくべつそちほう /特別措置法/
とくべつそんしつ /特別損失/
とくべつたいぐう /特別待遇/
とくべつちゅうかんかいさつ /特別中間改札/
とくべつちゅうもん /特別注文/
とくべつてん /特別展/
とくべつとそう /特別塗装/
とくべつはんぷ /特別頒布/
とくべつばん /特別盤/特別版/
とくべつばんぐみ /特別番組/
とくべつふろく /特別付録/
とくべつへん /特別編/
とくべつへんしゅう /特別編集/
とくべつほじゅうけん /特別補充券/
とくべつようしえんぐみ /特別養子縁組/
とくべつりえき /特別利益/
とくべつりょうきん /特別料金/
とくべつりょうきんふよう /特別料金不要/
とくべつりょうり /特別料理/
とくべつれいかい /特別例会/
とくべつわく /特別枠/
とくべつわりびき /特別割引/
とくほう /特報/
とくほん /読本/
とくま /徳間/
とくましょてん /徳間書店/
とくまぶんこ /徳間文庫/
とくまる /徳丸/得丸/
とくみ /徳見/徳美/
とくみち /篤道/
とくみつ /徳光/
とくむ /特務/
とくむかん /特務艦/
とくむきかん /特務機関/
とくむしかん /特務士官/
とくむそうちょう /特務曹長/
とくめい /匿名/特命/
とくめいか /匿名化/
とくめいきぼう /匿名希望/
とくめいせい /匿名性/
とくめいせいど /匿名制度/
とくめいとうこう /匿名投稿/
とくめいとうしょ /匿名投書/
とくめいほうしき /匿名方式/
とくもく /徳目/
とくもと /徳元/徳本/
とくもり /特盛/
とくやく /特約/
とくやくてん /特約店/
とくやす /徳康/
とくやま /徳山/
とくやまこうせん /徳山高専/
とくやまし /徳山市/
とくやまそーだ /徳山曹達/
とくゆう /特有/
とくゆき /得之/徳行/
とくよう /徳用/特用/
とくようひん /徳用品/
とくようぶくろ /徳用袋/
とくら /戸倉/都倉/十倉/
とくりつ /特立/
とくりつちゅうおうたいざ /特立中央胎座/
とくれい /特例/督励/
とくれいくかん /特例区間/
とくれいてき /特例的/
とくろん /特論/
とくわり /特割/
とぐち /戸口/
とぐら /戸倉/
とけ /土気/
とけい /時計/
とけいかん /時計館/
とけいきのう /時計機能/
とけいしょうぶ /時計勝負/
とけいじかけ /時計仕掛/
とけいじぎょうほんぶ /時計事業本部/
とけいぜんたい /時計全体/
とけいだい /時計台/
とけいつき /時計付/
とけいてん /時計店/
とけいとう /時計塔/
とけいないぞう /時計内蔵/
とけいないぞうがた /時計内蔵型/
とけいほうこう /時計方向/
とけつ /吐血/
とけん /都県/覩見/
とけんどう /都県道/
とげ /刺/棘/朿/
とげつきょうふきん /渡月橋付近/
とげとげしい /刺々しい/
とこ /常/床/
とこう /渡航/都甲/
とこうさき /渡航先/
とこうしゃ /渡航者/
とこうじょうほう /渡航情報/
とこうひ /渡航費/
とこし /戸越/
とこしえき /戸越駅/
とこしぎんざ /戸越銀座/
とこしこうえん /戸越公園/
とこなつ /常夏/
とこなめ /常滑/
とこなめせん /常滑線/
とこのま /床の間/床ノ間/
とこばしら /床柱/
とこや /床屋/
とこやだんぎ /床屋談義/
とこやま /床山/
とこよ /常世/
ところ /所/処/處/
ところが /処が/
ところざわ /所沢/
ところざわし /所沢市/
ところざわしざいじゅう /所沢市在住/
ところどころ /所々/
とごう /戸郷/
とさ /土佐/
とさけん /土佐犬/
とさしみず /土佐清水/
とさず /土佐酢/
とさっこ /土佐っ子/
とさつ /屠殺/
とさでんてつ /土佐電鉄/
とさやま /土佐山/
とさやまだ /土佐山田/
とさんせん /土讃線/
とざき /戸崎/
とざと /外里/
とざま /外様/
とざまだいみょう /外様大名/
とざわ /戸沢/
とざん /登山/
とざんあんない /登山案内/
とざんかいし /登山開始/
とざんき /登山記/
とざんきち /登山基地/
とざんきゃく /登山客/
とざんきょうそう /登山競争/
とざんぐち /登山口/
とざんぐつ /登山靴/
とざんしゃ /登山者/
とざんそうび /登山装備/
とざんてつどう /登山鉄道/
とざんでんしゃ /登山電車/
とざんどう /登山道/
とし /年/歳/都市/利/俊/寿/捷/敏/稔/暁/世/繁/壽/祀/夙/駿/肇/
としあき /利明/寿明/敏明/俊明/俊彰/俊昭/敏昭/利昭/俊朗/敏彰/繁明/敏朗/聡明/俊章/年昭/壽/
としあけ /年明け/
としうえ /年上/
としえ /とし恵/俊恵/利絵/季衣/敏江/敏枝/
としお /利夫/敏夫/敏男/寿男/俊男/俊夫/俊雄/敏雄/利男/利雄/寿夫/登志夫/利生/俊朗/稔雄/寿雄/利朗/淑夫/敏郎/
としおとこ /年男/
としおんな /年女/
としか /都市化/
としかさ /年嵩/
としかず /寿一/寿和/俊一/利一/敏一/俊和/利和/敏和/
としかつ /利勝/敏克/
としかん /都市間/
としかんいどう /都市間移動/
としかんきょう /都市環境/
としかんてつどう /都市間鉄道/
としかんゆそう /都市間輸送/
としかんれんらく /都市間連絡/
としがい /都市外/
としがた /都市型/
としき /俊樹/敏生/歳樹/敏樹/年樹/稔貴/戸敷/年紀/
としきんこう /都市近郊/
としきんこうちいき /都市近郊地域/
としぎんこう /都市銀行/
としくに /年邦/
としけいかく /都市計画/
としけいかくどうろ /都市計画道路/
としけん /都市圏/
としこ /俊子/敏子/利子/とし子/年子/トシ子/寿子/淑子/登志子/
としこうがく /都市工学/
としこうそく /都市高速/
としこうぞう /都市構造/
としこうつう /都市交通/
としこうつうけん /都市交通研/
としこうつうねんぽう /都市交通年報/
としこうぼうせん /都市攻防戦/
としこし /年越し/
としご /年子/
としごいのまつり /祈年祭/
としごろ /年頃/
とししげ /利重/
としした /年下/
とししゅうゆう /都市周遊/
としじ /俊治/
としそうおう /年相応/
としぞう /俊三/
としたいこう /都市対抗/
としたいこうやきゅう /都市対抗野球/
としたか /敏隆/利孝/俊孝/
としただ /利忠/俊匡/
としたに /利谷/
としちず /都市地図/
としつき /年月/
としつぐ /壽二/俊嗣/敏嗣/
としてつどう /都市鉄道/
としてる /敏輝/
としない /都市内/
としなお /利直/俊直/
としなみ /年波/
としなり /利成/
としのこう /年の功/
としのころ /年の頃/
としのせ /歳の瀬/年の瀬/
としのぶ /利伸/敏伸/利信/
としのり /敏憲/年紀/利則/寿則/利典/俊則/敏規/敏則/俊範/聡徳/
としはる /季栄/利治/俊治/敏治/寿晴/
としひこ /敏彦/俊彦/捷彦/利彦/年彦/寿彦/稔彦/壽彦/
としひさ /俊久/敏寿/利久/
としひで /俊秀/俊英/
としひと /敏仁/
としひろ /利博/俊宏/敏宏/敏弘/利広/俊裕/敏裕/利弘/利浩/俊弘/俊博/敏啓/歳弘/利宏/俊浩/
としふさ /俊房/
としふみ /敏文/年史/俊史/俊文/
としぶ /都市部/
としぶちず /都市部地図/
としぶんか /都市文化/
としほど /年程/
としま /豊島/年増/利島/戸島/十島/戸嶋/
としまえん /豊島園/
としまおか /豊島岡/
としまおかじょがくえん /豊島岡女学園/
としまおかじょしがくえん /豊島岡女子学園/
としまく /豊島区/
としまくみなみおおつか /豊島区南大塚/
としまさ /敏正/
としみ /年美/都志見/寿実/敏巳/利美/
としみち /季道/利通/利道/俊道/
としみつ /利光/敏光/俊光/
としめい /都市名/
としゃ /吐瀉/
としゃぶつ /吐瀉物/
としや /俊哉/俊弥/俊也/敏也/利也/敏哉/
としやす /利泰/敏康/敏靖/
としゅ /徒手/
としゅくうけん /徒手空拳/
としゅつ /吐出/
としゅつりょう /吐出量/
としゅつりょうぶそく /吐出量不足/
としゆき /利之/俊幸/敏行/俊之/利行/俊行/敏幸/敏之/利幸/歳之/
としょ /図書/
としょかかり /図書掛/
としょかん /図書館/
としょかんいん /図書館員/
としょかんがく /図書館学/
としょかんしりょう /図書館資料/
としょかんじょうほうがく /図書館情報学/
としょかんじょうほうだい /図書館情報大/
としょかんじょうほうだいがく /図書館情報大学/
としょかんだい /図書館大/
としょかんまえ /図書館前/
としょかんれんじょうほう /図書関連情報/
としょきょく /図書局/
としょく /塗色/
としょけん /図書券/
としょけんさく /図書検索/
としょしつ /図書室/
としょしついがい /図書室以外/
としょしゅっぱん /図書出版/
としょしりょうしつ /図書資料室/
としょしんぶん /図書新聞/
としょひ /図書費/
としょぶもん /図書部門/
としょぶんかん /図書分館/
としよ /敏代/
としより /年寄/年寄り/
としよりかぶ /年寄株/
としろう /俊朗/利郎/俊郎/敏郎/
としん /都心/
としんかん /都心間/
としんがわ /都心側/
としんじゅんかんせん /都心循環線/
としんじょうくう /都心上空/
としんち /都心地/
としんちく /都心地区/
としんない /都心内/
としんぶ /都心部/
としんぶくかん /都心部区間/
としんぶぶん /都心部分/
としんほうこう /都心方向/
とじ /刀自/綴/
とじかっこ /閉括弧/
とじき /戸敷/
とじこみ /綴じ込み/
とじま /戸島/
とじまり /戸締り/
とじょう /途上/登城/図情/
とじょうこく /途上国/
とじょうだい /図情大/
とす /鳥栖/
とすし /鳥栖市/
とせ /歳/
とせい /渡世/
とせいにん /渡世人/
とぜい /都税/
とぜつ /途絶/杜絶/
とぜんいき /都全域/
とそ /屠蘇/
とそう /塗装/
とそうかんりょうご /塗装完了後/
とそうき /塗装機/
とそうご /塗装後/
とそうしじ /塗装指示/
とそうずみ /塗装済/
とそうせつめい /塗装説明/
とそうはば /塗装幅/
とそうぶ /塗装部/
とそうへんこう /塗装変更/
とそうへんこうちゅう /塗装変更中/
とそうまえ /塗装前/
とそうめん /塗装面/
とそうめんせき /塗装面積/
とたん /途端/塗炭/
とだ /戸田/
とだい /東京都立大学/
とだか /戸高/
とだし /戸田市/
とだせいじ /戸田誠司/
とだな /戸棚/
とち /土地/栃/橡/杤/柮/
とちお /栃尾/
とちかがみもく /トチカガミ目/Hydrocharitales/
とちかわ /橡川/
とちかん /土地勘/
とちがら /土地柄/
とちぎ /栃木/朽木/
とちぎけん /栃木県/
とちぎけんじん /栃木県人/
とちぎけんない /栃木県内/
とちぎし /栃木市/
とちぎしゅっしん /栃木出身/
とちぎょうせい /土地行政/
とちしゅうよう /土地収用/
とちしょとくほう /土地所得法/
とちじ /都知事/
とちじせん /都知事選/
とちたいさく /土地対策/
とちだい /土地代/
とちない /栃内/
とちのわか /栃乃和歌/
とちばいしゅう /土地買収/
とちひょうかしょ /土地評価書/
とちぶんじょうしき /土地分譲式/
とちほゆうぜい /土地保有税/
とちほんいせい /土地本位制/
とちぼっしゅう /土地没収/
とちもと /栃本/
とちもんだい /土地問題/
とちゅう /途中/
とちゅうえき /途中駅/
とちゅうえきじょうこう /途中駅乗降/
とちゅうえきそうご /途中駅相互/
とちゅうえきそうごかん /途中駅相互間/
とちゅうきけん /途中棄権/
とちゅうきゅうえん /途中休演/
とちゅうきゅうけい /途中休憩/
とちゅうけいか /途中経過/
とちゅうけいゆ /途中経由/
とちゅうけいろ /途中経路/
とちゅうげしゃ /途中下車/
とちゅうげしゃいん /途中下車印/
とちゅうこうき /途中降機/
とちゅうこうたい /途中交代/
とちゅうさんか /途中参加/
とちゅうしゅつじょう /途中出場/
とちゅうしょうりゃく /途中省略/
とちゅうず /途中図/
とちゅうたいじょう /途中退場/
とちゅうだんかい /途中段階/
とちゅうちゃ /杜仲茶/
とちゅうていしゃ /途中停車/
とちゅうりゃく /途中略/
とちゅうりようしゃ /途中利用者/
とちょう /都庁/
とちょういてん /都庁移転/
とちりようけいかく /土地利用計画/
とちりようこうりつ /土地利用効率/
とちわかじだい /栃若時代/
とっか /特化/特価/
とっかい /特快/特解/
とっかてき /特化的/
とっかひん /特価品/
とっかん /突貫/吶喊/
とっかんこうじ /突貫工事/
とっき /特記/突起/特器/特機/
とっきじこう /特記事項/
とっきたい /突起体/
とっきぶつ /突起物/
とっきゅう /特急/特級/
とっきゅういがい /特急以外/
とっきゅうか /特急化/
とっきゅうがた /特急型/
とっきゅうがたしゃりょう /特急型車両/
とっきゅうがたでんしゃ /特急型電車/
とっきゅうけん /特急券/
とっきゅうしゃ /特急車/
とっきゅうしゃりょう /特急車両/
とっきゅうしゅ /特級酒/
とっきゅうしょく /特急色/
とっきゅうたいひ /特急退避/
とっきゅうつうかまち /特急通過待ち/
とっきゅうでんしゃ /特急電車/
とっきゅうでんしゃか /特急電車化/
とっきゅうはくちょう /特急白鳥/
とっきゅうほうしき /特急方式/
とっきゅうよう /特急用/
とっきゅうようしゃりょう /特急用車両/
とっきゅうりょうきん /特急料金/
とっきゅうれっしゃ /特急列車/
とっきょ /特許/
とっきょか /特許課/特許化/
とっきょかんけい /特許関係/
とっきょけん /特許権/
とっきょこうほう /特許公報/
とっきょしゅつがん /特許出願/
とっきょしゅつがんちゅう /特許出願中/
とっきょしょう /特許証/
とっきょしりょう /特許資料/
とっきょしんがい /特許侵害/
とっきょしんせい /特許申請/
とっきょじむしょ /特許事務所/
とっきょせいど /特許制度/
とっきょせんりゃく /特許戦略/
とっきょちょう /特許庁/
とっきょちょうさ /特許調査/
とっきょないよう /特許内容/
とっきょほう /特許法/
とっきょもんだい /特許問題/
とっきょりょう /特許料/
とっく /疾っく/疾く/
とっくり /徳利/
とっくん /特訓/
とっくんちゅう /特訓中/
とっけつ /突厥/
とっけん /特権/特研/
とっけんかいきゅう /特権階級/
とっけんてき /特権的/
とっこう /特攻/特効/特高/徳行/
とっこうき /特攻機/
とっこうたい /特攻隊/
とっこうだいさくせん /特攻大作戦/
とっこうやく /特効薬/
とっこうやろう /特攻野郎/
とっさ /咄嗟/
とっしゅつ /突出/
とっしん /突進/
とっしんりょく /突進力/
とっしんわざ /突進技/
とったん /突端/
とって /取手/把手/取っ手/把っ手/
とってい /突堤/
とっとり /鳥取/
とっとりかん /鳥取間/
とっとりぎじゅつかいはつ /鳥取技術開発/
とっとりけん /鳥取県/
とっとりけんよなごし /鳥取県米子市/
とっとりさきゅう /鳥取砂丘/
とっとりし /鳥取市/
とっとりだい /鳥取大/
とっとりだいがく /鳥取大学/
とっぱ /突破/
とっぱこう /突破口/
とっぱつ /突発/
とっぱつげんしょう /突発現象/
とっぱつしん /突発疹/
とっぱつせいはっしん /突発性発疹/
とっぱつてき /突発的/
とっぱつてきじょうしょう /突発的上昇/
とっぱつはっしん /突発発疹/
とっぱほうほう /突破方法/
とっぱりょく /突破力/
とっぱん /凸版/トッパン/
とっぱんいんさつ /凸版印刷/
とっぴ /突飛/
とっぴょうし /突拍子/
とっぷ /トップ/
とっぷう /突風/
とつ /突/凸/吶/咄/柮/訥/
とつか /戸塚/
とつかえいぎょうしょ /戸塚営業所/
とつかえき /戸塚駅/
とつかえきりようしゃ /戸塚駅利用者/
とつかきんぺん /戸塚近辺/
とつかく /戸塚区/
とつかくみん /戸塚区民/
とつかわ /十津川/
とつがた /凸型/
とつがたしゃたい /凸型車体/
とつがたでんき /凸型電機/
とつがわ /十津川/
とつきとうか /十月十日/
とつぎさき /嫁ぎ先/
とつけつごう /凸結合/
とつげき /突撃/突激/
とつげきたい /突撃隊/
とつじょ /突如/
とつじょしゅつげん /突如出現/
とつぜん /突然/
とつぜんいんたい /突然引退/
とつぜんし /突然死/
とつぜんへんい /突然変異/
とつでん /凸電/
とつにゅう /突入/
とつにゅうぐち /突入口/
とつへいほう /凸閉包/
とつべん /訥弁/
とつほう /凸包/
とつめん /凸面/
とづか /戸塚/
とてい /徒弟/
とていせい /徒弟制/
とても /迚/迚も/
とでん /都電/
ととう /徒党/渡頭/
ととき /十時/
とど /椴/
とどう /都道/
とどうけいけん /渡道経験/
とどうふけん /都道府県/
とどうふけんごと /都道府県毎/
とどうふけんざかい /都道府県境/
とどうふけんじちたい /都道府県自治体/
とどうふけんじょうれい /都道府県条例/
とどうふけんちじ /都道府県知事/
とどうふけんめい /都道府県名/
とどけ /届/屆/
とどけがき /届書/
とどけで /届出/届け出/
とどけでぎむ /届出義務/
とどけでじこう /届出事項/
とどけでずみしょう /届出済証/
とどけでせい /届出制/
とどけでにん /届出人/
とどほっけむら /椴法華村/
とどまつ /椴/
とどむ /閼/
とどめ /止め/
とどめる /閼/
とどろき /轟/等々力/軣/轟き/
とどろきおん /轟音/
となー /トナー/
とない /都内/
とないかんじょうせん /都内環状線/
とないきんこう /都内近郊/
とないぼうしょ /都内某所/
とないろせん /都内路線/
となかい /馴鹿/
となき /渡名喜/
となみ /砺波/礪波/渡並/外波/
となり /隣/隣り/鄰/
となりあわせ /隣合わせ/
となりきんじょ /隣近所/
となりぐみ /隣組/
となりどうし /隣同士/
となりまち /隣町/
となりむら /隣村/
となん /都南/
とにかく /兎に角/
とね /刀根/利根/
とねがわ /利根川/
とねぐん /利根郡/
とねやま /刀根山/
との /殿/
とのうち /登内/
とのおか /外岡/
とのがた /殿方/
とのさま /殿様/
とのしょう /土庄/
とのみ /富海/
とのやまちょう /殿山町/
とはん /登坂/登攀/
とはんしゃせん /登坂車線/
とば /鳥羽/賭場/
とばいき /鳥羽行/
とばえき /鳥羽駅/
とばく /賭博/
とばくうりあげきん /賭博売上金/
とばくさんぎょう /賭博産業/
とばくざい /賭博罪/
とばくざいいはん /賭博罪違反/
とばくしじょう /賭博市場/
とばくしゅべつ /賭博種別/
とばくじょう /賭博場/
とばくせい /賭博性/
とばくばしょ /賭博場所/
とばす /都バス/
とばせん /鳥羽線/
とばた /戸畑/
とばやま /鳥羽山/
とばり /戸張/帳/帷/幄/幃/
とひ /都費/
とび /鳶/飛び/鴟/鵄/
とびいり /飛び入り/
とびおか /飛岡/
とびおり /飛び降り/
とびきゅう /飛び級/
とびさき /飛先/飛び先/
とびしま /飛島/
とびしょく /鳶職/
とびた /飛田/
とびどうぐ /飛道具/飛び道具/
とびばこ /飛び箱/
とびひ /飛び火/
とびら /扉/
とびらいち /扉位置/
とびらえ /扉絵/
とびらせん /扉線/
とびらふきん /扉付近/
とびわし /飛鷲/
とぴっくす /トピックス/
とふ /塗布/
とふぎじゅつ /塗布技術/
とふけん /都府県/
とふご /塗付後/
とふつ /渡仏/
とぶくろ /戸袋/
とぶくろまど /戸袋窓/
とべ /戸部/砥部/
とべい /渡米/
とほ /徒歩/
とほう /途方/
とほすうふん /徒歩数分/
とほつうがく /徒歩通学/
とほれんらく /徒歩連絡/
とぽろじー /トポロジー/
とま /苫/笘/篷/
とまく /塗膜/
とまこまい /苫小牧/
とましの /苫篠/
とます /斗/
とまた /苫田/
とまつ /戸松/塗沫/塗抹/
とまと /トマト/
とまべち /苫米地/
とままえ /苫前/
とまり /泊まり/泊/渡真利/泊り/
とまりこみ /泊り込み/
とみ /富/冨/トミ/登美/當/
とみあい /富合/
とみうら /冨浦/富浦/
とみえ /富江/
とみお /富美男/富男/富夫/富雄/
とみおか /富岡/冨岡/
とみおかこうこう /富岡高校/
とみおかにし /富岡西/
とみおかはちまんぐう /富岡八幡宮/
とみおかぼうはてい /富岡防波堤/
とみか /富加/
とみかわ /富川/
とみくじ /富籤/
とみぐすく /豊見城/
とみこ /富子/登美子/富美子/
とみさと /富里/
とみさとちょう /富里町/
とみさとまち /富里町/
とみさわ /富沢/冨沢/
とみざわ /富沢/富澤/
とみしま /富島/
とみしろ /都城/
とみしろこうこう /豊見城高校/
とみじ /富治/
とみじゅうろう /富十郎/
とみた /富田/冨田/
とみたやすこ /富田靖子/
とみたろう /富太郎/
とみつかちょう /富塚町/
とみて /冨手/
とみとく /富徳/
とみなが /富永/冨永/
とみなり /冨成/
とみに /頓に/
とみの /富野/
とみはま /富浜/
とみはり /富張/
とみひこ /富彦/
とみひさ /富久/
とみひさちょう /富久町/
とみまつ /富松/
とみや /富谷/
とみやす /富安/
とみやちょう /富谷町/
とみやま /富山/
とみよし /富吉/
とみん /都民/
とみんきょうしゅうじょ /都民教習所/
とみんばん /都民版/
とむ /吐夢/
とむら /戸村/外村/
とめ /登米/留/
とめおき /留置/
とめがね /止め金/
とめきち /留吉/
とめぐん /登米郡/
とめこ /留子/
とめしょ /留所/
とめじ /留治/
とめそで /留袖/
とめど /止処/留処/
とめべん /止め弁/
とめん /塗面/
とも /共/友/智/知/朝/供/朋/伴/恭/具/艫/舮/靹/鞆/侶/
ともあき /智朗/智明/智彰/恭章/公明/倫明/
ともい /友井/
ともいし /友石/
ともいち /友一/
ともえ /知重/巴/友衛/
ともえがわ /巴川/
ともえがわせいししょ /巴川製紙所/
ともえぐみ /巴組/
ともえだ /友枝/
ともえなげ /巴投げ/
ともえふじ /巴富士/
ともお /友雄/智央/智夫/朋夫/友朗/知夫/智雄/
ともおか /友岡/
ともか /友香/
ともかず /共和/友和/智一/智和/
ともがおか /友ヶ丘/
ともがら /讎/讐/
ともき /知樹/朋喜/友喜/智樹/友紀/
ともきち /友吉/
ともきよ /友清/
ともこ /知子/智子/朋子/友子/倫子/朝子/とも子/
ともざる /友猿/
ともし /知士/
ともしび /灯/燭/灯し火/燈/
ともじ /友治/知司/
ともぞう /友蔵/
ともたか /智孝/友隆/
ともたけ /智武/
ともたろう /智太郎/
ともだ /友田/
ともだおれ /共倒れ/
ともだち /友達/
ともだちかん /友達間/
ともだちづくり /友達作り/
ともだちていど /友達程度/
ともだちどうし /友達同士/
ともだちわりびき /友達割引/
ともち /砥用/
ともちか /朋哉/知親/友近/
ともづな /繿/纜/
ともとし /智年/
ともども /共々/
ともなか /邑中/
ともなが /朝永/友永/
ともながしんいちろう /朝永振一郎/
ともに /共に/
ともの /伴野/
とものうら /鞆の浦/
とものかい /友の会/
とものり /知紀/知徳/智紀/智徳/友紀/智則/友則/知典/智規/
ともはな /友花/
ともはる /智春/知治/
ともばたらき /共働き/
ともひこ /智彦/友彦/知彦/
ともひさ /知久/朋久/智久/友久/
ともひで /知英/智秀/
ともひと /智仁/智斉/
ともひろ /智洋/知宏/智弘/恭祐/知浩/智広/智浩/共洋/朋宏/友広/智博/友洋/朋博/
ともびき /友引/
ともべ /友部/
ともまさ /智真/
ともまつ /友松/
ともみ /知美/知実/智美/朋美/知視/智巳/具視/具実/具美/智己/友海/友視/とも美/
ともみち /智道/友道/
ともみつ /伴光/
ともみはら /倶美原/
とももり /知盛/
ともや /智也/知也/
ともやす /友康/朋康/
ともゆき /智之/知行/智行/共之/知之/朋幸/智幸/朋之/友幸/
ともゆみ /智之/
ともよ /知世/智世/知代/
ともよし /智義/智由/知義/友良/知節/
とや /戸谷/外谷/
とやかく /兎や角/
とやま /富山/外山/戸山/
とやまえき /富山駅/
とやまがわ /富山側/
とやまぎたん /富山技短/
とやまくうこう /富山空港/
とやまけん /富山県/
とやまけんけい /富山県警/
とやまけんこすぎちょう /富山県小杉町/
とやまけんだい /富山県大/
とやまけんとやまし /富山県富山市/
とやまけんりつだい /富山県立大/
とやまけんりつだいがく /富山県立大学/
とやまさん /富山産/
とやまし /富山市/
とやましがい /富山市街/
とやましない /富山市内/
とやましんこう /富山新港/
とやまじゅうたく /戸山住宅/
とやまだい /富山大/
とやまだいがく /富山大学/
とやまちてつ /富山地鉄/
とやまちほうてつどう /富山地方鉄道/
とやまちょう /戸山町/
とやまはつ /富山発/
とやまびん /富山便/
とやまわん /富山湾/
とゆう /都有/
とゆうち /都有地/
とよ /豊/豐/トヨ/
とよあき /豊明/
とよあけ /豊明/
とようち /豊内/
とようら /豊浦/
とよおか /豊岡/豊丘/
とよおかく /豊岡区/
とよおかこうじょう /豊岡工場/
とよかず /豊和/
とよかわ /豊川/
とよかわいなり /豊川稲荷/
とよき /豊樹/
とよきち /豊吉/
とよぎだい /豊技大/
とよくに /豊国/
とよくら /豊倉/
とよこ /豊子/
とよこう /豊高/
とよころ /豊頃/
とよさか /豊栄/
とよさく /豊作/
とよさと /豊里/豊郷/
とよさわ /豊沢/
とよしき /豊四季/
とよしな /豊科/
とよしなかん /豊科間/
とよしま /豊島/豊嶋/
とよじ /豊治/
とよす /豊洲/
とよすえき /豊洲駅/
とよすふとう /豊洲埠頭/
とよた /豊田/トヨタ/
とよたいき /豊田行/
とよたこうせん /豊田高専/
とよたし /豊田市/
とよたしゃたい /トヨタ車体/
とよたじどうしゃ /トヨタ自動車/
とよたちゅうけん /豊田中研/
とよたま /豊玉/
とよたゆき /豊田行/
とよだ /豊田/
とよだこうき /豊田工機/
とよだこうぎょうだいがく /豊田工業大学/
とよだせん /豊田線/
とよだつうしょう /豊田通商/
とよつ /豊津/
とよてつ /豊鉄/
とよとみ /豊臣/豊富/
とよとみがた /豊臣方/
とよなか /豊中/
とよなかし /豊中市/
とよなかしてん /豊中支店/
とよなかしない /豊中市内/
とよね /豊根/
とよの /豊能/豊野/
とよのぶ /豊信/豊伸/
とよのぼり /豊登/
とよはし /豊橋/
とよはしえき /豊橋駅/
とよはしかん /豊橋間/
とよはしきた /豊橋北/
とよはしきんぺん /豊橋近辺/
とよはしぎかだい /豊橋技科大/
とよはしぎじゅつかがくだいがく /豊橋技術科学大学/
とよはしぎだい /豊橋技大/
とよはしけいとう /豊橋系統/
とよはしし /豊橋市/
とよはしほうめん /豊橋方面/
とよはま /豊浜/
とよはら /豊原/
とよひこ /豊彦/
とよひさ /豊久/
とよひせん /豊肥線/
とよひと /十余一/
とよひほんせん /豊肥本線/
とよひら /豊平/
とよひらがわ /豊平川/
とよひらく /豊平区/
とよひろ /豊広/豊弘/
とよふく /豊福/
とよふみ /東洋史/豊文/
とよま /登米/
とよまえかわさき /豊前川崎/
とよまつ /豊松/
とよまる /豊丸/
とよやま /豊山/
とら /虎/寅/乕/
とらい /渡来/トライ/戸来/
とらいあんぐる /トライアングル/
とらいけい /渡来系/
とらいじん /渡来人/
とらいち /寅市/
とらえかた /捉え方/
とらお /虎雄/寅男/寅雄/虎男/
とらがしら /虔/
とらきち /寅吉/虎吉/
とらぎ /トラ技/
とらくす /寅楠/
とらくた /トラクタ/
とらくたー /トラクター/
とらさん /寅さん/
とらぞう /虎三/虎造/
とらっきんぐ /トラッキング/
とらっく /トラック/
とらとう /虎党/
とらのまき /虎の巻/
とらのもん /虎の門/虎ノ門/
とらばーゆ /トラバーユ/
とらひこ /寅彦/
とらひめ /虎姫/
とらぶる /トラブル/
とらんく /トランク/
とらんじすた /トランジスタ/
とらんぷ /トランプ/
とり /鷄/鳥/酉/取り/取/鶏/禽/
とりあえず /取りあえず/取り敢えず/
とりあげ /取り上げ/
とりあつかい /取り扱い/取扱/取あつかい/取扱い/
とりあつかいかくちょう /取扱拡張/
とりあつかいかた /取り扱い方/
とりあつかいしゃ /取扱車/取扱者/
とりあつかいしょうひん /取扱商品/
とりあつかいせつめいしょ /取扱説明書/
とりあつかいてん /取扱店/
とりあつかいもと /取扱元/
とりい /鳥居/鳥井/
とりいそぎ /取り急ぎ/
とりいれ /取入れ/
とりう /鳥生/
とりうちぼう /鳥撃帽/
とりうみ /鳥海/
とりえ /取り柄/取柄/
とりお /トリオ/
とりおき /取り置き/
とりかえし /取り返し/
とりかご /鳥籠/
とりかじ /取舵/
とりかた /取り方/
とりかぶとぞく /Aconitum/トリカブト属/
とりがー /トリガー/
とりがい /鳥飼/
とりがら /鳥ガラ/
とりきめ /取り決め/
とりくみ /取組/取組み/
とりくみひょう /取組表/
とりくんだ /取り組んだ/
とりけし /取り消し/取消/取消し/
とりけししょぶん /取消処分/
とりけしでんぴょう /取消伝票/
とりこ /虜/虜擒/俘/
とりこし /取り越し/
とりこしぐろう /取り越し苦労/
とりこみ /取り込み/取込/
とりごえ /鳥越/
とりごや /鳥小屋/
とりさか /鳥坂/
とりさげ /取り下げ/
とりさわ /鳥澤/鳥沢/
とりざた /取りざた/取沙汰/
とりざら /取り皿/
とりしましやく /取締役/
とりしまり /取締り/取締/取り締り/
とりしまりじじょう /取締事情/
とりしまりほう /取締法/
とりしまりやく /取締役/
とりしまりやくかい /取締役会/
とりしまりやくしゃちょう /取締役社長/
とりしまりやくほんぶちょう /取締役本部長/
とりしらべ /取り調べ/取調/取調べ/
とりしらべしつ /取調室/
とりす /鳥巣/
とりすこうつう /鳥栖交通/
とりせつ /取説/
とりたち /鳥達/
とりたて /取立/
とりたに /鳥谷/
とりだい /鳥大/
とりだか /取り高/
とりだし /取り出し/取出/
とりちがえかた /取り違え方/
とりつ /都立/
とりつかせい /都立家政/
とりつきょういくけんきゅうじょ /都立教育研究所/
とりつぎ /取次/
とりつぎがいしゃ /取次会社/
とりつぎてん /取次店/
とりつけ /取付/取り付け/
とりつけかくど /取付角度/
とりつけせつめいしょ /取付説明書/
とりつけぶ /取付部/
とりつけぶしゅうへん /取付部周辺/
とりつけぶぶん /取付部分/
とりつけほうほう /取付方法/
とりつけりょう /取付料/
とりつこう /都立高/
とりつこうこう /都立高校/
とりつだい /都立大/東京都立大学/
とりつだいがく /都立大学/
とりつだいちり /都立大地理/
とりつだいぶつり /都立大物理/
とりつびじゅつかん /都立美術館/
とりてき /取的/
とりてん /鳥天/
とりで /砦/取手/塞/
とりでいえん /取手以遠/
とりでいほく /取手以北/
とりでにこう /取手二高/
とりにく /鶏肉/鳥肉/
とりにんげん /鳥人間/
とりの /Trino/
とりのいち /酉の市/
とりのこ /鳥の子/
とりはだ /鳥肌/
とりひき /取り引き/取引/
とりひきかかく /取引価格/
とりひきさき /取引先/取り引き先/
とりひきざいりょう /取引材料/
とりひきじょ /取引所/
とりひきないよう /取引内容/
とりひきほうほう /取引方法/
とりぶん /取り分/
とりぷる /トリプル/
とりほうだい /取り放題/
とりまえ /取り前/
とりまき /取り巻き/
とりめにあか /トリメニア科/Trimeniaceae/
とりもち /取り持ち/
とりもの /捕物/
とりものちょう /捕物帖/捕物帳/
とりや /鳥屋/鳥谷/
とりやま /鳥山/
とりやめ /取り止め/
とりょう /塗料/
とりよせ /取り寄せ/
とりろう /鶏郎/
とりわき /鳥脇/
とるこ /土耳古/土耳其/
とれーしんぐ /トレーシング/
とれーどおふ /トレードオフ/
とれーなー /トレーナー/
とれーにんぐ /トレーニング/
とれい /トレイ/
とれだか /取れ高/
とれつ /堵列/
とれん /都連/
とれんでぃ /トレンディ/
とれんど /トレンド/
とろ /瀞/吐露/
とろいせき /登呂遺跡/
とろう /徒労/
とろふぃー /トロフィー/
とろり /トロリ/
とわ /登和/永遠/
とわだ /十和田/
とわだこ /十和田湖/
とわだし /十和田市/
とん /豚/敦/頓/沌/遁/屯/噸/惇/東/問/暾/燉/瓲/遯/飩/丼/團/団/
とんいっきょく /東一局/
とんかつや /とんかつ屋/
とんきょう /頓狂/
とんこう /遁甲/燉煌/敦煌/
とんこつ /豚骨/
とんこつあじ /豚骨味/
とんさんきょく /東三局/
とんざ /頓挫/
とんし /頓死/
とんしょく /褪色/
とんじ /遁辞/
とんじゃく /頓着/
とんじょ /東女/
とんじる /豚汁/
とんじるふう /豚汁風/
とんせい /遁世/煌星/遯世/
とんそう /遁走/
とんぞく /遁俗/
とんだばやし /富田林/
とんち /頓知/頓智/
とんちゃく /頓着/
とんちんかん /頓珍漢/
とんでん /屯田/
とんなんしゃぺい /東南西北/
とんにきょく /東二局/
とんねる /トンネル/
とんば /東場/
とんばら /頓原/
とんび /鳶/
とんぼ /蜻蛉/
とんま /頓馬/
とんや /問屋/
とんやがい /問屋街/
とんやくみあい /問屋組合/
ど /度/土/奴/怒/℃/努/°/戸/呶/孥/弩/駑/堵/
ど< /度/
ど> /度/
ど、にち /土、日/
どーなつ /ドーナツ/
どーむ /ドーム/
どあ /ドア/
どあい /度合/度合い/
どあつ /土圧/
どあつけい /土圧計/
どあほ /ど阿呆/
どい /土居/土井/土肥/
どいがき /土井垣/
どいつ /独逸/ドイツ/独乙/獨逸/獨乙/何奴/独/
どいつご /ドイツ語/
どう /同/道/堂/動/導/瞳/胴/銅/童/洞/撞/萄/憧/藤/働/〃/々/僮/儂/嫐/恫/慟/撓/橈/獰/瞠/耨/艟/鬧/如何/陶/桐/ゞ/
どう> /同/
どうあい /同愛/
どうあいきねんびょういん /同愛記念病院/
どうあく /道悪/
どうあげ /胴上げ/
どうあん /同案/
どうあんたすう /同案他数/同案多数/
どうあんふくすう /同案複数/
どうい /同意/同位/
どういいんかい /同委員会/
どういぎ /同意義/
どういけん /同意見/
どういけんたすう /同意見多数/
どういげんそ /同位元素/
どういご /同意語/
どういしょ /同意書/
どういそう /同位相/
どういそうしゃぞう /同位相写像/
どういたい /同位体/
どういたいこうか /同位体効果/
どういたいひ /同位体比/
どういっしゅ /同一種/
どういつ /同一/
どういつえき /同一駅/
どういつか /同一化/
どういつきしゅ /同一機種/同一騎手/
どういつきょうそう /同一競走/
どういつきょくめん /同一局面/
どういつぎょう /同一行/
どういつけいえい /同一経営/
どういつけいしき /同一形式/
どういつけいしきない /同一形式内/
どういつげんご /同一言語/
どういつし /同一視/
どういつしほん /同一資本/
どういつしゃしゅ /同一車種/
どういつしゃせんない /同一車線内/
どういつしゃめい /同一車名/
どういつしゅうかい /同一周回/
どういつしゅうはすう /同一周波数/
どういつしゅし /同一主旨/
どういつしょうてんきょり /同一焦点距離/
どういつしょぞく /同一所属/
どういつじこく /同一時刻/
どういつじょうけん /同一条件/
どういつじんぶつ /同一人物/
どういつせい /同一性/
どういつせいひん /同一製品/
どういつせいほじけん /同一性保持権/
どういつせかい /同一世界/
どういつせん /同一線/
どういつせんじょう /同一線上/
どういつそしき /同一組織/
どういつぞく /同一属/
どういつちんぎん /同一賃金/
どういつてん /同一点/
どういつとうひょうしゃ /同一投票者/
どういつないよう /同一内容/
どういつにん /同一人/
どういつねん /同一年/
どういつはんてい /同一判定/
どういつひんしつ /同一品質/
どういつびん /同一便/
どういつふごう /同一符号/
どういつへいめん /同一平面/
どういつへんせいちゅう /同一編成中/
どういつほうこう /同一方向/
どういつほんすう /同一本数/
どういつめい /同一名/
どういつもじ /同一文字/
どういつりょういき /同一領域/
どういつりょうきん /同一料金/
どういつろうどう /同一労働/
どういつろせん /同一路線/
どういつわ /同一話/
どういつわく /同一枠/
どういん /動員/
どういんすう /動員数/
どういんりつ /動員率/
どういんりょく /動員力/
どうえき /同駅/
どうえん /導演/
どうおう /道央/
どうおん /同音/
どうおんいぎご /同音異義語/
どうおんくんひょう /同音訓表/
どうか /同化/銅貨/同課/道家/導火/道歌/
どうかいぎ /同会議/
どうかいじょう /同会場/
どうかかく /同価格/
どうかく /同格/同角/動確/
どうかこうぞう /同化構造/
どうかこん /同化根/
どうかごうぶつ /銅化合物/
どうかせん /導火線/
どうかそしき /同化組織/
どうかつ /恫喝/
どうかひか /同花被花/
どうかん /同感/導管/道管/道灌/
どうかんじいおんご /同漢字異音語/
どうかんすう /導関数/
どうかんとく /同監督/
どうかんようそ /導管要素/
どうが /動画/童画/
どうがあっしゅくきかく /動画圧縮規格/
どうがい /道外/
どうがく /同額/
どうがくねん /同学年/
どうがしま /堂ヶ島/
どうがぞう /動画像/
どうがた /同型/
どうがたかん /同型艦/
どうがたき /同型機/
どうがたしゃ /同型車/
どうがまいすう /動画枚数/
どうがん /童顔/動眼/
どうき /同期/動機/動悸/銅器/同機/動気/
どうきかい /同期会/
どうきかいろ /同期回路/
どうきかく /同規格/
どうきかさん /同期加算/
どうきがた /同期型/
どうききこう /同期機構/
どうきしき /同期式/
どうきしきしょり /同期式処理/
どうきしきてんそう /同期式転送/
どうきしゅ /同機種/
どうきしゅうはすう /同期周波数/
どうきしょり /同期処理/
どうきしんごう /同期信号/
どうきじ /同記事/
どうきじょう /動機上/
どうきせい /同期性/同期生/
どうきせつぞく /同期接続/
どうきちょうそうき /同期調相機/
どうきつうしん /同期通信/
どうきてき /同期的/
どうきてん /同期点/
どうきてんそう /同期転送/
どうきてんそうそくど /同期転送速度/
どうきにゅうしゃ /同期入社/
どうきほうしき /同期方式/
どうきゅう /同級/慟泣/撞球/
どうきゅうしゃ /同厩舎/
どうきゅうせい /同級生/
どうきゅうせいどうし /同級生同士/
どうきょ /同居/
どうきょう /同郷/道教/同香/
どうきょうけい /道教系/
どうきょうじん /同郷人/
どうきょく /同局/同曲/
どうきょしゃ /同居者/
どうきょじゅうにん /同居住人/
どうきょにん /同居人/
どうきょり /同距離/
どうきん /同斤/同金/同衾/
どうぎ /同義/道義/動議/胴着/道着/
どうぎご /同義語/
どうぎごじしょ /同義語辞書/
どうぎしん /道義心/
どうぎじょう /道義上/
どうぎていしゅつ /動議提出/
どうぎてき /道義的/
どうぎてきせきにん /道義的責任/
どうぎはんぷく /同義反復/
どうぎょう /同業/
どうぎょうしゃ /同業者/
どうぎょうしゅ /同業種/
どうぎょうしゅきぎょうかん /同業種企業間/
どうぎょうたしゃ /同業他社/
どうぎょく /同玉/
どうぎん /同銀/
どうく /同区/
どうくかん /同区間/
どうくそうきょくぜんしゅう /独奏曲全集/
どうくつ /洞窟/
どうくつしゅうへん /洞窟周辺/
どうくつせんし /洞窟戦士/
どうくつない /洞窟内/
どうくん /同君/同訓/
どうぐ /道具/
どうぐだて /道具立て/
どうぐち /洞口/
どうぐばこ /道具箱/
どうぐや /道具屋/
どうけ /道化/道家/
どうけい /同型/同形/同桂/同系/同慶/憧憬/
どうけいき /同形機/
どうけいさんき /同計算機/
どうけいしゃぞう /同型写像/同形写像/
どうけいしょく /同系色/
どうけいせい /同形性/同型性/
どうけいたい /同形態/
どうけいたいおう /同型対応/
どうけいとう /同系統/
どうけいどうだい /同形同大/
どうけいはんぷく /同型反復/
どうけいほうしゃそしき /同形放射組織/
どうけいれつ /同系列/
どうけし /道化師/
どうけつ /洞穴/
どうけん /同権/同県/
どうけんきゅうしつ /同研究室/
どうげつ /同月/
どうげん /道玄/同源/
どうげんざか /道玄坂/
どうこ /銅壺/
どうこう /動向/瞳孔/同行/同校/同好/同興/同工/道光/
どうこういきょく /同工異曲/
どうこうかい /同好会/
どうこうかいぜんたい /同好会全体/
どうこうこう /同高校/
どうこうしゃ /同行者/
どうこうちょうさ /動向調査/
どうこうなど /動向等/
どうこうのし /同好の士/
どうこうほう /道交法/
どうこうほういはん /道交法違反/
どうこうほうじょう /道交法上/
どうこうほうてきようがい /道交法適用外/
どうこく /同国/同刻/慟哭/
どうこくじん /同国人/
どうこん /同梱/同根/
どうご /道後/
どうごうきん /銅合金/
どうごおんせん /道後温泉/
どうごげん /同語源/
どうごはんぷく /同語反復/
どうさ /動作/同左/
どうさい /道斎/
どうさおん /動作音/
どうさか /動作可/
どうさかくにん /動作確認/
どうさかくにんご /動作確認後/
どうさかくにんじょうほう /動作確認情報/
どうさかくにんよう /動作確認用/
どうさかのう /動作可能/
どうさかんきょう /動作環境/
どうさかんきょうせってい /動作環境設定/
どうさきしゅ /動作機種/
どうさぎれ /動作切/
どうさくしゃ /同作者/
どうさけいぞくじかん /動作継続時間/
どうさげんり /動作原理/
どうさしゅ /動作主/
どうさしゅつりょく /動作出力/
どうさじ /動作時/
どうさじっけん /動作実験/
どうさじっせき /動作実績/
どうさじょうきょう /動作状況/
どうさじょうけん /動作条件/
どうさじょうたい /動作状態/
どうさせい /動作性/
どうさそう /動作相/
どうさそくど /動作速度/
どうさちゅう /動作中/
どうさつ /洞察/
どうさつりょく /洞察力/
どうさていし /動作停止/
どうさてきもんだい /動作的問題/
どうさてん /動作点/
どうさでんあつ /動作電圧/
どうさとくせい /動作特性/
どうさふのう /動作不能/
どうさふりょう /動作不良/
どうさぶ /動作部/
どうさほしょう /動作保証/
どうさみかくにん /動作未確認/
どうさよう /動作用/
どうさようでんち /動作用電池/
どうさりょういき /動作領域/
どうさん /動産/道三/
どうざい /同罪/
どうざっし /同雑誌/
どうざん /銅山/
どうし /同士/動詞/同志/同氏/同市/同誌/導師/道志/
どうしうち /同士打ち/同士撃ち/
どうしか /動詞化/
どうしかい /同士会/
どうしかいどう /道志街道/
どうしかく /動詞格/
どうしかつよう /動詞活用/
どうしけい /動詞形/
どうしさくひん /同氏作品/
どうししゃ /同志社/
どうししゃだい /同志社大/
どうししゃだいがく /同志社大学/
どうした /堂下/
どうしつ /同室/同質/
どうしつせい /同質性/
どうして /如何して/
どうしゃ /同社/動車/同車/
どうしゃせい /同社製/
どうしゃはっこう /同社発行/
どうしゅ /同種/同株/
どうしゅうき /同周期/
どうしゅく /同宿/
どうしゅし /同趣旨/
どうしゅぞく /同種族/
どうしゅぞくかん /同種属間/
どうしゅつ /導出/
どうしゅつかてい /導出過程/
どうしゅつかのう /導出可能/
どうしゅつがた /導出型/
どうしゅつきそく /導出規則/
どうしゅつぎ /導出木/
どうしゅつけい /導出系/
どうしゅつけいていぎぶ /導出系定義部/
どうしゅつさき /導出先/
どうしゅつしえん /導出支援/
どうしゅつほう /導出法/
どうしゅりゅうし /同種粒子/
どうしゅりゅうしせい /同種粒子性/
どうしょ /同所/同書/
どうしょう /銅賞/同床/道床/
どうしょうかいりょう /道床改良/
どうしょうてん /同焦点/
どうしょく /同色/
どうしょくけい /同色系/
どうしょくぶつ /動植物/
どうしょくぶつけんえきぜい /動植物検疫税/
どうしょくぶつめい /動植物名/
どうしりょう /同資料/
どうしん /童心/同心/
どうしんえん /同心円/
どうしんえんじょう /同心円状/同心円上/
どうじ /同時/童子/同次/動時/同字/
どうじえんそう /同時演奏/
どうじか /同時化/
どうじかいさい /同時開催/
どうじかん /同時間/
どうじき /同時期/
どうじく /同軸/
どうじくかいてん /同軸回転/
どうじくじょう /同軸上/
どうじけいすう /同時計数/
どうじけん /同事件/
どうじこうしん /同時更新/
どうじこく /同時刻/
どうじこくめん /同時刻面/
どうじし /同時枝/
どうじしゅうろく /同時収録/
どうじしゅつりょくかのう /同時出力可能/
どうじしんこう /同時進行/
どうじしんこうけい /同時進行形/
どうじしんこうせい /同時進行性/
どうじしんこうてき /同時進行的/
どうじじっこう /同時実行/
どうじじっこうとうかせい /同時実行透過性/
どうじじょうえい /同時上映/
どうじせい /同時性/
どうじせいきぎょうれつ /同時生起行列/
どうじそうさ /同時操作/
どうじそうしんかのう /同時送信可能/
どうじたはつせい /同時多発性/
どうじたはつてき /同時多発的/
どうじだい /同時代/
どうじだいせい /同時代性/
どうじちょうり /同時調理/
どうじつ /同日/
どうじつうやく /同時通訳/
どうじてんとう /同時点灯/
どうじてんとうぼうし /同時点灯防止/
どうじとうこう /同時投稿/
どうじどうしょ /同時同所/
どうじにゅうりょく /同時入力/
どうじはつおん /同時発音/
どうじはつおんすう /同時発音数/
どうじはつばい /同時発売/
どうじひょうじ /同時表示/
どうじほうそう /同時放送/
どうじほっそく /同時発足/
どうじぼしゅう /同時募集/
どうじま /堂島/
どうじゅん /同順/
どうじゅんい /同順位/
どうじょう /同上/同情/道場/同乗/道上/堂上/
どうじょうがた /土壌型/
どうじょうけん /同条件/
どうじょうけんどうりょうきん /同条件同料金/
どうじょうしゃ /同乗者/
どうじょうしゃよう /同乗者用/
どうじょうしん /同情心/
どうじょうじ /道成寺/
どうじょうだいにこう /同条第二項/
どうじょうてき /同情的/
どうじょうない /道場内/
どうじょうひょう /同情票/
どうじょうみゃく /動静脈/
どうじょうやぶり /道場破り/
どうじろくおん /同時録音/
どうじん /同人/道仁/
どうじんし /同人誌/
どうじんしかつどう /同人誌活動/
どうじんしけっさく /同人誌傑作/
どうじんしさっか /同人誌作家/
どうじんしそくばいかい /同人誌即売会/
どうじんしゅっしん /同人出身/
どうじんしよう /同人誌用/
どうじんしるい /同人誌類/
どうすう /同数/
どうず /同図/
どうせい /同性/同棲/同姓/銅製/動静/
どうせいあい /同性愛/
どうせいあいしゃ /同性愛者/
どうせいけっこん /同性結婚/
どうせいじだい /同棲時代/
どうせいちゅう /同棲中/
どうせいどうめい /同姓同名/
どうせいのう /同性能/
どうせいふ /同政府/
どうせき /同席/道関/
どうせだい /同世代/
どうせん /導線/同船/銅線/動線/
どうせんこう /同専攻/
どうぜい /同勢/
どうぜん /同然/
どうそう /同窓/同相/
どうそうかい /同窓会/
どうそうかいし /同窓会誌/
どうそうかいほう /同窓会報/
どうそうかいめいぼ /同窓会名簿/
どうそうせい /同窓生/
どうそく /同側/
どうそじん /道祖神/
どうそん /道村/同村/
どうぞう /銅像/
どうぞく /同族/道俗/
どうぞくがいしゃ /同族会社/
どうたい /導体/動態/同体/胴体/
どうたいけい /同体型/胴体径/
どうたいほぞん /動体保存/動態保存/
どうたく /銅鐸/
どうだい /同大/同題/
どうだいがく /同大学/
どうだいがくいん /同大学院/
どうだいら /堂平/
どうだん /道断/同断/同段/満天星/道斷/
どうち /同値/同地/≡/⇔/同治/
どうちいき /同地域/
どうちかんけい /同値関係/
どうちく /同地区/
どうちせい /同値性/
どうちてき /同値的/
どうちゃく /撞着/同着/
どうちゃくごほう /撞着語法/
どうちゅう /道中/
どうちゅうき /道中記/
どうちょう /同調/道庁/
どうちょうかいろ /同調回路/
どうちょうきょくせん /同調曲線/
どうちょうしゃ /同調者/
どうちょうせいちょう /同調生長/
どうちょうそうち /同調装置/
どうちょうてん /同調点/
どうちるい /同値類/
どうつう /導通/
どうてい /同定/童貞/同底/道程/
どうていあん /同提案/
どうていど /同程度/
どうていりつ /同定率/
どうてき /動的/
どうてきかいせき /動的解析/
どうてきかてい /動的仮定/
どうてききおくかんり /動的記憶管理/
どうてききごう /動的記号/
どうてきくうりきそうち /動的空力装置/
どうてきけいかくほう /動的計画法/
どうてきせぎょ /動的制御/
どうてきそくばく /動的束縛/
どうてきはいぶん /動的配分/
どうてきふかぶんさん /動的負荷分散/
どうてきめいれい /動的命令/
どうてきろんり /動的論理/
どうてん /同点/動転/動顛/動点/鬧天/
どうてんけっしょう /同点決勝/
どうてんだん /同点弾/
どうでん /導電/北海道電力/道伝/道傳/
どうでんい /同電位/
どうでんせい /導電性/
どうでんたい /導電体/
どうとう /同等/道東/同党/
どうとういじょう /同等以上/
どうとうきのう /同等機能/
どうとうせい /同等性/
どうとうひん /同等品/同当品/
どうとうほうめん /道東方面/
どうとく /道徳/
どうとくかん /道徳観/道徳感/
どうとくきはん /道徳規範/
どうとくきょういく /道徳教育/
どうとくけいじじょうがく /道徳形而上学/
どうとくしん /道徳心/
どうとくじょう /道徳上/
どうとくせい /道徳性/動特性/
どうとくてき /道徳的/
どうとくてきけんち /道徳的見地/
どうとくてきそんげん /道徳的尊厳/
どうとくてつがく /道徳哲学/
どうとくてん /同得点/
どうとくほうそく /道徳法則/
どうとんぼり /道頓堀/
どうどう /堂々/同道/道々/
どうどうめぐり /堂々巡り/
どうない /道内/
どうないじこくひょう /道内時刻表/
どうないばんじこくひょう /道内版時刻表/
どうないよう /同内容/
どうなん /道南/
どうにゅう /導入/
どうにゅういぜん /導入以前/
どうにゅうかいし /導入開始/
どうにゅうかのう /導入可能/
どうにゅうき /導入期/
どうにゅうきそく /導入規則/
どうにゅうきょういく /導入教育/
どうにゅうぐち /導入口/
どうにゅうしょき /導入初期/
どうにゅうじ /導入時/
どうにゅうじょう /導入上/
どうにゅうちょくぜん /導入直前/
どうにゅうてき /導入的/
どうにゅうとうしょ /導入当初/
どうにゅうぶ /導入部/
どうにゅうぶぶん /導入部分/
どうにゅうほう /導入法/
どうにゅうほうほう /導入方法/
どうにゅうまえ /導入前/
どうにん /同人/
どうねん /同年/動燃/
どうねんだい /同年代/
どうねんど /動粘度/
どうねんれい /同年齢/
どうのじ /々/
どうは /導波/
どうはい /同輩/
どうはく /銅箔/
どうはち /銅鉢/
どうはろ /導波路/
どうはん /同伴/
どうはんきょうぎしゃ /同伴競技者/
どうはんしゃ /同伴者/
どうば /同馬/
どうばち /銅鉢/
どうばん /銅板/
どうばんがてん /銅版画展/
どうばんぐみ /同番組/
どうひ /胴皮/同飛/
どうひせい /同飛成/
どうひょう /同表/道標/
どうびょう /同病/
どうびょういん /同病院/
どうふ /同歩/豆腐/
どうふう /同封/
どうふく /同腹/
どうふけん /道府県/
どうふごう /同符号/
どうぶつ /動物/
どうぶつあいごきょうかい /動物愛護協会/
どうぶつあいじょうものがたり /動物愛情物語/
どうぶつえん /動物園/
どうぶつえんいき /動物園行/
どうぶつえんせん /動物園線/
どうぶつえんまえ /動物園前/
どうぶつがく /動物学/
どうぶつがくしゃ /動物学者/
どうぶつぎゃくたい /動物虐待/
どうぶつぐん /動物群/
どうぶつこうえんせん /動物公園線/
どうぶつこうどうがく /動物行動学/
どうぶつしゃしん /動物写真/
どうぶつじっけん /動物実験/
どうぶつせい /動物性/
どうぶつたち /動物達/
どうぶつだいぜんしゅう /動物大全集/
どうぶつちゅうしん /動物中心/
どうぶつびょういん /動物病院/
どうぶつほごだんたい /動物愛護団体/
どうぶつめい /動物名/
どうぶつゆ /動物油/
どうぶん /同文/
どうぶんしょ /同文書/
どうぶんや /同分野/
どうべや /同部屋/
どうべんきこう /動弁機構/
どうほう /同報/同胞/同朋/同法/
どうほうあん /同法案/
どうほうこう /同方向/
どうほうこく /同報告/
どうほうつうしん /同報通信/
どうほく /道北/
どうぼいん /同母音/
どうま /胴間/
どうまごえ /胴間声/
どうまさつ /動摩擦/
どうまさつけいすう /動摩擦係数/動摩擦系数/
どうみゃく /動脈/
どうみゃくけっちゅう /動脈血中/
どうみゃくけつ /動脈血/
どうみゃくこうか /動脈硬化/
どうみゃくさいけつ /動脈採血/
どうみゃくじょう /動脈上/
どうみゃくちゅう /動脈中/
どうみゃくない /動脈内/
どうみゃくりゅう /動脈瘤/
どうみん /道民/
どうめい /同盟/同名/
どうめいいし /同名異市/
どうめいえいが /同名映画/
どうめいかんけい /同盟関係/
どうめいきょく /同名曲/
どうめいぐん /同盟軍/
どうめいし /動名詞/同名市/
どうめいしゃ /同盟者/
どうめん /道免/道面/
どうもう /獰猛/童蒙/艟艨/
どうもく /瞠目/
どうもと /胴元/
どうもん /洞門/同門/
どうや /銅谷/同夜/
どうやく /同役/
どうゆう /同友/道有/
どうゆうかい /同友会/
どうゆうち /道有地/
どうよう /同様/動揺/童謡/
どうように /同様に/
どうら /銅鑼/
どうらく /道楽/
どうらくはんぶん /道楽半分/
どうらくむすめ /道楽娘/
どうらくもの /道楽者/
どうらん /動乱/
どうり /道理/
どうりきがく /動力学/
どうりきがくてき /動力学的/
どうりつ /同率/道立/
どうりつしゅい /同率首位/
どうりつゆうしょう /同率優勝/
どうりょう /同僚/同量/
どうりょうきん /同料金/
どうりょうじょうし /同僚上司/
どうりょうやく /同僚役/
どうりょく /動力/
どうりょくかっくうき /動力滑空機/
どうりょくげん /動力源/
どうりょくしゃ /動力車/
どうりょくしゅうちゅう /動力集中/
どうりょくせいのう /動力性能/
どうりょくせん /動力船/
どうりょくそうち /動力装置/
どうりょくだいしゃ /動力台車/
どうりょくでんたつけい /動力伝達系/
どうりょくでんたつそうち /動力伝達装置/
どうりょくぶ /動力部/
どうりょくぶんさんほうしき /動力分散方式/
どうりょくろ /動力炉/
どうりん /動輪/
どうりんかいてんすう /動輪回転数/
どうりんけい /動輪径/
どうるい /同類/
どうるいがっちゃく /同類合着/
どうるいこう /同類項/
どうるいたすう /同類多数/
どうれつ /同列/
どうれつし /同列視/
どうれん /道連/
どうろ /道路/
どうろうんそうしゃりょう /道路運送車両/
どうろかくちょう /道路拡張/
どうろかんけい /道路関係/
どうろかんりしゃ /道路管理者/
どうろがわ /道路側/
どうろぎょうせい /道路行政/
どうろけいかく /道路計画/
どうろけんせつ /道路建設/
どうろこうじ /道路工事/
どうろこうだん /道路公団/
どうろこうつう /道路交通/
どうろこうつうほう /道路交通法/
どうろこんざつ /道路混雑/
どうろじじょう /道路事情/
どうろじじょうなど /道路事情等/
どうろじゅうたい /道路渋滞/
どうろじょう /道路上/
どうろじょうきょう /道路状況/
どうろじょうほう /道路情報/
どうろせいび /道路整備/
どうろせいびろん /道路整備論/
どうろせん /同路線/
どうろぜい /道路税/
どうろぞい /道路沿/
どうろだい /道路代/
どうろちず /道路地図/
どうろちずぼん /道路地図本/
どうろちゅうおう /道路中央/
どうろちょう /道路長/
どうろとうけい /道路統計/
どうろはくしょ /道路白書/
どうろはば /道路幅/
どうろばんごう /道路番号/
どうろひょうしき /道路標識/
どうろひょうじ /道路標示/道路表示/
どうろふくいん /道路幅員/
どうろへんちょう /道路偏重/
どうろへんちょうせいさく /道路偏重政策/
どうろほう /道路法/
どうろほしゅうよさん /道路補修予算/
どうろみぎがわ /道路右側/
どうろもう /道路網/
どうろゆそう /道路輸送/
どうろようりょう /道路容量/
どうろよこ /道路横/
どうろわき /道路脇/
どうわ /同和/童話/
どうわがくしゅう /同和学習/
どうわきょういく /同和教育/
どうわく /同枠/
どうわくば /同枠馬/
どうわこうぎょう /同和鉱業/
どうわさっか /童話作家/
どうわさべつ /同和差別/
どうわしゅう /童話集/
どうわたいさくじぎょう /同和対策事業/
どうわちく /同和地区/
どうわちくがい /同和地区外/
どうわちくじゅうみん /同和地区住民/
どうわぶらく /同和部落/
どうわもんだい /同和問題/
どおし /同士/
どおり /通り/通/
どかた /土方/
どかん /土管/
どがいし /度外視/
どき /土器/時/怒気/
どきがわ /土器川/
どきがわぶぶん /土器川部分/
どきどき /ドキドキ/
どきぶんめい /土器文明/
どきゅう /土休/弩級/
どきゅめんてーしょん /ドキュメンテーション/
どきゅめんと /ドキュメント/
どきょう /度胸/読経/
どきょういっぱつ /度胸一発/
どきん /土禁/
どぎも /度肝/
どく /毒/読/独/徳/獨/讀/髑/
どくいり /毒入/
どくえき /毒液/
どくえさ /毒餌/
どくえん /独演/
どくかい /読解/
どくかいりょく /読解力/
どくが /毒牙/
どくがく /独学/
どくがし /毒菓子/
どくがす /毒ガス/
どくがん /独眼/
どくがんりゅう /独眼竜/
どくがんりゅうまさむね /独眼竜政宗/
どくきんほう /独禁法/
どくぐん /独軍/
どくぐんこうくうき /独軍航空機/
どくけ /毒気/
どくけし /毒消し/
どくご /読後/独語/
どくごかん /読後感/
どくごかんそう /読後感想/
どくごかんそうぶん /読後感想文/
どくさい /独裁/
どくさいこっか /独裁国家/
どくさいしゃ /独裁者/
どくさいしゃせい /独裁者制/
どくさいしゅぎきょういく /独裁主義教育/
どくさいしゅぎしゃ /独裁主義者/
どくさいせい /独裁制/
どくさいせいけん /独裁政権/
どくさいせいじ /独裁政治/
どくさいたいせい /独裁体制/
どくさつ /毒殺/
どくしゃ /読者/
どくしゃがわ /読者側/
どくしゃさんか /読者参加/
どくしゃしょうたい /読者招待/
どくしゃしょし /読者諸子/
どくしゃじしん /読者自身/
どくしゃすう /読者数/
どくしゃぜんいん /読者全員/
どくしゃそう /読者層/
どくしゃたいしょう /読者対象/
どくしゃとうこう /読者投稿/
どくしゃとうひょう /読者投票/
どくしゃらん /読者欄/
どくしゅう /独習/
どくしゅうしょ /独習書/
どくしょ /読書/
どくしょう /独唱/
どくしょうしゃ /独唱者/
どくしょか /読書家/
どくしょかい /読書会/
どくしょかんそうぶん /読書感想文/
どくしょけいこう /読書傾向/
どくしょこんなんじ /読書困難児/
どくしょしょうがい /読書障害/
どくしょとう /読書灯/
どくしょりょく /読書力/
どくしょれき /読書歴/
どくしん /独身/読唇/
どくしんおとこ /独身男/
どくしんきぞく /独身貴族/
どくしんしゃ /独身者/
どくしんじだい /独身時代/
どくしんじゅつ /読唇術/読心術/
どくしんじょせい /独身女性/
どくしんせいかつ /独身生活/
どくしんせいかつしゃ /独身生活者/
どくしんだんせい /独身男性/
どくしんどうし /独身同士/
どくしんもの /独身者/
どくしんりょう /独身寮/
どくじ /独自/
どくじかいはつ /独自開発/
どくじかいろ /独自回路/
どくじきかく /独自規格/
どくじぎじゅつ /独自技術/
どくじしよう /独自仕様/
どくじせい /独自性/
どくじほうしき /独自方式/
どくじもじ /独自文字/
どくじゃ /毒蛇/
どくじろせん /独自路線/
どくせい /毒性/
どくせいじっけん /毒性実験/
どくせいひょうか /毒性評価/
どくせいぶん /毒成分/
どくせき /毒螫/
どくせん /独占/独擅/
どくせんか /独占化/
どくせんきんしほう /独占禁止法/
どくせんけいやく /独占契約/
どくせんしほんしゅぎ /独占資本主義/
どくせんしよう /独占使用/
どくせんじゅしょう /独占授賞/
どくせんじょう /独擅場/
どくせんじょうたい /独占状態/
どくせんてき /独占的/
どくせんはんばい /独占販売/
どくせんゆにゅう /独占輸入/
どくせんよく /独占欲/
どくぜつ /毒舌/
どくぜつか /毒舌家/
どくぜつせん /毒舌戦/
どくぜん /独善/
どくぜんけいこう /独善傾向/
どくぜんしゃ /独善者/
どくぜんしゅぎ /独善主義/
どくぜんせい /独善性/
どくぜんてき /独善的/
どくぜんてきけいこう /独善的傾向/
どくそ /毒素/
どくそう /独創/独奏/独走/毒草/
どくそうかい /独奏会/
どくそうきょく /独奏曲/
どくそうしゃ /独創者/独奏者/
どくそうじょうたい /独走状態/
どくそうせい /独創性/
どくそうてき /独創的/
どくそうてきはっそうほう /独創的発想法/
どくそうよう /独奏用/
どくそうりょく /独創力/
どくそん /独尊/獨尊/
どくたー /ドクター/
どくだけ /毒茸/
どくだみか /ドクダミ科/Saururaceae/
どくだん /独断/
どくだんじょう /独壇場/
どくだんせんこう /独断専行/
どくだんてき /独断的/
どくとく /独特/
どくぬき /毒抜き/
どくは /読破/
どくはい /毒杯/
どくはく /独白/
どくばり /毒針/
どくぶつ /毒物/
どくほん /読本/
どくぼう /独房/
どくみ /毒見/
どくみょう /独明/
どくむし /毒虫/
どくやく /毒薬/
どくりつ /独立/
どくりつあん /独立案/
どくりつうんどう /独立運動/
どくりつがた /独立型/
どくりつきねんかん /独立記念館/
どくりつきねんび /独立記念日/
どくりつぎゆうぐん /独立義勇軍/
どくりつぎょうせいほうじん /独立行政法人/
どくりつぐれんたい /独立愚連隊/
どくりつけい /独立系/
どくりつこく /独立国/
どくりつご /独立語/独立後/
どくりつさいさん /独立採算/
どくりつしゃりん /独立車輪/
どくりつしゅうごう /独立集合/
どくりつじぎょうしゃ /独立事業者/
どくりつじしょう /独立事象/
どくりつじゅ /独立樹/
どくりつじゅうそしき /独立柔組織/
どくりつせい /独立性/
どくりつせいりょく /独立勢力/
どくりつせんげん /独立宣言/
どくりつせんそう /独立戦争/
どくりつたんてん /独立単点/
どくりつだいがくいん /独立大学院/
どくりつだんたい /独立団体/
どくりつちゅうおうたいざ /独立中央胎座/
どくりつてん /独立点/
どくりつどっぽ /独立独歩/
どくりつへんすう /独立変数/
どくりつみんぞく /独立民族/
どくりつりろん /独立理論/
どくりょう /読了/
どくりょうご /読了後/
どくりょく /独力/
どくろ /髑髏/
どぐう /土偶/
どけい /時計/
どけん /土建/
どけんぎょう /土建業/
どけんぎょうしゃ /土建業者/
どげざ /土下座/
どこ /何処/
どこう /土侯/土光/
どこか /何処/
どこそこ /何処其処/
どこらへん /どこら辺/
どごう /怒号/
どさけん /ドサ健/
どさん /土讃/
どさんこ /道産子/
どしつ /土質/怒叱/
どしゃ /土砂/
どしゃぶり /土砂降り/
どじょう /土壌/鰍/泥鰌/鯲/鰌/土壤/
どじょうない /土壌内/
どじょうめん /土壌面/
どじん /土人/
どすう /度数/
どすうぶんぷ /度数分布/
どすてば /土捨場/
どせい /土星/
どせいけい /土星系/
どせきりゅう /土石流/
どせきりゅうはっせい /土石流発生/
どそう /土葬/
どそく /土足/
どぞう /土蔵/
どぞく /土俗/
どぞくてき /土俗的/
どたんば /土壇場/
どだい /土台/
どだん /土壇/
どちゃく /土着/
どちゃくみんぞく /土着民族/
どちゅう /土中/
どちょう /怒張/
どちら /何方/
どっかい /読解/
どっかいのうりょく /読解能力/
どっかいりょく /読解力/
どっかいりょくぶそく /読解力不足/
どっきょう /読経/
どっきょうだいがく /独協大学/
どっきんぐ /ドッキング/
どっきんほう /独禁法/
どっく /ドック/
どっち /何方/
どっと /ドット/
どっとたんい /ドット単位/
どっぽ /独歩/
どつ /肭/
どつぼ /ドツボ/
どて /土手/塢/土堤/
どてぐち /土手口/
どてみち /土手道/
どてら /褞袍/
どとう /怒涛/怒濤/
どどいつ /都々逸/
どなべ /土鍋/
どなり /隣/鄰/
どにち /土日/
どにちいがい /土日以外/
どにちきゅうじつ /土日休日/
どにちげつ /土日月/
どにちしゅくじつ /土日祝日/
どにちしゅくじついがい /土日祝日以外/
どにちちゅう /土日中/
どの /殿/
どのう /土嚢/
どはつ /怒髪/
どば /土場/
どばし /土橋/
どひ /土肥/奴婢/
どひょう /土俵/
どひょういり /土俵入/土俵入り/
どひょうぎわ /土俵際/
どひょうちゅうおう /土俵中央/
どぶがい /蚌/
どぶろ /土風炉/
どへき /土壁/
どべい /土塀/
どぼく /土木/
どぼくがく /土木学/
どぼくぎょうしゃ /土木業者/
どぼくけい /土木系/
どぼくけんせつこうがく /土木建設工学/
どぼくこうじ /土木工事/
どぼくこうぞうかいせき /土木構造解析/
どぼくさぎょうよう /土木作業用/
どま /土間/
どまり /止まり/
どまんなか /ド真中/
どみん /土民/
どめ /度目/
ども /共/
どもん /土門/
どよう /土曜/土用/
どようしんや /土曜深夜/
どようにちよう /土曜日曜/
どようばん /土曜晩/
どようび /土曜日/
どようびしゅっぱつ /土曜日出発/
どら /銅鑼/錚/鐃/鑼/
どらいば /ドライバ/
どらいばー /ドライバー/
どらいぶ /ドライブ/
どらえもん /ドラえもん/
どらっぐ /ドラッグ/
どらふと /ドラフト/
どらま /ドラマ/
どらむ /ドラム/
どらむす /ドラムス/
どらわん /銅羅湾/
どり /取り/
どりーむらんど /ドリームランド/
どりあ /ドリア/
どりょう /度量/
どりょうこう /度量衡/
どりょく /努力/
どりょくか /努力家/
どりょくかてい /努力過程/
どりょくぎむ /努力義務/
どりょくしょう /努力賞/
どりょくちゅう /努力中/
どりょくもくひょう /努力目標/
どる /＄/ドル/
どるい /土塁/土類/
どるいきんぞく /土類金属/
どれい /奴隷/
どれいかいほう /奴隷解放/
どれいしゅ /奴隷主/
どれいしょうにん /奴隷商人/
どれいせん /奴隷船/
どれいたち /奴隷達/
どれいてき /奴隷的/
どれっしんぐ /ドレッシング/
どろ /泥/土呂/
どろじあい /泥仕合/泥試合/
どろっぷ /ドロップ/
どろつち /泥土/
どろどろ /泥々/
どろなわ /泥縄/
どろぬま /泥沼/
どろぬまか /泥沼化/
どろぬまりゅう /泥沼流/
どろぼう /泥棒/
どろぼうたいさく /泥棒対策/
どろぼうねこ /泥棒猫/
どろみず /泥水/
どろみち /泥道/
どろよけ /泥除け/
どん /丼/鈍/呑/曇/貪/嫩/緞/
どんか /鈍化/
どんかく /鈍角/
どんかん /鈍感/
どんき /鈍器/
どんぐり /ドングリ/団栗/團栗/
どんこ /鈍行/
どんこう /鈍行/
どんしょく /貪食/
どんじゅう /鈍重/
どんす /緞子/
どんそく /鈍足/
どんぞこ /どん底/
どんちょう /緞帳/鈍重/
どんつう /鈍痛/
どんてん /曇天/
どんぶり /丼/
どんま /鈍磨/鈍麻/
どんもの /丼物/
どんよく /貪欲/
どんよくさ /貪欲さ/
どんらん /貪婪/曇鸞/
どんるい /丼類/
な /名/那/奈/菜/茄/納/南/儺/娜/拿/
なあて /名宛/
ない /内/無/乃/
ない> /内/
ないあつ /内圧/
ないい /内意/
ないいんせい /内因性/
ないうちゅう /内宇宙/
ないえ /奈井江/
ないえん /内縁/
ないか /内科/内化/内火/
ないかい /内界/内回/内科医/内海/
ないかいこうろ /内海航路/
ないかく /内閣/内角/
ないかくくんれい /内閣訓令/
ないかくこくじ /内閣告示/
ないかくせい /内閣制/
ないかくそうじしょく /内閣総辞職/
ないかくそうりだいじん /内閣総理大臣/
ないかくふ /内閣府;総理府、経済企画庁、沖縄開発庁が2001年1月の中央省庁再編で再編されたもの/
ないかくふしんにん /内閣不信任/
ないかくふしんにんあん /内閣不信任案/
ないかくぶんこ /内閣文庫/
ないかひ /内果皮/
ないがい /内外/
ないがいかかくさ /内外価格差/
ないがいそう /内外装/
ないがしろ /蔑ろ/
ないがめん /内画面/
ないき /内記/内規/
ないきじゅんかん /内気循環/
ないきょく /内局/
ないきん /内勤/
ないきんこん /内菌根/
ないくう /内腔/
ないぐう /内宮/
ないけい /内径/
ないげんけい /内原型/
ないこう /内向/内攻/内訌/
ないこうせい /内向性/
ないこうてき /内向的/
ないこく /内国/
ないこくさん /内国産/
ないこくさんしゅぼば /内国産種牡馬/
ないこくさんば /内国産馬/
ないさいぼうかい /内細胞塊/
ないざい /内在/
ないざいか /内在化/
ないざいてきせいしつ /内在的性質/
ないざいぶつ /内在物/
ないし /乃至/〜/内侍/
ないしき /内式/
ないしきょう /内視鏡/
ないしきょうけんさ /内視鏡検査/
ないしゃこう /内斜行/
ないしゅう /内周/
ないしゅうちょう /内周長/
ないしゅっけつ /内出血/
ないしょ /内緒/
ないしょう /内省/内証/内鞘/
ないしょく /内職/
ないしょばなし /内緒話/
ないしん /内心/内申/内診/
ないしんおう /内親王/
ないしんしょ /内申書/
ないしんのう /内親王/
ないしんふくざつ /内心複雑/
ないじ /内示/内耳/
ないじつ /内実/
ないじゅ /内需/
ないじゅかくだい /内需拡大/
ないじょ /内助/
ないじょう /内情/
ないじん /内陣/
ないすん /内寸/
ないせい /内省/内政/内製/内生/
ないせいかんしょう /内政干渉/
ないせいじょう /内清浄/
ないせいせいちょう /内生生長/
ないせいてき /内省的/
ないせいぶんし /内生分枝/
ないせいほうこく /内省報告/
ないせいもんだい /内政問題/
ないせき /内積/
ないせつ /内接/
ないせつえん /内接円/
ないせん /内線/内戦/
ないせんじょう /内線上/
ないせんじょうたい /内戦状態/
ないせんでんわ /内線電話/
ないせんでんわもう /内線電話網/
ないせんでんわよう /内線電話用/
ないせんばんごう /内線番号/
ないせんひょう /内線表/
ないせんもう /内線網/
ないそう /内装/内挿/内層/
ないそうほう /内挿法/
ないそく /内足/内側/
ないぞう /内蔵/内臓/
ないぞうおんげん /内蔵音源/
ないぞうかのう /内蔵可能/
ないぞうかんじ /内蔵漢字/
ないぞうがた /内蔵型/
ないぞうき /内蔵機/
ないぞうこてい /内蔵固定/
ないぞうしっかん /内臓疾患/
ないぞうでんち /内蔵電池/
ないぞうとけい /内蔵時計/
ないぞうどけい /内蔵時計/
ないぞうはれつ /内臓破裂/
ないぞうほうしき /内蔵方式/
ないぞうよう /内蔵用/
ないぞうろしゅつけい /内蔵露出計/
ないたい /内帯/内体/
ないたいせつ /内体説/
ないたつ /内達/
ないだいじん /内大臣/
ないだく /内諾/
ないだん /内談/
ないち /内地/
ないちけんしゅういん /内地研修員/
ないつう /内通/
ないてい /内定/内偵/
ないていしき /内定式/
ないていしゃ /内定者/
ないていしょ /内定書/
ないてき /内的/
ないてききじゅんおん /内的基準音/
ないてん /内点/
ないと /ナイト/
ないとう /内藤/
ないない /内々/
ないないてい /内々定/
ないにゅう /内乳/
ないねん /内燃/
ないねんき /内燃機/
ないねんきかん /内燃機関/内撚機関/
ないひ /内皮/
ないふ /ナイフ/
ないふく /内服/
ないふくえき /内服液/
ないふくやく /内服薬/
ないふん /内紛/
ないぶ /内部/
ないぶうちゅう /内部宇宙/
ないぶかいろ /内部回路/
ないぶかんすう /内部関数/
ないぶきこう /内部機構/
ないぶきごう /内部記号/
ないぶけいしき /内部形式/
ないぶけつごう /内部結合/
ないぶけつごうすう /内部結合数/
ないぶこーど /内部コード/
ないぶこうせい /内部構成/
ないぶこうそうてき /内部抗争的/
ないぶこうぞう /内部構造/
ないぶこうりょく /内部抗力/
ないぶこんごうしき /内部混合式/
ないぶごういきげん /内部合意期限/
ないぶしょり /内部処理/
ないぶしょりそくど /内部処理速度/
ないぶしよう /内部仕様/
ないぶしりょう /内部資料/
ないぶじかん /内部時間/
ないぶじじょう /内部事情/
ないぶじつげん /内部実現/
ないぶじゅうりょくは /内部重力波/
ないぶじゆうど /内部自由度/
ないぶじょうたい /内部状態/
ないぶじょうほう /内部情報/
ないぶせい /内部生/
ないぶせってい /内部設定/
ないぶせん /内部線/
ないぶそうさ /内部操作/
ないぶそうしょく /内部装飾/
ないぶぞうせつ /内部増設/
ないぶだんせん /内部断線/
ないぶていこう /内部抵抗/
ないぶてき /内部的/
ないぶてきおう /内部適応/
ないぶてききのう /内部的機能/
ないぶどうさ /内部動作/
ないぶは /内部波/
ないぶひずみ /内部歪/
ないぶひばくせんりょう /内部被曝線量/
ないぶひょう /内部表/
ないぶひょうげん /内部表現/
ないぶふせいごう /内部不整合/
ないぶぶんぴつこうぞう /内部分泌構造/
ないぶぶんれつ /内部分裂/
ないぶへんすう /内部変数/
ないぶほうかい /内部崩壊/
ないぶむじゅん /内部矛盾/
ないぶもーど /内部モード/
ないぶもでる /内部モデル/
ないぶもんだい /内部問題/
ないぶりゅうほ /内部留保/
ないぶりょういき /内部領域/
ないぶん /内聞/内分/
ないぶんぴつ /内分泌/
ないぶんぴつけい /内分泌系/
ないへき /内壁/
ないほう /内包/
ないほうてき /内包的/
ないほうろんり /内包論理/
ないみつ /内密/
ないむ /内務/
ないむしょう /内務省/
ないめん /内面/
ないめんか /内面化/
ないめんせい /内面性/
ないめんてき /内面的/
ないもう /内毛/
ないや /内野/
ないやあんだ /内野安打/
ないやおうえんだん /内野応援団/
ないやく /内約/
ないやしゅ /内野手/
ないやじゆうせき /内野自由席/
ないやじん /内野陣/
ないやせき /内野席/
ないゆう /内憂/
ないゆうがいかん /内憂外患/
ないよう /内容/
ないよういぜん /内容以前/
ないよういちらん /内容一覧/
ないようかくにん /内容確認/
ないようぎんみ /内容吟味/
ないようこうかい /内容公開/
ないようこうがい /内容梗概/
ないようごかん /内容互換/
ないようしだい /内容次第/
ないようしょうめい /内容証明/
ないようじたい /内容自体/
ないようせき /内容積/
ないようせつめい /内容説明/
ないようちゅう /内容中/
ないようてき /内容的/
ないようどおり /内容通り/
ないようなど /内容等/
ないようは /内容派/
ないようふめい /内容不明/
ないようぶ /内容部/
ないようぶつ /内容物/
ないようぶんせき /内容分析/
ないようぶんるい /内容分類/
ないようへんこう /内容変更/
ないようべつ /内容別/
ないようべつじっせき /内容別実績/
ないようほうふ /内容豊富/
ないようりょう /内容量/
ないらん /内乱/内覧/
ないりく /内陸/
ないりくせい /内陸性/
ないりくぶ /内陸部/
ないりょく /内力/
ないりん /内輪/
ないりんいがい /内輪以外/
ないりんさ /内輪差/
ないろん /ナイロン/
ないわくせい /内惑星/
なうて /名うて/
なえ /苗/奈江/
なえぎ /苗木/
なえこ /苗子/
なえどこ /苗床/
なえば /苗場/
なえばやま /苗場山/
なえぼ /苗穂/
なえむら /苗村/
なお /直/尚/奈央/菜穂/奈緒/猶/
なおあき /尚明/直明/
なおい /直井/
なおいち /直一/
なおいり /直入/
なおえ /直江/尚江/
なおえつ /直江津/
なおえつかん /直江津間/
なおかず /直一/直和/
なおかつ /直勝/猶且/
なおかわ /直川/
なおき /直樹/直紀/直喜/直毅/尚紀/
なおきしょう /直木賞/
なおきち /直吉/
なおこ /直子/奈保子/尚子/菜生子/奈央子/菜桜子/奈緒子/
なおさら /尚更/
なおざり /等閑/
なおし /直し/尚史/直史/直/直志/尚士/
なおしかた /直し方/
なおしま /直島/
なおじ /直治/
なおずみ /直純/尚純/
なおた /直田/
なおたか /直孝/
なおたけ /尚武/
なおと /直人/尚人/
なおとし /直利/直敏/尚稔/
なおのぶ /直宣/
なおのり /尚憲/直徳/尚紀/
なおはら /猶原/
なおはる /直治/
なおひこ /直彦/尚彦/
なおひさ /直久/尚久/
なおひで /直秀/
なおひと /直仁/直人/
なおひろ /直広/直廣/尚弘/尚宏/直弘/直宏/
なおふみ /直史/尚文/
なおまさ /直昌/
なおみ /奈緒美/直美/なお美/名保美/尚美/奈穂美/直実/奈保美/
なおみち /直道/
なおや /直也/尚也/直弥/尚哉/
なおゆき /直幸/尚之/直行/直之/尚幸/
なおよし /直義/直良/
なか /中/仲/那珂/
なかあし /中足/
なかあだち /中阿達/
なかい /中井/中居/仲井/仲居/
なかいえき /中井駅/
なかいけ /仲池/
なかいず /中伊豆/
なかいち /中市/
なかいひでお /中井英夫/
なかいま /仲井真/
なかいみほ /中井美穂/
なかいり /中入/
なかいわ /中岩/
なかう /なか卯/
なかうち /中内/
なかうま /中馬/
なかうみ /中海/
なかえ /中江/
なかえちょうみん /中江兆民/
なかお /中尾/
なかおか /中岡/
なかおかちまち /仲御徒町/
なかおがわてっきょう /中尾川鉄橋/
なかかるいざわ /中軽井沢/
なかかわね /中川根/
なかがい /仲買/
なかがいうち /中谷内/
なかがいにん /仲買人/
なかがき /中垣/
なかがた /中潟/
なかがみ /中上/
なかがみけんじ /中上健次/
なかがわ /中川/仲川/那賀川/那珂川/
なかがわら /中河原/
なかき /中木/
なかきた /中北/中来田/
なかぎし /中岸/
なかぎり /中桐/中限/
なかく /中区/
なかくら /中倉/仲倉/
なかくろ /・/
なかぐすく /中城/
なかぐろ /・/
なかけちょう /名掛丁/
なかこうじ /仲小路/
なかこま /中巨摩/
なかごう /中郷/
なかごし /中越/
なかごみ /中込/
なかごめ /中込/
なかごろ /中頃/中ごろ/
なかさき /中崎/
なかさく /中作/
なかさつない /中札内/
なかさと /中里/
なかさんげ /中山下/
なかざいけ /中在家/
なかざき /仲崎;姓/中崎;姓/
なかざと /中里;姓/仲里;姓/
なかざわ /中沢;姓/中澤;姓/仲沢;姓/
なかした /中下/
なかしべつ /中標津/
なかしべつかん /中標津間/
なかしほろ /中士幌/
なかしま /中島;姓/中嶋;姓/
なかしょう /中庄/
なかじま /中島;姓/中嶋;姓/中陦;姓/
なかじまけん /中島研/
なかじまつねゆき /中島常幸/
なかじまふとう /中島埠頭/
なかじゅく /中宿/
なかじょう /中條/中条/
なかす /中洲/中須/中州/
なかすぎ /中杉/
なかすじ /中筋/
なかすみ /中済/
なかず /中頭/
なかせ /中瀬/
なかせん /中仙/
なかせんどう /中山道/中仙道/
なかそ /中曽/
なかそね /中曽根/仲宗根/
なかそねやすひろ /中曽根康弘/
なかぞの /中園/中薗/
なかた /中田/仲田/
なかたがい /仲たがい/仲違い/
なかたじま /中田島/
なかたじまさきゅう /中田島砂丘/
なかたど /仲多度/
なかたに /中谷/仲谷/
なかたね /中種子/
なかだ /中田/仲田/
なかだいら /中平/
なかだかおり /仲田薫理/
なかだち /仲立ち/中立/
なかだちょう /中田町/
なかだて /中舘/
なかだるみ /中だるみ/
なかち /仲地/中地/
なかちく /中地区/
なかちょう /中長/
なかぢ /中地/
なかつ /中津/
なかつえ /中津江/中枝/
なかつか /中塚/
なかつかさ /中務/
なかつがる /中津軽/
なかつがわ /中津川/
なかつがわりんどう /中津川林道/
なかつぎ /中継ぎ/
なかつぶんこう /中津分校/
なかつやま /中津山/
なかづり /中吊り/
なかてん /・/中点/ナカテン/
なかで /中出/
なかとう /中藤/
なかとがわ /中戸川/
なかとき /中時/
なかとさ /中土佐/
なかとみ /中富/
なかとんべつ /中頓別/
なかなお /仲直/
なかなおり /仲直り/
なかなか /仲々/中々/難々/
なかにいかわ /中新川/
なかにいだ /中新田/
なかにし /中西/
なかにほん /中日本/
なかにわ /中庭/
なかね /中根/中値/仲値/
なかの /中野/仲野/
なかのいせい /中野以西/
なかのいとう /中野以東/
なかのえき /中野駅/
なかのく /中野区/
なかのくち /中之口/
なかのさんぷらざ /中野サンプラザ/
なかのし /中野市/
なかのしはつ /中野始発/
なかのしま /中之島/中野島/
なかのしょう /中之庄/中ノ庄/
なかのしょてん /中野書店/
なかのじょう /中之条/
なかのだい /中野台/
なかのぶがくえん /中延学園/
なかのべ /中延/
なかのほうめん /中野方面/
なかのむさしの /中野武蔵野/
なかはた /中畑;姓/
なかはら /中原;姓/
なかはらえき /中原駅/
なかはらかいかん /中原会館/
なかはらかいどう /中原街道/
なかはらく /中原区/
なかはらちゅうや /中原中也/
なかば /半ば/
なかばやし /中林/
なかばる /中原/
なかひがし /中東;姓/
なかひら /中平/
なかび /中日/
なかびしゃ /中飛車/
なかびょうし /中表紙/
なかぶと /中太/
なかへじ /中辺路/
なかほど /中程/
なかほり /中堀/
なかま /仲間/中間/仲魔/
なかまいしき /仲間意識/
なかまいり /仲間入/仲間入り/
なかまうち /仲間内/
なかまき /中牧/
なかまたち /仲間達/
なかまち /中町/仲町/
なかまつ /中松/
なかまどうし /仲間同士/
なかまる /・/中束/
なかみ /中身/中味/
なかみかわ /中見川/
なかみせ /仲見世/
なかみぞ /中溝/
なかみち /仲道/中道/
なかみなと /那珂湊/
なかむら /中村/仲村/
なかむらく /中村区/
なかむらけん /中村研/
なかむらこうこう /中村高校/
なかむらし /中村市/
なかむらたかし /中村尚司/
なかむらや /中村屋/
なかめぐろ /中目黒/
なかめぐろがわ /中目黒側/
なかめぐろてまえ /中目黒手前/
なかもず /中百舌鳥/
なかもと /中本/
なかもり /中森/
なかもりあきな /中森明菜/
なかもん /中門/
なかや /中谷/中屋/中矢/仲谷/
なかやま /中山/仲山/
なかやまきねん /中山記念/
なかやまけいばじょう /中山競馬場/
なかやましば /中山芝/
なかやませいこうしょ /中山製鋼所/
なかやまだいしょうがい /中山大障害/
なかやまとうげ /中山峠/
なかやまひんば /中山牝馬/
なかやまみほ /中山美穂/
なかやまりょう /中山陵/
なかゆび /中指/
なかよく /仲良く/
なかよし /仲良し/
なかりゃく /中略/
なかれ /勿/莫れ/勿れ/毋れ/毋/毓/
なかわきべつえき /中湧別駅/
なかわり /中割り/
なかんずく /就中/
なが /長/永/
ながあめ /長雨/
ながい /永井/長井/長居/永射/
ながいかふう /永井荷風/
ながいき /長生き/長生/
ながいきゅうぎじょう /長居球技場/
ながいけ /長池/
ながいこうえん /長居公園/
ながいし /長石/
ながいす /長椅子/
ながいずみ /長泉/
ながいた /長板/
ながうた /長唄/
ながえ /永江/
ながえさんきょう /長江三峡/
ながお /長尾/永尾/長緒/長夫/
ながおか /長岡/永岡/
ながおかえき /長岡駅/
ながおかきょう /長岡京/
ながおかきょうし /長岡京市/
ながおかきょうほうめん /長岡京方面/
ながおかぎかだい /長岡技科大/
ながおかぎじゅつだい /長岡技術大/
ながおかぎだい /長岡技大/
ながおかし /長岡市/
ながおかてんじん /長岡天神/
ながおかてんじんてん /長岡天神店/
ながおせん /長尾線/
ながおだい /長尾台/
ながおとうげ /長尾峠/
ながき /長岐/
ながぎし /永岸/
ながくて /長久手/
ながくら /長倉/
ながくらしんでんふきん /長蔵新田付近/
ながぐつ /長靴/
ながけちょう /名掛丁/
ながさ /長さ/
ながさか /長坂/
ながさき /長崎/永崎/
ながさきえき /長崎駅/
ながさきえきまえ /長崎駅前/
ながさきかようさい /長崎歌謡祭/
ながさきかんこう /長崎観光/
ながさきくうこう /長崎空港/
ながさきけん /長崎県/
ながさきけんえい /長崎県営/
ながさきけんおおむらし /長崎県大村市/
ながさきけんちょう /長崎県庁/
ながさきこう /長崎港/
ながさきし /長崎市/
ながさきしがい /長崎市外/
ながさきしない /長崎市内/
ながさきしゅっしん /長崎出身/
ながさきしゅっしんしゃ /長崎出身者/
ながさきしんぶん /長崎新聞/
ながさきせん /長崎線/
ながさきぞうせんじょ /長崎造船所/
ながさきだい /長崎大/
ながさきだいがく /長崎大学/
ながさきでんき /長崎電軌/
ながさきでんききどう /長崎電気軌道/
ながさきでんてつ /長崎電鉄/
ながさきどう /長崎道/
ながさきにちだい /長崎日大/
ながさきばん /長崎版/
ながさきへんせい /長崎編成/
ながさきほんせん /長崎本線/
ながさきや /長崎屋/
ながさきゆき /長崎行/
ながさきわん /長崎湾/
ながさく /永作/
ながさわ /永沢/長沢/長澤/
ながしだい /流し台/
ながしま /長島/長嶋/永嶋/永島/
ながしまおんせん /長島温泉/
ながしまかずしげ /長島一茂/
ながしまかんとく /長嶋監督/
ながしましげお /長嶋茂雄/
ながす /長洲/
ながすぎ /長過ぎ/
ながずぼん /長ズボン/
ながせ /永瀬/長瀬/
ながせさんぎょう /長瀬産業/
ながそで /長袖/
ながた /永田/長田/長多/
ながたちょう /永田町/
ながたに /永谷/長谷/
ながたにえん /永谷園/
ながたにえんほんぽ /永谷園本舗/
ながたび /長旅/
ながちょうば /長丁場/
ながっちり /長っ尻/
ながつ /長津/永津/
ながつか /長塚/長束/
ながつき /長月/
ながつだ /長津田/
ながつだえき /長津田駅/
ながつだけいゆ /長津田経由/
ながつだけいゆう /長津田経由/
ながつづき /長続き/永続き/
ながつま /長妻/
ながづくえ /長机/
ながてぶくろ /長手袋/
ながてほうこう /長手方向/
ながでんわ /長電話/
ながと /長門/長戸/
ながとし /長年/
ながとみ /長富/長冨/
ながとも /長友/永友/
ながとろ /長瀞/
ながなが /長々/
ながぬま /長沼/
ながねぎ /長葱/
ながねん /長年/永年/
ながの /長野/永野/長能/永埜/
ながのえき /長野駅/
ながのえきこうない /長野駅構内/
ながのがわ /長野側/
ながのけん /長野県/
ながのけんおかやし /長野県岡谷市/
ながのけんきそぐん /長野県木曽郡/
ながのけんしゅっしん /長野県出身/
ながのけんみん /長野県民/
ながのこう /長野高/
ながのこうじょう /長野工場/
ながのこうせん /長野高専/
ながのし /長野市/
ながのしぎかい /長野市議会/
ながのししゅっしん /長野市出身/
ながのしない /長野市内/
ながのしゃりょうく /長野車両区/
ながのしんかんせん /長野新幹線/
ながのじどうしゃどう /長野自動車道/
ながのだい /長野大/
ながのだいがく /長野大学/
ながのでんてつ /長野電鉄/
ながのどう /長野道/
ながのにほんむせん /長野日本無線/
ながのはら /長野原/
ながのはらくさつぐち /長野原草津口/
ながのほうめん /長野方面/
ながはし /長橋/
ながはた /永幡/
ながはま /長浜/長濱/
ながはまかん /長浜間/
ながはまていしょく /長浜定食/
ながはまゆき /長浜行/
ながはら /長原/永原/
ながばなし /長話/
ながふさ /長房/
ながぶせ /長伏/
ながぶち /長渕/長淵/
ながぶちつよし /長淵剛/
ながほ /長保/
ながまさ /長政/
ながまち /長町/
ながまちえき /長町駅/
ながまつ /永松/長松/
ながみ /永見/
ながみつ /長光/永光/
ながみね /長峯/長嶺/
ながむね /長宗/
ながめ /長目/眺め/
ながもち /長もち/長持ち/長持/
ながもちうた /長持唄/
ながもり /永森/
ながや /長家/長屋/長谷/
ながやす /永安/
ながやま /長山/永山/
ながやまえき /永山駅/
ながゆ /長湯/
ながゆき /長幸/
ながよ /長与/
ながよけいゆ /長与経由/
ながよし /永吉/
ながら /乍/乍ら/長柄/長良/
ながらがわ /長良川/
ながらがわかこうせき /長良川河口堰/
ながらがわてつどう /長良川鉄道/
ながらく /長らく/
ながれ /流れ/
ながれさぎょう /流作業/
ながれず /流れ図/
ながれぼし /流れ星/
ながれもの /流れ者/
ながれやま /流山/
ながわ /名川/奈川/
ながわずらい /長患い/痼/
なき /泣き/鳴/(concat "(\073_\073)")/
なきがお /泣き顔/
なきがら /亡骸/
なきごえ /鳴き声/鳴声/
なきむし /泣き虫/
なきり /奈切/
なぎ /凪/薙/梛/椥/奈義/南木/
なぎさ /渚/
なぎそ /南木曾/
なぎなた /長刀/薙刀/
なぎなたがた /長刀形/
なぎなたほこ /長刀鉾/
なぎなたぼこ /長刀鉾/
なぎょう /ナ行/
なくなく /泣く泣く/
なくら /名倉/
なぐ /薙/
なぐさめ /慰め/
なぐも /南雲/
なぐら /名倉/殴羅/
なぐり /名栗/
なぐりがき /殴り書き/
なげうり /投げ売り/
なげざお /投げ竿/
なげし /長押/
なげづり /投げ釣/
なげやり /投げ遣り/
なこ /名古/
なこうど /仲人/
なこそ /勿来/
なご /名護/名古/
なごや /名古屋/名越/那古屋/
なごやいがい /名古屋以外/
なごやえいぎょうしょ /名古屋営業所/
なごやえき /名古屋駅/
なごやえきちか /名古屋駅地下/
なごやえきていしゃ /名古屋停車/
なごやえきまえ /名古屋駅前/
なごやきゅうじょう /名古屋球場/
なごやきんこう /名古屋近郊/
なごやきんこぐん /名古屋金鯱軍/
なごやきんぺん /名古屋近辺/
なごやくうこう /名古屋空港/
なごやぐち /名古屋口/
なごやけいえい /名古屋経営/
なごやけいばじょう /名古屋競馬場/
なごやけいゆ /名古屋経由/
なごやけんきゅうしょ /名古屋研究所/
なごやこうえん /名古屋公演/
なごやこうぎょうだい /名古屋工業大/
なごやこうそく /名古屋高速/
なごやこうだい /名古屋工大/
なごやし /名古屋市/
なごやしきんこう /名古屋市近郊/
なごやししゃ /名古屋支社/
なごやしてん /名古屋支店/
なごやしない /名古屋市内/
なごやしはつ /名古屋始発/
なごやしぶ /名古屋支部/
なごやしゅうへん /名古屋周辺/
なごやしゅっしん /名古屋出身/
なごやじょう /名古屋城/
なごやじん /名古屋人/
なごやせいさくしょ /名古屋製作所/
なごやせん /名古屋線/
なごやたいかい /名古屋大会/
なごやだい /名古屋大/
なごやだいいん /名古屋大院/
なごやだいがく /名古屋大学/
なごやだいしょうてん /名古屋大賞典/
なごやだいり /名古屋大理/
なごやちく /名古屋地区/
なごやてつどう /名古屋鉄道/
なごやにし /名古屋西/
なごやはつ /名古屋発/
なごやばしょ /名古屋場所/
なごやべん /名古屋弁/
なごやほうめん /名古屋方面/
なごやほんせん /名古屋本線/
なごやまつり /名古屋祭/
なごやめいぶつ /名古屋名物/
なごり /名残/名残り/
なごん /納言/
なさけ /情/情け/
なさぬなか /生さぬ仲/
なざし /名指し/
なし /梨/無/
なしじ /梨子地/
なしだ /梨田/
なしだい /梨大/
なしのつぶて /梨の礫/
なしょなる /ナショナル/
なじみ /馴染/
なす /那須/茄子/那州/ナス/
なすおんせん /那須温泉/
なすか /ナス科/
なすこうじょう /那須工場/
なすしおばら /那須塩原/
なすすべ /為す業/為す術/
なすもく /ナス目/Solanales/
なすもくぐん /ナス目群/
なずな /薺/
なぜ /何故/名瀬/
なぜか /何故か/
なぜなら /∵/
なぞ /謎/
なぞがく /謎学/
なぞとき /謎解き/
なぞわざ /謎技/
なた /屶/釶/鉈/
なたしょう /名田庄/
なたに /名谷/
なだ /灘/
なだい /名代/名題/灘井/
なだきたどおり /灘北通/
なだく /灘区/
なだこう /灘高/灘校/
なだこうこう /灘高校/
なだこうとうがっこう /灘高等学校/
なださき /灘崎/
なだたる /名立たる/
なだち /名立/
なだちゅう /灘中/
なだちゅうがく /灘中学/
なだれ /雪崩/
なだれげんしょう /雪崩現象/
なだれしき /雪崩式/
なち /那智/
なっ /納/
なっせん /捺染/
なっと /ナット/
なっとう /納豆/
なっとうきん /納豆菌/
なっとうしゅう /納豆臭/
なっとうまき /納豆巻/
なっとく /納得/
なっとくかん /納得感/
なっぱ /菜葉/菜っ葉/
なつ /夏/捺/奈津/
なつあき /夏秋/
なついがい /夏以外/
なついろ /夏色/
なついん /捺印/
なつえ /夏江/
なつお /夏生/
なつおんな /夏女/
なつかし /懐かし/
なつかぜ /夏風邪/
なつかわ /夏川/
なつがき /夏牡蛎/
なつがた /夏型/
なつがっこう /夏学校/
なつがっしゅく /夏合宿/
なつき /夏生/夏樹/夏木/無月/奈月/
なつぎ /夏着/
なつくさ /夏草/
なつこ /なつ子/奈津子/那津子/夏子/
なつこみ /夏コミ/
なつごう /夏号/
なつごろ /夏頃/
なつしんぽ /夏シンポ/
なつじかん /夏時間/
なつじゅう /夏中/
なつぜんご /夏前後/
なつぞら /夏空/
なつの /夏野/
なつば /夏場/
なつばしょ /夏場所/
なつばて /夏バテ/
なつばん /夏版/
なつひこ /夏彦/
なつふく /夏服/
なつまけ /夏負/
なつまつり /夏祭/
なつみ /夏美/夏巳/菜摘/奈津美/夏実/
なつむき /夏向き/
なつめ /夏目/棗/棘/
なつめそうせき /夏目漱石/
なつめまさこ /夏目雅子/
なつもの /夏物/
なつやさい /夏野菜/
なつやすみ /夏休み/夏休/
なつやま /夏山/
なつよ /夏代/
なつよう /夏用/
なづけおや /名付親/
なでしこ /撫子/
なでしこもく /ナデシコ目/Caryophyllales/
なでしこもくぐん /ナデシコ目群/
なではら /撫原/
なでら /斜平/
なとり /名取/
なとりうむ /ナトリウム/
なとりし /名取市/
など /等/
などなど /等々/
なな /七/７/奈々/ナナ/奈奈/
なない /七位/
なないろ /七色/
なないろかいいき /七色海域/
ななえ /七重/奈々絵/奈々江/七栄/
ななお /七尾/
ななおせん /七尾線/
ななかい /七会/
ななかく /七角/
ななきた /七北田/
ななくさ /七草/
ななくま /七隈/
ななこ /奈々子/7個/七個/
ななころび /七転び/
ななさわ /奈々沢/
ななさん /七三/
ななし /名無/
ななしょく /七色/
ななじゅうねんだい /七十年代/
ななじょう /七条/
ななじょうかわらまち /七条河原町/
ななせ /七瀬/
ななそ /七十/
ななたび /七度/
ななたま /七玉/
ななだいせん /七大戦/
ななだる /七滝/
ななつ /七つ/七ツ/
ななつか /七塚/
ななつたき /七ッ滝/
ななつもり /七ッ森/
ななねん /七年/
ななねんめ /七年目/
ななひき /七匹/
ななふしぎ /七不思議/
ななぶ /七部/
ななみ /七生/七海/
ななめ /斜め/
ななめうしろ /斜め後ろ/
ななめこうほう /斜後方/
ななめぜんぽう /斜前方/
ななやしろ /七社/
ななやま /七山/
ななれんしょう /七連勝/
なに /何/
なにいろ /何色/
なにうりば /何売場/
なにか /何科/何か/
なにかと /何彼と/
なにがし /某/何某/
なにがた /何型/
なにけい /何系/
なにけん /何県/
なにげ /何気/
なにご /何語/
なにごと /何事/何言/
なにさま /何様/
なにしろ /何しろ/
なにじん /何人/
なにせん /何線/
なにせんせい /何先生/
なにとぞ /何卒/
なになに /何々/何何/
なにはさておき /何は扨措き/
なにばしょ /何場所/
なにぶん /何分/
なにもの /何者/何物/
なにもよう /何模様/
なにや /何屋/
なにゆえ /何故/
なによう /何用/
なにわ /浪花/浪速/灘/難波/
なにわぶし /浪花節/
なぬし /名主/
なのか /７日/七日/7日/
なのかしゅうき /七日週期/
なのかめ /七日目/
なのこ /菜子/
なのはな /菜の花/
なのり /名乗り/
なは /那覇/
なはえき /那覇駅/
なはくうこう /那覇空港/
なはけいゆ /那覇経由/
なはこうつう /那覇交通/
なはさば /鯆/
なはし /那覇市/
なはしでん /那覇市電/
なはしない /那覇市内/
なはり /奈半利/名張/
なばな /菜花/
なばり /名張/
なばりせん /名張線/
なふだ /名札/
なぶら /▽/∇/
なへん /奈辺/那辺/
なべ /鍋/邉/辺/邊/
なべかい /鍋会/
なべき /鍋気/
なべた /鍋田/
なべたに /鍋谷/
なべて /並べて/
なべの /鍋野/
なべはり /鍋貼/
なべもの /鍋もの/鍋物/
なほ /菜穂/尚/猶/
なほこ /菜穂子/
なほざり /等閑/
なほし /直衣/
なほみ /奈保美/
なほもって /尚以て/
なま /生/
なまいき /生意気/
なまえ /名前/
なまえいがい /名前以外/
なまえいり /名前入/
なまえかんり /名前管理/
なまえくうかん /名前空間/
なまえしてい /名前指定/
なまえじたい /名前自体/
なまえつきぱいぷ /名前付きパイプ/
なまえひょう /名前表/
なまえよう /名前用/
なまえようもじ /名前用文字/
なまえんそう /生演奏/
なまえんそうか /生演奏家/
なまおと /生音/
なまおん /生音/
なまかいとうきのう /生解凍機能/
なまかわ /生皮/
なまかんせん /生観戦/
なまがき /生蛎/生牡蛎/
なまがし /生菓子/
なまがっき /生楽器/
なまがわ /生皮/
なまき /生木/
なまくび /生首/
なまぐさ /生臭/腥/
なまけぐせ /怠け癖/
なまけもの /怠け者/
なまげんこう /生原稿/
なまこ /ナマコ/海鼠/
なまごめ /生米/
なまごろし /生殺し/
なまざかな /生魚/
なましいたけ /生椎茸/
なましゅつえん /生出演/
なましょく /生食/
なまじ /憖/
なまじっか /憖っか/
なまじゃけ /生鮭/
なまじゃしん /生写真/
なます /膾/鱠/韲/
なますじこ /生筋子/
なまず /鯰/癜/鮠/
なませっこう /生石膏/
なまたまご /生卵/
なまため /生天目/生田目/
なまだら /生ダラ/
なまちゅうけい /生中継/
なまつば /生唾/
なまづめ /生詰/
なまなしけん /山梨県/
なまなま /生生/生々/
なまにく /生肉/
なまはけい /生波形/
なまはんか /生半可/
なまばな /生花/
なまばんぐみ /生番組/
なまびょうほう /生兵法/
なまぴ /生ピ/
なまふ /生麩/
なまへんじ /生返事/
なまほうそう /生放送/
なまぼし /生乾し/
なままめ /生豆/
なまみ /生身/
なまみず /生水/
なまみそ /生味噌/
なまむぎ /生麦/
なまめん /生麺/
なまもの /生物/
なまやさい /生野菜/
なまり /鉛/訛/
なまりいた /鉛板/
なまりいり /鉛入/
なまりかごうぶつ /鉛化合物/
なまりだん /鉛弾/
なまりばん /鉛版/
なまりぶくろ /鉛袋/
なまろく /生録/
なみ /並/波/〜/奈美/浪/奈巳/奈未/竝/名美/
なみあい /浪合/
なみあし /並足/
なみいか /並以下/
なみうち /波打/
なみうちぎわ /波内際/波打ち際/波打際/
なみえ /浪江/
なみお /波雄/
なみおか /浪岡/
なみおと /波音/
なみかぜ /波風/
なみかた /波方/
なみかわ /浪川/並河/
なみがい /浪貝/
なみがけ /並罫/
なみき /並木/行木/
なみきおおはし /並木大橋/
なみきざ /並木座/
なみきみち /並木道/
なみこし /浪越/
なみしょう /浪商/
なみせい /並製/
なみせん /波線/
なみたいてい /並大抵/
なみだ /涙/泪/
なみだがお /涙顔/
なみだがた /涙型/
なみだきん /涙金/
なみだごえ /涙声/
なみだめ /涙目/
なみなみ /並々/
なみの /波野/
なみのり /波乗/
なみへい /波平/
なみま /波間/
なむ /南無/
なむあみだぶつ /南無阿弥陀仏/
なむさん /南無三/
なめ /滑/嘗/
なめいし /大理石/
なめかた /行方/
なめかわ /滑川/
なめがた /行方/
なめくじ /蛞蝓/
なめらか /滑らか/
なめりかわ /滑川/
なめりかわふきん /滑川付近/
なや /納屋/納谷/
なやみ /悩み/
なゆ /那由/
なゆた /那由多/那由他/奈由太/
なよろ /名寄/
なよろほんせん /名寄本線/
なら /奈良/楢/平城/柞/枹/
ならい /奈良井/
ならいごと /習い事/
ならえき /奈良駅/
ならお /奈良尾/
ならおか /奈良岡/
ならかわ /楢川/
ならかん /奈良間/
ならき /奈良木/
ならきんぺん /奈良近辺/
ならく /奈落/
ならけん /奈良県/
ならけんこうりやまし /奈良県郡山市/
ならけんなんぶ /奈良県南部/
ならけんみん /奈良県民/
ならこうぎょうこうせん /奈良工業高専/
ならこうぎょうこうとうせんもんがっこう /奈良工業高等専門学校/
ならこうせん /奈良高専/
ならこうつう /奈良交通/
ならさき /楢崎/
ならざき /楢崎/
ならし /奈良市/
ならししゅうへん /奈良市周辺/
ならしてん /奈良支店/
ならしない /奈良市内/
ならしの /習志野/
ならしのし /習志野市/
ならじだい /奈良時代/
ならじょしだい /奈良女子大/
ならじょしだいがく /奈良女子大学/
ならず /不成/
ならせん /奈良線/
ならせんえんせん /奈良線沿線/
ならせんきょうよう /奈良線共用/
ならせんたん /奈良先端/
ならせんたんかがくぎじゅつだいがくいんだいがく /奈良先端科学技術大学院大学/
ならせんたんだい /奈良先端大/
ならせんない /奈良線内/
ならちく /奈良地区/
ならちょう /奈良町/
ならでん /奈良電/
ならは /楢葉/
ならはら /奈良原/
ならば /→/⊃/
ならび /並び/
ならびかえ /並び換え/
ならへいあんじだい /奈良平安時代/奈良・平安時代/
ならべかえ /並べ替え/並べ変え/
ならほうめん /奈良方面/
ならやま /平城山/
ならやまぶしこう /楢山節考/
ならゆき /奈良行/
ならわし /習わし/
なり /也/成/就/斉/鳴り/形/哉/
なりあがり /成り上がり/
なりあき /成昭/
なりあきら /斉彬/
なりお /成雄/
なりかわ /成川/
なりきん /成金/
なりきんしゅみ /成金趣味/
なりぎん /成銀/
なりこ /成子/
なりこま /成駒/
なりさと /成里/
なりさわ /成沢/成澤/
なりしげ /成茂/
なりしま /成嶋/
なりた /成田/
なりたかん /成田間/
なりたくうこう /成田空港/
なりたくうこうえき /成田空港駅/
なりたくうこうかん /成田空港間/
なりたくうこうちゃく /成田空港着/
なりたくうこうとうそう /成田空港闘争/
なりたくうこうふきん /成田空港付近/
なりたくうこうもんだい /成田空港問題/
なりたけいゆ /成田経由/
なりたし /成田市/
なりたしざいじゅう /成田市在住/
なりたしんかんせん /成田新幹線/
なりたしんぽう /成田新法/
なりたずし /成田逗子/
なりたせん /成田線/
なりたち /成立ち/
なりたつ /成り立つ/
なりたにし /成田西/
なりたはつ /成田発/
なりたびん /成田便/
なりたほうめん /成田方面/
なりたや /成田屋/
なりたりこん /成田離婚/
なりち /成知/
なりて /為り手/
なりと /成人/
なりとみ /成富/
なりとも /成知/成伴/
なりはら /成原/
なりひと /成人/
なりひらばし /業平橋/
なりひらばしえき /業平橋駅/
なりひろ /成洋/
なります /成増/
なりまつ /成松/
なりみ /也実/也美/
なりみつ /成允/
なりもと /成本/
なりやす /成康/
なりゆき /成行き/成行/
なりよし /成良/
なりわ /成羽/
なりわい /生業/業/
なる /成/徳/鳴/奈留/
なるあき /成章/
なるお /鳴尾/成雄/
なるおきねん /鳴尾記念/
なるかみ /鳴神/
なるき /成紀/
なるきよ /成清/
なるけ /成毛/
なるこ /鳴子/
なるご /鳴子/
なるさわ /鳴澤/成澤/鳴沢/成沢/
なるさわりんどう /鳴沢林道/
なるしま /成嶋/
なるせ /成瀬/鳴瀬/
なるせだい /成瀬台/
なるたき /鳴滝/
なるち /成知/
なると /鳴門/
なるとう /成東/
なるとおおはし /鳴門大橋/
なるときょうていじょう /鳴門競艇場/
なるとだい /鳴門鯛/
なるひこ /徳彦/
なるひさ /徳寿/
なるひろ /成広/
なるべく /成る可く/可成/
なるほど /成程/成る程/
なるみ /成美/鳴海/成己/
なるみつ /成光/
なるよし /成良/
なれ /慣れ/馴/
なわ /縄/苗/名和/繩/
なわおか /縄岡/
なわしろ /苗代/
なわた /縄田/
なわて /畷/縄手/
なわとび /縄跳び/
なわない /縄綯い/
なわばしご /縄梯子/
なわばり /縄張/縄張り/
なをれ /名折れ/
なん /何/難/南/軟/楠/男/納/喃/娚/
なん> /何/
なんあり /難有り/
なんい /難易/南緯/何位/
なんいど /難易度/
なんいどせってい /難易度設定/
なんいどちょうせい /難易度調整/
なんいない /何位内/
なんえん /何円/
なんおう /南欧/
なんおうけい /南欧系/
なんおうふく /何往復/
なんおく /何億/
なんおくえん /何億円/
なんおくかい /何億回/
なんおくねん /何億年/
なんおん /軟音/
なんか /南下/軟化/
なんかい /何回/南海/難解/何階/
なんかいおうこく /南海王国/
なんかいきしかわせん /南海貴志川線/
なんかいじしん /南海地震/
なんかいせん /何回線/南海戦/
なんかいたかのせん /南海高野線/
なんかいてん /何回転/
なんかいでんしゃ /南海電車/
なんかいでんてつ /南海電鉄/
なんかいほうそう /南海放送/
なんかいほんせん /南海本線/
なんかいめ /何回目/
なんかいりゅう /南海龍/
なんかげつ /何箇月/何か月/何ヶ月/何カ月/
なんかこくご /何か国語/何カ国語/
なんかしょ /何か所/何箇所/何ヶ所/何ヵ所/何カ所/
なんかじょう /何箇条/
なんかん /難関/何巻/南関/
なんかんぶん /何巻分/
なんかんめ /何巻目/
なんが /軟臥/
なんがい /南外/
なんがつ /何月/
なんがつごう /何月号/
なんがつごろ /何月頃/
なんがつなんにち /何月何日/
なんがつなんにちごう /何月何日号/
なんがめん /何画面/
なんき /何機/南紀/
なんきごう /南紀号/
なんきしらはま /南紀白浜/
なんきつ /難詰/
なんきゅう /軟球/
なんきょく /南極/何曲/難局/難曲/何局/
なんきょくえっとうたい /南極越冬隊/
なんきょくかんかい /南極環海/
なんきょくかんそくたい /南極観測隊/
なんきょくけん /南極圏/
なんきょくしゅうきょくいき /南極周極域/
なんきょくしゅうきょくりゅう /南極周極流/
なんきょくじょうやく /南極条約/
なんきょくたいりく /南極大陸/
なんきょくめ /何曲目/
なんきん /南京/軟禁/
なんきんかんらく /南京陥落/
なんきんぎゃくさつじけん /南京虐殺事件/
なんきんこうりゃく /南京攻略/
なんきんし /南京市/
なんきんじけん /南京事件/
なんきんせんし /南京戦史/
なんきんだいぎゃくさつ /南京大虐殺/
なんきんぼうぎゃくじけん /南京暴虐事件/
なんぎ /難儀/
なんぎょう /何行/難行/難業/
なんぎょうめ /何行目/
なんく /何区/
なんくかん /何区間/
なんくせ /難癖/何癖/
なんくち /何口/
なんくみ /何組/
なんぐう /南宮/
なんけた /何桁/
なんけん /何件/何軒/軟件/
なんげん /何軒/南限/
なんこ /何個/
なんこう /難航/南港/軟膏/楠公/南高/軟攻/南光/
なんこうがい /軟口蓋/
なんこうがいびおん /軟口蓋鼻音/
なんこうだい /南光台/
なんこうどう /南江堂/
なんこうふらく /難攻不落/
なんこうまえ /楠公前/
なんこつ /軟骨/
なんこつぎょ /軟骨魚/
なんご /南後/喃語/
なんごう /何号/南郷/
なんごうかん /何号館/
なんごうしゃ /何号車/
なんごうせん /何号線/
なんごく /南国/
なんさい /何歳/何才/
なんさく /何作/
なんさくめ /何作目/
なんさつ /何冊/
なんざ /軟座/
なんざん /南山/難産/
なんざんだい /南山大/
なんざんだいがく /南山大学/
なんし /難思/
なんしあい /何試合/
なんしあいめ /何試合目/
なんしき /軟式/
なんしきやきゅう /軟式野球/
なんしつ /軟質/
なんしつまい /軟質米/
なんしゃしゅ /何車種/
なんしゅ /何種/
なんしゅう /何周/何週/
なんしゅうかん /何週間/
なんしゅうかんまえ /何週間前/
なんしゅうねん /何周年/
なんしゅうめ /何周目/
なんしゅるい /何種類/
なんしょ /難所/
なんしょう /何勝/
なんしょうなんぱい /何勝何敗/
なんしょく /難色/何色/男色/
なんしん /南進/
なんじ /何時/汝/何次/爾/難事/尓/
なんじいこう /何時以降/
なんじかん /何時間/
なんじけん /難事件/
なんじころ /何時頃/
なんじごろ /何時頃/
なんじっかい /何十回/
なんじっけん /何十件/
なんじっつう /何十通/
なんじってん /何十点/
なんじっぷん /何十分/
なんじなんぷん /何時何分/
なんじゃく /軟弱/
なんじゃくか /軟弱化/
なんじゃくもの /軟弱者/
なんじゅう /何十/何重/難渋/
なんじゅうえん /何十円/
なんじゅうおくこ /何十億個/
なんじゅうだい /何十台/
なんじゅうにん /何十人/
なんじゅうねん /何十年/
なんじゅうばい /何十倍/
なんじゅうばしん /何十馬身/
なんじゅうびょうかん /何十秒間/
なんじゅうまん /何十万/
なんじゅうまんにん /何十万人/
なんじゅうまんまい /何十万枚/
なんじゅうもん /何十問/
なんじゅうりょう /何十両/
なんじゅっかい /何十回/
なんじゅっけん /何十件/何十軒/
なんじゅっしゅうねんきねん /何十周年記念/
なんじゅっしゅるい /何十種類/
なんじゅっつう /何十通/
なんじゅってん /何十点/
なんじゅっぴき /何十匹/
なんじゅっぷん /何十分/
なんじゅっぽん /何十本/
なんじょう /南城/南条/南常/南條/何条/何乗/
なんじら /汝等/
なんすい /軟水/
なんせ /何せ/
なんせい /南西/軟性/何世/南勢/
なんせいき /何世紀/
なんせいこうくう /南西航空/
なんせいしょとう /南西諸島/
なんせいたん /南西端/
なんせいちく /南西地区/
なんせいにほん /南西日本/
なんせいぶ /南西部/
なんせいほうこう /南西方向/
なんせき /何隻/
なんせだい /何世代/
なんせん /南線/
なんせんめ /何戦目/
なんぜん /何千/
なんぜんえん /何千円/
なんぜんじ /南禅寺/
なんぜんつう /何千通/
なんぜんにん /何千人/
なんぜんねん /何千年/
なんぜんびき /何千匹/
なんぜんまん /何千万/
なんぜんまんえん /何千万円/
なんぜんまんにん /何千万人/
なんそう /何層/何走/
なんそく /何足/
なんそしき /軟組織/
なんたい /軟体/何体/男体/
なんたいさん /男体山/
なんたいどうぶつ /軟体動物/
なんたん /南端/
なんたんい /何単位/
なんだい /何台/難題/何代/
なんだばつ /何打罰/
なんだん /何段/南淡/
なんだんかい /何段階/
なんちしっかん /難治疾患/
なんちゃく /何着/
なんちゃくりく /軟着陸/
なんちゅう /南中/
なんちゅうじこく /南中時刻/
なんちょう /難聴/何丁/軟調/南朝/
なんちょうしゃ /難聴者/
なんつう /何通/
なんつうめ /何通目/
なんて /何て/
なんてい /軟庭/
なんてき /何滴/
なんてつ /軟鉄/
なんてん /難点/何点/何店/
なんてんか /ナンテン科/Nandinaceae/
なんてんぽ /何店舗/
なんでも /何でも/
なんでもや /何でも屋/
なんと /何と/南斗/南都/
なんとう /南東/何頭/軟投/南島/何等/
なんとうがたとうしゅ /軟投型投手/
なんとうきゅう /何等級/
なんとうせん /南東線/
なんとうは /軟投派/
なんとおり /何通り/
なんとか /何とか/
なんとなく /何となく/
なんとなれば /∵/
なんど /何度/難度/納戸/
なんどう /南洞/
なんどうせん /軟銅線/
なんどき /何時/
なんどく /難読/
なんどくちめい /難読地名/
なんどちょう /納戸町/
なんどめ /何度目/
なんなく /難なく/難無く/
なんなんせい /南南西/
なんなんとう /南南東/
なんにち /何日/
なんにちかん /何日間/
なんにちぐらい /何日位/
なんにちご /何日後/
なんにちごろ /何日頃/
なんにちづけ /何日付/
なんにちぶん /何日分/
なんにちまえ /何日前/
なんにちめ /何日目/
なんにん /何人/
なんにんぶん /何人分/
なんにんめ /何人目/
なんねん /何年/
なんねんうえ /何年上/
なんねんかん /何年間/
なんねんがた /何年型/
なんねんくらいまえ /何年位前/
なんねんご /何年後/
なんねんせい /難燃性/何年生/
なんねんなんがつ /何年何月/
なんねんなんがつごう /何年何月号/
なんねんなんがつなんにち /何年何月何日/
なんねんなんくみ /何年何組/
なんねんばん /何年版/
なんねんぶん /何年分/
なんねんまえ /何年前/
なんねんめ /何年目/
なんの /南野/何の/
なんのう /南濃/
なんはく /何拍/
なんはこ /何箱/
なんば /難波/
なんばー /ナンバー/
なんばい /何杯/何倍/
なんばら /南原/
なんばりき /何馬力/
なんばん /何番/南蛮/軟盤/
なんばんせん /何番線/
なんばんち /何番地/
なんばんめ /何番目/
なんぱ /軟派/難破/
なんぱく /何泊/何拍/
なんぱこ /何箱/
なんぱせん /難破船/
なんぱつ /何発/
なんぱつめ /何発目/
なんひき /何匹/
なんひょう /何票/
なんびき /何匹/
なんびと /何人/
なんびゃく /何百/
なんびゃくえん /何百円/
なんびゃくぎょう /何百行/
なんびゃくこうねんさき /何百光年先/
なんびゃくつう /何百通/
なんびゃくにん /何百人/
なんびゃくねん /何百年/
なんびゃくまん /何百万/
なんびゃくまんえん /何百万円/
なんびゃっこ /何百個/
なんびょう /何秒/難病/
なんびょういない /何秒以内/
なんびょうかん /何秒間/
なんぴと /何人/
なんぴょう /何票/
なんぴょうよう /南氷洋/
なんぴん /何品/
なんふつ /南仏/
なんふん /何分/
なんぶ /何部/南部/南武/軟部/
なんぶしせん /南武支線/
なんぶしゅっしん /南部出身/
なんぶせん /南武線/
なんぶせんえんせん /南武線沿線/
なんぶつ /難物/
なんぶはくじん /南部白人/
なんぶん /何分/
なんぷう /南風/
なんぷくじ /南福寺/
なんぷん /何分/
なんぷんまち /何分待ち/
なんへんせい /何編成/
なんべい /南米/
なんべいおうふく /南米往復/
なんべいきたはんぶん /南米北半分/
なんべいけい /南米系/
なんべいさん /南米産/
なんべいしゅうこう /南米就航/
なんべいしゅうゆう /南米周遊/
なんべいしゅうゆうけん /南米周遊券/
なんべいせん /南米線/
なんべいびょう /南米病/
なんべいほうめん /南米方面/
なんべいりょこう /南米旅行/
なんぺん /何編/
なんぼいん /軟母音/
なんぼく /南北/
なんぼくかん /南北間/
なんぼくせいぶん /南北成分/
なんぼくせん /南北線/
なんぼくせんかくえき /南北線各駅/
なんぼくせんそう /南北戦争/
なんぼくちょう /南北朝/
なんぼくちょうせん /南北朝鮮/
なんぼくねつゆそう /南北熱輸送/
なんぼくもんだい /南北問題/
なんぼくりゅう /南北流/
なんぼくりゅうりょう /南北流量/
なんぼん /何本/
なんぼんばしら /何本柱/
なんぼんめ /何本目/
なんぽ /何歩/
なんぽう /南方/
なんぽうかぜ /南方風/
なんぽうぐんしゅうだん /南方軍集団/
なんぽうけい /南方系/
なんぽうしゅっしん /南方出身/
なんぽく /南北/
なんぽろ /南幌/
なんぽん /何本/
なんまい /何枚/
なんまん /何万/
なんまんえん /何万円/
なんまんてん /何万点/
なんまんにん /何万人/
なんまんねん /何万年/
なんまんまい /何万枚/
なんみょうほうれんげきょう /南無妙法蓮華経/
なんみん /難民/
なんみんえんじょ /難民援助/
なんみんきゅうさいじょ /難民救済所/
なんみんく /難民区/
なんみんはん /難民班/
なんめい /何名/
なんめん /何面/南面/
なんもう /軟毛/
なんもく /南牧/
なんもじ /何文字/
なんもん /難問/何問/
なんもんしゅう /難問集/
なんもんそくとう /難問即答/
なんや /南谷/
なんよう /南陽/南洋/何曜/
なんようび /何曜日/
なんら /何等/何ら/
なんらか /何らか/
なんり /南里/
なんりゅうせき /南流石/
なんりょう /何両/
なんりょうへんせい /何両編成/
なんりょうめ /何両目/
なんりん /何輪/
なんれつ /何列/
なんれんさ /何連鎖/
なんろ /難路/
なんわ /何話/
なんわり /何割/
に /二/荷/迩/弐/煮/尼/似/２/弍/丹/2/児/邇/岻/貳/貮/爾/
にーず /ニーズ/
にーたん /ニータン/
にあう /似合う/
にあげ /荷揚げ/
にあつかい /荷扱い/
にあみす /ニアミス/
にい /兄/新/二位/新居/
にいい /新居/
にいいかかくてい /二位以下確定/
にいかっぷ /新冠/
にいかっぷちょう /新冠町/
にいかわ /新川/
にいがき /新垣/
にいがた /新潟/
にいがたえき /新潟駅/
にいがたかん /新潟間/
にいがたぐち /新潟口/
にいがたけん /新潟県/
にいがたこうつう /新潟交通/
にいがたさん /新潟産/
にいがたし /新潟市/
にいがたしない /新潟市内/
にいがたしゅっしん /新潟出身/
にいがただい /新潟大/
にいがただいがく /新潟大学/
にいがただいしょうてん /新潟大賞典/
にいがたちいき /新潟地域/
にいがたてっこうしょ /新潟鉄工所/
にいがたてん /新潟店/
にいがたほうそう /新潟放送/
にいがたみつこし /新潟三越/
にいがためいくん /新潟明訓/
にいがためいくんこう /新潟明訓高/
にいがためいくんこうこう /新潟明訓高校/
にいがたゆき /新潟行/
にいくら /新倉/
にいさと /新里/
にいさん /兄さん/
にいざ /新座/
にいざか /新坂/
にいざかまち /新坂町/
にいざき /新居崎/
にいざと /新里/
にいじま /新島/
にいじょう /二以上/
にいだ /新田/
にいちゃん /兄ちゃん/
にいつ /新津/
にいつま /新妻/
にいつる /新鶴/
にいづま /新妻/
にいで /新出/
にいな /二名/
にいぬま /新沼/
にいはま /新居浜/
にいはら /新原/
にいはり /新治/
にいはる /新治/
にいはるぐん /新治郡/
にいばる /新治/
にいべ /新部/
にいほ /仁保/新穂/
にいみ /新美/新見/新実/新實/
にいむら /新村/
にいるぴと /二色人/
にいんせい /二院制/
にうけ /荷受け/荷受/
にうけにん /荷受人/
にえ /贄/錵/
にえゆ /煮湯/
にお /匂/鳰/仁尾/
におい /匂い/匂/
におう /仁王/
におうふく /二往復/
におうみや /匂宮/
におくりにん /荷送人/
におし /二推し/
におろし /荷卸し/荷下ろし/
にか /二課/二価/
にかい /二階/二回/２回/2階/２階/2回/
にかいこうかん /二回交換/
にかいさんじゅつ /二階算術/
にかいせき /二階席/
にかいせきしょうめん /二階席正面/
にかいせん /二回戦/
にかいだて /二階建/
にかいていど /二回程度/
にかいどう /二階堂/
にかいどうこうこう /二階堂高校/
にかいめ /２回目/二回目/
にかいめいこう /二回目以降/
にかく /仁鶴/
にかげつ /二箇月/二ヶ月/二カ月/
にかげつぶん /二箇月分/二カ月分/
にかこく /二ヵ国/
にかしょ /二箇所/2箇所/二カ所/
にかほ /仁賀保/
にかわ /膠/仁川/
にかわせ /荷為替/
にかん /二冠/
にかんちゅうしんちゅう /二環中心柱/
にが /苦/
にがお /似顔/
にがおえ /似顔絵/
にがおえたいしょう /似顔絵大賞/
にがさ /苦さ/
にがたけ /苦竹/
にがつ /２月/二月/2月/如月/
にがつかくめい /二月革命;1848年フランスでの革命。これにより王政から共和制に移行した。/
にがて /苦手/
にがてちゅう /苦手中/
にがみ /苦味/
にがむし /苦虫/
にがゆ /煮粥/
にがわ /仁川/
にがわせ /荷為替/
にがわらい /苦笑い/
にがん /二眼/
にき /二基/二木/仁木/
にきかい /二期会/
にきしゅ /二機種/
にきび /靤/
にきゅう /二級/
にきゅうしゅ /二級酒/
にきゅうひん /二級品/
にきょく /二曲/二極/
にきょくか /二極化/
にきょくめ /二曲目/
にぎてき /二義的/
にぎにぎしい /賑々しい/
にぎやか /賑やか/
にぎょう /二行/2行/
にぎょうめいか /二行目以下/
にぎりずし /握り鮨/
にぎわい /賑/
にく /肉/
にくあつ /肉厚/
にくか /肉果/
にくかい /肉塊/
にくが /肉芽/
にくがかり /肉係/
にくがん /肉眼/
にくがんせいず /肉眼星図/
にくきゅう /肉球/
にくぎゅう /肉牛/
にくけい /肉桂/
にくげ /肉芽/
にくしつ /肉質/
にくしみ /憎しみ/
にくしゅ /肉腫/
にくしょく /肉食/
にくしょくきょうりゅう /肉食恐竜/
にくしょくぎょ /肉食魚/
にくしょくせい /肉食性/
にくしん /肉親/
にくじき /肉食/
にくじゅう /肉汁/
にくじる /肉汁/
にくすい /肉穂/肉垂/
にくすいかじょ /肉穂花序/
にくずくか /ニクズク科/Myristicaceae/
にくせい /肉声/
にくたい /肉体/
にくたいかんけい /肉体関係/
にくたいてき /肉体的/
にくたいてきくつう /肉体的苦痛/
にくたいてきけっかん /肉体的欠陥/
にくたいてきさい /肉体的差異/
にくたいてきちから /肉体的力/
にくたいてきとくちょう /肉体的特徴/
にくたいてきゆうえつ /肉体的優越/
にくたいねんれい /肉体年齢/
にくたいは /肉体派/
にくたいろうどう /肉体労働/
にくだい /肉代/
にくだま /肉玉/
にくだん /肉弾/肉彈/
にくだんせん /肉弾戦/肉彈戰/
にくづき /肉付き/
にくづけ /肉付け/
にくづめ /肉詰め/
にくはく /肉迫/肉薄/
にくひつ /肉筆/
にくへん /肉片/
にくぼう /肉棒/
にくや /肉屋/
にくよく /肉欲/
にくりょうり /肉料理/
にくるい /肉類/
にぐるま /荷車/
にぐん /二軍/二群/
にけん /二研/二件/二間/２研/二軒/
にげ /逃げ/
にげあし /逃げ足/
にげきり /逃げ切り/
にげごし /逃げ腰/
にげば /逃げ場/
にげみず /逃げ水/
にげみち /逃げ道/
にげん /二元/
にげんしゃ /二玄社/
にげんてき /二元的/
にげんろん /二元論/
にこ /二個/2個/:-)/(^^)/
にこう /二項/2項/二高/
にこうえんざんし /二項演算子/
にこうかんけい /二項関係/2項関係/
にこうぶんぷ /二項分布/
にこく /二国/
にこごり /煮凝/
にこちん /ニコチン/
にこにこ /ニコニコ/(^_^)/^_^/
にこみ /煮込/煮込み/
にご /二語/
にごう /二号/二合/
にごうかん /二号館/
にごうめ /二合目/
にごりえ /濁江/
にごん /二言/
にさ /二叉/
にさくひん /二作品/
にさつ /二冊/
にさつぶん /二冊分/
にさぶんし /二叉分枝/
にさん /二三/二、三/
にさんか /二酸化/
にさんかいおう /二酸化硫黄/
にさんかたんそ /二酸化炭素/
にさんかちっそ /二酸化窒素/
にさんにち /二三日/２、３日/
にざえもん /仁左衛門/
にざかな /煮魚/
にし /西/爾志/螺/二死/
にしあい /二試合/
にしあいづ /西会津/
にしあおやま /西青山/
にしあかし /西明石/
にしあかしていしゃ /西明石停車/
にしあざい /西浅井/
にしあざぶ /西麻布/
にしあち /西阿知/
にしあまね /西周/
にしあらい /西新井/
にしあらいかん /西新井間/
にしありえ /西有家/
にしありた /西有田/
にしあわくら /西粟倉/
にしい /西井/
にしいえ /西家/
にしいけ /西池/
にしいず /西伊豆/
にしいずほうめん /西伊豆方面/
にしいちさんるい /二死一三塁/
にしいばらき /西茨城/
にしいる /西入ル/
にしいわい /西磐井/
にしいんたあ /西インター/
にしうすき /西臼杵/
にしうみ /西海/
にしうみばしけいゆ /西海橋経由/
にしうめだ /西梅田/
にしうら /西浦/西裏/
にしうわ /西宇和/
にしお /西尾/
にしおおい /西大井/
にしおおいえき /西大井駅/
にしおおさかせん /西大阪線/
にしおおじ /西大路/
にしおおじごじょう /西大路五条/
にしおおじしじょう /西大路四条/
にしおおじしちじょう /西大路七条/
にしおおつ /西大津/
にしおおつえき /西大津駅/
にしおか /西岡/
にしおかざきかん /西岡崎間/
にしおぎ /西荻/
にしおぎくぼ /西荻窪/
にしおぎくぼえき /西荻窪駅/
にしおせんけいとう /西尾線系統/
にしおちあい /西落合/
にしかいがん /西海岸/
にしかいがんおうふく /西海岸往復/
にしかいがんけいゆ /西海岸経由/
にしかいがんけいゆう /西海岸経由/
にしかいがんちく /西海岸地区/
にしかいがんとし /西海岸都市/
にしかいがんりょうきん /西海岸料金/
にしかごしま /西鹿児島/
にしかごしまかん /西鹿児島間/
にしかさい /西葛西/
にしかしま /西鹿島/
にしかすがい /西春日井/
にしかぜ /西風/
にしかた /西片/西方/西形/
にしかつやま /西勝山/
にしかつら /西桂/
にしかど /西門/西角/
にしかながわじゅうみん /西神奈川住民/
にしかなざわ /西金沢/
にしかも /西加茂/
にしかるいざわ /西軽井沢/
にしかるいざわちょう /西軽井沢町/
にしかわ /西川/
にしかわきよし /西川きよし/
にしかん /西館/
にしかんだ /西神田/
にしかんばら /西蒲原/
にしがいち /西垣内/
にしがき /西垣/
にしがや /西ヶ谷/
にしがわ /西側/
にしがわしょこく /西側諸国/
にしがわじゆうしゃかい /西側自由社会/
にしがわじゆうせかい /西側自由世界/
にしがわじんえい /西側陣営/
にしがわせんしんこく /西側先進国/
にしがわぜんたい /西側全体/
にしき /錦/二式/西紀/西木/
にしきえ /錦絵/
にしきがおか /錦ヶ丘/
にしきがわてつどう /錦川鉄道/
にしきぎか /ニシキギ科/Celastraceae/
にしきぎもく /ニシキギ目/Celastrales/
にしきた /西北/
にしきちょう /錦町/
にしきど /錦戸/
にしきどう /錦堂/
にしきね /和稲/
にしきみ /錦見/
にしきょうごく /西京極/
にしきょうごくきゅうじょう /西京極球場/
にしきょうとえき /西京都駅/
にしきりゅう /西桐生/
にしきりゅうえき /西桐生駅/
にしぎょうく /西京区/
にしぎんざ /西銀座/
にしく /西区/
にしくあさまちょう /西区浅間町/
にしくじょう /西九条/
にしくじょうかん /西九条間/
にしくにさき /西国東/
にしくびき /西頚城/
にしくわな /西桑名/
にしくわなえき /西桑名駅/
にしぐち /西口/
にしぐちちかがい /西口地下街/
にしこう /西高/
にしこうえん /西公園/
にしこうべ /西神戸/
にしこく /西国/
にしこくぶんじ /西国分寺/
にしこくら /西小倉/
にしこくらえきまえ /西小倉駅前/
にしこまごめ /西駒込/
にしこむすび /西小結/
にしご /西語/二死後/
にしごう /西郷/
にしごうし /西合志/
にしごたんだ /西五反田/
にしさんそう /西三荘/
にしさんどう /西参道/
にしざおう /西蔵王/
にしざき /西崎/
にしざわ /西澤/西沢/
にしざわじゅんいち /西澤潤一/
にししおがま /西塩釜/
にしした /西下/
にししば /西柴/
にししらい /西白井/
にししらいかん /西白井間/
にししらかわ /西白河/
にししん /西新/
にししんじゅく /西新宿/
にししんじゅくしてん /西新宿支店/
にししんじゅくほうめん /西新宿方面/
にしじま /西嶋/西島/
にしじん /西陣/西新/
にしすぎ /西杉/
にしすずらんだい /西鈴蘭台/
にしせきわけ /西関脇/
にしせんだい /西仙台/
にしせんぼく /西仙北/
にしぜき /西関/
にしぞの /西園/
にしたかしまだい /西高島台/
にしたが /西多賀/
にしたてやま /西館山/西舘山/
にしたに /西谷/
にしたま /西多摩/
にしたんざわ /西丹沢/
にしだ /西田/
にしだいら /西平/
にしだけ /西岳/
にしださちこ /西田佐知子/
にしだて /西館/
にしだとしゆき /西田敏行/
にしちく /西地区/
にしつがる /西津軽/
にしてつ /西鉄/
にしてつおおむたせん /西鉄大牟田線/
にしてつきたきゅうしゅうせん /西鉄北九州線/
にしてつびん /西鉄便/
にしてつふくおか /西鉄福岡/
にしてつふくしません /西鉄福島線/
にしてつろせん /西鉄路線/
にしとう /西棟/
にしとうきょう /西東京/
にしとうきょうたいかい /西東京大会/
にしとさ /西土佐/
にしとさむら /西土佐村/
にしとじょうかん /西都城間/
にしとなみ /西砺波/西礪波/
にしどいつ /西ドイツ/西独/
にしどうろ /西道路/
にしどみ /西富/
にしな /仁科/西名/
にしなかじまみなみかた /西中島南方/
にしなが /西永/
にしなきねんざいだん /仁科記念財団/
にしなす /西那須/
にしなだ /西灘/
にしなり /西成/
にしにっぽり /西日暮里/
にしにっぽりほうめん /西日暮里方面/
にしにっぽん /西日本/
にしにっぽんがいしゃせん /西日本会社線/
にしにほん /西日本/
にしにほんいせい /西日本以西/
にしにほんいち /西日本一/
にしにほんいちえん /西日本一円/
にしにほんがくせい /西日本学生/
にしにほんがわ /西日本側/
にしにほんきょうとせん /西日本京都線/
にしにほんくかん /西日本区間/
にしにほんけん /西日本圏/
にしにほんご /西日本語/
にしにほんごか /西日本語化/
にしにほんししゃ /西日本支社/
にしにほんしぶ /西日本支部/
にしにほんしんぶん /西日本新聞/
にしにほんじょうもんご /西日本縄文語/
にしにほんたんだいふ /西日本短大付/西日本短大附/
にしにほんへん /西日本編/
にしね /西根/
にしの /西野/
にしのおもて /西之表/
にしのきょう /西の京/
にしのしま /西ノ島/
にしのだいら /西の平/
にしのはら /西之原/
にしのみや /西宮/
にしのみやいせい /西宮以西/
にしのみやいとう /西宮以東/
にしのみやかん /西宮間/
にしのみやきたぐち /西宮北口/
にしのみやきたぐちかん /西宮北口間/
にしのみやきたぐちつうか /西宮北口通過/
にしのみやきゅうぎじょう /西宮球技場/
にしのみやきゅうじょう /西宮球場/
にしのみやし /西宮市/
にしのみやせん /西宮線/
にしはくしまちょう /西白島町/
にしはし /西橋/
にしはた /西畑/
にしはちおうじえき /西八王子駅/
にしはま /西浜/
にしはら /西原/
にしはりだしこむすび /西張出小結/
にしはりだしせきわけ /西張出関脇/
にしはる /西春/
にしはんきゅう /西半球/
にしはんぶん /西半分/
にしばん /西版/
にしひら /西平/
にしひろしまし /西広島市/
にしび /西日/西陽/
にしびわじま /西枇杷島/
にしふじ /西富士/
にしふじのみや /西富士宮/
にしふな /西船/
にしふなばし /西船橋/
にしふなばしえき /西船橋駅/
にしふなばしかん /西船橋間/
にしべ /西部/
にしほ /西穂/
にしほうめん /西方面/
にしほだか /西穂高/
にしほんまち /西本町/
にしまいづる /西舞鶴/
にしまき /西牧/
にしまごめ /西馬込/
にしまごめいき /西馬込行/
にしまごめかん /西馬込間/
にしまごめゆき /西馬込行/
にしまち /西町/
にしまつ /西松/
にしまつうら /西松浦/
にしまど /西窓/
にしみや /西宮/
にしみやきたぐちえき /西宮北口駅/
にしむら /西村/
にしむらや /西村屋/
にしむらやま /西村山/
にしむろ /西牟婁/
にしめ /西目/
にしめいはん /西名阪/
にしめや /西目屋/
にしめら /西米良/
にしもと /西本/
にしもとかんとく /西本監督/
にしもり /西森/
にしもろかた /西諸県/
にしゃ /二者/二社/
にしゃかん /二者間/
にしゃたくいつ /二者択一/
にしゃたくいつかんけい /二者択一関係/
にしや /西屋/
にしやいづ /西焼津/
にしやつしろ /西八代/
にしやま /西山/
にしやまぼくじょう /西山牧場/
にしゅ /二種/
にしゅうかん /二週間/2週間/
にしゅうかんご /二週間後/
にしゅうかんまえ /二週間前/
にしゅうめいこう /二周目以降/
にしゅうれんぞく /二週連続/
にしゅつ /二出/
にしゅつしゅうさんかじょ /二出集散花序/
にしゅるい /二種類/
にしょう /二章/
にしょうがくしゃ /二松学舎/
にしょうてん /二焦点/
にしょうめ /二勝目/
にしょく /二食/二色/
にしよこづな /西横綱/
にしよこはま /西横浜/
にしよどがわ /西淀川/
にしわかまつ /西若松/
にしわき /西脇/
にしわせだ /西早稲田/
にしわだ /西和田/
にしん /鰊/二審/二進/鯡/2進/
にしんき /二進木/
にしんぎ /二進木/
にしんすう /2進数/二進数/
にしんひょうげん /二進表現/
にしんほう /２進法/二進法/
にしんわ /2進和/
にじ /二次/虹/2時/２次/二児/二時/2次/二字/
にじいかんそく /二次維管束/
にじいろ /虹色/
にじおくれようそ /二次遅れ要素/
にじおんげん /2次音源/
にじかい /二次会/
にじかこう /二次加工/
にじかん /二時間/2時間/
にじかんすう /二次関数/
にじかんせん /二次巻線/二次感染/
にじかんみゃく /二次間脈/
にじがわ /二次側/
にじき /二時期/
にじきおく /二次記憶/
にじきおくそうち /二次記憶装置/
にじきおくばいたい /二次記憶媒体/
にじきょくせん /二次曲線/
にじきょくめん /２次曲面/ 2 次曲面/
にじく /二軸/
にじけい /2次系/
にじけん /二次元/
にじげん /二次元/2次元/２次元/
にじこ /虹子/
にじしき /二次式/
にじしぶ /二次篩部/
にじしょうがい /二次障害/
にじしよう /二次使用/
にじしようりょう /二次使用料/
にじじこ /二次事故/
にじすいしょう /虹水晶/
にじせい /二字姓/
にじせいちょう /二次生長/
にじたいしゃ /二次代謝/
にじっさい /二十歳/
にじっせいき /二十世紀/
にじっぴき /二十匹/
にじていすう /二時定数/
にじてき /二次的/2次的/
にじてきちょさくぶつ /二次的著作物/
にじでんせつ /虹伝説/
にじでんち /二次電池/
にじとうごう /二次統合/
にじとうごうしょり /二次統合処理/
にじの /虹野/
にじはいふ /二次配布/
にじはいふしゃ /二次配布者/
にじばいあす /二次バイアス/
にじばん /二次版/
にじぶんれつそしき /二次分裂組織/
にじへき /二次壁/
にじほうていしき /二次方程式/
にじみゃく /二次脈/
にじもくぶ /二次木部/
にじゅう /二重/二十/2重/廿/
にじゅうあご /二重顎/
にじゅういちじょう /二一条/
にじゅういっせいき /二十一世紀/
にじゅういっぴき /二十一匹/
にじゅういんようふ /二重引用符/
にじゅううつし /二重写し/二重映し/
にじゅうおくこうねん /二十億光年/
にじゅうおんせい /二重音声/
にじゅうか /二重化/
にじゅうかくさん /二重拡散/
にじゅうかてい /二重過程/
にじゅうかべ /二重壁/
にじゅうかん /二重管/
にじゅうかんせつ /二重間接/
にじゅうきじゅん /二重基準/
にじゅうこうぞう /二重構造/
にじゅうこくせき /二重国籍/
にじゅうし /二十四/
にじゅうしょう /二重唱/
にじゅうじんかく /二重人格/
にじゅうすうせき /二十数隻/
にじゅうすうねんまえ /二十数年前/
にじゅうせい /二重性/
にじゅうせいきゅう /二重請求/
にじゅうせきぶん /二重積分/
にじゅうせん /2重線/二重線/
にじゅうそう /二重奏/
にじゅうたいけい /二重体系/
にじゅうだい /二十代/
にじゅうていぎ /二重定義/
にじゅうでんじ /二重電磁/
にじゅうとうこう /二重投稿/
にじゅうとうとく /二重登録/
にじゅうとうひょう /二重投票/
にじゅうとうろく /二重登録/
にじゅうにひき /二十二匹/
にじゅうねん /二十年/
にじゅうはんてん /二重反転/
にじゅうばし /二重橋/
にじゅうばしまえ /二重橋前/
にじゅうばしまええき /二重橋前駅/
にじゅうひてい /2重否定/
にじゅうぼいん /二重母音/
にじゅうまど /二重窓/
にじゅうまる /二重丸/◎/
にじゅうまん /二十万/
にじゅうめんそう /二十面相/
にじゅうろこう /二重露光/
にじゅうわく /二重枠/
にじゅっさい /二十歳/
にじゅっさいいじょう /二十歳以上/
にじゅっせいき /二十世紀/
にじゅっせいきすうがく /二十世紀数学/
にじゅっぴき /二十匹/
にじょ /二女/
にじょう /二乗/二条/2乗/二丈/
にじょうごさ /二乗誤差/
にじょうてきしゅうかんせい /日常的習慣性/
にじょうほう /二乗法/
にじょうわ /２乗和/
にじよせん /二次予選/
にじりゅうし /2次粒子/
にじる /煮汁/
にじるし /荷印/
にじんえい /二陣営/
にすうか /二数花/
にすがた /荷姿/
にせ /偽/贋/偐/僞/
にせい /二世/２声/
にせき /二関/
にせけいかん /偽警官/
にせこ /ニセコ/
にせさつ /偽札/
にせたんてい /偽探偵/
にせほんちょう /二瀬本町/
にせもの /偽物/贋物/偽者/
にせん /二千/二線/二錢/
にせんきゅう /二線級/
にせんしき /二線式/
にせんにんいじょう /二千人以上/
にそう /二層/尼僧/二相/二曹/
にそうしきせんたくき /二槽式洗濯機/
にそく /二足/
にそくさんもん /二束三文/
にそくほこう /二足歩行/
にた /仁多/
にたい /二体/
にたいもんだい /二体問題/
にただ /仁多田/
にたどり /似鳥/
にたに /二谷/
にたにた /ニタニタ/
にたにゆりえ /二谷友里恵/
にたみ /仁多見/
にたやま /仁田山/
にたろう /二太郎/
にだい /2大/二台/荷台/二大/
にだいかいちょう /二代会長/
にだいしょうぐん /二代将軍/
にだいめ /二代目/二台目/
にだし /荷出し/
にだな /荷棚/
にだん /二段/
にだんかい /二段階/2段階/
にだんかいまえ /二段階前/
にだんがさね /二段重ね/
にだんぐみ /二段組/
にだんこうげき /二段攻撃/
にだんめ /二段目/
にち /日/二値/2値/
にちいき /日域/
にちいだい /日医大/
にちいん /日陰/
にちえい /日英/日影/日栄/
にちおう /日欧/
にちおん /日音/
にちか /二値化/2値化/二千翔/
にちかもくきんど /日火木金土/
にちかん /日間/
にちが /日我/
にちがく /日額/
にちがぞう /二値画像/
にちぎん /日銀/
にちぎんそうさい /日銀総裁/
にちげつ /日月/
にちげつかすい /日月火水/
にちげつかすいもく /日月火水木/
にちげん /日限/
にちご /日後/
にちじ /日時/日次/
にちじび /日耳鼻/
にちじゅう /日中/
にちじょう /日常/
にちじょういっぱん /日常一般/
にちじょうかいわ /日常会話/
にちじょうかいわげんご /日常会話言語/
にちじょうかいわしゅうとく /日常会話修得/
にちじょうがいねん /日常概念/
にちじょうぎょうむ /日常業務/
にちじょうげんご /日常言語/
にちじょうご /日常語/
にちじょうさはん /日常茶飯/
にちじょうさはんじ /日常茶飯事/
にちじょうしゃかい /日常社会/
にちじょうしゅ /日常酒/
にちじょうしゅうかん /日常習慣/
にちじょうせい /日常性/
にちじょうせいかつ /日常生活/
にちじょうせいかつじょう /日常生活上/
にちじょうせいかつぜんぱん /日常生活全般/
にちじょうちしき /日常知識/
にちじょうてき /日常的/
にちじょうてきがいねん /日常的概念/
にちじょうてきじょうきょう /日常的状況/
にちじょうてきひょうげん /日常的表現/
にちじょうてきびょうしゃ /日常的描写/
にちじょうりよう /日常利用/
にちじょたいだい /日女体大/
にちずい /日瑞/
にちだい /日大/日本大学/
にちだいこうどう /日大講堂/
にちだいさくらがおか /日大桜ヶ丘/
にちだいさくらがおかこうこう /日大桜ヶ丘高校/
にちだいせいさんこう /日大生産工/
にちだいだいがくいん /日大大学院/
にちだいつるがおか /日大鶴ヶ丘/
にちだいにこう /日大二高/
にちだいぶざん /日大豊山/
にちだいぶざんじょしこうこう /日大豊山女子高校/
にちだいやまがた /日大山形/
にちだいりこう /日大理工/
にちだいりこうこうくう /日大理工航空/
にちだいりこうでんし /日大理工電子/
にちづけ /日付/
にちでん /日電/
にちでんきょう /日電協/
にちでんせい /日電製/
にちでんばん /日電版/
にちどう /日動/
にちどうかさい /日動火災/
にちどく /日独/
にちなん /日南/
にちなんかいがん /日南海岸/
にちなんがくえん /日南学園/
にちなんし /日南市/
にちにち /日々/
にちはむ /日本ハム/
にちはら /日原/
にちはん /日半/日販/
にちふつ /日仏/
にちぶ /日舞/
にちぶん /日分/日文/
にちべい /日米/
にちべいかいぎ /日米会議/
にちべいかいせん /日米開戦/
にちべいかかくさ /日米価格差/
にちべいかがくきょうどうけんきゅう /日米科学共同研究/
にちべいかがくきょうりょくじぎょう /日米科学協力事業/
にちべいかん /日米間/
にちべいかんらくさ /日米間落差/
にちべいきょうどう /日米共同/
にちべいきょうどうけんきゅう /日米共同研究/
にちべいけいざいきょうぎ /日米経済協議/
にちべいこうくうきょうてい /日米航空協定/
にちべいこうくうぼかん /日米航空母艦/
にちべいこうしょう /日米交渉/
にちべいこうぞうきょうぎ /日米構造協議/
にちべいしんぜん /日米親善/
にちべいせんそう /日米戦争/
にちべいたいこう /日米対抗/
にちべいだいがくせい /日米大学生/
にちべいとっきょもんだい /日米特許問題/
にちべいひかく /日米比較/
にちべいぼうえきまさつ /日米貿易摩擦/
にちべいやきゅう /日米野球/
にちべんれん /日弁連/
にちほうほんせん /日豊本線/
にちぼうしん /日貿信/
にちぼつ /日没/
にちぼつご /日没後/
にちぼつじこく /日没時刻/
にちぼつまえ /日没前/
にちまえ /日前/
にちめ /日目/
にちめんじつぎょう /日綿実業/
にちや /日夜/
にちやどりょく /日夜努力/
にちゅう /二中/
にちょう /二鳥/
にちょうなげ /二丁投げ/
にちょうめ /二丁目/
にちよう /日曜/日用/
にちようあさ /日曜朝/
にちよううんきゅう /日曜運休/
にちようげきじょう /日曜劇場/
にちようごご /日曜午後/
にちようさいじつ /日曜祭日/
にちようしゅくじつ /日曜祝日/
にちようしゅっきん /日曜出勤/
にちようしんや /日曜深夜/
にちようだいく /日曜大工/
にちようだいくひん /日曜大工品/
にちようだいくひんてん /日曜大工品店/
にちようはつ /日曜発/
にちようばん /日曜版/
にちようひん /日用品/
にちようび /日曜日/
にちようびあさ /日曜日朝/
にちようびじゅつかん /日曜美術館/
にちようびゆうがた /日曜日夕方/
にちようぶん /日曜分/
にちようようがげきじょう /日曜洋画劇場/
にちようよる /日曜夜/
にちりょう /日糧/
にちりん /日輪/日林/
にちりんし /日林誌/
にちりんろん /日林論/
にちれき /日瀝/
にちれん /日蓮/
にちろ /日露/
にちろぎょぎょう /日魯漁業/
にちろせんえき /日露戦役/
にちろせんそう /日露戦争/
にちわ /日和/
にっか /日課/
にっかぎれん /日科技連/
にっかつ /日活/
にっかつこうぎょう /日活興業/
にっかゆし /日華油脂/
にっかわ /新川/
にっかん /日刊/日韓/
にっかんきょうてい /日韓協定/
にっかんけいば /日刊競馬/
にっかんこう /日刊工/
にっかんこうぎょう /日刊工業/
にっかんこうぎょうしんぶん /日刊工業新聞/
にっかんこうぎょうしんぶんしゃ /日刊工業新聞社/
にっかんこうしょう /日韓交渉/
にっかんこうそくせん /日韓高速船/
にっかんし /日刊紙/
にっかんじょうやく /日韓条約/
にっかんへいごうじ /日韓併合時/
にっかんやきゅう /日韓野球/
にっき /日記/日揮/
にっきしゅう /日記集/
にっきそう /日機装/
にっきちょう /日記帳/
にっきふう /日記風/
にっきゅう /日給/
にっきょう /日共/
にっきょうさい /日教済/
にっきょうそ /日教組/
にっきん /日勤/
にっくう /日空/
にっくに /新国/
にっけい /日経/日系/日計/肉桂/
にっけいきぎょう /日系企業/
にっけいこうくうがいしゃ /日系航空会社/
にっけいさんぎょうしんぶん /日経産業新聞/
にっけいしょう /日経賞/
にっけいしんしゅんはい /日経新春杯/
にっけいしんぶん /日経新聞/
にっけいしんぶんゆうかん /日経新聞夕刊/
にっけいじん /日系人/
にっけいにせい /日系二世/
にっけいひょう /日計表/
にっけいへいきん /日経平均/
にっけいれん /日経連/
にっけんかがく /日研化学/
にっこう /日光/日興/日航/日工/
にっこういがい /日光以外/
にっこうえき /日光駅/
にっこうがわ /日光側/
にっこうき /日航機/
にっこうきどう /日光軌道/
にっこうきょうせき /日鉱共石/
にっこうしょうけん /日興證券/日興証券/
にっこうせん /日光線/
にっこうほんせん /日光本線/
にっこうよく /日光浴/
にっこり /莞爾/
にっさん /日産/日参/
にっさんうんそう /日産運送/
にっさんしゃ /日産車/
にっさんしゃたい /日産車体/
にっさんじどうしゃ /日産自動車/
にっさんよこはま /日産横浜/
にっし /日誌/
にっしゃ /日射/
にっしゃびょう /日射病/
にっしゃびょうかんじゃ /日射病患者/
にっしゃりょう /日射量/
にっしゅう /日収/日周/
にっしょう /日商/日照/日章/
にっしょういわい /日商岩井/
にっしょうけん /日照権/
にっしょうけんもんだい /日照権問題/
にっしょうどう /日章堂/
にっしょうぶそく /日照不足/
にっしょうりょう /日照量/
にっしょく /日食/日蝕/
にっしん /日清/日進/日神/日新/日心/
にっしんげっぽ /日進月歩/
にっしんしょくひん /日清食品/
にっしんせいこう /日新製鋼/
にっしんせいふん /日清製粉/
にっしんせいゆ /日清製油/
にっしんせんそう /日清戦争/
にっしんちょう /日進町/
にっしんぼうせき /日清紡績/
にっすう /日数/
にっせい /日精/日生/
にっせいげきじょう /日生劇場/
にっせいさんぎょう /日製産業/
にっせき /日赤/日石/
にっそ /日ソ/
にった /新田/仁田/
にったいおうか /日体桜華/
にったいだい /日体大/
にったく /日拓/
にったん /日鍛/
にっちつ /日窒/
にっちも /二進も/
にっちゅう /日中/
にっちゅうかん /日中韓/日中間/
にっちゅうかんけい /日中関係/
にっちゅうさつえいよう /日中撮影用/
にっちゅうしよう /日中使用/
にっちゅうせんそう /日中戦争/
にっちゅうせんそうご /日中戦争後/
にっちゅうそうほう /日中双方/
にっちゅうゆうこう /日中友好/
にっちゅうりょこうしゃ /日中旅行社/
にっちょく /日直/
にっつう /日通/
にっつうこうくう /日通航空/
にってい /日程/日帝/
にっていえんき /日程延期/
にっていちょうせい /日程調整/
にっていてき /日程的/
にっていひょう /日程表/
にっていへんこう /日程変更/
にっていみつもり /日程見積り/
にってつ /日鉄/
にってれ /日テレ/
にってん /日展/
にっとー /ニットー/
にっとう /日当/日東/日塔/入唐/
にっとうしょいん /日東書院/
にっとうせいもう /日東製網/
にっとうぼう /日東紡/
にっとうぼうせき /日東紡績/
にっぴょう /日評/
にっぽう /日報/日豊/
にっぽうせん /日豊線/
にっぽうほんせん /日豊本線/
にっぽじしょ /日葡辞書/
にっぽり /日暮里/
にっぽん /日本/
にっぽんあすべすと /日本アスベスト/
にっぽんいち /日本一/
にっぽんかーぼん /日本カーボン/
にっぽんかい /日本海/
にっぽんかせい /日本化成/
にっぽんかん /日本間/
にっぽんがいし /日本ガイシ/日本碍子/
にっぽんきんぞく /日本金属/
にっぽんぎんこう /日本銀行/
にっぽんぐんじん /日本軍人/
にっぽんぐんぶたい /日本軍部隊/
にっぽんぐんへいし /日本軍兵士/
にっぽんけいゆ /日本経由/
にっぽんけいゆう /日本経由/
にっぽんけおり /日本毛織/
にっぽんけみこん /日本ケミコン/
にっぽんけみふぁ /日本ケミファ/
にっぽんこう /日本校/
にっぽんこうかいじ /日本公開時/
にっぽんこうかん /日本鋼管/
にっぽんこうくう /日本航空/
にっぽんこく /日本国/
にっぽんこくけんぽう /日本国憲法/
にっぽんころむびあ /日本コロムビア/
にっぽんご /日本語/
にっぽんしき /日本式/
にっぽんしん /日本新/
にっぽんしんぱん /日本信販/
にっぽんしんやく /日本新薬/
にっぽんじん /日本人/
にっぽんじんかんこうきゃく /日本人観光客/
にっぽんじんけんきゅうしゃ /日本人研究者/
にっぽんじんしんぱん /日本人審判/
にっぽんじんせんしゅ /日本人選手/
にっぽんすいさん /日本水産/
にっぽんせいこう /日本精工/
にっぽんせいふん /日本製粉/
にっぽんぜおん /日本ゼオン/
にっぽんたいかい /日本大会/
にっぽんつううん /日本通運/
にっぽんでんき /日本電気/
にっぽんでんこう /日本電工/
にっぽんでんそう /日本電装/
にっぽんでんつう /日本電通/
にっぽんとむそん /日本トムソン/
にっぽんどうろ /日本道路/
にっぽんはつじょう /日本発条/
にっぽんはむ /日本ハム/
にっぽんばし /日本橋/
にっぽんひゃくめいとうげ /日本百名峠/
にっぽんひゅーむかん /日本ヒューム管/
にっぽんびくたー /日本ビクター/
にっぽんぶどうかん /日本武道館/
にっぽんぺいんと /日本ペイント/
にっぽんほうそう /日本放送/
にっぽんほんど /日本本土/
にっぽんゆうせん /日本郵船/
にっぽんゆそうき /日本輸送機/
にっぽんゆにばっく /日本ユニバック/
にっぽんれーす /日本レース/
につう /二通/2通/
につうめ /2通目/
につけ /煮付け/
にづくり /荷作り/荷造り/
にづくりひ /荷造費/
にて /二手/
にてん /二点/2点/
にてんさんてん /二転三転/
にてんとうし /二点透視/
にとう /仁藤/二等/二頭/
にとうきん /二頭筋/
にとうしゃ /二等車/
にとうしん /二頭身/
にとうぶん /2等分/二等分/
にとうぶんせん /二等分線/
にとうへい /二等兵/
にとうへいそう /二等兵曹/
にとうへんさんかっけい /二等辺三角形/
にとうめ /二頭目/
にとうりゅう /二刀流/
にとうわしつ /二等和室/
にとべ /二藤部/
にとものがたり /二都物語/
にとろ /ニトロ/
にとろぐりせりん /ニトログリセリン/
にど /二度/
にどうち /二度打ち/
にどでま /二度手間/
にどぬり /二度塗/
にどめ /二度目/
にな /蜷/螺/
にないて /担い手/
にながわ /蜷川/
になんせん /日南線/
ににん /二人/
ににんさんきゃく /二人三脚/
ににんしょう /二人称/
ににんしょうたんすう /二人称単数/
にぬけ /２抜け/
にぬし /荷主/
にねん /二年/2年/２年/
にねんかん /二年間/
にねんご /二年後/
にねんせい /二年生/2年生/
にねんせいそうほん /二年生草本/
にねんまえ /二年前/
にねんめ /二年目/
にのあし /二の足/
にのかまえ /二構/二構え/
にのつぎ /二の次/
にのへ /二戸/
にのまい /二の舞/二の舞い/
にのまる /二の丸/
にのみや /二宮/
にのみやぶんいん /二宮分院/
には /二波/二派/
にはい /二杯/二敗/
にはか /俄/
にはく /二泊/二拍/2泊/
にはくみっか /二泊三日/
にはくめ /二拍目/
にはつ /二発/
にはつめ /二発目/
にはん /二犯/二版/
にばい /二倍/
にばいす /二杯酢/
にばしゃ /荷馬車/
にばん /二番/
にばんかん /二番館/
にばんせき /二番席/
にばんせん /二番煎/
にばんせんじ /二番煎じ/
にばんだしゃ /二番打者/
にばんちょう /二番町/
にばんて /二番手/
にばんめ /二番目/2番目/
にひき /二匹/
にひきめ /二匹目/
にひゃく /二百/
にひゃくすうじゅうねん /二百数十年/
にひゃくつう /二百通/
にひょうめいこう /二票目以降/
にびいろ /鈍色/
にふ /２符/二夫/
にふだ /荷札/
にふん /2分/
にぶ /二部/2部/II部/
にぶおんぷ /２分音符/
にぶつ /二物/
にぶん /二分/2分/
にぶんき /二分木/
にぶんぎ /二分木/2分木/
にぶんほう /二分法/2分法/
にへい /二瓶/
にへん /二辺/
にへんすう /2変数/
にべ /仁部/
にほ /二歩/
にほう /二方/
にほうじゅう /日本中/
にほうせい /二峰性/
にほてまえ /二歩手前/
にほん /日本/二本/
にほんあし /二本足/
にほんいかだいがく /日本医科大学/
にほんいがい /日本以外/
にほんいくえいかい /日本育英会/
にほんいじょう /日本以上/
にほんいたがらす /日本板硝子/
にほんいだい /日本医大/
にほんいち /日本一/
にほんいっしゅう /日本一周/
にほんいりゅうみん /日本居留民/
にほんえいが /日本映画/
にほんえいがしじょう /日本映画史上/
にほんえいせいほうそう /日本衛星放送/
にほんえん /日本円/
にほんえんかきょうかい /日本煙火協会/
にほんえんがん /日本沿岸/
にほんえんげきし /日本演劇史/
にほんおうふく /日本往復/
にほんおんがくこうこう /日本音楽高校/
にほんおんきょうがっかい /日本音響学会/
にほんおんきょうがっかいし /日本音響学会誌/
にほんか /二本化/
にほんかい /日本海/
にほんかいえんがん /日本海沿岸/
にほんかいかいせん /日本海海戦/
にほんかいがたきこう /日本海型気候/
にほんかいがわ /日本海側/
にほんかいぐん /日本海軍/
にほんかいこう /日本海溝/
にほんかいじゅうかん /日本海縦貫/
にほんかいようがっかい /日本海洋学会/
にほんかがっかい /日本化学会/
にほんかくち /日本各地/
にほんかぶ /日本株/
にほんかやく /日本化薬/
にほんかん /日本間/日本館/
にほんかんとうぐん /日本関東軍/
にほんが /日本画/
にほんがいし /日本ガイシ/日本碍子/
にほんがく /日本学/
にほんがくじゅつかいぎ /日本学術会議/
にほんがた /日本型/
にほんがわ /日本側/
にほんがわふたん /日本側負担/
にほんきいん /日本棋院/
にほんきか /日本帰化/
にほんきかいがっかい /日本機械学会/
にほんきかくきょうかい /日本規格協会/
にほんきぎょう /日本企業/
にほんきしょうきょうかい /日本気象協会/
にほんきどうぶたい /日本機動部隊/
にほんきょうさんとう /日本共産党/
にほんきょじゅうしゃ /日本居住者/
にほんきりすときょうだん /日本基督教団/
にほんきろく /日本記録/
にほんきんかい /日本近海/
にほんぎんこう /日本銀行/
にほんぎんこうけん /日本銀行券/
にほんぐん /日本軍/
にほんぐんえい /日本軍営/
にほんぐんこくしゅぎ /日本軍国主義/
にほんぐんじん /日本軍人/
にほんけいえいきょうかい /日本経営協会/
にほんけいざい /日本経済/
にほんけいざいしんぶん /日本経済新聞/
にほんけいざいしんぶんしゃ /日本経済新聞社/
にほんけいゆ /日本経由/
にほんけいゆう /日本経由/
にほんけんちくがっかい /日本建築学会/
にほんげんごがっかい /日本言語学会/
にほんこう /日本校/
にほんこうえん /日本公演/日本講演/
にほんこうかい /日本公開/
にほんこうかいばん /日本公開版/
にほんこうかん /日本鋼管/
にほんこうぎょう /日本鉱業/
にほんこうぎょうぎんこう /日本興業銀行/
にほんこうぎょうだい /日本工業大/
にほんこうぎょうだいがく /日本工業大学/
にほんこうくう /日本航空/
にほんこうそくつうしん /日本高速通信/
にほんこうだい /日本工大/
にほんこうつうこうしゃ /日本交通公社/
にほんこうでん /日本光電/
にほんこうぶつがっかい /日本鉱物学会/
にほんこく /日本国/日本國/
にほんこくがい /日本国外/
にほんこくけんぽう /日本国憲法/
にほんこくけんぽうか /日本国憲法下/
にほんこくせいふ /日本国政府/
にほんこくせき /日本国籍/
にほんこくせきりだつ /日本国籍離脱/
にほんこくどかいはつ /日本国土開発/
にほんこくない /日本国内/
にほんこくないたいしょう /日本国内対象/
にほんこくないはっこう /日本国内発行/
にほんこくないりょこう /日本国内旅行/
にほんこくみん /日本国民/
にほんこくみんぜんいん /日本国民全員/
にほんこだいし /日本古代史/
にほんこゆう /日本固有/
にほんご /日本語/
にほんごいがい /日本語以外/
にほんごいじょう /日本語以上/
にほんごうせいごむ /日本合成ゴム/
にほんごおん /日本語音/
にほんごおんいん /日本語音韻/
にほんごか /日本語化/日本語可/
にほんごかいせき /日本語解析/
にほんごかくちょう /日本語拡張/
にほんごかさぎょう /日本語化作業/
にほんごかんきょう /日本語環境/
にほんごかんけい /日本語関係/
にほんごかんじ /日本語漢字/
にほんごかんれん /日本語関連/
にほんごがく /日本語学/
にほんごきげん /日本語起源/
にほんごきのう /日本語機能/
にほんごきょうしつ /日本語教室/
にほんごきょうほん /日本語教本/
にほんごくどうし /日本極道史/
にほんござっし /日本語雑誌/
にほんごしょり /日本語処理/
にほんごしょるい /日本語書類/
にほんごじしょ /日本語辞書/
にほんごじまく /日本語字幕/
にほんごじまくばん /日本語字幕版/
にほんごせんよう /日本語専用/
にほんごたいおう /日本語対応/
にほんごたいおうばん /日本語対応版/
にほんごたんまつ /日本語端末/
にほんごちゅう /日本語中/
にほんごつう /日本語通/
にほんごてきかんかく /日本語的感覚/
にほんごどくとく /日本語独特/
にほんごにゅうしゅつりょく /日本語入出力/
にほんごにゅうりょく /日本語入力/
にほんごにゅうりょくかんきょう /日本語入力環境/
にほんごにゅうりょくきこう /日本語入力機構/
にほんごにゅうりょくちゅう /日本語入力中/
にほんごにゅうりょくほう /日本語入力法/
にほんごにゅうりょくほうほう /日本語入力方法/
にほんごのうりょく /日本語能力/
にほんごばん /日本語版/
にほんごばんよう /日本語版用/
にほんごひょうき /日本語表記/
にほんごひょうげん /日本語表現/
にほんごひょうじ /日本語表示/
にほんごふう /日本語風/
にほんごぶぶん /日本語部分/
にほんごぶん /日本語文/
にほんごぶんけん /日本語文献/
にほんごぶんしょ /日本語文書/
にほんごぶんしょう /日本語文章/
にほんごぶんちゅう /日本語文中/
にほんごぶんぽう /日本語文法/
にほんごへんかん /日本語変換/
にほんごへんかんよう /日本語変換用/
にほんごへんしゅう /日本語編集/
にほんごほうそう /日本語放送/
にほんごほんやく /日本語翻訳/
にほんごほんらい /日本語本来/
にほんごめい /日本語名/
にほんごめん /日本語面/
にほんごもじ /日本語文字/
にほんごもじれつ /日本語文字列/
にほんごやく /日本語訳/
にほんごやくご /日本語訳語/
にほんごよう /日本語用/
にほんごりょく /日本語力/
にほんごろん /日本語論/
にほんさいこ /日本最古/
にほんさいこう /日本最高/
にほんさいご /日本最後/
にほんさいしょ /日本最初/
にほんさいじょうりく /日本再上陸/
にほんさいだい /日本最大/
にほんさいだいきぼ /日本最大規模/
にほんさくひん /日本作品/
にほんさん /日本サン/日本産/
にほんさんぎょうしんぶん /日本産業新聞/
にほんさんそ /日本酸素/
にほんさんだいとうげ /日本三大峠/
にほんさんば /日本産馬/
にほんざる /日本猿/
にほんし /日本史/
にほんしかんけい /日本史関係/
にほんしき /日本式/
にほんしぎょう /日本紙業/
にほんししゃ /日本支社/
にほんしじょう /日本市場/日本市上/
にほんしたんほう /日本史探訪/
にほんしどうぶ /日本指導部/
にほんしぶ /日本支部/
にほんしほん /日本資本/
にほんしゃ /日本車/
にほんしゃかい /日本社会/
にほんしゃかいぜんたい /日本社会全体/
にほんしゃかいとう /日本社会党/
にほんしゃけいけん /日本車経験/
にほんしゃりょう /日本車両/
にほんしゅ /日本酒/
にほんしゅっぱつ /日本出発/
にほんしゅっぱん /日本出版/
にほんしゅっぱんしゃ /日本出版社/
にほんしゅど /日本酒度/
にほんしょう /日本賞/
にほんしょうぎれんめい /日本将棋連盟/
にほんしょえん /日本初演/
にほんしょき /日本書紀/日本書記/
にほんしょく /日本食/
にほんしょくてん /日本食店/
にほんしょくひん /日本食品/
にほんしよう /日本仕様/
にほんしん /日本新/
にほんしんきろく /日本新記録/
にほんしんとう /日本新党/
にほんしんどう /日本神道/
にほんしんぱん /日本信販/
にほんしんぶんきょうかい /日本新聞協会/
にほんしんりがっかい /日本心理学会/
にほんしんわ /日本神話/
にほんじかん /日本時間/
にほんじゅう /日本中/
にほんじゅうだん /日本縦断/
にほんじょうくう /日本上空/
にほんじょうだん /日本冗談/
にほんじょし /日本女子/
にほんじょしだいひょう /日本女子代表/
にほんじょせい /日本女性/
にほんじん /日本人/
にほんじんいがい /日本人以外/
にほんじんいぞく /日本人遺族/
にほんじんいっぱん /日本人一般/
にほんじんいみん /日本人移民/
にほんじんいんせい /日本人院生/
にほんじんかい /日本人会/
にほんじんかん /日本人観/
にほんじんかんこうきゃく /日本人観光客/
にほんじんかんとく /日本人監督/
にほんじんがくせい /日本人学生/
にほんじんがくぶせい /日本人学部生/
にほんじんがっこう /日本人学校/
にほんじんきしゃ /日本人記者/
にほんじんきょりゅうみん /日本人居留民/
にほんじんけんきゅうしゃ /日本人研究者/
にほんじんさっか /日本人作家/
にほんじんしよう /日本人仕様/
にほんじんじょうきゃく /日本人乗客/
にほんじんせんしゅ /日本人選手/
にほんじんだんぎ /日本人談義/
にほんじんてき /日本人的/
にほんじんてきこうどう /日本人的行動/
にほんじんどうし /日本人同士/
にほんじんはつ /日本人初/
にほんじんばぬし /日本人馬主/
にほんじんふうふ /日本人夫婦/
にほんじんみん /日本人民/
にほんじんりゅうがくせい /日本人留学生/
にほんじんりょこうしゃ /日本人旅行者/
にほんじんろん /日本人論/
にほんすいろきょうかい /日本水路協会/
にほんすうがっかい /日本数学会/
にほんすもうきょうかい /日本相撲協会/
にほんせい /日本製/
にほんせいこうしょ /日本製鋼所/
にほんせいさん /日本生産/
にほんせいねんかん /日本青年館/
にほんせいひん /日本製品/
にほんせいふ /日本政府/
にほんせいふく /日本征服/
にほんせいめい /日本生命/
にほんせきぐん /日本赤軍/
にほんせきじゅうじ /日本赤十字/
にほんせきじゅうじしゃ /日本赤十字社/
にほんせきゆ /日本石油/
にほんせめんと /日本セメント/
にほんせん /‖/
にほんせんしゅ /日本選手/
にほんせんしゅけん /日本選手権/
にほんぜい /日本勢/
にほんぜんこく /日本全国/
にほんぜんたい /日本全体/
にほんぜんど /日本全土/
にほんそーだ /日本曹達/
にほんたいいくだいがく /日本体育大学/
にほんたいおう /日本対応/
にほんたいかい /日本大会/
にほんたいざい /日本滞在/
にほんたいしかん /日本大使館/
にほんたたき /日本叩き/
にほんたんぺんぶもん /日本短編部門/
にほんだい /日本大/
にほんだいがく /日本大学/
にほんだいひょう /日本代表/
にほんだいひょうば /日本代表馬/
にほんだいら /日本平/
にほんだいりてん /日本代理店/
にほんだて /二本建/
にほんだんし /日本男子/
にほんだんじしっかく /日本男児失格/
にほんちく /日本地区/
にほんちず /日本地図/
にほんちめいさくいん /日本地名索引/
にほんちゃ /日本茶/
にほんちんぼつ /日本沈没/
にほんつう /日本通/
にほんつううん /日本通運/
にほんていえん /日本庭園/
にほんていこくぐん /日本帝国軍/
にほんていこくこくみん /日本帝国国民/
にほんていちゃく /日本定着/
にほんてき /日本的/
にほんてつどう /日本鉄道/
にほんてれび /日本テレビ/
にほんでんき /日本電気/
にほんでんきせい /日本電気製/
にほんでんさんき /日本電算機/
にほんでんし /日本電子/
にほんでんしけいさん /日本電子計算/
にほんでんしんでんわ /日本電信電話/
にほんでんそう /日本電装/
にほんでんとう /日本伝統/
にほんでんねつがっかい /日本伝熱学会/
にほんでんぱこうぎょう /日本電波工業/
にほんとう /日本刀/
にほんとうちか /日本統治化/
にほんとうちゃくびん /日本到着便/
にほんとくゆう /日本特有/
にほんどうぶつがっかい /日本動物学会/
にほんどうろこうだん /日本道路公団/
にほんどくじ /日本独自/
にほんどくとく /日本独特/
にほんない /日本内/
にほんなみ /日本並/
にほんにんちかがくかい /日本認知科学会/
にほんねこ /日本猫/
にほんのうりつきょうかい /日本能率協会/
にほんのりいれ /日本乗入/
にほんはっちゃく /日本発着/
にほんはつ /日本初/日本発/
にほんはつとうじょう /日本初登場/
にほんはつばい /日本発売/
にほんはむ /日本ハム/
にほんば /日本馬/
にほんばし /日本橋/
にほんばしじょがっかん /日本橋女学館/
にほんばしほんてん /日本橋本店/
にほんばしまるぜん /日本橋丸善/
にほんばしみつこし /日本橋三越/
にほんばん /日本版/日本盤/
にほんばんじまく /日本版字幕/
にほんばんだい /日本版第/
にほんひかりがっかい /日本光学会/
にほんひょうじゅんご /日本標準語/
にほんひょうろんしゃ /日本評論社/
にほんふう /日本風/
にほんふたん /日本負担/
にほんぶっきょう /日本仏教/
にほんぶっさん /日本物産/
にほんぶつりがっかい /日本物理学会/
にほんぶどう /日本武道/
にほんぶどうかん /日本武道館/
にほんぶもん /日本部門/
にほんぶよう /日本舞踊/
にほんぶん /日本文/
にほんぶんか /日本文化/
にほんぶんかしゃ /日本文華社/
にほんぶんかてき /日本文化的/
にほんぶんがく /日本文学/
にほんぶんげいしゃ /日本文芸社/
にほんぶんこう /日本分校/日本分光/
にほんへん /日本編/
にほんへんしゅうばん /日本編集盤/
にほんほうじんせつりつ /日本法人設立/
にほんほうそうきょうかい /日本放送協会/
にほんほうもん /日本訪問/
にほんまい /日本米/
にほんまち /日本町/
にほんまつ /二本松/
にほんまる /日本丸/
にほんみこうかい /日本未公開/
にほんみこうかいさく /日本未公開作/
にほんみはっぴょうきょく /日本未発表曲/
にほんみはつばい /日本未発売/
にほんみんよう /日本民謡/
にほんむかし /日本昔/
にほんむかしばなし /日本昔話/
にほんむけ /日本向/
にほんむせん /日本無線/
にほんめ /二本目/
にほんめい /日本名/
にほんもの /日本物/
にほんやきゅう /日本野球/
にほんやく /日本訳/
にほんやちょう /日本野鳥/
にほんやっきょくほう /日本薬局方/
にほんゆうせんたいしょう /日本有線大賞/
にほんよう /日本用/
にほんりくぐん /日本陸軍/
にほんりゅう /日本流/
にほんりゅうせいがっかい /日本流星学会/
にほんりょう /日本領/
にほんりょうじかん /日本領事館/
にほんりょうり /日本料理/
にほんりょうりかい /日本料理界/
にほんりょうりや /日本料理屋/
にほんりょこう /日本旅行/
にほんれっとう /日本列島/
にほんろぼっとがっかい /日本ロボット学会/
にぼし /煮干/
にまい /二枚/２枚/
にまいかんばん /二枚看板/
にまいがい /二枚貝/
にまいぐみ /二枚組/
にまいげり /二枚蹴り/
にまいごし /二枚腰/
にまいめ /二枚目/
にまいめやく /二枚目役/
にまめ /煮豆/
にまんえん /二万円/
にみや /二宮/
にみょう /二名/
にむら /二村/
にめい /二名/
にめん /二面/
にめんせい /二面性/
にめんたいぐん /二面体群/
にもうさく /二毛作/
にもじ /二文字/2文字/
にもじめ /二文字目/
にもつ /荷物/
にもつうんぱんよう /荷物運搬用/
にもつおきば /荷物置場/
にもつけんさ /荷物検査/
にもつごと /荷物毎/
にもつしつ /荷物室/
にもつしゃりょう /荷物車両/
にもつせいり /荷物整理/
にもつとびら /荷物扉/
にもつはんにゅう /荷物搬入/
にもつよう /荷物用/
にもの /煮物/
にもん /2問/
にゃく /若/蒻/
にやく /二役/
にゅーじーらんど /新西蘭/
にゅーす /ニュース/
にゅーすぐるーぷ /ニュースグループ/
にゅーず /ニューズ/
にゅーよーく /紐育/
にゅあんす /ニュアンス/
にゅいんちゅう /入院中/
にゅう /入/乳/柔/ν/廿/
にゅういん /入院/
にゅういんきかん /入院期間/
にゅういんさき /入院先/
にゅういんせいかつ /入院生活/
にゅういんちゅう /入院中/
にゅういんちりょう /入院治療/
にゅういんひ /入院費/
にゅううん /乳暈/
にゅうえい /入営/
にゅうえき /乳液/
にゅうえん /入園/
にゅうえんけん /入園券/
にゅうえんむりょう /入園無料/
にゅうえんりょう /入園料/
にゅうか /入荷/乳化/
にゅうかい /入会/
にゅうかいあんない /入会案内/
にゅうかいかのう /入会可能/
にゅうかいかんゆう /入会勧誘/
にゅうかいきぼう /入会希望/
にゅうかいきぼうしゃ /入会希望者/
にゅうかいきん /入会金/
にゅうかいきんめんじょ /入会金免除/
にゅうかいご /入会後/
にゅうかいごきぼう /入会御希望/
にゅうかいしかく /入会資格/
にゅうかいしゃ /入会者/
にゅうかいじ /入会時/
にゅうかいじき /入会時期/
にゅうかいたいかい /入会退会/
にゅうかいてつづき /入会手続き/
にゅうかいとくてん /入会特典/
にゅうかいひ /入会費/
にゅうかいひむりょう /入会費無料/
にゅうかいほうほう /入会方法/
にゅうかいまえ /入会前/
にゅうかいもうしこみしょ /入会申込書/
にゅうかいもうしこみちゅう /入会申込中/
にゅうかく /入閣/
にゅうかざい /乳化剤/
にゅうかじょうきょう /入荷情況/
にゅうかすう /入荷数/
にゅうかだいすう /入荷台数/
にゅうかまち /入荷待ち/
にゅうかりょう /入荷量/
にゅうかわ /丹生川/
にゅうかん /入館/入感/乳管/入管/
にゅうかんきょく /入感局/
にゅうかんけん /入館券/
にゅうかんりょう /入館料/
にゅうがく /入学/
にゅうがくきぼうしゃ /入学希望者/
にゅうがくきん /入学金/
にゅうがくご /入学後/
にゅうがくしき /入学式/
にゅうがくしけん /入学試験/
にゅうがくしけんもんだい /入学試験問題/
にゅうがくしゃ /入学者/
にゅうがくしゃぼしゅう /入学者募集/
にゅうがくじ /入学時/
にゅうがくせい /入学生/
にゅうがくていいん /入学定員/
にゅうがくとうじ /入学当時/
にゅうがくねんがっぴ /入学年月日/
にゅうがくねんど /入学年度/
にゅうがくりょう /入学料/
にゅうがん /乳癌/
にゅうきゅう /入厩/
にゅうきょ /入居/
にゅうきょう /入鋏/入京/
にゅうきょしかく /入居資格/
にゅうきょしゃ /入居者/
にゅうきょまえ /入居前/
にゅうきん /入金/
にゅうきんかくにんご /入金確認後/
にゅうきんがく /入金額/
にゅうきんひょう /入金票/
にゅうぎゅう /乳牛/
にゅうぎょ /入漁/
にゅうぎょう /乳業/
にゅうぎょく /入玉/
にゅうぎょけん /入漁権/
にゅうぎょりょう /入漁料/
にゅうこ /入庫/入呼/
にゅうこう /入稿/入構/入港/入校/
にゅうこく /入国/
にゅうこくかんりきょく /入国管理局/
にゅうこくかんりほう /入国管理法/
にゅうこくきょひ /入国拒否/
にゅうこくご /入国後/
にゅうこくさしょう /入国査証/
にゅうこくしんさ /入国審査/
にゅうこくしんさかん /入国審査官/
にゅうこくしんさりょう /入国審査料/
にゅうこくじ /入国時/
にゅうこくぜい /入国税/
にゅうこくちてん /入国地点/
にゅうこくび /入国日/
にゅうこくまえ /入国前/
にゅうこくよてい /入国予定/
にゅうこじ /入庫時/
にゅうこすう /入庫数/
にゅうこん /入魂/
にゅうごく /入獄/
にゅうさつ /入札/
にゅうさつかかく /入札価格/
にゅうさつきんがく /入札金額/
にゅうさつしき /入札式/
にゅうさつほうしき /入札方式/
にゅうさん /乳酸/
にゅうさんきんいんりょう /乳酸菌飲料/
にゅうざい /乳剤/
にゅうざいそう /乳剤層/
にゅうざいばんごう /乳剤番号/
にゅうざいめん /乳剤面/
にゅうざん /入山/
にゅうし /入試/乳歯/乳脂/
にゅうしか /入試課/
にゅうしかもく /入試科目/
にゅうしせいど /入試制度/
にゅうしち /入質/
にゅうしつ /入室/
にゅうしもんだい /入試問題/
にゅうしゃ /入社/入射/
にゅうしゃあんない /入社案内/
にゅうしゃいらい /入社以来/
にゅうしゃおん /入射音/
にゅうしゃかく /入射角/
にゅうしゃこう /入射光/
にゅうしゃご /入社後/
にゅうしゃしき /入社式/
にゅうしゃしきろしゅつけい /入射式露出計/
にゅうしゃしけん /入社試験/
にゅうしゃじ /入社時/
にゅうしゃそく /入射束/
にゅうしゃねんど /入社年度/
にゅうしゃは /入射波/
にゅうしゃび /入社日/
にゅうしゃまえ /入社前/
にゅうしゃめん /入射面/
にゅうしゃりゅうし /入射粒子/
にゅうしゅ /入手/
にゅうしゅいこう /入手以降/
にゅうしゅか /入手可/
にゅうしゅかてい /入手過程/
にゅうしゅかのう /入手可能/
にゅうしゅかのうせい /入手可能性/
にゅうしゅけいろ /入手経路/
にゅうしゅこんなん /入手困難/
にゅうしゅご /入手後/
にゅうしゅさき /入手先/
にゅうしゅしゅだん /入手手段/
にゅうしゅじゅん /入手順/
にゅうしゅずみ /入手済/
にゅうしゅちゅう /入手中/
にゅうしゅっこ /入出庫/
にゅうしゅっこくじ /入出国時/
にゅうしゅつ /入出/
にゅうしゅつこく /入出国/
にゅうしゅつこくじ /入出国時/
にゅうしゅつこくてつづき /入出国手続/入出国手続き/
にゅうしゅつりょく /入出力/
にゅうしゅつりょくかんけい /入出力関係/
にゅうしゅつりょくけい /入出力系/
にゅうしゅつりょくせっと /入出力セット/
にゅうしゅつりょくそうち /入出力装置/
にゅうしゅつりょくたんし /入出力端子/
にゅうしゅつりょくち /入出力値/
にゅうしゅつりょくとくせい /入出力特性/
にゅうしゅつりょくぱ /入出力パターン/
にゅうしゅつりょくぱたーん /入出力パターン/
にゅうしゅつりょくひどうき /入出力非同期/
にゅうしゅつりょくひょうげん /入出力表現/
にゅうしゅつりょくぶぶん /入出力部分/
にゅうしゅつりょくよう /入出力用/
にゅうしゅつりょくりょう /入出力量/
にゅうしゅてはいちゅう /入手手配中/
にゅうしゅなん /入手難/
にゅうしゅばしょ /入手場所/
にゅうしゅふかのう /入手不可能/
にゅうしゅふのう /入手不能/
にゅうしゅほう /入手法/
にゅうしゅほうほう /入手方法/
にゅうしゅもと /入手元/
にゅうしょ /入所/
にゅうしょう /入賞/入省/
にゅうしょうさくひん /入賞作品/
にゅうしょうしゃ /入賞者/
にゅうしょうじ /乳小児/
にゅうしょうりつ /入賞率/
にゅうしょきじゅん /入所基準/
にゅうしょく /入植/
にゅうしょくしゃ /入植者/
にゅうしょつりょく /入出力/
にゅうしん /入信/入心/
にゅうじ /乳児/
にゅうじき /乳児期/
にゅうじとっぱつ /乳児突発/
にゅうじとっぱつはっしん /乳児突発発疹/
にゅうじゃく /入寂;死ぬこと。仏教用語/
にゅうじゅく /入塾/
にゅうじょう /入場/乳状/入城/
にゅうじょうきゃくぞうか /入場客増加/
にゅうじょうきょく /入場曲/
にゅうじょうきんし /入場禁止/
にゅうじょうぐち /入場口/
にゅうじょうけん /入場券/
にゅうじょうけんきゃく /入場券客/
にゅうじょうご /入場後/
にゅうじょうしき /入場式/
にゅうじょうしゃ /入場者/
にゅうじょうしゃすう /入場者数/
にゅうじょうじ /入場時/
にゅうじょうじんいん /入場人員/
にゅうじょうせいげん /入場制限/
にゅうじょうせいりけん /入場整理券/
にゅうじょうまえ /入場前/
にゅうじょうむりょう /入場無料/
にゅうじょうりつ /入場率/
にゅうじょうりょう /入場料/
にゅうじょうりょうしゅうにゅう /入場料収入/
にゅうすい /入水/
にゅうせいひん /乳製品/
にゅうせき /入籍/
にゅうせん /入選/入線/入船/乳腺/
にゅうせんけん /入船券/
にゅうせんじかん /入線時間/
にゅうせんはっぴょう /入選発表/
にゅうぜん /入善/
にゅうそう /入槽/
にゅうたい /入隊/入体/入退/
にゅうたいかい /入退会/
にゅうたいしゅつ /入退出/
にゅうたいじょう /入退場/
にゅうたいじょうじ /入退場時/
にゅうだん /入団/
にゅうだんきぼう /入団希望/
にゅうだんきょひ /入団拒否/
にゅうだんご /入団後/
にゅうだんじ /入団時/
にゅうだんすんぜん /入団寸前/
にゅうだんてすと /入団テスト/
にゅうちゃく /入着/
にゅうちょう /入超/
にゅうてい /入廷/
にゅうてん /入店/
にゅうでん /入電/
にゅうとう /乳頭/入刀/入党/乳糖/
にゅうとうおんせん /乳頭温泉/
にゅうとうきん /乳頭筋/
にゅうとうとっき /乳頭突起/
にゅうどう /入道/
にゅうどうぐも /入道雲/
にゅうどうざき /入道崎/
にゅうねん /入念/
にゅうの /入野/
にゅうはくしょく /乳白色/
にゅうばい /入梅/
にゅうばち /乳鉢/
にゅうぶ /入部/
にゅうほうほう /入方法/
にゅうぼう /乳棒/乳房/
にゅうまく /入幕/
にゅうめん /入麺/
にゅうもん /入門/
にゅうもんかいせつ /入門解説/
にゅうもんかいていばん /入門改訂版/
にゅうもんき /入門機/
にゅうもんきょういく /入門教育/
にゅうもんこうざ /入門講座/
にゅうもんしゃ /入門者/
にゅうもんしゃよう /入門者用/
にゅうもんしょ /入門書/
にゅうもんしょていど /入門書程度/
にゅうもんてい /入門艇/
にゅうもんてき /入門的/
にゅうもんてきこうえん /入門的講演/
にゅうもんばん /入門版/
にゅうもんへん /入門編/
にゅうもんぼん /入門本/
にゅうもんよう /入門用/
にゅうよう /入用/
にゅうようじ /乳幼児/
にゅうよく /入浴/入欲/
にゅうよくきんし /入浴禁止/
にゅうよくけん /入浴券/
にゅうよくざい /入浴剤/
にゅうよくはっぽうき /入浴発泡器/
にゅうよくりょう /入浴料/
にゅうよくりょうきん /入浴料金/
にゅうらい /入来/
にゅうりょう /入寮/
にゅうりょうひ /入寮費/
にゅうりょうび /入寮日/
にゅうりょく /入力/
にゅうりょくいき /入力域/
にゅうりょくいち /入力位置/
にゅうりょくおん /入力音/
にゅうりょくおんあつ /入力音圧/
にゅうりょくかのう /入力可能/
にゅうりょくかんきょう /入力環境/
にゅうりょくかんじ /入力漢字/
にゅうりょくかんすう /入力関数/
にゅうりょくがわ /入力側/
にゅうりょくきのう /入力機能/
にゅうりょくきょくせん /入力曲線/
にゅうりょくきりかえ /入力切替/
にゅうりょくきろく /入力記録/
にゅうりょくぎょう /入力行/
にゅうりょくくうかん /入力空間/
にゅうりょくけいしき /入力形式/
にゅうりょくこうりつ /入力効率/
にゅうりょくご /入力後/
にゅうりょくごいっかつ /入力後一括/
にゅうりょくさいぼう /入力細胞/
にゅうりょくしき /入力式/
にゅうりょくしゃ /入力者/
にゅうりょくしゅうごう /入力集合/
にゅうりょくしゅうはすう /入力周波数/
にゅうりょくしょり /入力処理/
にゅうりょくしんごう /入力信号/
にゅうりょくじ /入力時/
にゅうりょくじげん /入力次元/
にゅうりょくじたい /入力自体/
にゅうりょくじょうたい /入力状態/
にゅうりょくじょうほう /入力情報/
にゅうりょくせってん /入力節点/
にゅうりょくせん /入力線/
にゅうりょくせんたく /入力選択/
にゅうりょくそう /入力層/入力相/
にゅうりょくそうかんかんけい /入力相関関係/
にゅうりょくそうち /入力装置/
にゅうりょくそくど /入力速度/
にゅうりょくたんし /入力端子/
にゅうりょくたんまつ /入力端末/
にゅうりょくだん /入力段/
にゅうりょくち /入力値/
にゅうりょくちゅう /入力中/
にゅうりょくてき /入力的/
にゅうりょくでんあつ /入力電圧/
にゅうりょくでんりゅう /入力電流/
にゅうりょくとちゅう /入力途中/
にゅうりょくはいれつ /入力配列/
にゅうりょくはけい /入力波形/
にゅうりょくはんいしてい /入力範囲指定/
にゅうりょくぱたあん /入力パターン/
にゅうりょくぱらめーた /入力パラメータ/
にゅうりょくふぁいる /入力ファイル/
にゅうりょくふかのう /入力不可能/
にゅうりょくぶ /入力部/
にゅうりょくぶん /入力文/
にゅうりょくへんかん /入力変換/
にゅうりょくべくとるち /入力ベクトル値/
にゅうりょくほう /入力法/
にゅうりょくほうしき /入力方式/
にゅうりょくほうほう /入力方法/
にゅうりょくめん /入力面/
にゅうりょくもじ /入力文字/
にゅうりょくもじすう /入力文字数/
にゅうりょくよう /入力用/
にゅうりょくようそ /入力要素/
にゅうりょくようりょう /入力容量/
にゅうりょくりきりつ /入力力率/
にゅうりょくりょういき /入力領域/
にゅうりょくれい /入力例/
にゅうりょくれつ /入力列/
にゅうりょくわく /入力枠/
にゅうりん /乳輪/
にゅうわ /柔和/
にゅりょくしんごう /入力信号/
にょ /女/如/汝/
にょい /如意/
にょう /尿/女/繞/獰/
にょうい /尿意/
にょうけっせき /尿結石/
にょうけんさ /尿検査/
にょうさいかん /尿細管/
にょうそ /尿素/
にょうどう /尿道/
にょうどうえん /尿道炎/
にょうどうけっせき /尿道結石/
にょうはち /鐃鉢;仏具/
にょうぼう /女房/
にょうぼうやく /女房役/
にょうまく /尿膜/
にょうろ /尿路/
にょうろけっせき /尿路結石/
にょかん /女官/
にょじつ /如実/
にょたい /女体/
にょにん /女人/
にょほう /如法/
にょほうあんや /如法暗夜/
にょらい /如来/
にょろ /〜/
によう /二葉/二様/
によど /仁淀/
にら /韮/薤/韭/
にらさき /韮崎/
にらさわ /韮沢/
にらづか /韮塚/
にらみ /睨み/
にらみあい /睨み合い/
にらめっこ /睨めっこ/
にらやま /韮山/
にらやまちょう /韮山町/
にらんせいそうせいじ /二卵性双生児/
にりつ /二律/
にりつはいはん /二律背反/
にりゅう /二流/
にりゅうか /二硫化/
にりん /二輪/２輪/
にりんか /二輪花/
にりんきょうしつ /二輪教室/
にりんくどう /二輪駆動/
にりんしゃ /二輪車/
にりんしゃかんきょう /二輪車環境/
にりんじどうしゃ /二輪自動車/
にりんつうこうきんし /二輪通行禁止/
にりんめんきょ /二輪免許/
にりんよう /二輪用/
にるい /二塁/二類/
にるいけい /二類型/
にるいしゅ /二塁手/
にるいそうきゅう /二塁送球/
にるいそうしゃ /二塁走者/
にるいだ /二塁打/
にるいるいしん /二塁塁審/
にれ /楡/
にれい /楡井/
にれつ /二列/
にれつごせい /二列互生/
にれつめ /二列目/
にれんぱつ /二連発/
にろう /二浪/
にわ /庭/丹羽/二羽/二話/
にわか /俄/俄か/仁輪加/
にわかあめ /にわか雨/瀑/
にわき /庭木/
にわきょういく /庭教育/
にわさか /庭坂/
にわさき /庭先/
にわし /庭師/
にわせ /庭瀬/
にわた /庭田/
にわたし /荷渡/
にわとり /鶏/ニワトリ/鷄/
にわの /庭野/
にわり /二割/
にん /人/任/認/妊/忍/刃/仁/儿/刄/姙/
にんい /任意/∀/
にんいいんたい /任意引退/
にんいいんたいせんしゅ /任意引退選手/
にんいかい /任意回/
にんいかくど /任意角度/
にんいかんすう /任意関数/
にんいきょくめん /任意曲面/
にんいこ /任意個/
にんいこすう /任意個数/
にんいしゅっとう /任意出頭/
にんいせい /任意性/
にんいだんたい /任意団体/
にんいちょう /任意長/
にんいほうき /任意法規/
にんいほけん /任意保険/
にんか /認可/
にんかせい /認可制/
にんかん /任官/
にんき /人気/任期/
にんきいか /人気以下/
にんきうすどうし /人気薄同士/
にんきうま /人気馬/
にんきかん /人気館/
にんききしゅ /人気機種/
にんききゅうじょうしょう /人気急上昇/
にんききゅうだん /人気球団/
にんきさくひん /人気作品/
にんきさっか /人気作家/
にんきしゃしゅ /人気車種/
にんきしょうひん /人気商品/
にんきじゅん /人気順/
にんきじょうい /人気上位/
にんきじょうしょう /人気上昇/
にんきせんこう /人気先行/
にんきせんしゅ /人気選手/
にんきぜっちょう /人気絶頂/
にんきちゅう /任期中/
にんきていか /人気低下/
にんきとうひょう /人気投票/
にんきばくはつ /人気爆発/
にんきばん /人気盤/
にんきばんぐみ /人気番組/
にんきひりつ /人気比率/
にんきもの /人気者/
にんきょう /仁侠/任侠/
にんぎょ /人魚/
にんぎょう /人形/
にんぎょうあそび /人形遊び/
にんぎょうか /人形化/
にんぎょうかいぞう /人形改造/
にんぎょうかん /人形館/
にんぎょうげき /人形劇/
にんぎょうげきだん /人形劇団/
にんぎょうさっか /人形作家/
にんぎょうし /人形師/
にんぎょうちょう /人形町/
にんぎょうちょうえき /人形町駅/
にんぎょうてき /人形的/
にんぎょうはくぶつかん /人形博物館/
にんぎょうよう /人形用/
にんぎょでん /人魚伝/
にんぎょひめ /人魚姫/
にんく /忍苦/人工/
にんぐみ /人組/
にんげつ /人月/
にんげん /人間/
にんげんあいて /人間相手/
にんげんいがい /人間以外/
にんげんかい /人間界/
にんげんかん /人間観/
にんげんかんきょう /人間環境/
にんげんかんけい /人間関係/
にんげんがくるい /人間学類/
にんげんがた /人間型/
にんげんがわ /人間側/
にんげんぎらい /人間嫌い/
にんげんけいたい /人間形態/
にんげんげきじょう /人間劇場/
にんげんげんり /人間原理/
にんげんこうがく /人間工学/
にんげんこうがくかい /人間工学会/
にんげんこうがくてき /人間工学的/
にんげんこくほう /人間国宝/
にんげんさま /人間様/
にんげんしこう /人間志向/
にんげんしっかく /人間失格/
にんげんしゃかい /人間社会/
にんげんしゃかいせいぶつ /人間社会生物/
にんげんじしん /人間自身/
にんげんじたい /人間自体/
にんげんじょうほう /人間情報/
にんげんせい /人間性/
にんげんせいてき /人間性的/
にんげんそうさ /人間操作/
にんげんそんざい /人間存在/
にんげんぞう /人間像/
にんげんたち /人間達/
にんげんだいがく /人間大学/
にんげんてき /人間的/
にんげんてきみりょく /人間的魅力/
にんげんてきよういん /人間的要因/
にんげんとくゆう /人間特有/
にんげんどうし /人間同士/
にんげんなみ /人間並/
にんげんばくだん /人間爆弾/
にんげんばなれ /人間離れ/
にんげんばんじさいおう /人間万事塞翁/
にんげんひとり /人間一人/
にんげんひとりひとり /人間一人一人/
にんげんふうしゃ /人間風車/
にんげんみ /人間味/
にんげんよう /人間用/
にんげんりかい /人間理解/
にんげんわざ /人間技/
にんさんばけしち /人三化七/
にんしき /認識/
にんしきあやまりりつ /認識誤り率/
にんしきかがく /認識科学/
にんしきかがくか /認識科学科/
にんしきかてい /認識過程/
にんしきかんいげんご /認識簡易言語/
にんしきがく /認識学/
にんしききこう /認識機構/
にんしきけい /認識系/
にんしきけっか /認識結果/
にんしきこうぞう /認識構造/
にんしきさんぷる /認識サンプル/
にんしきしゅたい /認識主体/
にんしきしょり /認識処理/
にんしきじかん /認識時間/
にんしきじしょ /認識辞書/
にんしきじっけん /認識実験/
にんしきせいど /認識精度/
にんしきせいのう /認識性能/
にんしきそうち /認識装置/
にんしきたいしょう /認識対象/
にんしきど /認識度/
にんしきのうりょく /認識能力/
にんしきはんい /認識範囲/
にんしきぶ /認識部/
にんしきぶそく /認識不足/
にんしきほうほう /認識方法/
にんしきほうほうろん /認識方法論/
にんしきもじれつ /認識文字列/
にんしきよう /認識用/
にんしきりつ /認識率/
にんしきりょく /認識力/
にんしきりろん /認識理論/
にんしきろん /認識論/
にんしゅう /人衆/
にんしょう /認証/人称/認照/
にんしょうきこう /認証機構/
にんしょうしき /認証式/
にんしん /妊娠/
にんしんしゅっさん /妊娠出産/
にんしんしょき /妊娠初期/
にんしんじ /妊娠時/
にんしんちゅう /妊娠中/
にんしんちゅうぜつ /妊娠中絶/
にんしんてきれいき /妊娠適齢期/
にんじゃ /忍者/
にんじゃでら /忍者寺/
にんじゃぶげいちょう /忍者武芸帳/
にんじゃぶたい /忍者部隊/
にんじゃもの /忍者物/
にんじゃやく /忍者役/
にんじゅう /忍従/
にんじゅつ /忍術/
にんじょう /人情/刃傷/
にんじょうきげき /人情喜劇/
にんじょうざた /刃傷沙汰/
にんじょうばなし /人情話/人情噺/
にんじょうみ /人情味/
にんじん /人参/人蔘/忍人/
にんずう /人数/
にんずうこうか /人数効果/
にんずうこうせい /人数構成/
にんずうせいげん /人数制限/
にんずうてき /人数的/
にんずうはあく /人数把握/
にんずうひ /人数比/
にんずうぶん /人数分/
にんそう /人相/
にんそうがく /人相学/
にんそく /人足/
にんたい /忍耐/
にんたいりょく /忍耐力/
にんち /認知/任地/
にんちかがく /認知科学/
にんちかがくかい /認知科学会/
にんちかがくかいいん /認知科学会員/
にんちかがくがっかい /認知科学学会/
にんちかがくしつ /認知科学室/
にんちかがくしゃ /認知科学者/
にんちかがくせみなあ /認知科学セミナー/
にんちかがくせんしょ /認知科学選書/
にんちかがくてき /認知科学的/
にんちかがっかい /認知科学会/
にんちかてい /認知過程/
にんちきこう /認知機構/
にんちきのう /認知機能/
にんちしょり /認知処理/
にんちしんり /認知心理/
にんちしんりがく /認知心理学/
にんちしんりがくしゃ /認知心理学者/
にんちしんりがくてき /認知心理学的/
にんちじっけん /認知実験/
にんちてき /認知的/
にんちてきかつどう /認知的活動/
にんちてききのう /認知的機能/
にんちてきとていせい /認知的徒弟制/
にんちど /認知度/
にんちのうりょく /認知能力/
にんちばいたい /認知媒体/
にんちぶんさんしょりこうぞう /認知分散処理構造/
にんちもでる /認知モデル/
にんちりろん /認知理論/
にんてい /認定/
にんていい /認定医/
にんていか /認定課/
にんていきき /認定機器/
にんていきじゅん /認定基準/
にんていこう /認定校/
にんていこうじょう /認定工場/
にんていしょう /認定証/
にんていじっしゃばん /認定実写版/
にんていせいど /認定制度/
にんていばんごう /認定番号/
にんていひん /認定品/
にんていほうほう /認定方法/
にんてん /人天/
にんてんどう /任天堂/仁天堂/
にんてんどうせい /任天堂製/
にんでん /人天/
にんとく /仁徳/
にんどう /忍道/
にんなじ /仁和寺/
にんにく /大蒜/葫/
にんにち /人日/
にんねん /人年/
にんぴ /認否/
にんぴにん /人非人/
にんぴょう /任憑/
にんぴん /人品/
にんぶん /人分/
にんぷ /妊婦/人夫/
にんぽう /忍法/
にんぽうちょう /忍法帖/忍法帳/
にんまえ /人前/
にんむ /任務/
にんむしっぱい /任務失敗/
にんむじょうきょう /任務状況/
にんめ /人目/
にんめい /任命/任名/
にんめいけん /任命権/
にんめいほうしき /任命方式/
にんめん /任免/
にんよう /任用/認容/
にんようご /任用後/
ぬ /奴/怒/濡/
ぬいめ /縫目/
ぬいもの /縫物/
ぬえ /鵺/
ぬか /糠/
ぬかた /額田/
ぬかばたらき /糠働き/
ぬかびら /糠平/
ぬかびらこ /糠平湖/
ぬき /貫/抜き/
ぬきい /貫井/
ぬきさし /抜き差し/
ぬきだし /抜き出し/
ぬきに /抜き荷/
ぬきみ /抜き身/
ぬきやま /抜山/
ぬぎき /脱着/
ぬくい /貫井/
ぬくしな /温品/
ぬけ /脱/抜/抜け/
ぬけあな /抜け穴/抜穴/
ぬけがけ /抜け駆け/抜駆/
ぬけがら /脱殻/抜殻/蛻/
ぬけに /抜け荷/抜荷/
ぬけにん /抜忍/
ぬけみち /抜け道/抜道/
ぬけめ /抜目/抜け目/
ぬさ /帛/
ぬし /主/
ぬすっと /盗人/
ぬすびと /盗人/
ぬすみ /盗み/窃/
ぬすみぎき /盗み聞き/
ぬすみぐい /盗み食い/
ぬすみみ /盗み見/
ぬすむ /窃/
ぬた /垈/
ぬの /布/
ぬのいち /布市/
ぬのいちまち /布市町/
ぬのかわ /布川/
ぬのじ /布地/
ぬのせい /布製/
ぬのせいとざんぐつ /布製登山靴/
ぬのはし /布橋/
ぬのはらえき /布原駅/
ぬのびき /布引/
ぬのむら /布村/
ぬのめ /布目/
ぬま /沼/
ぬまうえ /沼上/
ぬまお /沼尾/
ぬまおか /沼岡/
ぬまかみ /沼上/
ぬまがみ /沼上/
ぬまくない /沼宮内/
ぬまくま /沼隈/
ぬまくら /沼倉/
ぬまぐち /沼口/
ぬまざき /沼崎/
ぬまず /沼津/
ぬまずこう /沼津港/
ぬまずこうじょう /沼津工場/
ぬまずし /沼津市/
ぬまずひがし /沼津東/
ぬまた /沼田/
ぬまたちょう /沼田町/
ぬまち /沼地/
ぬまづ /沼津/
ぬまづこう /沼津港/
ぬまづし /沼津市/
ぬまべ /沼部/
ぬまべえき /沼部駅/
ぬまやま /沼山/
ぬめ /絖/
ぬり /塗/
ぬりえ /塗り絵/
ぬりかべ /塗壁/塗り壁/
ぬりぐすり /塗薬/
ぬりつけ /塗付/
ぬるま /微温/
ぬるまゆ /ぬるま湯/
ぬれぎぬ /濡れ衣/濡衣/
ぬれごと /濡れ事/濡事/
ぬれば /濡れ場/濡場/
ぬればいろ /濡羽色/
ね /根/値/寝/音/子/禰/祢/嶺/寢/涅/袮/
ねーちゃん /ネーちゃん/
ねーみんぐ /ネーミング/
ねーむ /ネーム/
ねあがり /値上がり/根上/
ねあがりまつ /根上り松/
ねあげ /値上げ/値上/
ねあせ /寝汗/
ねい /禰/寧/祢/嚀/佞/侫/檸/濘/聹/
ねいき /寝息/
ねいじつ /寧日/
ねいす /寝椅子/
ねいひつ /寧謐/
ねいろ /音色/
ねうち /値打/値打ち/
ねえ /姉/
ねえさま /姉様/
ねえさん /姉さん/
ねえちゃん /姉ちゃん/
ねえよ /寧代/
ねお /根尾/
ねおき /寝起き/寝起/
ねおじうむ /Nd/ネオジウム/
ねおん /ネオン/
ねが /願/
ねがい /願い/願/
ねがいごと /願い事/
ねがいさげ /願い下げ/
ねがいで /願い出/
ねがえり /寝返り/
ねがお /寝顔/
ねがさ /値がさ/
ねがみ /根上/
ねぎ /葱/
ねぎあか /ネギ亜科/
ねぎか /葱科/
ねぎし /根岸/
ねぎしけいばじょう /根岸競馬場/
ねぎしけいばじょうあと /根岸競馬場跡/
ねぎししんりんこうえん /根岸森林公園/
ねぎしせん /根岸線/
ねぎしちょう /根岸町/
ねぎとろどん /ねぎとろ丼/
ねぎり /値切/値切り/
ねくたい /ネクタイ/
ねくび /寝首/
ねくら /根暗/
ねぐら /塒/
ねぐりじぇ /ネグリジェ/
ねこ /猫/
ねこあし /猫脚/
ねこか /猫科/
ねこかん /猫缶/
ねこかんけい /猫関係/
ねこがた /猫型/
ねこぐるま /猫車/
ねこじまん /猫自慢/
ねこぜ /猫背/
ねこた /猫田/
ねこて /猫手/
ねこは /猫派/
ねこべ /猫部/
ねこま /猫魔/猫間/
ねこむすめ /猫娘/
ねこめいし /猫目石/
ねごこち /寝心地/
ねごと /寝言/
ねごろ /根来/
ねさがり /値下がり/
ねさげ /値下/値下げ/
ねざかな /根魚/
ねざき /根崎/
ねざし /根差し/
ねざめ /寝醒め/
ねしょうがつ /寝正月/
ねしょんべん /寝小便/
ねじ /螺/捻子/螺子/捩子/ネジ/
ねじこみ /捩じ込み/
ねじめ /根占/
ねじりはちまき /捩じり鉢巻き/捩り鉢巻き/
ねじろ /根城/
ねず /根津/禰津/
ねずみ /鼠/鼡/
ねずみいろ /鼠色/
ねずみおとこ /鼠男/
ねずみたち /鼠達/
ねぞう /寝惚/寝相/
ねた /ネタ/
ねたんぽ /根担保/
ねだめ /寝溜め/
ねだやし /根絶やし/
ねだん /値段/
ねだんいがい /値段以外/
ねだんいじょう /値段以上/
ねだんこうしょう /値段交渉/
ねだんさ /値段差/
ねだんそうおう /値段相応/
ねだんそうとう /値段相当/
ねだんてき /値段的/
ねだんとう /値段等/
ねだんひょう /値段表/
ねだんふめい /値段不明/
ねだんぶん /値段分/
ねだんへんどう /値段変動/
ねっか /熱河/
ねっから /根っから/
ねっき /熱気/
ねっききゅう /熱気球/
ねっきゅう /熱球/
ねっきょう /熱狂/
ねっきょうてき /熱狂的/
ねっく /ネック/
ねっけつ /熱血/
ねっけつかん /熱血漢/
ねっけつしゅじんこう /熱血主人公/
ねっけん /熱圏/
ねっこ /根っこ/
ねっしゃ /熱写/
ねっしゃびょう /熱射病/
ねっしゅ /熱酒/
ねっしょう /熱唱/
ねっしん /熱心/
ねっすい /熱水/
ねっせん /熱戦/熱線/
ねったい /熱帯/
ねったいうりん /熱帯雨林/
ねったいぎょ /熱帯魚/
ねったいぎょかんけい /熱帯魚関係/
ねったいぎょしいく /熱帯魚飼育/
ねったいぎょや /熱帯魚屋/
ねったいぎょよう /熱帯魚用/
ねったいさん /熱帯産/
ねったいせい /熱帯性/
ねったいていきあつ /熱帯低気圧/
ねったいや /熱帯夜/
ねったいやむけ /熱帯夜向/
ねったいりん /熱帯林/
ねっちゅう /熱中/
ねっちゅうしょう /熱中症/
ねっちゅうせんげん /熱中宣言/
ねっと /ネット/
ねっとう /熱湯/熱闘/
ねっとわーく /ネットワーク/
ねっぱ /熱波/
ねっぱつ /熱発/
ねっぷう /熱風/
ねつ /熱/捏/
ねつあい /熱愛/
ねつあいちゅう /熱愛中/
ねつい /熱意/
ねつうんどう /熱運動/
ねつえん /熱演/
ねつえんじゅんかん /熱塩循環/
ねつか /熱価/
ねつかくはんのうだん /熱核反応弾/
ねつかんわ /熱緩和/
ねつき /寝付き/
ねつきょうきゅう /熱供給/
ねつぐん /熱群/
ねつけいれん /熱痙攣/
ねつけん /熱研/
ねつげん /熱源/
ねつこうかん /熱交換/
ねつこうかんがた /熱交換型/
ねつこうかんき /熱交換器/
ねつこうかんぶ /熱交換部/
ねつこうりつ /熱効率/
ねつしょり /熱処理/
ねつしょりずみ /熱処理済/
ねつじょう /熱情/
ねつせっしょく /熱接触/
ねつそくど /熱速度/
ねつそんしつ /熱損失/
ねつそんしつけいすう /熱損失係数/
ねつぞう /捏造/
ねつたいさく /熱対策/
ねつちゅうせいし /熱中性子/
ねつちゅうせいしかいせき /熱中性子解析/
ねつちゅうせいしそく /熱中性子束/
ねつていこう /熱抵抗/
ねつてき /熱的/
ねつてんしゃ /熱転写/
ねつてんしゃしき /熱転写式/
ねつてんしゃほうしき /熱転写方式/
ねつでんたつりつ /熱伝達率/
ねつでんつい /熱電対/
ねつでんどう /熱伝導/
ねつでんどうせい /熱伝導性/
ねつでんどうりつ /熱伝導率/
ねつでんどうろん /熱伝導論/
ねつはっさん /熱発散/
ねつはっせい /熱発生/
ねつびょう /熱病/
ねつふか /熱負荷/
ねつふくしゃ /熱輻射/
ねつぶつりがく /熱物理学/
ねつへいこう /熱平衡/
ねつへんか /熱変化/
ねつへんせい /熱変性/
ねつべん /熱弁/
ねつぼう /熱望/
ねつぼうそう /熱暴走/
ねつぼうちょう /熱膨張/
ねつゆそう /熱輸送/
ねつようりょう /熱容量/
ねつよく /熱浴/
ねつりき /熱力/
ねつりきがく /熱力学/
ねつりきがくけい /熱力学系/
ねつりきがくてき /熱力学的/
ねつりきがくてきかんけい /熱力学的関係/
ねつりゅう /熱流/
ねつりょう /熱量/
ねつるい /熱涙/
ねつれつ /熱烈/
ねづ /根津/禰津/
ねづえき /根津駅/
ねづか /根塚/
ねづけ /値付け/
ねづじんぱち /根津甚八/
ねとまり /寝泊まり/
ねどこ /寝床/
ねなしぐさ /根無草/
ねなりがき /根成柿/
ねはば /値幅/
ねはん /涅槃/
ねば /根羽/
ねびえ /寝冷え/
ねびき /値引き/
ねびきか /値引可/
ねびきすう /値引数/
ねびきりつ /値引率/値引き率/
ねふだ /値札/
ねぶかわ /根府川/
ねぶくろ /寝袋/
ねぶくろじさん /寝袋持参/
ねぶそく /寝不足/
ねほしょう /根保証/
ねぼう /寝坊/
ねまき /寝間着/
ねまわし /根回し/
ねみだれ /寝乱れ/
ねみみ /寝耳/
ねむけ /眠気/
ねむのき /棔/
ねむりきょうしろう /眠狂四郎/
ねむりひめ /眠り姫/
ねむろ /根室/
ねむろえき /根室駅/
ねもと /根本/根元/
ねもとけん /根元研/
ねものがたり /寝物語/
ねや /閨/
ねやがわ /寝屋川/
ねやがわきんこう /寝屋川近郊/
ねやがわし /寝屋川市/
ねやがわしゃこ /寝屋川車庫/
ねらい /狙い/
ねらいうち /狙い撃ち/狙い打ち/
ねり /練/練り/
ねりこう /練香/
ねりべい /練塀/
ねりま /練馬/
ねりまえき /練馬駅/
ねりまかん /練馬間/
ねりまく /練馬区/
ねりまくみん /練馬区民/
ねりまりくうんきょく /練馬陸運局/
ねるそん /ネルソン/
ねるちんすく /尼布楚/
ねわざ /寝技/
ねん /年/念/粘/燃/撚/捻/稔/拈/棯/然/
ねんあけ /年明/
ねんいじょう /年以上/
ねんいちど /年一度/
ねんいっかい /年一回/
ねんいり /念入り/念入/
ねんえき /粘液/
ねんえきさいぼう /粘液細胞/
ねんかい /年会/
ねんかいひ /年会費/
ねんかいひむりょう /年会費無料/
ねんかん /年間/年刊/年鑑/
ねんかんかっそうにっすう /年間滑走日数/
ねんかんこうどく /年間購読/
ねんかんこうどくりょう /年間購読料/
ねんかんさいた /年間最多/
ねんかんしていせき /年間指定席/
ねんかんしぼうすう /年間死亡数/
ねんかんしょうきん /年間賞金/
ねんかんしょうひでんりょく /年間消費電力/
ねんかんそうこうにゅうがく /年間総購入額/
ねんかんとうろく /年間登録/
ねんかんへいきん /年間平均/
ねんかんほうそう /年間放送/
ねんかんよさん /年間予算/
ねんかんよやく /年間予約/
ねんかんよやくせき /年間予約席/
ねんが /年賀/
ねんがく /年額/
ねんがじょう /年賀状/
ねんがじょうはいたつ /年賀状配達/
ねんがじょうよう /年賀状用/
ねんがっぴ /年月日/
ねんがはがき /年賀葉書/
ねんがらねんじゅう /年がら年中/
ねんがん /念願/
ねんき /年期/年忌/年季/
ねんきぼうこう /年期奉公/
ねんきゅう /年休/
ねんきゅうぼ /年休簿/
ねんきん /年金/粘菌/
ねんきんききん /年金基金/
ねんきんせいかつ /年金生活/
ねんきんせいど /年金制度/
ねんきんほう /年金法/
ねんくれ /年暮/
ねんぐ /年貢/
ねんけいかく /年計画/
ねんげつ /年月/
ねんげん /年限/
ねんこう /年功/
ねんこうじょれつ /年功序列/
ねんこうちんぎん /年功賃金/
ねんご /年後/
ねんごう /年号/
ねんごろ /年頃/懇ろ/
ねんさ /年差/
ねんさん /年産/
ねんざ /捻挫/
ねんし /年始/撚糸/
ねんしき /年式/
ねんしきそうおう /年式相応/
ねんしきていど /年式程度/
ねんしきふめい /年式不明/
ねんしきゅうぎょう /年始休業/
ねんした /年下/
ねんしほうそう /年始放送/
ねんしゃ /念写/
ねんしゅう /年収/
ねんしゅうにゅう /年収入/
ねんしゅつ /捻出/
ねんしょ /念書/年初/
ねんしょう /年少/燃焼/年商/
ねんしょうおんど /燃焼温度/
ねんしょうぐみ /年少組/
ねんしょうけいさん /燃焼計算/
ねんしょうこうりつ /燃焼効率/
ねんしょうしけん /燃焼試験/
ねんしょうしつ /燃焼室/
ねんしょうじかん /燃焼時間/
ねんしょうじょうたい /燃焼状態/
ねんしょうそう /年少層/
ねんしょうそくど /燃焼速度/
ねんしょうでんぱんこうりつ /燃焼伝搬効率/
ねんしょうとう /燃焼筒/
ねんしょうど /燃焼度/
ねんじ /年次/年時/
ねんじけいかく /年次計画/
ねんじすいい /年次推移/
ねんじそうかい /年次総会/
ねんじゅう /年中/
ねんじゅうじゅうたい /年中渋滞/
ねんじゅうむきゅう /年中無休/
ねんすう /年数/
ねんすうせんえん /年数千円/
ねんせい /年生/年制/粘性/
ねんせいりょく /粘性力/
ねんそつ /年卒/
ねんたんい /年単位/
ねんだい /年代/
ねんだいき /年代記/
ねんだいこうはん /年代後半/
ねんだいじゅん /年代順/
ねんだいぜんはん /年代前半/
ねんだいとくてい /年代特定/
ねんだいべつ /年代別/
ねんだいもの /年代物/
ねんちゃく /粘着/
ねんちゃくけいすう /粘着係数/
ねんちゃくざい /粘着材/粘着剤/
ねんちゃくしき /粘着式/
ねんちゃくせい /粘着性/
ねんちゃくぶぶん /粘着部分/
ねんちゃくりょく /粘着力/
ねんちゅう /年中/
ねんちゅうぎょうじ /年中行事/
ねんちょう /年長/粘稠/
ねんちょうしゃ /年長者/
ねんてん /捻転/
ねんとう /念頭/年頭/
ねんど /年度/粘度/粘土/
ねんどう /念動/
ねんどきかく /粘度規格/
ねんどしつ /粘土質/
ねんどだいひょうば /年度代表馬/
ねんどない /年度内/
ねんどまつ /年度末/
ねんない /年内/
ねんないうけつけちゅう /年内受付中/
ねんないちゅう /年内中/
ねんないはつばい /年内発売/
ねんねん /年々/年年/
ねんねんかん /千年間/
ねんねんさいさい /年年歳歳/
ねんのため /念のため/為念/念の為/
ねんはん /年半/
ねんばらい /年払い/
ねんばん /年版/
ねんぱ /念波/
ねんぱい /年配/年輩/
ねんぱいしゃ /年配者/
ねんぴ /燃費/然費/
ねんぴいちらん /燃費一覧/
ねんぴけい /燃費計/
ねんぴこうじょう /燃費向上/
ねんぴじゅうし /燃費重視/
ねんぴせつやく /燃費節約/
ねんぴょう /年表/
ねんぴりつ /燃費率/
ねんぶつ /念仏/
ねんぶつじ /念仏寺/
ねんぶん /年分/
ねんぷ /年譜/年賦/
ねんべつ /年別/
ねんぽう /年報/年俸/念法/
ねんぽうけいやくせい /年俸契約制/
ねんまえ /年前/
ねんまく /粘膜/
ねんまくめん /粘膜面/
ねんまつ /年末/
ねんまつさいしゅう /年末最終/
ねんまつちょうせい /年末調整/
ねんまつどうよう /年末同様/
ねんまつねんし /年末年始/
ねんまつねんしきゅうか /年末年始休暇/
ねんまつばんぐみ /年末番組/
ねんまつほうどう /年末報道/
ねんめ /年目/
ねんらい /年来/
ねんり /年利/
ねんりかんざん /年利換算/
ねんりき /念力/
ねんりつ /年率/
ねんりまわり /年利回り/
ねんりょう /燃料/燃量/
ねんりょうけい /燃料系/燃料計/
ねんりょうさいくる /燃料サイクル/
ねんりょうしゅうごうたい /燃料集合体/
ねんりょうしょうひりつ /燃料消費率/
ねんりょうしょうひりょう /燃料消費量/
ねんりょうじたい /燃料自体/
ねんりょうそうち /燃料装置/
ねんりょうだい /燃料代/
ねんりょうひ /燃料費/
ねんりょうふんしゃ /燃料噴射/
ねんりょうぶそく /燃料不足/
ねんりょうほきゅう /燃料補給/
ねんりょうぼう /燃料棒/
ねんりょうゆそう /燃料輸送/
ねんりん /年輪/
ねんれい /年齢/年令/
ねんれいげんてい /年齢限定/
ねんれいこうせい /年齢構成/
ねんれいさ /年令差/年齢差/
ねんれいせいげん /年齢制限/年令制限/
ねんれいせいべつ /年齢性別/
ねんれいせってい /年齢設定/
ねんれいそう /年齢層/
ねんれいそうおう /年齢相応/
ねんれいてき /年齢的/
ねんれいふしょう /年齢不詳/
ねんれいべつ /年齢別/年令別/
の /野/之/乃/埜/廼/濃/−/
のーと /ノート/帳面/
のいけ /野池/
のいず /ノイズ/
のいち /野市/
のいろーぜ /ノイローゼ/
のう /能/脳/農/納/膿/王/濃/悩/皇/嚢/惱/曩/瑙/碯/腦/衲/能生/獰/
のういがい /脳以外/
のういっけつ /脳溢血/
のうえん /農園/脳炎/濃艶/
のうおんか /濃音化/
のうか /農家/
のうかい /納会/
のうかいだい /能開大/
のうかがく /脳科学/
のうかがくぶ /脳科学部/
のうかく /能格/
のうかくこうぞう /能格構造/
のうかすいたい /脳下垂体/
のうかん /能管/納棺/納竿/脳幹/
のうかんき /農閑期/
のうかんけい /脳関係/
のうかんしょうがい /脳幹障害/
のうがき /能書き/
のうがく /農学/
のうがくけんきゅうか /農学研究科/
のうがくどう /能楽堂/
のうがくぶ /農学部/
のうがや /能ヶ谷/
のうき /納期/農機/納城/
のうきぐ /農機具/
のうきのう /脳機能/
のうきょう /農協/納経/
のうきん /納金/
のうぎょう /農業/
のうぎょうこく /農業国/
のうぎょうしょとく /農業所得/
のうぎょうじゅうじしゃ /農業従事者/
のうぎょうせいぶつけん /農業生物研/
のうぎょうよう /農業用/
のうぎょうようち /農業用地/
のうぐ /農具/
のうけつりゅう /脳血流/
のうけつりゅうりょう /脳血流量/
のうけん /脳研/
のうげいかがく /農芸化学/
のうげか /脳外科/
のうこう /濃厚/農工/農耕/
のうこうかのう /農耕可能/
のうこうしゃかい /農耕社会/
のうこうそく /脳梗塞/
のうこうだい /農工大/
のうこうだいがく /農工大学/
のうこうぶんか /農耕文化/
のうこうみん /農耕民/
のうこうよう /農耕用/
のうこつ /納骨/
のうこん /濃紺/
のうさい /納采/
のうさいぼう /脳細胞/
のうさぎょう /農作業/
のうさく /農作/
のうさくぶつ /農作物/
のうさくもつ /農作物/
のうさつ /悩殺/納札/
のうさつじょ /納札所/
のうさん /農産/
のうさんち /農産地/
のうさんぶつ /農産物/
のうざい /能材/
のうざしょう /脳挫傷/
のうし /脳死/直衣/
のうしじょうたい /脳死状態/
のうしゃ /納車/
のうしゃかい /納射会/
のうしゃきねん /納車記念/
のうしゃご /納車後/
のうしゃじ /納車時/
のうしゃとうじ /納車当時/
のうしゃび /納車日/
のうしゃまえ /納車前/
のうしゅく /濃縮/
のうしゅくかんげん /濃縮還元/
のうしゅくど /濃縮度/
のうしゅくよう /濃縮用/
のうしゅっけつ /脳出血/
のうしょ /能書/
のうしょう /農相/脳漿/
のうしょうがい /脳障害/
のうしょくけい /濃色系/
のうしんけい /脳神経/
のうしんとう /脳震盪/
のうじ /農事/
のうじず /脳磁図/
のうじょう /農場/嚢状/
のうじょうさん /農場産/
のうじょうよう /嚢状葉/
のうじれき /農事歴/
のうすいしょう /農水省/
のうずい /脳髄/
のうせい /能性/農政/
のうぜい /納税/
のうぜいかんけい /納税関係/
のうぜいきげん /納税期限/
のうぜいぎむしゃ /納税義務者/
のうぜいしゃ /納税者/
のうぜいしょ /納税書/
のうぜいしょうめい /納税証明/
のうぜいしょうめいしょ /納税証明書/
のうぜいしんせいしょ /納税申請書/
のうぜいつうちしょ /納税通知書/
のうぜんかずら /凌霄蔓/
のうそう /農宗/
のうそうぶん /放送分/
のうそっちゅう /脳卒中/
のうそん /農村/
のうそんしょう /脳損傷/
のうそんふうけい /農村風景/
のうたん /濃淡/
のうたんがぞう /濃淡画像/
のうたんち /濃淡値/
のうだ /納田/
のうだい /農大/
のうだいいちこう /農大一高/
のうち /納地/農地/野内/
のうてい /脳底/
のうてん /脳天/
のうてんき /能天気/脳天気/腦天氣/
のうど /濃度/農奴/
のうどう /能動/農道/
のうどうおんじょうせいぎょ /能動音場制御/
のうどうきつえん /能動喫煙/
のうどうせいぎょ /能動制御/
のうどうたい /能動態/
のうどうてき /能動的/
のうどかいほう /農奴解放/
のうどち /濃度値/
のうどてき /濃度的/
のうない /脳内/
のうないしゅっけつ /脳内出血/
のうないしんけい /脳内神経/
のうにゅう /納入/
のうにゅうか /納入価/
のうにゅうきかん /納入期間/
のうにゅうきげん /納入期限/
のうにゅうぎょうしゃ /納入業者/
のうにゅうこくちしょ /納入告知書/
のうにゅうさきじゅうしょ /納入先住所/
のうにゅうしょ /納入書/
のうにゅうじ /納入時/
のうにゅうじっせき /納入実績/
のうにん /納人/
のうは /脳波/
のうはう /ノウハウ/
のうはつうしん /脳波通信/
のうはんき /農繁期/
のうひょう /脳表/
のうひん /納品/
のうひんけつ /脳貧血/
のうひんさき /納品先/
のうひんしょ /納品書/
のうひんじ /納品時/
のうひんまち /納品待ち/
のうふ /納付/農夫/農婦/
のうふきげん /納付期限/
のうふしゃ /納付者/
のうふしょ /納付書/
のうふせいきゅう /納付請求/
のうぶたい /能舞台/
のうべん /能弁/
のうほう /嚢胞/農法/膿疱/
のうほん /納本/
のうまく /脳膜/
のうみ /能美/能見/
のうみそ /脳味噌/
のうみつ /濃密/
のうみん /農民/
のうみんが /農民画/
のうみんで /農民出/
のうみんふう /農民風/
のうむ /濃霧/
のうめん /能面/
のうやく /農薬/
のうやくくうさん /農薬空散/
のうやくしゃ /能役者/
のうやくせいぶん /農薬成分/
のうやま /納山/
のうよう /膿瘍/嚢瘍/
のうらん /悩乱/
のうり /脳裏/能吏/
のうりつ /能率/
のうりつかいぜん /能率改善/
のうりつてき /能率的/
のうりゅうさん /濃硫酸/
のうりょう /納涼/脳梁/
のうりょうさい /納涼祭/
のうりょく /能力/濃緑/
のうりょくいっぱい /能力一杯/
のうりょくきゅう /能力給/
のうりょくけんていしけん /能力検定試験/
のうりょくこうじょう /能力向上/
のうりょくさ /能力差/
のうりょくしだい /能力次第/
のうりょくしゃ /能力者/
のうりょくしゅぎ /能力主義/
のうりょくしょく /濃緑色/
のうりょくじたい /能力自体/
のうりょくじょう /能力上/
のうりょくじょうしょう /能力上昇/
のうりょくち /能力値/
のうりょくてき /能力的/
のうりょくひょうか /能力評価/
のうりょくぶそく /能力不足/
のうりん /農林/
のうりんしょう /農林省/
のうりんすいさん /農林水産/
のうりんすいさんぎょう /農林水産業/
のうりんすいさんしょう /農林水産省/
のえ /野家/
のえる /Ｎｏёｌ/
のおがた /直方/
のおがたえき /直方駅/
のおがたし /直方市/
のかみ /野上/
のがき /野垣/
のがた /野方/
のがみ /野上/埜上/
のがみでんてつ /野上電鉄/
のがわ /野川/野河/
のき /軒/
のきさき /軒先/
のきした /軒下/
のきなみ /軒並/
のぎ /禾/野木/乃木/芒/野義/
のぎく /野菊/
のぎさか /乃木坂/
のぎざか /乃木坂/
のぎし /野岸/
のぎわようこ /野際陽子/
のぐち /野口/
のぐちけん /野口研/
のぐちひでよ /野口英世/
のげ /野毛/
のこ /鋸/
のこぎり /鋸/
のこした /残した/
のこのしま /能古島/
のこり /残り/
のさか /野坂/野栄/
のさっぷ /納沙布/
のざき /野崎/野咲/
のざききた /野崎北/
のざきさんぎょう /野崎産業/
のざと /野里/
のざらし /野晒し/
のざる /野猿/
のざわ /野沢/野澤/
のざわおんせん /野沢温泉/
のざわな /野沢菜/
のし /熨/熨斗/
のした /野下/
のしぶくろ /熨斗袋/
のしろ /能代/野城/能城/
のしろえき /能代駅/
のしろこう /能代工/
のじ /野路/
のじま /野島/野嶋/
のじゅく /野宿/
のじり /野尻/
のじりこ /野尻湖/
のじん /野人/
のずえ /野末/
のせ /野瀬/能瀬/能勢/
のせがわ /野迫川/
のせぐち /能勢口/
のせでんしゃ /能勢電車/
のぞえ /野添/野副/
のぞき /覗/
のぞみ /望/希/稀/
のぞむ /望/
のぞりこ /野反湖/
のたれじに /野垂れ死に/
のだ /野田/
のだがわ /野田川/
のだし /野田市/
のだせん /野田線/
のだせんこうじせん /野田専光寺線/
のだはま /野田浜/
のだはんしん /野田阪神/
のち /後/
のちかわ /後川/
のちのち /後々/
のちほど /後程/
のっとり /乗っ取り/
のっぽろ /野幌/
のつ /野津/
のつはる /野津原/
のづき /野月/
のづみ /野積み/
のてん /野天/
のてんぶろ /野天風呂/
ので /野出/
のでら /野寺/
のと /能登/能都/
のとかわ /能登川/
のとがわ /能登川/
のとしゅっしん /能登出身/
のとじま /能登島/
のとせん /能登線/
のとせんでんか /能登線電化/
のとちほう /能登地方/
のとはんとう /能登半島/
のとろ /能取/
のど /喉/咽/
のどか /長閑/
のどぼとけ /喉仏/
のどもと /喉元/
のなか /野中/野仲/
のなみ /野並/
のの /野々/
ののいち /野々市/
ののか /野々香/
ののはら /野々原/
ののむら /野々村/
ののやま /野々山/
のはら /野原/
のばし /伸ばし/
のばす /〜〜〜〜〜〜〜〜/
のばなし /野放し/野放図/
のひら /野平/
のび /野火/伸/
のびた /のび太/
のびと /野人/
のびのび /伸び伸び/
のびりつ /伸び率/伸率/
のびる /野蒜/
のふせ /野伏/
のぶ /信/伸/宣/延/暢/修/順/展/亘/惟/允/
のぶあき /伸明/信昭/信明/伸晃/宣明/延晃/悦旦/
のぶえ /信恵/伸枝/延枝/
のぶお /信夫/信男/伸生/伸夫/信雄/宣夫/信朗/信生/陳雄/暢夫/
のぶおき /暢興/
のぶかず /信和/
のぶかつ /信克/信勝/信雄/
のぶき /信樹/信木/伸樹/
のぶくに /信邦/
のぶこ /信子/敦子/伸子/暢子/延子/展子/
のぶし /野武士/
のぶじ /伸自/伸治/
のぶすけ /宣介/
のぶた /信太/
のぶたか /信孝/信高/信隆/伸啓/
のぶただ /信忠/
のぶなが /信長/
のぶはら /信原/
のぶはる /伸治/
のぶひこ /延彦/伸彦/信彦/暢彦/宣彦/
のぶひさ /延久/信久/順久/暢久/
のぶひで /宣秀/
のぶひと /宣仁/
のぶひろ /伸浩/信寛/伸弘/信洋/信宏/宣博/伸啓/信博/宣弘/伸裕/展弘/伸廣/信弘/伸広/
のぶまさ /宣政/伸昌/
のぶみつ /信光/
のぶや /誠也/暢也/信也/
のぶやす /信康/宣保/延康/
のぶゆき /信之/信幸/伸行/信行/伸之/暢之/展之/伸幸/宣之/伸介/
のぶよし /信義/伸好/
のぶろう /宣郎/伸郎/信郎/
のへじ /野辺地/
のべ /野辺/延べ/野邊/
のべおか /延岡/
のべおかかん /延岡間/
のべな /野辺名/
のべにんこうすう /延人工数/
のべにんずう /延人数/
のべやま /野辺山/
のべやまてんもんだい /野辺山天文台/
のほう /野方/野放/
のほうず /野放図/
のほり /野堀/
のほろはつ /野幌発/
のぼり /上り/登/幟/
のぼりざか /登り坂/上り坂/
のぼりせん /上り線/
のぼりと /登戸/
のぼりとえき /登戸駅/
のぼりべつ /登別/
のぼる /昇/登/
のま /野間/々/
のまおい /野馬追/
のまち /野町/
のみ /蚤/能美/乃美/鑿/
のみかい /飲み会/呑み会/
のみくい /飲み喰い/呑み喰い/
のみぐん /能美郡/
のみしろ /呑み代/飲み代/
のみだい /飲み代/
のみねーと /ノミネート/
のみほうだい /飲み放題/
のみみず /飲み水/
のみもの /飲み物/飲物/
のみや /飲み屋/野宮/飮み屋/呑屋/
のみやま /野見山/
のむぎとうげ /野麦峠/
のむら /野村/乃村/
のむらしょうけん /野村証券/野村證券/
のむらそうけん /野村総研/
のも /野茂/
のもざき /野母崎/
のもと /野本/
のやま /野山/
のら /野良/
のらいぬ /野良犬/
のらしごと /野良仕事/
のらねこ /野良猫/
のり /紀/法/則/典/徳/憲/範/規/ノリ/海苔/矩/糊/雅/宜/就/哲/伯/悳/乗り/規範/朔/弼/教/孔/昇/
のりあい /乗合/乗り合い/
のりあき /典明/倫明/則明/憲章/憲明/法明/典昭/範明/紀明/紀昭/規昭/徳晶/
のりいれ /乗入/乗り入れ/
のりいれきゅうこう /乗入急行/
のりえ /法枝/礼江/
のりお /典夫/徳雄/範夫/紀男/紀夫/則夫/則郎/憲夫/憲生/昇男/典生/展男/憲雄/典男/
のりおり /乗り降り/
のりかえ /乗換/
のりかえあんない /乗換案内/
のりかええき /乗換駅/
のりかえきゃく /乗換客/
のりかえぐち /乗換口/
のりかえじかん /乗換時間/
のりかえそんしつ /乗換損失/
のりかえたんか /乗換単価/
のりかず /紀和/則和/
のりかた /乗り方/
のりき /乗り気/
のりくみいん /乗組員/
のりくみいんすがた /乗組員姿/
のりくら /乗鞍/
のりくらおんせん /乗鞍温泉/
のりくらこうげん /乗鞍高原/
のりくらだけ /乗鞍岳/
のりこ /紀子/範子/典子/法子/倫子/則子/のり子/祈子/徳子/乃梨子/訓子/能理子/規子/賀子/教子/
のりこし /乗り越し/乗越/
のりこしえき /乗越駅/
のりごこち /乗心地/乗り心地/
のりざね /徳実/
のりしげ /則茂/
のりたか /則貴/典孝/
のりたけ /則竹/憲武/
のりちか /乃親/
のりつぎ /乗り継ぎ/乗継/
のりつぎえき /乗継駅/
のりつぎしていえき /乗継指定駅/
のりつぎとっきゅうけん /乗継特急券/
のりつぎわりびき /乗継割引/
のりつぎわりびきせいど /乗継割引制度/
のりづき /法月/
のりづけ /糊付け/糊付/
のりと /祝詞/
のりのみや /紀宮/
のりのみやさま /紀宮様/
のりば /乗り場/乗場/
のりひこ /紀彦/憲彦/規彦/
のりひさ /則久/範久/典久/典尚/哲久/
のりひと /徳仁/
のりひろ /典大/憲広/紀大/則浩/
のりふみ /憲文/
のりべんとう /海苔弁当/
のりほ /範穂/
のりまき /則巻/
のりまさ /典正/紀政/
のりまつ /乗松/
のりむね /倫宗/
のりもと /紀元/
のりもの /乗り物/乗物/
のりものけん /乗物券/
のりや /法也/紀哉/
のりやす /典康/
のりゆき /範幸/規行/則行/憲行/則之/紀之/規之/徳行/宜之/哲之/典行/徳幸/敬之/紀幸/矩之/憲之/則征/
のりよ /記代/
のりよし /紀吉/法良/徳芳/徳吉/
のりろう /憲郎/
のるうぇー /諾威/
のるむ /ノルム/
のれん /暖簾/
のろ /野呂/
のろい /呪い/
のろけ /惚気/
のろし /烽/烽火/燧/狼煙/
のわき /野分/
のんき /呑気/暢気/暖気/
は /葉/歯/派/破/波/琶/端/覇/羽/杷/把/刃/播/巴/頗/張/芭/簸/爬/跛/刄/叭/坡/垪/怕/霸/玻/碆/笆/菠/葩/陂/齒/
はーぐ /海牙/
はーと /ハート/
はーど /ハード/
はーどでぃすく /ハードディスク/
はーぶ /ハーブ/
はあく /把握/
はあん /破闇/
はい /配/杯/敗/背/輩/肺/牌/排/拝/廃/盃/俳/灰/徘/裴/佩/坏/孛/廢/悖/憊/拜/擺/旆/沛/湃/珮/琲/癈/碚/胚/霈/睥/埴/這/稗/吠/
はいあん /廃案/
はいい /廃位/
はいいけつごう /配位結合/
はいいろ /灰色/
はいいろいっしょく /灰色一色/
はいいろぐま /灰色熊/
はいいん /敗因/配員/
はいうぇい /ハイウェイ/
はいえい /背泳/
はいえき /廃液/廃駅/
はいえきしょり /廃液処理/
はいえつ /拝謁/
はいえん /肺炎/排煙/
はいえんか /排煙家/
はいえんど /ハイエンド/
はいえんのうりょく /排煙能力/
はいおく /廃屋/
はいか /配下/拝火/排架/配架/
はいかい /徘徊/俳諧/誹諧/徘諧/
はいかつりょう /肺活量/
はいかん /廃刊/配管/拝観/
はいかんきゃく /拝観客/
はいかんごう /廃刊号/
はいかんじ /廃刊時/
はいかんていし /拝観停止/
はいかんめい /配管名/
はいかんりょう /拝観料/
はいが /胚芽/
はいがいうんどう /排外運動/
はいがた /灰型/
はいがん /肺ガン/肺癌/拝顔/
はいがんけんしん /肺癌検診/
はいがんし /肺癌死/
はいがんしぼうりつ /肺癌死亡率/
はいがんしぼうりつひ /肺癌死亡率比/
はいがんぞうか /肺癌増加/
はいき /廃棄/排気/
はいきあつ /排気圧/
はいきおん /排気音/
はいきおんどけいこく /排気温度警告/
はいきかん /排気管/
はいきがす /排気ガス/
はいきがわ /排気側/
はいききじゅん /廃機基準/
はいききせい /排気規制/
はいきけい /排気系/
はいきこう /排気口/
はいきしき /排気式/
はいきしょぶん /廃棄処分/
はいきたいさく /排気対策/
はいきていこう /排気抵抗/
はいきねつ /排気熱/
はいきのう /肺機能/
はいきひよう /廃棄費用/
はいきひんど /廃棄頻度/
はいきぶつ /廃棄物/
はいきべん /排気弁/
はいきみゃくどう /排気脈動/
はいきゃく /廃却/
はいきゅう /配給/排球/廃休/配球/
はいきゅうがいしゃ /配給会社/
はいきゅうけん /配給権/
はいきゅうまい /配給米/
はいきゅうもう /配給網/
はいきゅうりょく /配給力/
はいきょ /廃虚/廃墟/
はいきょう /俳協/背教/
はいきょく /廃局/
はいきりょう /排気量/
はいきりょうへんこう /排気量変更/
はいきん /背筋/
はいきんぐ /ハイキング/
はいきんりょく /背筋力/
はいぎょう /廃業/
はいく /俳句/
はいぐうし /配偶子/
はいぐうしゃ /配偶者/
はいぐうしゃせんたく /配偶者選択/
はいぐうしゃてあて /配偶者手当/
はいぐうしゃわりびき /配偶者割引/
はいけい /背景/拝啓/拝敬/
はいけいおん /背景音/
はいけいが /背景画/
はいけいこう /背景光/
はいけいざつおん /背景雑音/
はいけいしょく /背景色/
はいけいせい /胚形成/
はいけいせかい /背景世界/
はいけいせってい /背景設定/
はいけいちしき /背景知識/
はいけいちょうさ /背景調査/
はいけいふくしゃ /背景輻射/
はいけいほうしゃ /背景放射/
はいけっかく /肺結核/
はいけつしょう /敗血症/
はいけん /拝見/
はいげき /排撃/
はいこう /廃校/廃鉱/配向/廃坑/配光/
はいこうじょう /廃工場/
はいこうせい /配光性/
はいこうとくせい /配光特性/
はいご /背後/廃語/
はいごう /配合/
はいごれい /背後霊/
はいさつ /拝察/廃札/
はいざい /廃材/配剤/
はいざら /灰皿/
はいざん /敗残/
はいし /廃止/
はいしあん /廃止案/
はいしえき /廃止駅/
はいしけってい /廃止決定/
はいしご /廃止後/
はいししんせい /廃止申請/
はいしせん /廃止線/
はいしたいしょうせん /廃止対象線/
はいしちょくぜん /廃止直前/
はいしつ /癈疾/
はいしび /廃止日/
はいしほうほう /廃止方法/
はいしまぎわ /廃止間際/
はいしもんだい /廃止問題/
はいしゃ /廃車/歯医者/配車/敗者/
はいしゃあつかい /廃車扱い/
はいしゃいんたい /敗者引退/
はいしゃく /拝借/
はいしゃしゃりょう /廃車車両/
はいしゃしょう /廃車証/
はいしゃしょうめいしょ /廃車証明書/
はいしゃたい /廃車体/
はいしゃちょくぜん /廃車直前/
はいしゃび /廃車日/
はいしゃふっかつ /敗者復活/
はいしゃりょうすう /廃車両数/
はいしゅ /胚珠/
はいしゅつ /排出/輩出/
はいしゅつきじゅん /排出基準/
はいしゅつりょう /排出量/
はいしょう /廃娼/
はいしょうき /排障器/
はいしょく /配色/敗色/憊色/
はいしん /背信/配信/
はいしんこうい /背信行為/
はいしんつうち /配信通知/
はいじ /拝辞/
はいじく /胚軸/
はいじま /拝島/
はいじまえき /拝島駅/
はいじまかん /拝島間/
はいじません /拝島線/
はいじゅ /拝受/
はいじゅくれい /廃塾令/
はいじょ /排除/
はいじょかんこく /排除勧告/
はいじょのうりょく /排除能力/
はいじょろん /排除論/
はいじん /廃人/俳人/癈人/
はいじんどうよう /廃人同様/
はいじんもくぜん /廃人目前/
はいすい /排水/配水/背水/
はいすいかん /排水管/配水管/
はいすいき /排水機/
はいすいこう /排水口/排水溝/
はいすいこうか /排水効果/
はいすいこうよう /排水口用/
はいすいしゅ /肺水腫/
はいすいしょり /排水処理/
はいすいせい /排水性/
はいすいせいのう /排水性能/
はいすいのうりょく /排水能力/
はいすいのじん /背水乃陣/
はいすいよう /排水用/
はいすいりょう /排水量/
はいせい /廃星/
はいせき /排斥/
はいせつ /排泄/
はいせつぶつ /排泄物/
はいせん /配線/敗戦/廃船/廃線/配船/
はいせんあと /廃線跡/
はいせんぎょうしゃ /配線業者/
はいせんこく /敗戦国/
はいせんご /敗戦後/
はいせんざいりょう /配線材料/
はいせんしき /廃線敷/
はいせんしようりょう /配線使用料/
はいせんじ /敗戦時/
はいせんじたい /配線自体/
はいせんすう /敗戦数/
はいせんず /配線図/
はいせんずしゅう /配線図集/
はいせんせつだん /配線切断/
はいせんちょう /配線長/
はいせんひっし /敗戦必至/
はいせんまえ /敗戦前/
はいぜつ /廃絶/
はいぜん /配膳/沛然/
はいぜんしゅうりょう /配膳終了/
はいそ /敗訴/
はいそう /配送/敗走/
はいそうきこう /配送機構/
はいそうきのう /配送機能/
はいそうけい /配送系/
はいそうけいろ /配送経路/
はいそうさき /配送先/
はいそうしょり /配送処理/
はいそうてすうりょう /配送手数料/
はいそうほうほう /配送方法/
はいそうよう /配送用/
はいそうようしゃりょう /配送用車輌/
はいそうりょう /配送料/配送量/
はいそく /背足/背側/
はいそん /廃村/
はいぞう /肺臓/
はいぞく /配属/
はいた /排他/歯痛/
はいたい /敗退/胚胎/
はいたしゅぎてき /排他主義的/
はいたせいぎょ /排他制御/
はいたつ /配達/
はいたついん /配達員/
はいたつしゃ /配達者/
はいたつしょうめい /配達証明/
はいたつじ /配達時/
はいたつじこ /配達事故/
はいたつにん /配達人/
はいたつほうほう /配達方法/
はいたつまえ /配達前/
はいたてき /排他的/
はいたてきろんりわ /排他的論理和/
はいだ /灰田/
はいだん /俳壇/
はいち /配置/
はいちいぜん /配置以前/
はいちがえ /配置換/配置替え/
はいちご /配置後/
はいちじょう /配置上/
はいちじょうきょう /配置状況/
はいちず /配置図/
はいちてんかん /配置転換/
はいちもんだい /配置問題/
はいちゃく /敗着/
はいちゅうりつ /排中律/
はいちょう /拝聴/
はいつ /ハイツ/
はいていらおゆえ /海底撈月/
はいてく /ハイテク/
はいてん /配点/配転/
はいてんけっか /配点結果/
はいてんねがい /配転願/配転願い/
はいでん /配電/拝殿/
はいでんばん /配電盤/
はいとう /配当/
はいとうきん /配当金/
はいとうそしき /配当組織/
はいとうぶん /配当分/
はいとうれい /廃刀令/
はいとく /背徳/
はいどう /廃道/
はいどく /拝読/
はいにち /排日/
はいにゅう /胚乳/
はいにょうこんなん /排尿困難/
はいにん /背任/
はいにんざい /背任罪/
はいねつ /排熱/廃熱/
はいのう /背嚢/胚嚢/
はいはん /排反/背反/
はいはんちけん /廃藩置県/
はいばら /榛原/生原/
はいばらぐんない /榛原郡内/
はいばん /廃盤/廃版/廃番/
はいばんじょうほう /廃盤情報/
はいばんほう /胚盤胞/
はいばんろうぜき /杯盤狼籍/
はいぱい /配牌/
はいひん /廃品/廢品/
はいび /配備/拝眉/
はいびょう /肺病/
はいびん /配便/
はいふ /配布/配付/肺腑/
はいふえんじょ /配布援助/
はいふかのう /配布可能/
はいふき /灰吹/
はいふきてい /配布規定/
はいふきや /灰吹屋/
はいふきょひ /配布拒否/
はいふきんし /配布禁止/
はいふく /拝復/
はいふけいたい /配布形態/
はいふさき /配布先/
はいふしゃ /配布者/
はいふしゅだん /配布手段/
はいふじ /配布時/
はいふじき /配布時期/
はいふじゆう /配布自由/
はいふじょうけん /配布条件/配付条件/
はいふせいげん /配布制限/
はいふちゅうし /配付中止/配布中止/
はいふてすうりょう /配布手数料/
はいふはんい /配布範囲/
はいふはんいいがい /配布範囲以外/
はいふばしょ /配布場所/
はいふばん /配付版/
はいふひん /配布品/
はいふぶつ /配布物/
はいふぶん /配布分/
はいふほうほう /配布方法/
はいふもと /配布元/
はいふよう /配布用/
はいふよていび /配布予定日/
はいふん /―/ハイフン/‐/
はいぶ /背部/
はいぶつ /廃物/
はいぶつりよう /廃物利用/
はいぶん /配分/拝聞/
はいぶんがく /配分額/
はいぶんしゃ /配分者/
はいぶんひょう /配分表/
はいぶんほうほう /配分方法/
はいべん /排便/
はいほう /肺胞/肺袋/
はいほん /配本/
はいぼく /敗北/
はいぼくしゅぎ /敗北主義/
はいむ /ハイム/
はいめ /敗目/
はいめい /拝命/
はいめん /背面/
はいめんひこう /背面飛行/
はいもん /肺門/
はいや /肺野/
はいやく /配役/
はいゆ /廃油/
はいゆう /俳優/
はいゆうざ /俳優座/
はいゆうたち /俳優達/
はいよう /廃用/胚葉/
はいらん /排卵/
はいらんび /排卵日/
はいり /背理/
はいりくち /入り口/
はいりほう /背理法/
はいりょ /配慮/
はいりょう /拝領/
はいれい /拝礼/
はいれつ /配列/排列/
はいれつがたへんかん /配列型変換/
はいれつけい /配列型/
はいれつけいさん /配列計算/
はいれつすう /配列数/
はいれつせいやく /配列制約/
はいれつぜんたい /配列全体/
はいれつない /配列内/
はいれつひょうじ /配列表示/
はいれつへんすう /配列変数/
はいれつめい /配列名/
はいれつりょういき /配列領域/
はいれべる /ハイレベル/
はいろ /廃炉/
はいろーざ /ハイローザ/
はうす /ハウス/
はえ /蝿/蠅/南風/
はえとり /蝿取り/
はえぬき /生え抜き/
はえばる /南風原/
はおう /覇王/
はおうでん /覇王伝/
はおり /羽織/
はか /墓/破瓜/
はかい /破壊/破戒/
はかいかつどう /破壊活動/
はかいかのうぶつ /破壊可能物/
はかいこうい /破壊行為/
はかいこうさく /破壊工作/
はかいこうさくしゃ /破壊工作者/
はかいこうどう /破壊行動/
はかいご /破壊後/
はかいし /墓石/破壊子/
はかいしゃ /破壊者/
はかいしん /破壊神/
はかいてき /破壊的/
はかいてきだいにゅう /破壊的代入/
はかいど /破壊度/
はかいもくひょう /破壊目標/
はかいりつ /破壊率/
はかいりょく /破壊力/
はかく /破格/
はかくね /破格値/
はかげ /葉陰/
はかず /葉数/
はかせ /博士/
はかせいかてい /博士課程/
はかせかてい /博士課程/
はかせかていこうき /博士課程後期/
はかせかていぜんき /博士課程前期/
はかせがくいろんぶん /博士学位論文/
はかせこうきかてい /博士後期課程/
はかせごう /博士号/
はかせぜんきかてい /博士前期課程/
はかせへんにゅう /博士編入/
はかせへんにゅうしけん /博士編入試験/
はかせろんぶん /博士論文/
はかた /博多/伯方/
はかたいがい /博多以外/
はかたいき /博多行/
はかたえいぎょうしょ /博多営業所/
はかたえき /博多駅/
はかたえきこうつう /博多駅交通/
はかたえきわき /博多駅脇/
はかたかん /博多間/
はかたく /博多区/
はかたちゃく /博多着/
はかたはく /博多泊/
はかたはつ /博多発/
はかたびん /博多便/
はかたふう /博多風/
はかたべん /博多弁/
はかたほうめん /博多方面/
はかたみなみ /博多南/
はかたみなみえき /博多南駅/
はかたゆき /博多行/
はかたわん /博多湾/
はかば /墓場/
はかま /袴/
はかまいり /墓参り/
はかまだ /袴田/
はかむら /墓村/
はかり /秤/
はかりごと /謀/
はが /芳賀/羽賀/波賀/
はがいじめ /羽交い絞め/羽交い締め/
はがき /葉書/ハガキ/葉書き/
はがぐん /芳賀郡/
はがしょてん /芳賀書店/
はがしょぼう /芳賀書房/
はがた /歯形/
はがね /鋼/
はがわ /羽川/
はがん /破顔/
はき /破棄/覇気/破毀/杷木/
はきけ /吐き気/吐気/
はきもの /履物/
はきゅう /波及/
はきゅうこうか /波及効果/
はきょく /破局/
はきょくすんぜん /破局寸前/
はぎ /萩/矧/脛/
はぎお /萩尾/
はぎしり /歯軋り/
はぎた /萩田/
はぎたに /萩谷/
はぎの /萩野/
はぎのつき /萩の月/
はぎのまち /萩野町/
はぎはら /萩原/
はぎひら /萩平/
はぎまつり /萩まつり/
はぎもと /萩本/
はぎもときんいち /萩本欽一/
はぎもり /萩森/
はぎや /萩谷/
はぎょう /ハ行/
はぎれ /歯切れ/歯切/
はぎわら /萩原/
はく /泊/白/迫/伯/薄/博/拍/柏/舶/粕/箔/珀/剥/魄/狛/亳/佰/岶/帛/愽/搏/擘/蘗/璞/膊/陌/栢/
はくあ /白亜/白堊/
はくあい /博愛/
はくあき /白亜期/白堊紀/
はくい /白衣/羽咋/伯井/伯夷;商周革命のころの孤竹国の公子/
はくう /白雨/
はくうん /白雲/
はくえい /搏景/
はくえん /白煙/
はくおう /白鴬/白鴎/白鳳/
はくかい /擘開/
はくがい /迫害/
はくがいしゃ /迫害者/
はくがく /博学/
はくがん /白眼/
はくがんし /白眼視/
はくぎ /博儀/
はくぎん /白銀/
はくげい /白鯨/
はくげき /迫撃/搏撃/
はくげきほう /迫撃砲/
はくさい /白菜/舶載/
はくさん /白山/
はくさんした /白山下/
はくし /博士/白紙/薄志/搏摯/
はくしいにん /白紙委任/
はくしいにんじょう /白紙委任状/
はくしかてい /博士課程/
はくしがくいろんぶん /博士学位論文/
はくしき /博識/
はくしごう /博士号/
はくしてっかい /白紙撤回/
はくしとうあん /白紙答案/
はくしま /白島/
はくしゃ /拍車/薄謝/
はくしゃく /伯爵/
はくしゃくふじん /伯爵夫人/
はくしゅ /拍手/
はくしゅかっさい /拍手喝采/
はくしょ /白書/帛書/
はくしょく /白色/
はくしょくえきしょう /白色液晶/
はくしょくか /白色化/
はくしょくこう /白色光/
はくしょくざつおん /白色雑音/
はくしょくじんしゅ /白色人種/
はくしろんぶん /博士論文/
はくしん /迫真/白新/
はくじ /白磁/
はくじつ /白日/
はくじゃ /白蛇/
はくじゃく /薄弱/
はくじゃくじ /薄弱児/
はくじょう /白状/薄情/
はくじん /白人/白刃/
はくじんおんがく /白人音楽/
はくじんけい /白人系/
はくじんしはい /白人支配/
はくじんせんよう /白人専用/
はくじんせんようれっしゃ /白人専用列車/
はくすい /白水/
はくすいしゃ /白水社/
はくすう /拍数/泊数/搏数/
はくせい /剥製/
はくせん /白線/
はくせんきん /白癬菌/白鮮菌/
はくせんしゃ /白泉社/薄銭社/
はくぜん /白髯/
はくた /伯太/
はくだく /白濁/
はくだつ /剥奪/はく奪/
はくだん /白檀/
はくち /白痴/泊地/
はくちず /白地図/
はくちゅう /白昼/伯仲/
はくちゅうこう /白昼光/
はくちゅうむ /白昼夢/
はくちゅうむてき /白昼夢的/
はくちょう /白鳥/
はくちょうこ /白鳥湖/
はくちょうごう /白鳥号/
はくちょうざ /白鳥座/
はくちょうだい /白鳥台/
はくちょうのうた /白鳥の歌/
はくつる /白鶴/
はくつるびじゅつかん /白鶴美術館/
はくてん /白点/
はくとう /白糖/白桃/
はくどう /拍動/白道/
はくないしょう /白内障/
はくねつ /白熱/
はくねつこう /白熱光/
はくねつとう /白熱灯/
はくはつ /白髪/
はくはつちゅん /白發中/
はくはつはくぜん /白髪白髯/
はくはん /白斑/
はくば /白馬/
はくばい /白梅/
はくばえき /白馬駅/
はくばえきまえ /白馬駅前/
はくばさんけい /白馬山系/
はくばのりくら /白馬乗鞍/
はくばのりくらこくさい /白馬乗鞍国際/
はくばほうめん /白馬方面/
はくばん /白板/薄板/
はくひょう /薄氷/
はくひんかんげきじょう /博品館劇場/
はくび /白眉;蜀漢の馬良の通称。転じて優れたもの/
はくびせん /伯備線/
はくふ /白布/帛布/
はくぶつ /博物/
はくぶついん /博物院/
はくぶつかん /博物館/
はくぶつかんかいかん /博物館開館/
はくぶつかんどうぶつえん /博物館動物園/
はくぶつがく /博物学/
はくぶつし /博物誌/博物史/
はくへい /白兵/
はくへいせん /白兵戦/
はくほう /白鳳/
はくほうどう /博報堂/
はくぼ /薄暮/
はくぼく /白墨/
はくま /白魔/
はくまい /白米/
はくまく /薄膜/白膜/
はくめ /拍目/
はくめい /薄命/
はくめんか /薄面化/
はくや /白夜/
はくゆん /学胤/
はくよう /伯洋/
はくようけん /伯養軒/
はくようしゃ /白洋舎/白揚社/
はくらい /舶来/
はくらいひん /舶来品/
はくらく /伯楽/剥落/白楽/
はくらん /博覧/
はくらんかい /博覧会/
はくらんきょうき /博覧強記/
はくり /剥離/薄利/白痢/
はくりき /薄力/
はくりきこ /薄力粉/
はくりきこむぎこ /薄力小麦粉/
はくりこっせつ /剥離骨折/
はくりざい /剥離剤/
はくりせいそう /剥離清掃/
はくりたばい /薄利多売/
はくりゅう /白龍/
はくりょく /迫力/薄力/
はくりょくこ /薄力粉/
はくりょくじゅうぶん /迫力充分/
はくりょくまんてん /迫力満点/
はくれんが /白煉瓦/
はくろ /白露/
はくろう /伯労/
はくろん /博論/
はぐき /歯茎/齦/歯ぐき/
はぐるま /歯車/
はぐるましき /歯車式/
はぐるましきてつどう /歯車式鉄道/
はぐるまひ /歯車比/
はぐれぐも /浮浪雲/
はぐろ /羽黒/歯黒/
はけ /刷毛/捌け/
はけい /波形/
はけいかいせき /波形解析/
はけいにんしき /波形認識/
はけいぶんせき /波形分析/
はけいほせい /波形補正/
はけいれい /波形例/
はけん /派遣/覇権/
はけんあらそい /覇権争い/
はけんがいしゃ /派遣会社/
はけんさき /派遣先/
はけんしゃいん /派遣社員/
はげ /ハゲ/禿/
はげあたま /禿頭/
はげたか /禿鷹/
はげやま /禿山/
はげん /波源/
はこ /箱/函/運/葉子/□/匡/凾/筥/箪/匣/
はこいり /箱入り/箱入/
はこう /破口/跛行/波高/
はこうぶんぷ /波高分布/
はこえ /箱絵/
はこえふう /箱絵風/
はこがた /箱型/
はこがたしゃたい /箱型車体/
はこさきぐう /筥崎宮/
はこざき /箱崎/筥崎/
はこざきちょう /箱崎町/
はこした /箱下/
はこだて /函館/
はこだていき /函館行/
はこだてえき /函館駅/
はこだてきねん /函館記念/
はこだてけいばじょう /函館競馬場/
はこだてしがい /函館市街/
はこだてしゅっしん /函館出身/
はこだてせん /函館線/
はこだてどっく /函館ドック/
はこだてほんせん /函館本線/
はこだてやま /函館山/
はこづけ /箱付/
はこづめ /箱詰め/箱詰/
はこにわ /箱庭/
はこね /箱根/
はこねえきでん /箱根駅伝/
はこねしんどう /箱根新道/
はこねじ /箱根路/
はこねとざん /箱根登山/
はこねとざんてつどう /箱根登山鉄道/
はこねほうめん /箱根方面/
はこねゆもと /箱根湯本/
はこねゆもといき /箱根湯本行/
はこねゆもとゆき /箱根湯本行/
はこねわん /箱根湾/
はこはんぶん /箱半分/
はこぶね /箱舟/箱船/方舟/
はこまつ /筥松/
はこものちゅうしん /箱物中心/
はこもり /箱守/
はご /羽子/
はごいた /羽子板/
はごろも /羽衣/
はさい /破砕/
はさき /波崎/刃先/
はさこ /羽迫/
はさつおん /破擦音/
はさま /迫/挟間/
はさみ /螯/鋏/波佐見/
はさみうち /挟み撃ち/挟み打ち/挾み撃ち/挾み打ち/
はさみつけ /挾み付け/
はさん /破産/破算/
はさんかんざいにん /破産管財人/
はさんしゃ /破産者/
はさんすんぜん /破産寸前/
はさんせんこく /破産宣告/
はさんほう /破産法/
はさんほごしんせい /破産保護申請/
はざい /端材/
はざかい /端境/
はざかいき /端境期/
はざくら /葉桜/
はざま /硲/狭間/陌間/羽佐間/間/
はざまぐみ /間組/
はざわ /羽沢/
はし /橋/端/箸/走/觜/梯/枦/
はしうえとうけつちゅうい /橋上凍結注意/
はしうら /橋浦/
はしお /走尾/
はしか /麻疹/
はしかみ /階上/
はしかわ /橋川/
はしがき /端書/
はしがみ /橋上/
はしがみえき /橋上駅/
はしくら /橋倉/
はしくれ /端くれ/
はしぐち /橋口/
はしけ /艀/
はしげた /橋桁/橋げた/
はしご /梯子/
はしずめ /橋爪/
はした /端/
はしたか /鷂/
はしたがね /端金/端た金/
はしたに /橋谷/
はしため /婢/
はしだ /橋田/
はしだて /橋立/
はしづめ /橋詰/橋爪/
はしの /橋野/
はしのすけ /橋之助/
はしば /羽柴/
はしばし /端々/
はしばひでよし /羽柴秀吉/
はしばみ /榛/
はしひめ /橋姫/
はしま /羽島/
はしもと /橋本/
はしもとえき /橋本駅/
はしもとてん /橋本店/
はしもととっきゅう /橋本特急/
はしもとりゅうたろう /橋本龍太郎/
はしゃ /覇者/
はしゅ /把手/播種/
はしゅつ /派出/
はしゅつしょ /派出所/派出署/
はしゅつじょ /派出所/
はしょうふう /破傷風/
はしら /柱/
はしらたに /柱谷/
はしらとりつけかなぐ /柱取付金具/
はしらどけい /柱時計/
はしり /走り/
はしりかた /走り方/
はしりがき /走り書き/
はしわたし /橋渡し/
はじ /恥/端/始/把持/初/耻/土師/
はじかみ /薑/
はじま /羽島/
はじまり /始まり/
はじめ /肇/一/初め/甫/馨/壱/元/哉/始/初/弌/壹/始め/創/
はじめて /初めて/
はじめね /始め値/始値/
はじめまして /始めまして/
はじゃ /破邪/覇者/
はじょう /波状/
はじょうこうげき /波状攻撃/
はじょうろ /波状路/
はじらい /羞じらい/
はす /蓮/斜/
はすい /破水/
はすいけ /蓮池/
はすう /端数/波数/歯数/
はすうしょり /端数処理/
はすか /ハス科/Nelumbonaceae/
はすこ /蓮子/
はすだ /蓮田/
はすっぱ /蓮葉/蓮っ葉/
はすぬま /蓮沼/
はすぬまちょう /蓮沼町/
はすのはぎりか /ハスノハギリ科/Hernandiaceae/
はすは /泰葉/
はすみ /羽純/蓮見/羽角/羽須美/蓮實/
はすむかい /斜向い/
はず /筈/
はずい /筈井/
はずかしめ /辱め/
はずみぐるま /弾み車/
はずれ /外/
はせ /長谷/馳/
はせい /派生/長谷井/
はせいきそく /派生規則/
はせいけい /派生型/
はせいげん /派生源/
はせいご /派生語/
はせいてき /派生的/
はせいぶつ /派生物/
はせがわ /長谷川/
はせがわこうむてん /長谷川工務店/
はせくら /支倉/
はせべ /長谷部/
はせみ /長谷見/
はせん /破線/波線/
はせんぶ /波線部/
はぜ /櫨/鯊/枦/
はそうさき /配送先/
はそく /波束/
はそん /破損/
はそんじこ /破損事故/
はそんりつ /破損率/
はた /旗/畑/幡/端/畠/幡多/秦/波多/旛/旙/籏/羽田/幟/傍/機/波田/圃/側/将/
はたあげ /旗揚/旗揚げ/
はたい /波帯/
はたいけ /幡池/
はたいろ /旗色/
はたうえ /畑上/
はたえ /二十重/波多江/
はたおか /畑岡/
はたおり /旗折/
はたがしら /旗頭/
はたがや /幡ヶ谷/
はたきこみ /叩き込み/
はたけ /畑/畠/
はたけやま /畠山/畑山/
はたご /旅籠/
はたさ /畑佐/
はたさく /畑作/
はたざき /畑崎/
はたして /果して/
はたしょう /秦荘/
はたじるし /旗印/
はたたて /旗立/
はただ /畠田/畑田/
はたち /二十歳/２０歳/二十/畑地/
はたとせ /二十歳/
はたなか /畑中/畑仲/畠中/
はたの /波多野/籏野/羽田野/秦野/幡野/畑野/
はたのう /畑農/
はたのえき /秦野駅/
はたのえきまえ /秦野駅前/
はたのし /秦野市/
はたのだいだんち /秦野台団地/
はたのていしゃ /秦野停車/
はたはた /鰰/
はたふり /旗振り/
はたぶ /幡生/
はたむら /畑村/
はため /傍目/はた目/
はたもと /播本/畑本/
はたや /畑谷/
はたやま /畑山/畠山/
はたら /働/
はたらき /働き/
はたん /破綻/
はだ /肌/膚/羽田/
はだあい /肌合/
はだあれ /肌あれ/肌荒/
はだいろ /肌色/
はだか /裸/
はだかけ /肌掛け/
はだかてがた /裸手形/
はだかび /裸火/
はだかむぎ /裸麦/
はだぎ /肌着/
はだざわり /肌触り/
はだし /裸足/跣/
はだの /秦野/
はだぶとん /肌布団/
はだみ /肌身/
はだん /破談/破断/
はち /八/鉢/８/蜂/ハチ/捌/椀/
はちあわせ /鉢合わせ/
はちうえ /鉢植/
はちおうじ /八王子/
はちおうじかん /八王子間/
はちおうじがわ /八王子側/
はちおうじこうこう /八王子高校/
はちおうじざいじゅう /八王子在住/
はちおうじし /八王子市/
はちおうじじっせん /八王子実践/
はちおうじじっせんこうこう /八王子実践高校/
はちおうじせん /八王子線/
はちおうじどうぶつえん /八王子動物園/
はちおうじひがしこう /八王子東高/
はちおうじほうめん /八王子方面/
はちおうじりょうきんじょ /八王子料金所/
はちかい /八開/
はちがつ /八月/8月/葉月/
はちく /破竹/
はちけん /八軒/
はちげんすう /八元数/
はちこう /ハチ公/
はちこうだい /八工大/
はちごうめ /八合目/
はちじ /八時/
はちじゅう /八十/
はちじゅうに /八十二/
はちじゅうにぎんこう /八十二銀行/
はちじゅうはちや /八十八夜/
はちじょう /八丈/八条/鉢状/
はちじょうぐち /八条口/
はちじょうじま /八丈島/
はちにん /八人/
はちにんていど /八人程度/
はちねん /八年/
はちねんいじょう /八年以上/
はちのす /蜂の巣/
はちのへ /八戸/
はちのへくじせん /八戸久慈線/
はちのへこうぎょうだい /八戸工業大/
はちのへこうぎょうだいがく /八戸工業大学/
はちのへこうだいいち /八戸工大一/
はちのへせん /八戸線/
はちのへはつ /八戸発/
はちはちかんたい /八八艦隊/
はちばん /八番/
はちばんめ /八番目/
はちぶ /八分/８分/八部/
はちぶおんぷ /８分音符/♪/
はちぶせやま /鉢伏山/
はちほん /八本/
はちほんまつ /八本松/
はちまい /八枚/
はちまき /鉢巻/
はちまん /八幡/
はちまんぐう /八幡宮/
はちまんじんじゃ /八幡神社/
はちまんたい /八幡平/
はちまんまち /八幡町/
はちまんやま /八幡山/
はちみつ /蜂蜜/
はちめんろっぴ /八面六臂/
はちもの /鉢物/
はちもり /八森/
はちゃめちゃ /葉茶目茶/
はちや /蜂屋/八谷/鉢谷/
はちゅう /爬虫/
はちゅうるい /爬虫類/爬蟲類/
はちょう /波長/
はちょういぞんせい /波長依存性/
はちょうごと /波長毎/
はちょうせいぶん /波長成分/
はちょうせんい /波長遷移/
はちりゅう /八竜/
はちろ /八路/
はちろう /八郎/
はちろうがた /八郎潟/
はちろぐん /八路軍/
はっ /発/法/發/
はっか /発火/薄荷/
はっかー /ハッカー/
はっかい /発会/八戒/
はっかいさん /八海山/
はっかいしき /発会式/
はっかかのう /発火可能/
はっかく /発覚/
はっかくとうしょ /発覚当初/
はっかせき /発火石/
はっかち /発火値/
はっかてん /発火点/
はっかひんど /発火頻度/
はっかりつ /発火率/
はっかん /発刊/発汗/
はっかんび /発刊日/
はっき /発揮/発輝/
はっきゅう /発給/薄給/
はっきょう /発狂/
はっきょうし /発狂死/
はっきょうすんぜん /発狂寸前/
はっきり /ハッキリ/
はっきん /発禁/白金/
はっきんしょぶん /発禁処分/
はっきんせんでんきょく /白金線電極/
はっきんそうどう /発禁騒動/
はっく /八九/
はっくつ /発掘/
はっくつけっか /発掘結果/
はっくつばんぐみ /発掘番組/
はっけ /八卦/
はっけい /八景/発勁/
はっけいおき /八景沖/
はっけいじま /八景島/
はっけっきゅう /白血球/
はっけつびょう /白血病/
はっけん /発見/発券/白鍵/
はっけんいこう /発見以降/
はっけんいち /発見位置/
はっけんかがく /発見科学/
はっけんがくしゅう /発見学習/
はっけんしゃ /発見者/
はっけんしゃいがい /発見者以外/
はっけんじこく /発券時刻/発見時刻/
はっけんちてん /発券地点/
はっけんてき /発見的/
はっけんてきがくしゅう /発見的学習/
はっけんでん /八犬伝/
はっけんねん /発見年/
はっけんばん /白鍵盤/
はっけんほうほう /発見方法/発券方法/
はっこ /発呼/
はっこう /発行/発酵/発光/発効/醗酵/薄幸/八紘/白光/
はっこういちう /八紘一宇/
はっこうがいしゃ /発行会社/
はっこうき /発行機/
はっこうきかん /発行機関/
はっこうしゃ /発行者/
はっこうしゃべつ /発行社別/
はっこうしゅ /発酵酒/
はっこうしゅう /発酵臭/
はっこうしゅうりょう /発酵終了/
はっこうしょ /発行所/
はっこうじ /発行時/
はっこうじかん /発光時間/
はっこうじき /発行時期/
はっこうじぎょう /発行事業/
はっこうじゅみょう /発光寿命/
はっこうじょ /発行所/
はっこうじょうきょう /発行状況/
はっこうじょうたい /発酵状態/
はっこうすう /発行数/
はっこうせいぶつ /発光生物/
はっこうせん /八高線/
はっこうせんでんか /八高線電化/
はっこうたい /発光体/
はっこうだ /八甲田/
はっこうださん /八甲田山/
はっこうてすうりょう /発行手数料/
はっこうにん /発行人/
はっこうねん /発行年/
はっこうねんがっぴ /発行年月日/
はっこうねんど /発行年度/
はっこうばんごう /発行番号/
はっこうび /発行日/
はっこうびぜんじつ /発行日前日/
はっこうぶ /発光部/
はっこうぶすう /発行部数/
はっこうぶつ /発行物/
はっこうほうほう /発行方法/
はっこうまいすう /発行枚数/
はっこうもと /発行元/
はっこうよていび /発行予定日/
はっこうりょう /発光量/発行量/
はっこつ /白骨/
はっこつしたい /白骨死体/
はっこよう /発呼用/
はっさい /八歳/
はっさく /八朔/
はっさむ /発寒/
はっさん /発散/
はっさんていり /発散定理/
はっしゃ /発射/発車/
はっしゃおん /発射音/
はっしゃかくど /発射角度/
はっしゃかん /発射管/
はっしゃこう /発射口/
はっしゃご /発車後/
はっしゃじ /発射時/発車時/
はっしゃじかん /発車時間/
はっしゃじこく /発車時刻/
はっしゃじこくひょう /発車時刻表/
はっしゃだい /発射台/
はっしゃちょくぜん /発車直前/
はっしゃばんせん /発車番線/
はっしゃび /発車日/
はっしゃほうこう /発射方向/
はっしゃまえ /発車前/
はっしゃようび /発車曜日/
はっしゅち /ハッシュ値/
はっしゅひょう /ハッシュ表/
はっしょう /発祥/八章/発消/発症/八省/
はっしょうご /発症後/
はっしょうち /発祥地/
はっしょうねんれい /発症年齢/
はっしょうまえ /発症前/
はっしょく /発色/
はっしょくげんしょう /発色現像/
はっしょくざい /発色剤/
はっしょくすう /発色数/
はっしょくせい /発色性/
はっしょくとくせい /発色特性/
はっしん /発信/発疹/発振/発進/八神/発震/
はっしんおん /発信音/発振音/
はっしんかいろ /発振回路/
はっしんかそく /発進加速/
はっしんがわ /発信側/
はっしんき /発振器/発信機/発信器/発振機/
はっしんきょく /発信局/
はっしんげん /発信源/
はっしんさき /発信先/
はっしんし /発振子/
はっしんしゃ /発信者/
はっしんじ /発信時/発進時/発震時/
はっしんじこく /発信時刻/
はっしんじょうたい /発信状態/
はっしんせんよう /発信専用/
はっしんせんようでんわ /発信専用電話/
はっしんちゅう /発信中/
はっしんちょくご /発進直後/
はっしんていし /発進停止/
はっしんどうさ /発信動作/
はっしんにん /発信人/
はっしんにんばらい /発信人払い/
はっしんひょうき /八進表記/
はっしんび /発信日/
はっしんふのう /発進不能/
はっしんぶ /発信部/
はっしんぶぶん /発振部分/
はっしんほうしき /発振方式/
はっしんほうほう /発振方法/発進方法/
はっしんもと /発信元/
はっしんよう /発信用/
はっすい /発水/
はっすいかこう /発水加工/
はっすいざい /溌水剤/
はっすいせい /溌水性/発水性/撥水性/
はっせい /発生/発声/八世/
はっせいかいすう /発生回数/
はっせいかいろ /発生回路/
はっせいかくりつ /発生確立/
はっせいかしょ /発生箇所/
はっせいかんかく /発生間隔/
はっせいがく /発生学/
はっせいき /発生器/
はっせいきかん /発声器官/
はっせいきげん /発生起源/
はっせいきこう /発声機構/
はっせいくかん /発声区間/
はっせいげん /発生源/
はっせいげんいん /発生原因/
はっせいご /発生後/
はっせいしゃ /発声者/
はっせいじ /発生時/
はっせいじかん /発声時間/
はっせいじき /発声時期/
はっせいじこく /発生時刻/
はっせいじゅん /発生順/
はっせいじょうきあつ /発生蒸気圧/
はっせいじょうきりょう /発生蒸気量/
はっせいすう /発生数/
はっせいてき /発生的/
はっせいてきにんしきろん /発生的認識論/
はっせいてん /発生点/
はっせいとうじ /発生当時/
はっせいないよう /発声内容/
はっせいねん /発生年/
はっせいねんがっぴ /発生年月日/
はっせいねんど /発生年度/
はっせいばしょ /発生場所/
はっせいひん /発生品/
はっせいひんど /発生頻度/
はっせいぶんか /発生分化/
はっせいほう /発生法/
はっせいほうこう /発生方向/
はっせいもと /発生元/
はっせいよういん /発生要因/
はっせいりつ /発生率/
はっせいりゆう /発生理由/
はっせいりょう /発生量/
はっせいれんしゅう /発声練習/
はっせん /八千/八仙/
はっそう /発送/発想/発走/
はっそうあいず /発走合図/
はっそうき /発走機/
はっそうきぼう /発送希望/
はっそうぎょうむ /発送業務/
はっそうけい /発想系/
はっそうご /発送後/
はっそうさき /発送先/
はっそうしえん /発想支援/
はっそうしゃ /発送者/
はっそうしゅだん /発送手段/
はっそうしょり /発送処理/
はっそうじ /発送時/
はっそうじたい /発想自体/
はっそうじょがい /発走除外/
はっそうふかのう /発送不可能/
はっそうぶつ /発送物/
はっそうほう /発想法/発送法/
はっそうほうほう /発想方法/
はっそうまえ /発走前/
はっそうよう /発送用/
はっそうよてい /発送予定/
はっそうりょう /発送料/
はっそく /発足/
はった /八田/
はったつ /発達/
はったつしんり /発達心理/
はったつしんりがく /発達心理学/
はったつしんりがくしゃ /発達心理学者/
はったつだんかい /発達段階/
はったつど /発達度/
はったん /発端/八反/
はったんにしき /八反錦/
はっちゃく /発着/
はっちゃくしん /発着信/
はっちゃくじかん /発着時間/
はっちゃくじょ /発着所/
はっちゃくじょう /発着場/
はっちゃくすう /発着数/
はっちゃくち /発着地/
はっちゃくてん /発着点/
はっちゃくびん /発着便/
はっちゃくりょうほう /発着両方/
はっちゃくわく /発着枠/
はっちゅう /発注/八中/
はっちゅうしゃ /発注者/
はっちゅうじゅん /発注順/
はっちゅうずみ /発注済/
はっちゅうぬし /発注主/
はっちょう /八丁/
はっちょうぼり /八丁堀/
はっちょうみそ /八丁味噌/
はってん /発展/
はってんかのうせい /発展可能性/
はってんき /発展期/
はってんけい /発展形/発展型/
はってんけいい /発展経緯/
はってんせい /発展性/
はってんだんかい /発展段階/
はってんてき /発展的/
はってんてきかいけつ /発展的解決/
はってんてきかいさん /発展的解散/
はってんてきかいしょう /発展的解消/
はってんとじょう /発展途上/
はってんとじょうき /発展途上期/
はってんとじょうこく /発展途上国/
はってんとじょうちゅう /発展途上中/
はってんとちゅう /発展途中/
はってんとちゅうこく /発展途中国/
はってんほうこう /発展方向/
はっと /法度/
はっとう /八東/
はっとうしん /八等身/
はっとり /服部/
はっとりせいこー /服部セイコー/
はっとりとけいてん /服部時計店/
はっぱ /葉っぱ/発破/
はっぴ /法被/
はっぴき /八匹/
はっぴゃく /八百/
はっぴょう /発表/
はっぴょういらい /発表以来/
はっぴょうかい /発表会/
はっぴょうかいし /発表開始/
はっぴょうかのうていいん /発表可能定員/
はっぴょうがいよう /発表概要/
はっぴょうきじ /発表記事/
はっぴょうきぼうしゃ /発表希望者/
はっぴょうけいしき /発表形式/
はっぴょうけいたい /発表形態/
はっぴょうけっていご /発表決定後/
はっぴょうけんすう /発表件数/
はっぴょうこうえん /発表講演/
はっぴょうご /発表後/
はっぴょうさき /発表先/
はっぴょうしゃ /発表者/
はっぴょうしゃしめい /発表者氏名/
はっぴょうしゃぼしゅう /発表者募集/
はっぴょうしゃめい /発表者名/
はっぴょうしゅうりょう /発表終了/
はっぴょうしりょう /発表資料/
はっぴょうじ /発表時/
はっぴょうじかん /発表時間/
はっぴょうじき /発表時期/
はっぴょうじゅん /発表順/
はっぴょうずみ /発表済/
はっぴょうだいめい /発表題名/
はっぴょうだいもく /発表題目/
はっぴょうてんじかい /発表展示会/
はっぴょうとうしょ /発表当初/
はっぴょうとうじ /発表当時/
はっぴょうないよう /発表内容/
はっぴょうねん /発表年/
はっぴょうねんだい /発表年代/
はっぴょうばんごう /発表番号/
はっぴょうび /発表日/
はっぴょうぼしゅう /発表募集/
はっぴょうまえ /発表前/
はっぴょうもうしこみ /発表申込/
はっぴょうもうしこみあんない /発表申込案内/
はっぴょうもうしこみさき /発表申込先/
はっぴょうもうしこみしめきり /発表申込締切/
はっぴょうもうしこみすう /発表申込数/
はっぴょうもうしこみひょう /発表申込票/
はっぴょうようし /発表要旨/発表用紙/
はっぴょうよていしゃ /発表予定者/
はっぴょうれんしゅう /発表練習/
はっぴょうろんぶん /発表論文/
はっぴよう /発表/
はっぷ /発布/髪膚/
はっぷん /発奮/発憤/
はっぺい /八平/
はっぽう /八方/発砲/発泡/
はっぽうえん /八芳園/
はっぽうおね /八方尾根/
はっぽうおん /発砲音/
はっぽうこうげん /白峰高原/
はっぽうさい /八宝菜/
はっぽうざい /発泡剤/
はっぽうじけん /発砲事件/
はっぽうせい /発泡性/
はっぽうせつ /発砲説/
はっぽうびじん /八方美人/
はっぽうびじんてき /八方美人的/
はっぽうもく /八方目/
はつ /発/初/髪/醗/溌/撥/發/癶/秡/釟/髮/鉢/捌/
はつ> /初/
はつあん /発案/
はつあんしゃ /発案者/
はつあんだ /初安打/
はつい /発意/
はついく /発育/
はついくがく /発育学/
はついくじょう /発育上/
はついし /初石/
はつうま /初午/
はつうり /初売/初売り/
はつえ /初絵/初江/
はつえいぎょううんてん /初営業運転/
はつえき /発駅/
はつえきけん /発駅券/
はつえん /発煙/
はつえんとう /発煙筒/発煙灯/発炎筒/
はつお /初男/
はつおん /発音/撥音/
はつおんいじょう /発音異常/
はつおんき /発音器/
はつおんきこう /発音機構/
はつおんきごう /発音記号/
はつおんきごうか /発音記号化/
はつおんきごうれつ /発音記号列/
はつおんけい /発音系/
はつおんしゃ /発音者/
はつおんしゅぎ /発音主義/
はつおんじょう /発音上/
はつおんすう /発音数/
はつおんたい /発音体/
はつおんひょうき /発音表記/
はつおんびん /撥音便/
はつおんふごう /発音符合/
はつおんふめい /発音不明/
はつおんぶぶん /発音部分/
はつおんれんしゅう /発音練習/
はつか /２０日/二十日/廿日/20日/
はつかいち /甘日市/廿日市/
はつかん /発艦/
はつかんせつ /初冠雪/
はつかんせん /初感染/初観戦/
はつかんそう /初完走/
はつかんとう /初完投/
はつかんとうしょうり /初完投勝利/
はつかんぷう /初完封/
はつかんぷうしょうり /初完封勝利/
はつが /発芽/
はつがお /初顔/
はつがつお /初鰹/
はつがぼうし /発芽防止/
はつがり /初狩/
はつがん /発癌/発ガン/発がん/
はつがんせい /発癌性/
はつがんぶっしつ /発癌物質/
はつぎ /発議/
はつぎしゃ /発議者/
はつくろぼし /初黒星/
はつげん /発言/発現/撥弦/
はつげんがっき /撥弦楽器/
はつげんけいしつ /発現形質/
はつげんけん /発言権/
はつげんしゃ /発言者/
はつげんじ /発言時/
はつげんちゅう /発言中/
はつげんないよう /発言内容/
はつげんほうほう /発言方法/
はつげんりょう /発現量/
はつげんりょく /発言力/
はつこい /初恋/
はつこいでんせつ /初恋伝説/
はつこうかい /初公開/
はつこうぎょう /初興業/初興行/
はつご /発語/初子/
はつさいよう /初採用/
はつさわ /初沢/
はつさんか /初参加/
はつさんせん /初参戦/
はつしば /初芝/
はつしも /初霜/
はつしゅえん /初主演/
はつしゅっきん /初出勤/
はつしゅっしいちらん /初出誌一覧/
はつしゅっそう /初出走/
はつしゅっそうば /初出走馬/
はつしゅってい /初出艇/
はつしゅっぱん /初出版/
はつしゅつじょう /初出場/
はつしゅつじょうこう /初出場校/
はつしゅつじょうゆうしょう /初出場優勝/
はつしゅつば /初出馬/
はつしゅび /初守備/
はつしょうがいせいは /初障害制覇/
はつしょうり /初勝利/
はつしん /発進/
はつしんしゅつ /初進出/
はつじこく /発時刻/
はつじも /初霜/
はつじゅしょう /初受賞/
はつじょう /発情/発条/
はつじょうき /発情期/
はつすべり /初滑り/
はつずりぶん /初刷分/
はつせいは /初制覇/
はつせんぱつ /初先発/
はつそうこう /初走行/
はつたいけつ /初対決/
はつたいけん /初体験/
はつたろう /初太郎/
はつたんぺんしゅう /初短篇集/
はつだい /初台/
はつだいえき /初台駅/
はつだいひょう /初代表/
はつだせき /初打席/
はつちょうせん /初挑戦/
はつづり /初釣/
はつで /初出/
はつでん /発電/
はつでんき /発電器/発電機/発電気/
はつでんきかんけい /発電機関係/
はつでんげんり /発電原理/
はつでんこうりつ /発電効率/
はつでんしせつ /発電施設/
はつでんしょ /発電所/
はつでんせつび /発電設備/
はつでんよう /発電用/
はつでんりょう /発電量/
はつとうこう /初投稿/
はつとうこうきねん /初投稿記念/
はつとうさい /初搭載/
はつとうじょう /初登場/
はつとうじょうおんげん /初登場音源/
はつとうばん /初登板/初投板/
はつとみ /初富/
はつどう /発動/
はつどうき /発動機/
はつに /初荷/
はつね /初音/
はつねつ /発熱/發熱/
はつねつたい /発熱体/
はつねつちゅう /発熱中/
はつねつりょう /発熱量/
はつはる /初春/
はつばい /発売/
はつばいえき /発売駅/
はつばいえんき /発売延期/
はつばいかいし /発売開始/
はつばいかいしご /発売開始後/
はつばいかいしび /発売開始日/
はつばいがく /発売額/
はつばいがっぴ /発売月日/
はつばいきかん /発売期間/
はつばいきねん /発売記念/
はつばいきんし /発売禁止/
はつばいけってい /発売決定/
はつばいご /発売後/
はつばいしゃ /発売者/
はつばいしゅうりょうご /発売終了後/
はつばいしょにち /発売初日/
はつばいじ /発売時/
はつばいじかん /発売時間/
はつばいじき /発売時期/
はつばいじこく /発売時刻/
はつばいじこくまえ /発売時刻前/
はつばいじゅん /発売順/
はつばいじゅんえんちゅう /発売順延中/
はつばいじょ /発売所/
はつばいじょうきょう /発売状況/
はつばいじょうほう /発売情報/
はつばいすう /発売数/
はつばいずみ /発売済/
はつばいぜんご /発売前後/
はつばいぜんじつ /発売前日/
はつばいちゅう /発売中/
はつばいちゅうし /発売中止/
はつばいちょくご /発売直後/
はつばいちょくぜん /発売直前/
はつばいつき /発売月/
はつばいづき /発売月/
はつばいとうしょ /発売当初/
はつばいとうじ /発売当時/
はつばいとうじつ /発売当日/
はつばいひづけ /発売日付/
はつばいび /発売日/
はつばいびご /発売日後/
はつばいびそくかんばい /発売日即完売/
はつばいびとうじつ /発売日当日/
はつばいびまえ /発売日前/
はつばいびみてい /発売日未定/
はつばいびよくじつ /発売日翌日/
はつばいぶすう /発売部数/
はつばいぶん /発売分/
はつばいほうほう /発売方法/
はつばいまいすう /発売枚数/
はつばいまえ /発売前/
はつばいまどぐち /発売窓口/
はつばいみてい /発売未定/
はつばいもと /発売元/
はつばいもとれんらくさき /発売元連絡先/
はつばいよてい /発売予定/
はつばいよていひょう /発売予定表/
はつばいよていび /発売予定日/
はつばいわく /発売枠/
はつばしょ /初場所/
はつひ /初日/
はつひこう /初飛行/
はつひので /初日の出/
はつびょう /発病/
はつびょうりつ /発病率/
はつふゆ /初冬/
はつぶたい /初舞台/
はつほん /発本/
はつほんるいだ /初本塁打/
はつぼうえいせん /初防衛戦/
はつみ /初見/初実/
はつみみ /初耳/
はつめい /発明/
はつめいおう /発明王/
はつめいか /発明家/
はつめいしゃ /発明者/
はつめいひん /発明品/
はつもうで /初詣/
はつもの /初物/
はつもん /発問/
はつやくまん /初役満/
はつゆうしょう /初優勝/
はつゆき /初雪/
はつゆめ /初夢/
はつよう /発揚/
はつらいにち /初来日/
はつらつ /溌剌/溌刺/
はつれい /発令/
はつろ /発露/
はつわ /発話/
はつわしゃ /発話者/
はつわじ /発話時/
はつわじしん /発話自身/
はつわじょうほう /発話情報/
はつわちょう /発話長/
はつわないよう /発話内容/
はつわらい /初笑/
はづき /葉月/
はて /果て/
はてな /？/
はてんこう /破天荒/
はで /派手/
はでめ /派手目/
はと /鳩/鴿/
はとう /波頭/波濤/波涛/坡塘/坡頭/陂塘/
はとがや /鳩谷/
はとの /鳩野/
はとば /波止場/
はとむね /鳩胸/
はともと /波戸元/
はとやま /鳩山/
はとやまちょう /鳩山町/
はとり /羽鳥/
はどう /波動/覇道/波導/
はどうおんきょう /波動音響/
はどうかんすう /波動関数/
はどうけん /波動拳/
はどうせい /波動性/
はどうせいぶん /波動成分/
はどうば /波動場/
はどうほう /波動砲/
はどうほうていしき /波動方程式/
はどめ /歯止め/歯止/
はどり /羽鳥/
はな /花/鼻/華/話/離/洟/端/ハナ/塙/
はない /花井/
はないき /鼻息/
はないずみ /花泉/
はなうた /鼻歌/
はなうり /花売り/
はなうりむすめ /花売娘/
はなえ /英恵/花江/
はなお /鼻緒/
はなおか /花岡/
はなおかこうざん /花岡鉱山/
はなかご /花籠/
はなかぜ /鼻カゼ/鼻風邪/
はながた /花型/花形/鼻型/
はながたさんぎょう /花形産業/
はながたしきしゃ /花形指揮者/
はながたじょゆう /花形女優/
はながみ /鼻紙/
はながら /花柄/
はなき /花紀/花木/
はなきん /花金/
はなくそ /鼻糞/
はなくま /花隈/
はなぐもり /花曇/
はなげ /鼻毛/
はなこ /花子/華子/
はなこうぼう /花工房/
はなことば /花言葉/
はなさ /鼻差/
はなさか /花阪/
はなさかじじい /花咲爺/
はなさき /鼻先/花咲/
はなさきせん /花咲線/
はなざかり /花盛り/
はなざくら /花桜/
はなざけ /花酒/
はなざわ /花沢/
はなざんげ /花ざんげ/
はなし /話/噺/咄/譚/話し/
はなしあい /話し合い/話合い/話合/
はなしあいて /話し相手/話相手/
はなしあう /話し合う/
はなしいぜん /話以前/
はなしか /噺家/
はなしかた /話し方/
はなしがい /放し飼い/
はなしことば /話し言葉/話言葉/
はなしごえ /話し声/
はなしじたい /話自体/
はなしじょうず /話上手/
はなしずき /話好き/
はなしちゅう /話し中/話中/
はなして /話し手/
はなしてき /話的/
はなしはんぶん /話半分/
はなしべた /話下手/
はなしま /花島/
はなしょうぶ /花菖蒲/
はなしんじゅ /花真珠/
はなじ /鼻血/衄/衂/
はなじる /洟/
はなじるし /花印/
はなすじ /鼻筋/鼻梁/
はなずもう /花相撲/
はなずら /鼻面/
はなせ /花背/
はなせんじょう /鼻洗浄/
はなぞの /花園/華園/
はなぞのしゅつじょう /花園出場/
はなぞのじんじゃ /花園神社/
はなた /花田/
はなたか /花高/
はなたに /花谷/
はなたば /花束/
はなたばぞうてい /花束贈呈/
はなだ /花田/
はなだい /花代/
はなちるさと /花散里/
はなぢ /鼻血/
はなつまみ /鼻摘/
はなづら /鼻面/
はなてん /放出/
はなでんしゃ /花電車/
はなどき /花時/
はなどけい /花時計/
はなぬすびと /花盗人/
はなのえん /花宴/
はなのまき /花巻/
はなはく /花博/
はなはくかいじょう /花博会場/
はなはた /花畑/
はなはだ /甚/甚だ/
はなばたけ /花畑/
はなばな /花々/
はなばんか /花挽歌/
はなひゃっけい /花百景/
はなび /花火/
はなびえ /花冷/
はなびし /花火師/
はなびたいかい /花火大会/
はなびだま /花火玉/
はなびや /花火屋/
はなびら /花びら/花弁/
はなふさ /花房/
はなふだ /花札/
はなふぶき /花吹雪/
はなぶえ /鼻笛/
はなぶさ /花房/萼/蕚/
はなまき /花巻/
はなまききんぺん /花巻近辺/
はなまきしゅっしん /花巻出身/
はなまつり /花祭/花祭り/
はなまる /花丸/
はなみ /花見/
はなみく /花見区/
はなみず /鼻水/洟/
はなみずがわ /花水川/
はなみち /花道/
はなむけ /餞/
はなむこ /花婿/
はなむら /花村/
はなめがね /鼻眼鏡/
はなもじ /花文字/
はなもと /花本/
はなや /花屋/
はなやしき /花屋敷/
はなやま /花山/
はなよめ /花嫁/
はなよめいしょう /花嫁衣装/花嫁衣裳/
はなよめしゅぎょう /花嫁修行/
はなよめにんぎょう /花嫁人形/
はならび /歯並び/
はなれわざ /離れ業/
はなわ /塙/花輪/鼻輪/
はなわせん /花輪線/
はに /埴/
はにうだ /羽生田/
はにおか /埴岡;姓/
はにしな /埴科/
はにゅう /羽生/埴生/
はにゅうだ /羽生田/
はにわ /埴輪/
はぬけ /歯抜け/
はね /羽/羽根/翅/
はねいし /羽石/
はねおか /羽丘/
はねぎ /羽根木/
はねだ /羽田/
はねだおき /羽田沖/
はねだくうこう /羽田空港/
はねだけいゆ /羽田経由/
はねばし /跳ね橋/
はねぶとん /羽布団/
はねまくら /羽根枕/
はねむーん /ハネムーン/
はねむし /羽虫/
はねもの /羽物/羽根物/
はの /羽野/
はのうら /羽ノ浦/
はは /母/義母/
ははうえ /母上/
ははおや /母親/
ははおやいがい /母親以外/
ははおやがわ /母親側/
ははおやたち /母親達/
ははおやに /母親似/
ははおややく /母親役/
ははおやゆらい /母親由来/
ははかた /母方/
ははきぎ /帚木/
ははぎみ /母君/
ははこ /母子/
ははのひ /母の日/
はば /幅/巾/掵/
はばうえ /巾上/
はばかる /憚る/
はばつ /派閥/
はばつあらそい /派閥争い/
はばつじんじ /派閥人事/
はばとび /幅跳び/
はばひろ /幅広/巾広/
はばゆうせん /幅優先/
はびきの /羽曳野/
はぴょうしゃ /発表者/
はふ /破風/
はぶ /羽生/埴生/
はぶたえ /羽二重/
はぶらし /歯ブラシ/
はぶり /羽振り/
はへい /派兵/
はへん /破片/
はほろ /羽幌/
はほろせん /羽幌線/
はぼうほう /破防法/
はぼたんしょう /葉牡丹賞/
はぼまい /歯舞/
はぼまいしょとう /歯舞諸島/
はぼろ /羽幌/
はま /浜/濱/破魔/
はまお /浜尾/
はまおおつ /浜大津/
はまおおつえき /浜大津駅/
はまおか /浜岡/
はまかつ /浜勝/
はまかど /濱角/
はまかわ /浜川/濱川/
はまかわさき /浜川崎/
はまがくえん /浜学園/
はまがみ /浜上/濱上/
はまがわ /浜側/
はまき /葉巻/
はまきがた /葉巻型/
はまきた /浜北/
はまきょう /浜響/
はまぐち /浜口/
はまぐちちょう /浜口町/
はまぐり /蛤/
はまさか /浜坂/
はまさかちほう /浜坂地方/
はまさき /浜崎/濱崎/
はまざき /浜崎/
はましま /濱島/
はまじま /浜島/
はまたけ /浜竹/
はまだ /浜田/濱田/
はまだしょうご /浜田省吾/
はまだじどうしゃどう /浜田自動車道/
はまちどり /浜千鳥/
はまちょう /浜町/
はまっこ /浜っ子/
はまつか /濱塚/
はまで /濱出/
はまとんべつ /浜頓別/
はまな /浜名/
はまなか /浜中/濱中/
はまなこ /浜名湖/
はまなこおおはし /浜名湖大橋/
はまなこめいさん /浜名湖名産/
はまの /浜野/濱野/
はまべ /浜辺/浜部/
はまます /浜益/
はままつ /浜松/
はままついかだいがく /浜松医科大学/
はままついだい /浜松医大/
はままつえき /浜松駅/
はままつかん /浜松間/
はままつきち /浜松基地/
はままつきゅうぎじょう /浜松球技場/
はままつきゅうじょう /浜松球場/
はままつぎじゅつ /浜松技術/
はままつざいじゅう /浜松在住/
はままつし /浜松市/
はままつしえいきゅうじょう /浜松市営球場/
はままつしじょうほく /浜松市城北/
はままつしたいいくかん /浜松市体育館/
はままつしない /浜松市内/
はままつしぶ /浜松支部/
はままつしみんかいかん /浜松市民会館/
はままつしょくぎょうくんれんたんだい /浜松職業訓練短大/
はままつしょくぎょうたんだい /浜松職業短大/
はままつしょくくんたんだい /浜松職訓短大/
はままつじょう /浜松城/
はままつじょうこうえん /浜松城公園/
はままつたいかい /浜松大会/
はままつだこ /浜松凧/
はままつちょう /浜松町/
はままつちょうえき /浜松町駅/
はままつていしゃ /浜松停車/
はままつてん /浜松店/
はままつにし /浜松西/
はままつばん /浜松版/
はままつひゃくせん /浜松百選/
はままつほうめん /浜松方面/
はままで /浜迄/
はまみやせん /浜宮線/
はまめし /浜飯/
はまもと /濱本/
はまやき /浜焼/
はまやす /浜靖/
はまりきゅう /浜離宮/
はまりきゅうけいゆ /浜離宮経由/
はまりきゅうけいゆう /浜離宮経由/
はまりやく /填役/嵌まり役/嵌役/
はみ /葉美/
はみがき /歯磨き/歯磨/
はみがきこ /歯磨き粉/
はむし /羽虫/
はむら /羽村/
はめ /羽目/破目/
はめいた /羽目板/
はめこみ /嵌め込み/
はめつ /破滅/
はめつかん /破滅感/
はめつがた /破滅型/
はめつてき /破滅的/
はめつぶつ、はめつもの /破滅物/
はめん /波面/
はめんごうせい /波面合成/
はめんほう /波面法/
はも /鱧/羽茂/
はもの /刃物/端物/釖/
はものるい /刃物類/
はもん /波紋/破門/
はもんせんこく /破門宣告/
はもんほう /波紋法/
はや /早/早目/速/頓/鮠/
はやあし /速足/早足/
はやあるき /速歩き/
はやい /速い/
はやうち /速打ち/
はやうまれ /早生まれ/
はやお /早生/駿/
はやおき /早起き/
はやおくり /速送り/早送り/
はやおし /早押し/
はやかわ /早川/
はやかわこう /早川港/
はやかわしょぼう /早川書房/
はやかわでんき /早川電気/
はやかわでんきこうぎょう /早川電機工業/
はやかわぶんこ /早川文庫/
はやかわぶんこかん /早川文庫刊/
はやかわぶんこばん /早川文庫版/
はやがてん /早合点/
はやがね /早鐘/
はやがわり /早変わり/
はやき /勇樹/隼輝/
はやきた /早来/
はやく /早く/端役/破約/
はやくさ /早草/
はやくち /早口/
はやくちえいご /早口英語/
はやくちことば /早口言葉/
はやぐい /早喰い/
はやごせんしゅけん /早碁選手権/
はやさ /速さ/
はやさか /早坂/
はやざき /早咲き/
はやざし /早指し/
はやし /林/囃子/囃/
はやした /早下/
はやしだ /林田/
はやしば /林葉/
はやしばら /林原/
はやしま /早島/
はやしや /林家/林屋/
はやじに /早死/
はやせ /早瀬/早勢/
はやた /早田/
はやて /疾風/
はやで /早出/
はやと /隼人/勇人/早戸/
はやとき /早解き/
はやとちり /早とちり/
はやね /早寝/
はやねはやおき /早寝早起き/
はやの /早野/
はやば /早場/
はやばまい /早場米/
はやばや /早々/
はやばん /早番/早版/
はやびき /速弾き/
はやぶさ /隼/鶻/
はやべん /早弁/
はやま /葉山/端山/
はやまちょう /葉山町/
はやままち /葉山町/
はやみ /早見/速水/速見/
はやみず /速水/早水/
はやみち /早道/
はやみばん /早見板/
はやみひょう /早見表/
はやみみ /早耳/
はやみや /頓宮/早宮/
はやめ /早目/早め/速目/
はやり /流行/
はやわざ /早業/早技/
はら /原/腹/肚/
はらい /払/拂/祓/祓い/赦い/払い/
はらいかた /払い方/
はらいかわ /秡川/祓川/
はらいこみ /払い込み/払込/払込み/
はらいこみようし /払込用紙/
はらいさげ /払い下げ/
はらいだし /払い出し/
はらいっぱい /腹一杯/
はらいどの /払殿/
はらいもどし /払い戻し/払戻/払戻し/
はらいもどしきん /払戻金/
はらお /原尾/
はらおか /原岡/
はらから /同胞/
はらかわ /原川/
はらがまえ /腹構え/
はらき /原木/
はらぐあい /腹具合/
はらぐち /原口/
はらげい /腹芸/
はらこ /原子/
はらこし /原越/
はらごころ /腹心/
はらごしらえ /腹拵え/
はらさき /原崎/
はらさわ /原沢/原澤/
はらしま /原島/原嶋/
はらしょぼう /原書房/
はらじま /原島/
はらじゅく /原宿/
はらじゅくえき /原宿駅/
はらじゅくえきしゅうごう /原宿駅集合/
はらじゅくえきほうこう /原宿駅方向/
はらじゅくちか /原宿地下/
はらじゅくてん /原宿店/
はらせつこ /原節子/
はらたつのり /原辰徳/
はらだ /原田/
はらだきわこ /原田貴和子/
はらちがい /腹違い/
はらっぱ /原っぱ/
はらどけい /腹時計/
はらの /原野/
はらのまち /原町/原ノ町/
はらのや /原野谷/
はらひでこ /原日出子/
はらまち /原町/
はらまちだ /原町田/
はらみず /原水/
はらやま /原山/
はらよし /原良/
はらわた /腸/腑/
はらん /波乱/波蘭/波瀾/
はらんばんじょう /波乱万丈/
はらんぶくみ /波乱含み/
はり /張/針/播/梁/玻璃/蓁/鍼/貼/
はりあい /張合い/張り合い/
はりあな /針穴/
はりいち /針位置/
はりかえ /張替/
はりがね /針金/
はりがみ /貼り紙/張り紙/貼紙/張紙/はり紙/
はりがや /針ヶ谷/針谷/
はりき /針木/
はりきゅうちりょう /鍼灸治療/
はりくよう /針供養/
はりぐち /播口/
はりけん /破裏拳/
はりこ /張子/
はりこうかん /針交換/
はりこみ /張り込み/貼り込み/
はりさき /針先/
はりさきじこ /針先事故/
はりしごと /針仕事/
はりじょう /針状/
はりだしこむすび /張出小結/
はりだしせきわけ /張出関脇/
はりちりょう /針治療/
はりつけ /貼り付け/貼付/磔/張り付け/
はりぬい /針縫/
はりねずみ /蝟/
はりふだ /はり札/
はりま /播磨/針間/播摩/
はりまなげ /波離間投げ/
はりまなだ /播磨灘/
はりまのくに /播磨国/
はりまびと /播磨人/
はりまや /播磨屋/針間矢/
はりもと /張本/播本/
はりや /針谷/
はりやま /張山/
はる /春/治/晴/温/玄/請/青春/榛/
はるあき /春秋/
はるあきれんぱ /春秋連覇/
はるいがい /春以外/
はるいちばん /春一番/
はるうらら /春麗/
はるえ /春江/治恵/
はるお /春夫/春男/治男/治夫/治雄/春雄/晴夫/晴雄/東生/晴朗/
はるおか /春岡/
はるおみ /晴臣/
はるか /遥/晴香/遙/遥か/悠/
はるかぜ /春風/
はるかわ /春川/
はるがっしゅく /春合宿/
はるき /春木/春樹/治己/
はるきち /春吉/
はるぐち /春口/
はるけいば /春競馬/
はるこ /晴子/春子/治子/
はるごころ /春心/
はるごろ /春頃/
はるさき /春先/
はるさめ /春雨/
はるし /治志/
はるじ /春治/
はるた /春田/
はるだ /春田/
はるだんじ /春団次/
はるな /春菜/榛名/
はるなさん /榛名山/
はるなつ /春夏/
はるなつあきふゆ /春夏秋冬/
はるの /春野/榛野/
はるばしょ /春場所/
はるひ /晴日/春日/
はるひこ /春彦/晴彦/治彦/晴比古/
はるひさ /晴久/治久/春久/陽久/
はるひで /治秀/
はるひと /治人/
はるひろ /晴弘/
はるびん /哈爾浜/
はるふじ /春藤/
はるまき /春巻/
はるまつり /春祭/
はるみ /晴海/晴美/春美/晴見/はる美/
はるみだい /晴美台/
はるみつ /晴光/
はるみない /晴海内/
はるみふとう /晴海埠頭/
はるもの /春物/
はるやす /陽保/晴康/
はるやすみ /春休み/
はるやま /春山/
はるやまこうえん /春山公園/
はるゆき /春幸/陽之/治之/晴幸/治幸/
はるよ /春代/
はるよし /晴芳/
はるらんまん /春爛漫/
はれ /晴/晴れ/
はれお /晴夫/
はれぎ /晴れ着/晴着/
はれすがた /晴れ姿/
はれつ /破裂/
はれつおん /破裂音/
はれつせい /破裂性/
はればれ /晴々/晴れ晴れ/
はれま /晴れ間/晴間/
はれやま /晴山/
はれんち /破廉恥/
はろ /波呂/
はろう /波浪/
はわい /布哇/ハワイ/羽合/
はわいとう /ハワイ島/
はわたり /刃渡り/
はん /半/版/飯/反/判/坂/範/販/般/班/煩/汎/犯/畔/板/繁/頒/伴/釆/藩/氾/帆/搬/斑/叛/翻/瘢/拌/攀/槃/樊/泛/潘/燔/笵/絆/繙/胖/膰/范/蟠/袢/鈑/蕃/阪/幡/磐/凡/旛/
はん> /反/半/
はんい /範囲/犯意/
はんいがい /範囲外/
はんいしてい /範囲指定/
はんいせんたく /範囲選択/
はんいない /範囲内/
はんいぶんせき /範囲分析/
はんいめい /範囲名/
はんいん /班員/
はんうちゅう /反宇宙/
はんえい /反映/繁栄/半影/
はんえいきゅう /半永久/
はんえいきゅうきかん /半永久機関/
はんえいきゅうてき /半永久的/
はんえいきょうかいない /半影境界内/
はんえいちゅう /半影中/
はんえいてき /反映的/
はんえん /半円/
はんえんけい /攀縁茎/
はんおし /半押/
はんおん /半音/
はんおんいない /半音以内/
はんおんした /半音下/
はんか /汎化/繁華/頒価/
はんかい /半壊/半解/半開/半潰/
はんかいぎょうきのう /半改行機能/
はんかいしんけい /反回神経/
はんかいてん /半回転/
はんかがい /繁華街/
はんかく /半角/反核/
はんかくえいじへんかん /半角英字変換/
はんかくえいすう /半角英数/
はんかくえいすうきりかえ /半角英数切替/
はんかくえいすうこてい /半角英数固定/
はんかくえいすうじ /半角英数字/
はんかくえいすうにゅうりょく /半角英数入力/
はんかくかたかな /半角片仮名/
はんかくかな /半角仮名/半角カナ/
はんかくきごう /半角記号/
はんかくきりかえ /半角切替/
はんかくざいりょう /販拡材料/
はんかくすうじ /半角数字/
はんかくせいめい /反核声明/
はんかくぜんかく /半角全角/
はんかくにゅうりょく /半角入力/
はんかくぶん /半角分/
はんかくへんかん /半角変換/
はんかくめい /反革命/
はんかくもじ /半角文字/
はんかくもじすう /半角文字数/
はんかこ /半過去/
はんかこけい /半過去形/
はんかさん /半加算/
はんかせい /汎化性/
はんかた /汎型/
はんかちょう /犯科帳/
はんかつう /半可通/
はんかのうりょく /汎化能力/
はんかん /反感/半環/
はんかんきょうほぜんてき /反環境保全的/
はんかんすう /汎関数/
はんかんせい /半完成/
はんかんせいひん /半完成品/
はんかんせつわほう /半間接話法/
はんが /版画/
はんがか /版画化/版画家/
はんがきょうしつ /版画教室/
はんがく /半額/
はんがくいか /半額以下/
はんがくくらい /半額位/
はんがくけい /半額系/
はんがくけん /半額券/
はんがくせつ /半楽節/
はんがくていど /半額程度/
はんがくぶん /半額分/
はんがくめんじょ /半額免除/
はんがげいじゅつ /版画芸術/
はんがしゅっぱんぎょうしゃ /版画出版業者/
はんがじてん /版画事典/
はんがそ /半画素/
はんがた /版型/判型/
はんがてん /版画展/
はんがめいさくてん /版画名作展/
はんがりー /洪牙利/
はんがるい /版画類/
はんがん /判官/
はんき /半期/半旗/叛旗/搬器/
はんきかん /半規管/
はんきちすう /半吉数/
はんきゃくしき /半脚式/
はんきゅう /半休/阪急/半球/阪九/
はんきゅういしばしえき /阪急石橋駅/
はんきゅういたみ /阪急伊丹/
はんきゅういまづせん /阪急今津線/
はんきゅううめだ /阪急梅田/
はんきゅううめだえき /阪急梅田駅/
はんきゅうえんせん /阪急沿線/
はんきゅうきたせんりえき /阪急北千里駅/
はんきゅうけいれつ /阪急系列/
はんきゅうこうべせん /阪急神戸線/
はんきゅうこしょ /阪急古書/
はんきゅうさいいん /阪急西院/
はんきゅうさんのみや /阪急三宮/
はんきゅうしじょうおおみや /阪急四条大宮/
はんきゅうしんしゃ /阪急新車/
はんきゅうじょう /半球上/半球状/
はんきゅうせん /阪急線/
はんきゅうせんじゅうそうえき /阪急線十三駅/
はんきゅうせんりせん /阪急千里線/
はんきゅうたい /半球体/
はんきゅうたからづかせん /阪急宝塚線/
はんきゅうつかぐち /阪急塚口/
はんきゅうでんしゃ /阪急電車/
はんきゅうでんしゃおおみや /阪急電車大宮/
はんきゅうでんてつ /阪急電鉄/
はんきゅうとうほう /阪急東宝/
はんきゅうとっきゅう /阪急特急/
はんきゅうにしのみや /阪急西宮/
はんきゅうにしのみやきたぐち /阪急西宮北口/
はんきゅうはい /阪急杯/
はんきゅうふぇりー /阪九フェリー/
はんきゅうみかげえき /阪急御影駅/
はんきょう /反響/般教/反共/
はんきょうおん /反響音/
はんきょうしん /反共振/
はんきょうせい /半強制/
はんきょうていいしんごう /反響定位信号/
はんきょうばん /反響板/
はんきょうらん /半狂乱/
はんきょり /汎距離/
はんぎ /半技/
はんぎゃく /反逆/
はんぎゃくしゃ /反逆者/
はんぎょじん /半魚人/
はんくうかん /半空間/
はんくら /半クラ/
はんぐん /半群/反軍/
はんけい /半径/判型/
はんけつ /判決/
はんけつぶん /判決文/
はんけつぶんちゅう /判決文中/
はんけん /版権/半券/半研/
はんけんしょゆう /版権所有/
はんけんしんせい /版権申請/
はんげき /反撃/
はんげきかいし /反撃開始/
はんげきじょう /半劇場/
はんげきそち /反撃措置/
はんげきほうほう /反撃方法/
はんげっぽう /半月報/
はんげつ /半月/
はんげつじょう /半月状/
はんげつそんしょう /半月損傷/
はんげつばん /半月板/
はんげん /半減/半源/半舷/
はんげんか /半減化/
はんげんき /半減期/
はんげんご /半言語/
はんげんしりょく /反原子力/
はんげんぱつ /反原発/
はんこ /ハンコ/判子/
はんこう /反抗/犯行/
はんこうえい /半公営/
はんこうきょうきかん /半公共機関/
はんこうげんば /犯行現場/
はんこうせいめい /犯行声明/
はんこうたく /半光沢/
はんこけい /半固形/
はんこっかてき /反国家的/
はんこつ /反骨/
はんこてい /半固定/
はんこていていこう /半固定抵抗/
はんこてんろん /半古典論/
はんこん /瘢痕/
はんご /反語/
はんごう /飯盒/半合/
はんごてき /反語的/
はんごひょうげん /反語表現/
はんごんたん /反魂丹/
はんさ /煩瑣/
はんさき /飯崎/
はんさべつようごは /反差別用語派/
はんさよう /反作用/
はんざい /犯罪/
はんざいきろく /犯罪記録/
はんざいげんば /犯罪現場/
はんざいこうい /犯罪行為/
はんざいご /犯罪後/
はんざいしゃ /犯罪者/
はんざいしゃしんり /犯罪者心理/
はんざいしゅうだん /犯罪集団/
はんざいそうさ /犯罪捜査/
はんざいたいこく /犯罪大国/
はんざいてき /犯罪的/
はんざいとし /犯罪都市/
はんざいにゅうもん /犯罪入門/
はんざいはくしょ /犯罪白書/
はんざいぼうし /犯罪防止/
はんざいりつ /犯罪率/
はんざつ /繁雑/煩雑/
はんざわ /半澤/半沢/
はんざん /飯山/
はんし /半紙/
はんした /版下/
はんしちとりものちょう /半七捕物帳/
はんしつ /半室/
はんしはんしょう /半死半生/
はんしゃ /反射/販社/
はんしゃおん /反射音/
はんしゃおんあつ /反射音圧/
はんしゃおんじょう /反射音場/
はんしゃかい /反社会/
はんしゃかいせい /反社会性/
はんしゃかいてき /反社会的/
はんしゃかいてきこうい /反社会的行為/
はんしゃかいてきじんぶつ /反社会的人物/
はんしゃかく /反射角/
はんしゃかんすう /反射関数/
はんしゃがた /反射型/
はんしゃきょう /反射鏡/
はんしゃきょうど /反射強度/
はんしゃけい /反射系/
はんしゃけいすう /反射係数/
はんしゃけいろ /反射経路/
はんしゃこう /反射光/
はんしゃこうしき /反射光式/
はんしゃこうぞう /反射構造/
はんしゃざい /反射材/
はんしゃざいりょう /反射材料/
はんしゃしき /反射式/
はんしゃしんけい /反射神経/
はんしゃせい /反射性/
はんしゃせいど /反射精度/
はんしゃせいぶん /反射成分/
はんしゃそく /反射則/反射束/
はんしゃぞう /半写像/
はんしゃたい /反射体/
はんしゃてき /反射的/
はんしゃてん /反射点/
はんしゃとくせい /反射特性/
はんしゃは /反射波/
はんしゃばん /反射板/
はんしゃほうそく /反射法則/
はんしゃぼうえん /反射望遠/
はんしゃぼうえんきょう /反射望遠鏡/
はんしゃめん /反射面/
はんしゃめんだんめん /反射面断面/
はんしゃりつ /反射律/反射率/
はんしゃろ /反射炉/
はんしゅう /半周/
はんしゅうちょう /半周長/
はんしゅつ /搬出/
はんしゅりゅうは /反主流派/
はんしょう /反証/半焼/半鐘/
はんしょうかのう /反証可能/
はんしょく /繁殖/飯食/蕃殖/
はんしょくかつどう /繁殖活動/
はんしょくじ /繁殖時/
はんしょくち /繁殖地/
はんしょくば /繁殖馬/
はんしょくひんば /繁殖牝馬/
はんしょくほうほう /繁殖方法/
はんしょくりょく /繁殖力/
はんしん /阪神/半身/
はんしんあわじだいしんさい /阪神・淡路大震災/阪神淡路大震災/
はんしんかん /阪神間/
はんしんがわ /阪神側/
はんしんきゅうこう /阪神急行/
はんしんけいばじょう /阪神競馬場/
はんしんこうくう /阪神航空/
はんしんこうそく /阪神高速/
はんしんこくどう /阪神国道/
はんしんしせん /阪神支線/
はんしんしょうがい /阪神障害/
はんしんじだい /阪神時代/
はんしんせん /阪神戦/
はんしんだいしょうてん /阪神大賞典/
はんしんだいしんさい /阪神大震災/
はんしんちく /阪神地区/
はんしんちほう /阪神地方/
はんしんでんきてつどう /阪神電気鉄道/
はんしんでんしゃ /阪神電車/
はんしんでんてつ /阪神電鉄/
はんしんのだ /阪神野田/
はんしんはんぎ /半信半疑/
はんしんひゃっかてん /阪神百貨店/
はんしんふずい /半身不随/半身付随/
はんしんほんせん /阪神本線/
はんしんりゃくせんそう /反侵略戦争/
はんしんろん /汎心論/汎神論/
はんじ /判事/
はんじかん /半時間/
はんじせい /反磁性/
はんじせいこう /反磁性項/
はんじつ /反実/
はんじつかそう /反実仮想/
はんじどう /半自動/
はんじどうか /半自動化/
はんじどうてき /半自動的/
はんじみんとうひょう /反自民党票/
はんじゅうりょく /反重力/
はんじゅうりょくぶっしつ /反重力物質/
はんじゅく /半熟/
はんじゅくたまご /半熟卵/
はんじゅんじょ /半順序/
はんじょう /繁盛/繁昌/
はんじょうき /繁盛記/
はんすう /版数/反芻/半数/
はんすういか /半数以下/
はんすういじょう /半数以上/
はんせい /反省/半生/
はんせいかい /反省会/
はんせいき /半世紀/
はんせいしゃざい /反省謝罪/
はんせいてん /反省点/
はんせいひん /半製品/
はんせいふ /反政府/
はんせいふうんどう /反政府運動/
はんせいふしゅぎしゃ /反政府主義者/
はんせいふせいりょく /反政府勢力/
はんせいよくせつ /汎性欲説/
はんせつ /反切/
はんせん /帆船/反戦/
はんせんうんどう /反戦運動/
はんせんえいが /反戦映画/
はんせんけい /半線形/
はんせんしそう /反戦思想/
はんせんどうし /帆船同士/
はんせんもけい /帆船模型/
はんぜん /判然/
はんそ /反ソ/反訴/
はんそう /搬送/帆走/半荘/
はんそうき /搬送機/
はんそうちゅう /帆走中/
はんそうは /搬送波/
はんそうよう /搬送用/
はんそく /反則/販促/半束/
はんそくきっぷ /反則切符/
はんそくきん /反則金/
はんそくきんかりのうふ /反則金仮納付/
はんそくきんせいど /反則金制度/
はんそくこうい /反則行為/
はんそくとうきゅう /反則投球/
はんそくぶつ /販促物/
はんそくよう /販促用/
はんそくわざ /反則技/
はんそで /半袖/
はんぞう /半蔵/楾/
はんぞうもん /半蔵門/
はんぞうもんせん /半蔵門線/
はんぞうもんせんけいゆ /半蔵門線経由/
はんぞうもんせんけいゆう /半蔵門線経由/
はんぞうもんせんよう /半蔵門線用/
はんたい /反対/
はんたいいけん /反対意見/
はんたいうんどう /反対運動/
はんたいがわ /反対側/
はんたいきじ /反対記事/
はんたいぎし /反対岸/
はんたいご /反対語/
はんたいしゃ /反対者/
はんたいしゃせん /反対車線/
はんたいしゃたすう /反対者多数/
はんたいしょう /反対称/
はんたいしょうせい /反対称性/
はんたいしょうほうそく /反対称法則/
はんたいしょうりつ /反対称律/
はんたいしょく /反対色/
はんたいしんか /反対進化/
はんたいじ /繁体字/
はんたいじんもん /反対尋問/
はんたいすう /反対数/
はんたいせい /反体制/
はんたいせいてき /反体制的/
はんたいせいは /反体制派/
はんたいせつ /反対説/
はんたいたすう /反対多数/
はんたいとうこう /反対投稿/
はんたいとうひょう /反対投票/
はんたいとうひょうすう /反対投票数/
はんたいにんずう /反対人数/
はんたいは /反対派/
はんたいはのうみん /反対派農民/
はんたいひょう /反対票/
はんたいひょうめい /反対表明/
はんたいほうこう /反対方向/
はんたいほうめん /反対方面/
はんたいりゆう /反対理由/
はんたいろん /反対論/
はんたま /半玉/
はんたんい /班単位/
はんだ /半田/盤陀/
はんだい /阪大/大阪大学/飯台/版代/
はんだいきそこう /阪大基礎工/
はんだいきゅうきょうよう /阪大旧教養/
はんだいきょうようぶ /阪大教養部/
はんだいこう /阪大工/
はんだいこうがくぶ /阪大工学部/
はんだいじょうほう /阪大情報/
はんだいじょうほうこう /阪大情報工/
はんだいじんか /阪大人科/
はんだいせい /阪大生/
はんだいせんぱくかいよう /阪大船舶海洋/
はんだいつうしん /阪大通信/
はんだいつうしんこう /阪大通信工/
はんだいり /阪大理/
はんだいりぶつ /阪大理物/
はんだくおん /半濁音/
はんだくてん /半濁点/゜/
はんだぐちふきん /半田口付近/
はんだしみん /半田市民/
はんだずけ /半田付け/
はんだづけ /半田付け/
はんだふりょう /半田不良/
はんだん /判断/
はんだんかのう /判断可能/
はんだんきじゅん /判断基準/判断規準/
はんだんけっか /判断結果/
はんだんざいりょう /判断材料/
はんだんてん /判断点/
はんだんのうりょく /判断能力/
はんだんひかくざいりょう /判断比較材料/
はんだんほりゅう /判断保留/
はんだんようそ /判断要素/
はんだんりょく /判断力/
はんだんりょくひはん /判断力批判/
はんち /半値/
はんちか /半地下/
はんちしょう /半致傷/
はんちはば /半値幅/
はんちゃん /半荘/
はんちゅう /範疇/藩中/範中/範衷/
はんちゅうがい /範疇外/
はんちゅうめい /範疇名/
はんちょう /班長/反跳/
はんちょうおん /半長音/
はんちょうぼいん /半長母音/
はんちょうようし /反跳陽子/
はんちょうりゅうし /反跳粒子/
はんちょくせん /半直線/
はんちょっかんてき /反直観的/
はんつき /半月/
はんつきご /半月後/
はんつきまい /半搗き米/
はんて /半手/
はんてい /判定/
はんていいん /判定員/
はんていかいろ /判定回路/
はんていかのう /判定可能/
はんていき /判定機/
はんていきじゅん /判定基準/判定規準/
はんていきのう /判定機能/
はんていけっか /判定結果/
はんていこう /半抵抗/
はんていじたい /判定自体/
はんていじょうけん /判定条件/
はんていふかのう /判定不可能/
はんていふのう /判定不能/
はんていぶ /判定部/
はんていぶぶん /判定部分/
はんていぶん /判定文/
はんていほう /判定法/
はんていほうほう /判定方法/
はんていめい /判定名/
はんていもんだい /判定問題/
はんてつ /半徹/
はんてん /反転/斑点/飯店/半纏/反轉/
はんてんき /反転器/
はんてんこうしき /反転公式/
はんてんじ /反転時/
はんてんじかん /反転時間/
はんてんどうさ /反転動作/
はんてんひょうじ /反転表示/
はんてんもじ /反転文字/
はんでんし /反電子/
はんと /版図/
はんとう /半島/反騰/
はんとうまく /半透膜/
はんとうめい /半透明/
はんとうめいとりょう /半透明塗料/
はんとけい /反時計/
はんとけいまき /反時計巻/
はんとし /半年/
はんとしいじょう /半年以上/
はんとしいじょうまえ /半年以上前/
はんとしいない /半年以内/
はんとしかん /半年間/
はんとしくらい /半年位/
はんとしけいか /半年経過/
はんとしご /半年後/
はんとしごと /半年毎/
はんとししよう /半年使用/
はんとしていど /半年程度/
はんとしぶん /半年分/
はんとしほどまえ /半年程前/
はんとしまえ /半年前/
はんど /ハンド/
はんどう /反動/般道/半藤/
はんどうしそう1 /反動思想/
はんどうせい /半同棲/
はんどうたい /半導体/
はんどうたいかいはつ /半導体開発/
はんどうたいかんけい /半導体関係/
はんどうたいきき /半導体機器/
はんどうたいぎじゅつ /半導体技術/
はんどうたいぎじゅつぶ /半導体技術部/
はんどうたいけんきゅう /半導体研究/
はんどうたいけんきゅうじょ /半導体研究所/
はんどうたいさんぎょう /半導体産業/
はんどうたいじぎょうぶ /半導体事業部/
はんどうたいそし /半導体素子/
はんどく /判読/
はんどくふのう /判読不能/
はんどくようい /判読容易/
はんどばっぐ /ハンドバッグ/
はんどぶっく /ハンドブック/
はんどぼーる /ハンドボール/
はんどら /ハンドラ/
はんどりんぐ /ハンドリング/
はんどる /ハンドル/
はんな /阪奈/
はんなどうろ /阪奈道路/
はんなん /阪南/
はんなんだい /阪南大/
はんにじゅう /半二重/
はんにち /半日/反日/
はんにちいじょう /半日以上/
はんにちかん /半日間/
はんにちかんこう /半日観光/
はんにちかんじょう /反日感情/
はんにちけん /半日券/
はんにちご /半日後/
はんにちせいりょく /反日勢力/
はんにちていど /半日程度/
はんにっし /班日誌/
はんにゃ /般若/
はんにゃしんきょう /般若心経/
はんにゃとう /般若湯/
はんにゅう /搬入/
はんにゅうこう /搬入口/
はんにゅうとどけ /搬入届/
はんにゅうび /搬入日/
はんにゅうぶ /搬入部/
はんにん /犯人/半人/
はんにんがわ /犯人側/
はんにんぞう /犯人像/
はんにんたち /犯人達/
はんにんまえ /半人前/
はんにんまえみまん /半人前未満/
はんにんやく /犯人役/
はんね /半値/
はんねいか /半値以下/
はんねん /半年/
はんのう /反応/飯能/半農/半納/半能/
はんのうかくりつ /反応確率/
はんのうきこう /反応機構/
はんのうしき /反応式/
はんのうじかん /反応時間/
はんのうせい /反応性/
はんのうせっけい /反応設計/
はんのうせんたくせい /反応選択性/
はんのうそくど /反応速度/
はんのうそくどしき /反応速度式/
はんのうそくどろん /反応速度論/
はんのうだんめんせき /反応断面積/
はんのうりつ /反応率/
はんはちょう /半波長/
はんはん /半々/
はんば /飯場/半場/
はんばい /販売/半杯/
はんばいあいて /販売相手/
はんばいいん /販売員/
はんばいうちきり /販売打切り/
はんばいか /販売課/
はんばいかい /販売会/即売会/
はんばいかいし /販売開始/
はんばいかかく /販売価格/
はんばいがいしゃ /販売会社/
はんばいき /販売機/
はんばいきかん /販売期間/
はんばいきょてん /販売拠点/
はんばいきんし /販売禁止/
はんばいけいたい /販売形態/
はんばいけいやく /販売契約/
はんばいけいろ /販売経路/
はんばいけん /販売権/
はんばいさいていかかく /販売最低価格/
はんばいさき /販売先/
はんばいしゃ /販売者/
はんばいじ /販売時/
はんばいじき /販売時期/
はんばいじぎょうぶ /販売事業部/
はんばいじっせき /販売実績/
はんばいじょ /販売所/
はんばいじょう /販売場/
はんばいじょうけん /販売条件/
はんばいじょうほう /販売情報/
はんばいすう /販売数/
はんばいせいせき /販売成績/
はんばいせんりゃく /販売戦略/
はんばいそくしん /販売促進/
はんばいそしき /販売組織/
はんばいたいせい /販売体制/
はんばいたんい /販売単位/
はんばいだいすう /販売台数/
はんばいだいりてん /販売代理店/
はんばいだか /販売高/
はんばいちゅう /販売中/
はんばいちゅうし /販売中止/
はんばいてん /販売店/
はんばいてんとう /販売店頭/
はんばいばしょ /販売場所/
はんばいひ /販売費/
はんばいひん /販売品/
はんばいび /販売日/
はんばいぶ /販売部/
はんばいぶん /販売分/
はんばいほうしき /販売方式/
はんばいほうほう /販売方法/
はんばいまいすう /販売枚数/
はんばいまえ /販売前/
はんばいもう /販売網/
はんばいもと /販売元/
はんばいや /販売屋/
はんばいよう /販売用/
はんばいりえき /販売利益/
はんばいりょう /販売量/
はんばいりょういき /販売領域/
はんばく /反駁/反ばく/
はんぱ /半端/半波/
はんぱく /半泊/
はんぱせいりゅう /半波整流/
はんぱちょう /半波長/
はんぱつ /反発/反撥/
はんぱつさよう /反発作用/
はんぱつてき /反発的/
はんぱつりょく /反発力/
はんひれい /反比例/
はんひん /販品/
はんぴれい /反比例/
はんふだい /阪府大/
はんぶうすう /繁分数/
はんぶっしつ /反物質/
はんぶるぐ /漢堡/
はんぶん /半分/
はんぶんいか /半分以下/
はんぶんいじょう /半分以上/
はんぶんくらい /半分位/
はんぶんさぎ /半分詐欺/
はんぶんさんせい /半分賛成/
はんぶんししん /半分私信/
はんぶんしゅみ /半分趣味/
はんぶんじゃく /半分弱/
はんぶんじょうだん /半分冗談/
はんぶんすう /繁分数/
はんぶんぜんご /半分前後/
はんぶんていど /半分程度/
はんぶんほんき /半分本気/
はんぶんほんとう /半分本当/
はんぷ /頒布/帆布/
はんぷかい /頒布会/
はんぷく /反復/
はんぷくうんどうかたそんしょう /反復運動過多損傷/RSI/Repetitive Strain Injury/
はんぷくおんけい /反復音型/
はんぷくがくしゅう /反復学習/
はんぷくし /反復子/
はんぷくてき /反復的/
はんぷくはいれつ /反復配列/
はんぷくほう /反復法/
はんぷけん /頒布権/
はんべい /反米/
はんべいかんじょう /反米感情/
はんべつ /判別/
はんべつかのう /判別可能/
はんべつきょうぎ /班別協議/
はんべつしき /判別式/
はんべつしきかいせき /判別式解析/
はんべつしきかんすう /判別式関数/
はんべつしきほう /判別式法/
はんべつしんごう /判別信号/
はんべつふかのう /判別不可能/
はんべつほう /判別法/
はんぺい /汎平/
はんぺいた /半平太/
はんぺん /反変/
はんぺんてんそる /反変テンソル/
はんぼいん /半母音/
はんぼう /繁忙/
はんぼうき /繁忙期/
はんぽ /半歩/
はんぽてまえ /半歩手前/
はんまー /ハンマー/
はんみ /半身/
はんみっしつ /半密室/
はんみょう /斑猫/
はんむげん /半無限/
はんむら /半村/
はんめい /判明/
はんめいしだい /判明次第/
はんめん /反面/半面/版面/
はんめんきょうし /反面教師/
はんめんどうろ /反面道路/
はんも /繁茂/
はんもく /反目/
はんもと /版元/
はんもん /反問/斑紋/煩悶/
はんもんてん /板門店/
はんよう /汎用/
はんようおおがた /汎用大形/
はんようおおがたき /汎用大型機/
はんようか /汎用化/
はんようき /汎用機/
はんようきのうぶひん /汎用機能部品/
はんようきよう /汎用機用/
はんようけいさんき /汎用計算機/
はんようし /反陽子/
はんようせい /汎用性/
はんようせいぎょ /汎用制御/
はんようちょうへいれつ /汎用超並列/
はんようてき /汎用的/
はんようばん /汎用版/
はんようひん /汎用品/
はんようへいれつけいさんき /汎用並列計算機/
はんらく /反落/
はんらん /氾濫/反乱/叛乱/汎濫/
はんらんかくさく /反乱画策/
はんらんぐん /反乱軍/
はんらんざい /反乱罪/
はんりっぽうたい /半立方体/
はんりゅう /伴流;後流。「ばんりゅう」とも/
はんりゅうし はんりゅうし /反粒子/
はんりゅうしちょぞう /反粒子貯蔵/
はんりょ /伴侶/
はんりょく /反力/
はんれい /判例/反例/凡例/汎例/範例/煩禮/
はんれいいちらん /判例一覧/
はんれいけんきゅう /判例研究/
はんれいしゅう /判例集/
はんれつ /半列/
はんろ /販路/坂路/
はんろん /反論/汎論/
はんろんがわ /反論側/
はんろんしゃ /反論者/
はんろんしょうめい /反論証明/
はんろんとうこう /反論投稿/
はんわ /阪和/
はんわこうぎょう /阪和興業/
はんわじどうしゃどう /阪和自動車道/
はんわせん /阪和線/
はんわせんない /阪和線内/
はんわどう /阪和道/
ば /場/馬/芭/婆/罵/羽/塲/葉/庭/刃/刄/
ばー /バー/
ばーじょん /バージョン/
ばーべきゅー /バーベキュー/
ばーん /barn/
ばあ /婆/
ばあい /場合/
ばあいいがい /場合以外/
ばあいさくせい /場合作成/
ばあいぜんじゅつ /場合前述/
ばあいなど /場合等/
ばあいわけ /場合分け/
ばあさま /婆様/
ばあさん /婆さん/
ばあたりてき /場当たり的/
ばい /倍/売/賠/買/陪/梅/狽/培/煤/媒/楳/唄/貝/吠/Ｂｙ/焙/憊/賣/霾/黴/苺/
ばいあすろん /バイアスロン/
ばいいじょう /倍以上/
ばいいじょうばりき /倍以上馬力/
ばいいない /倍以内/
ばいう /梅雨/
ばいういこう /梅雨以降/
ばいうころ /梅雨頃/
ばいうぜんせん /梅雨前線/
ばいえん /煤煙/
ばいお /バイオ/
ばいおん /倍音/
ばいおんじょう /倍音上/
ばいおんそく /倍音速/
ばいおんれつ /倍音列/
ばいか /倍加/売価/倍化/買価/
ばいかい /媒介/
ばいかいてき /媒介的/
ばいかいへんすう /媒介変数/
ばいかいへんすうひょうじ /媒介変数表示/
ばいかく /倍角/
ばいかくひょうじ /倍角表示/
ばいかくもじ /倍角文字/
ばいかたんきだいがく /梅花短期大学/
ばいかん /売勘/
ばいがく /倍額/
ばいがくいじょう /倍額以上/
ばいきゃく /売却/
ばいきゃくきぼうかかく /売却希望価格/
ばいきゃくさき /売却先/
ばいきゃくじ /売却時/
ばいきゃくねだん /売却値段/
ばいきん /黴菌/
ばいく /バイク/
ばいくとう /バイク盗/
ばいくらい /倍位/
ばいけん /買券/
ばいこく /売国/
ばいこくど /売国奴/
ばいしつ /媒質/
ばいしつちゅう /媒質中/
ばいしゃく /媒酌/媒妁/
ばいしゃくにん /媒酌人/
ばいしゅう /買収/
ばいしゅうきょうそう /買収競争/
ばいしゅん /買春/売春/
ばいしゅんふ /売春婦/
ばいしゅんやど /買春宿/
ばいしょう /賠償/売笑/
ばいしょうがく /賠償額/
ばいしょうきん /賠償金/
ばいしょうせいきゅう /賠償請求/
ばいしょうせいきゅうけん /賠償請求権/
ばいしょうせきにん /賠償責任/
ばいしん /陪審/陪臣/
ばいしんいん /陪審員/
ばいしんいんせいど /陪審員制度/
ばいしんせい /陪審制/
ばいしんせいど /陪審制度/
ばいしんにん /陪審人/
ばいじん /煤塵/
ばいすう /倍数/
ばいすうけい /倍数系/
ばいせい /媒精/
ばいせいど /倍精度/
ばいせいどえんざん /倍精度演算/
ばいせいどか /倍精度化/
ばいせいどじっすう /倍精度実数/
ばいせいどひょうじ /倍精度表示/
ばいせいどふくそすう /倍精度複素数/
ばいせき /陪席/
ばいせん /焙煎/煤煎/
ばいそく /倍速/
ばいそくさいせい /倍速再生/
ばいぞう /倍増/
ばいぞうかん /倍増感/倍増管/
ばいぞうかんていど /倍増感程度/
ばいた /売女/
ばいたい /媒体/
ばいたいふもん /媒体不問/
ばいち /培地/
ばいちょう /倍長/倍調/
ばいていど /倍程度/
ばいてん /売店/
ばいと /バイト/
ばいとすう /バイト数/
ばいどく /梅毒/
ばいなり /バイナリ/
ばいなりー /バイナリー/
ばいにく /梅肉/
ばいにん /売人/
ばいはば /倍幅/
ばいはばいんじ /倍幅印字/
ばいばい /売買/倍々/
ばいばいえき /売買益/
ばいばいけいやく /売買契約/
ばいばいこうしょう /売買交渉/
ばいばいしゅん /売買春/
ばいばいしょうこきん /売買証拠金/
ばいひん /売品/
ばいふうかん /培風館/培風舘/
ばいぶれーた /バイブレータ/
ばいまん /倍満/
ばいめい /売名/
ばいめいしん /売名心/
ばいやく /売約/売薬/
ばいやくしょ /売約書/
ばいやくまん /倍役満/
ばいゆう /培雄/
ばいよう /培養/
ばいようえき /培養液/
ばいようりょう /倍容量/
ばいりつ /倍率/
ばいりつかくだい /倍率拡大/
ばいりょう /倍量/
ばいりん /梅林/
ばう /芒/
ばか /馬鹿/莫迦/莫伽/バカ/
ばかおんな /馬鹿女/
ばかく /馬格/
ばかしょうじき /馬鹿正直/
ばかじから /馬鹿力/
ばかず /場数/
ばかぢから /馬鹿力/
ばかづら /馬鹿面/
ばかていねい /馬鹿丁寧/
ばかとの /馬鹿殿/
ばかね /馬鹿値/
ばかばか /馬鹿馬鹿/
ばかばかしい /馬鹿馬鹿しい/バカバカしい/
ばかばなし /馬鹿話/
ばかもの /馬鹿者/
ばかやす /馬鹿安/
ばかやろう /馬鹿野郎/
ばかり /許り/許/
ばきゃく /馬脚/
ばきん /馬琴/
ばぎょう /バ行/
ばく /麦/爆/縛/駁/莫/漠/獏/曝/暴/幕/驀/寞/瀑/藐/貘/麥/博/
ばくえい /幕営/
ばくえき /博奕/
ばくえん /爆炎/
ばくおん /爆音/
ばくが /麦芽/
ばくがいんりょう /麦芽飲料/
ばくがとう /麦芽糖/
ばくげき /爆撃/
ばくげきき /爆撃機/
ばくげきぎじゅつ /爆撃技術/
ばくげきせいど /爆撃精度/
ばくげきたい /爆撃隊/
ばくさい /爆砕/博才/
ばくさつ /爆殺/
ばくし /爆死/
ばくしゅう /麦秋/
ばくしょう /爆笑/
ばくしょうげきじょう /爆笑劇場/
ばくしょうへん /爆笑編/
ばくしょうもの /爆笑物/
ばくしん /爆心/爆進/驀進/
ばくしんち /爆心地/
ばくすい /爆睡/
ばくせん /瀑泉/
ばくぜん /漠然/
ばくそう /爆走/麦草/爆装/
ばくだい /莫大/
ばくだっど /バクダッド/
ばくだん /爆弾/爆彈/
ばくだんおとこ /爆弾男/
ばくだんきじ /爆弾記事/
ばくだんとうか /爆弾投下/
ばくだんはつ /爆弾発/
ばくだんはつげん /爆弾発言/
ばくだんや /爆弾屋/
ばくだんりょう /爆弾量/
ばくち /博打/博奕/
ばくちく /爆竹/
ばくちゃく /縛着/
ばくちん /爆沈/
ばくちんちょくご /爆沈直後/
ばくてりあ /バクテリア/
ばくと /博徒/
ばくは /爆破/
ばくはじけん /爆破事件/
ばくはつ /爆発/
ばくはつおん /爆発音/
ばくはつしょうじょう /爆発症状/
ばくはつすんぜん /爆発寸前/
ばくはつてき /爆発的/
ばくはつてきりゅうこう /爆発的流行/
ばくはつぶつ /爆発物/
ばくはつりょく /爆発力/
ばくふ /幕府/瀑布/
ばくふう /爆風/
ばくふぐん /幕府軍/
ばくまつ /幕末/
ばくやく /爆薬/
ばくらい /爆雷/
ばくらいせん /爆雷戦/
ばくりゅう /瀑流/
ばくりょう /幕僚/
ばくれつ /爆裂/
ばくろ /暴露/曝露/
ばくろう /馬喰/伯楽/博労/伯労/
ばくろうちょう /馬喰町/
ばくろばなし /暴露話/
ばくろぼん /暴露本/
ばくろれべる /暴露レベル/
ばぐ /馬具/バグ/
ばぐん /馬群/
ばけ /化/
ばけかた /化け方/
ばけがく /化学/
ばけつ /バケツ/
ばけねこ /化猫/
ばけもの /化物/化け物/
ばけん /馬券/
ばけんうりあげ /馬券売上/
ばけんこうにゅう /馬券購入/
ばけんさくせん /馬券作戦/
ばけんじょうず /馬券上手/
ばけんだい /馬券代/
ばけんてき /馬券的/
ばけんはつばいご /馬券発売後/
ばけんはつばいまえ /馬券発売前/
ばこ /箱/
ばさし /馬刺/
ばさんち /馬産地/
ばし /橋/
ばしゃ /馬車/
ばしゃうま /馬車馬/
ばしゃく /馬借/
ばしゃじだい /馬車時代/
ばしゃみち /馬車道/
ばしゅ /馬主/
ばしょ /場所/
ばしょいがい /場所以外/
ばしょいどう /場所移動/
ばしょう /芭蕉/
ばしょがら /場所柄/
ばしょく /馬謖;三国時代・蜀漢の臣で、馬良の弟/
ばしょこくち /場所告知/
ばしょせつ /場所説/
ばしょせんてい /場所選定/
ばしょだい /場所代/
ばしょちゅう /場所中/
ばしょちょくぜん /場所直前/
ばしょてき /場所的/
ばしょふめい /場所不明/
ばしょまえ /場所前/
ばしょみてい /場所未定/
ばしら /柱/
ばしん /馬身/
ばじとうふう /馬耳東風/
ばじゅつ /馬術/
ばじょう /馬乗/馬上/
ばす /バス/
ばすーん /バスーン/
ばすえ /場末/
ばすけっと /バスケット/
ばすけっとぼーる /バスケットボール/
ばすてい /バス停/
ばすはば /バス幅/
ばすれふ /バスレフ/
ばせい /罵声/
ばぞく /馬族/馬賊/
ばた /畑/端/
ばたー /バター/
ばたい /馬体/
ばたいじゅう /馬体重/
ばたけ /畑/畠/
ばち /罰/鉢/撥/罸/
ばちがい /場違い/
ばちすもく /バチス目/Batidales/
ばちゅう /馬柱/
ばっか /麦価/
ばっかすきほう /バッカス記法/
ばっきょ /抜去/
ばっきん /罰金/
ばっきんがく /罰金額/
ばっきんけい /罰金刑/
ばっきんせい /罰金制/
ばっきんせいど /罰金制度/
ばっく /バック/
ばっくあっぷ /バックアップ/
ばっくえんど /バックエンド/
ばっくみらー /バックミラー/
ばっくりんぐ /バックリング/
ばっこ /跋扈/
ばっさい /伐裁/伐採/
ばっさつ /抜刷/
ばっさり /バッサリ/
ばっし /抜歯/抜糸/
ばっしじ /抜歯時/
ばっしゅつ /伐出/
ばっしょう /跋渉/
ばっじ /バッジ/
ばっすい /抜粋/
ばっすいえんそう /抜粋演奏/
ばっそく /罰則/
ばっそくきてい /罰則規定/
ばった /飛蝗/
ばったい /罰退/
ばっち /バッチ/
ばっちしょり /バッチ処理/
ばってき /抜擢/抜てき/
ばってん /罰点/
ばっと /バット/
ばっとう /伐倒/抜刀/
ばっとうじゅつ /抜刀術/
ばっふぁー /バッファー/
ばっぷ /罰符/
ばっぽん /抜本/
ばっぽんてき /抜本的/
ばつ /罰/×/抜/閥/筏/伐/跋/末/拔/罸/魃/
ばついっぱん /罰一般/
ばつぐん /抜群/
ばつぞく /閥族/
ばつたい /罰退/
ばつだ /罰打/
ばつばつ /××/
ばつぼく /伐木/
ばてい /馬丁/馬蹄/
ばとう /罵倒/馬頭/
ばとうきん /馬頭琴/
ばとうご /罵倒語/
ばとうせいうん /馬頭星雲/
ばとうようごは /罵倒用語派/
ばどみんとん /バドミントン/
ばな /鼻/
ばなし /話/
ばなはかん /バナハ環/
ばなはくうかん /バナハ空間/
ばなれ /場慣れ/離れ/
ばにく /馬肉/
ばにら /バニラ/
ばぬしめい /馬主名/
ばね /バネ/発条/
ばば /馬場/婆/
ばばかいぞう /馬場改造/
ばばぐち /馬場口/
ばばじょうたい /馬場状態/
ばばじる /婆汁/
ばばてきせい /馬場適正/
ばばない /馬場内/
ばばんれんふく /馬番連複/
ばふだ /場札/
ばふん /馬糞/
ばぼう /馬房/
ばぼうさく /馬防柵/
ばめい /馬名/
ばめいへいき /馬名併記/
ばめん /場面/
ばめんごと /場面毎/
ばめんせってい /場面設定/
ばめんてんかん /場面転換/
ばや /早/速/
ばやし /林/
ばら /薔薇/原/バラ/
ばらいろ /薔薇色/
ばらか /バラ科/
ばらき /原木/
ばらきなかやま /原木中山/
ばらぞく /薔薇族/
ばらのぷすもく /バラノプス目/Balanopales/
ばらもく /バラ目/Rosales/
ばらもくあぐん /バラ目亜群/
ばらもくぐん /バラ目群/
ばらんす /バランス/
ばり /針/罵詈/
ばりうむかごうぶつ /バリウム化合物/
ばりえーしょん /バリエーション/
ばりき /馬力/
ばりきさ /馬力差/
ばりざんぼう /罵詈讒謗/
ばりぞうごん /罵詈雑言/
ばる /原/
ばるかん /巴爾幹/
ばるく /バルク/
ばるぶ /バルブ/
ばれーぼーる /バレーボール/
ばれい /馬齢/
ばれいしょ /馬鈴薯/
ばれえ /バレエ/
ばれん /馬連/
ばれんたいん /バレンタイン/
ばろめーた /バロメータ/
ばん /番/版/晩/盤/万/判/磐/蛮/蕃/伴/坂/板/挽/萬/播/悗/旛/旙/礬/絆/蠻/輓/鑁/鷭/阪/幡/
ばんあれんたい /バンアレン帯/
ばんえつ /磐越/
ばんえつさいせん /磐越西線/
ばんえつじどうしゃどう /磐越自動車道/
ばんえつとうせん /磐越東線/
ばんか /挽歌/晩夏/晩歌/
ばんかい /挽回/
ばんかん /万感/
ばんがい /番外/番街/
ばんがいこうしえん /番外甲子園/
ばんがいち /番外地/
ばんがいへん /番外編/
ばんき /晩期/
ばんきょ /蟠踞/
ばんきん /板金/鈑金/
ばんきんや /板金屋/
ばんぎく /晩菊/
ばんくーばー /晩香坡/
ばんくみ /版組/
ばんぐみ /番組/
ばんぐみあんない /番組案内/
ばんぐみか /番組化/
ばんぐみかいしとうしょ /番組開始当初/
ばんぐみかいへん /番組改編/番組改変/
ばんぐみかいへんき /番組改編期/
ばんぐみかんけいしゃ /番組関係者/
ばんぐみこうせい /番組構成/
ばんぐみざっし /番組雑誌/
ばんぐみしゅうりょう /番組終了/
ばんぐみしゅうりょうご /番組終了後/
ばんぐみしゅうろくちゅう /番組収録中/
ばんぐみしょき /番組初期/
ばんぐみじたい /番組自体/
ばんぐみじょう /番組上/
ばんぐみじょうほうし /番組情報誌/
ばんぐみせいさく /番組製作/
ばんぐみせいさくしゃ /番組製作者/番組制作者/
ばんぐみせんでん /番組宣伝/
ばんぐみぜんたい /番組全体/
ばんぐみぜんぱん /番組全般/
ばんぐみたいこう /番組対抗/
ばんぐみだい /番組第/
ばんぐみちゅう /番組中/
ばんぐみちゅうし /番組中止/
ばんぐみどうし /番組同士/
ばんぐみない /番組内/
ばんぐみないよう /番組内容/
ばんぐみはいきゅう /番組配給/
ばんぐみはつ /番組初/
ばんぐみばんごう /番組番号/
ばんぐみひひょう /番組批評/
ばんぐみひょう /番組表/
ばんぐみひょういちらん /番組表一覧/
ばんぐみへんこう /番組変更/
ばんぐみへんせい /番組編成/
ばんぐみへんせいき /番組編成期/
ばんぐみほうえいじ /番組放映時/
ばんぐみほうそう /番組放送/
ばんぐみほんたい /番組本体/
ばんぐみめい /番組名/
ばんぐみめいへんこう /番組名変更/
ばんぐみよやく /番組予約/
ばんぐみらん /番組欄/
ばんぐみらんがい /番組欄外/
ばんけん /番犬/
ばんけんもと /版権元/
ばんこ /萬古/
ばんこう /磐高/蛮行/
ばんこく /万国/盤谷/
ばんこくきょうつう /万国共通/
ばんこくはくらんかい /万国博覧会/
ばんこん /晩婚/
ばんこんか /晩婚化/
ばんご /番後/
ばんごう /番号/
ばんごうあんない /番号案内/
ばんごういがい /番号以外/
ばんごうかんり /番号管理/
ばんごうごと /番号毎/
ばんごうしてい /番号指定/
ばんごうじゅん /番号順/
ばんごうたいけい /番号体系/
ばんごうつうち /番号通知/
ばんごうとくてい /番号特定/
ばんごうはんい /番号範囲/
ばんごうひょう /番号表/
ばんごうひょうじ /番号表示/
ばんごうぼ /番号簿/
ばんごうらん /番号欄/
ばんごうわく /番号枠/
ばんごはん /晩御飯/
ばんさい /磐西/
ばんさく /万策/
ばんさん /晩餐/
ばんさんかい /晩餐会/
ばんざい /万歳/
ばんざいさんしょう /万歳三唱/
ばんしつ /盤質/
ばんしゃく /晩酌/
ばんしゅう /晩秋/播州/
ばんしゅうあこう /播州赤穂/
ばんしゅうじん /播州人/
ばんしゅうちほう /播州地方/
ばんしゅん /晩春/
ばんしょ /板書/番所/
ばんしょう /万障/番匠/晩鐘/万象/
ばんしんどう /板振動/
ばんじ /万事/
ばんじきゅうす /万事窮す/
ばんじゃく /磐石/盤石/
ばんじょ /磐女/
ばんじょう /万丈/盤上/
ばんじん /万人/
ばんすい /晩翠/
ばんすいそうどう /晩翠草堂/
ばんすう /番数/
ばんせい /晩成/万世/
ばんせん /番線/番宣/
ばんせんけいゆ /播但線経由/
ばんぜん /万全/
ばんそう /伴奏/晩霜/
ばんそうこう /ばん創膏/絆創膏/
ばんそうしゃ /伴奏者/
ばんそうばん /伴奏版/
ばんそうぶ /伴奏部/
ばんぞく /蛮族/
ばんたん /万端/盤端/播但/
ばんたんせん /播但線/
ばんたんせんけいゆ /播但線経由/
ばんだ /万朶/
ばんだい /番台/万代/磐梯/
ばんだいあたみおんせん /磐梯熱海温泉/
ばんだいくぶん /番台区分/
ばんだいさん /磐梯山/
ばんだいちょう /磐梯町/
ばんち /番地/番値/
ばんちぶぶん /番地部分/
ばんちゃ /番茶/
ばんちょう /番丁/番長/番町/
ばんづけ /番付/
ばんづけがい /番付外/
ばんづけひょう /番付表/
ばんづけよそう /番付予想/
ばんて /番手/
ばんとう /番頭/晩冬/蛮刀/
ばんど /バンド/
ばんどう /坂東/
ばんどうたまさぶろう /坂東玉三郎/
ばんない /判内/坂内/
ばんなぐろ /花畔/
ばんなん /万難/
ばんにん /番人/万人/
ばんにんきょうつう /万人共通/
ばんにんびょうどう /万人平等/
ばんねん /晩年/
ばんの /番野/坂野/伴野/
ばんのう /万能/
ばんのうえんざん /万能演算/
ばんのうかぎ /万能鍵/
ばんのうがた /万能型/
ばんのうきかい /万能機械/
ばんのうきぐ /万能器具/
ばんのうざお /万能竿/
ばんのうせい /万能性/
ばんのうやく /万能薬/
ばんば /輓馬/
ばんばん /バンバン/
ばんばんざい /万万歳/
ばんばんじー /棒々鶏/棒棒鶏/
ばんぱく /万博/
ばんぱん /万般/
ばんぶつ /万物/
ばんぶつるてん /万物流転/
ばんぷう /蛮風/
ばんべつ /万別/
ばんぺい /番兵/
ばんみん /万民/
ばんめ /番目/
ばんめし /晩飯/
ばんめん /盤面/
ばんめんひだりうえ /盤面左上/
ばんめんみぎうえ /盤面右上/
ばんゆう /万有/蛮勇/
ばんゆういんりょく /万有引力/
ばんゆういんりょくていすう /万有引力定数/
ばんらい /万雷/
ばんり /万里/萬里/
ばんりのちょうじょう /万里の長城/
ばんりばし /万里橋/
ばんりゅう /伴流;後流。「はんりゅう」とも/
ばんれいしか /バンレイシ科/Annonaceae/
ぱ /波/破/播/羽/
ぱーせんと /パーセント/％/
ぱーそなりてぃ /パーソナリティ/
ぱーそなる /パーソナル/
ぱーつ /パーツ/
ぱーてぃ /パーティ/
ぱーてぃー /パーティー/
ぱーと /パート/
ぱーとたいまー /パートタイマー/
ぱーとなー /パートナー/
ぱーふぇくと /パーフェクト/
ぱーみっしょん /パーミッション/
ぱーみる /‰/
ぱーる /パール/
ぱあそう /八索/
ぱい /牌/敗/杯/配/パイ/π/盃/Π/
ぱいちゅー /白酒/
ぱいなっぷるもく /パイナップル目/Bromeliales/
ぱいぷ /パイプ/
ぱいぷや /ぱいぷ屋/
ぱいろっと /パイロット/
ぱお /包/
ぱおず /包子/
ぱぎょう /パ行/
ぱく /朴/拍/泊/博/愽/駮/
ぱけっと /パケット/
ぱこ /箱/
ぱじゃま /パジャマ/
ぱす /パス/
ぱすた /パスタ/
ぱすてる /パステル/
ぱすめい /パス名/
ぱすわーど /パスワード/
ぱずる /パズル/
ぱそこん /パソコン/
ぱそこんつうしん /パソコン通信/
ぱそつう /パソ通/
ぱたーん /パターン/
ぱたーんにんしき /パターン認識/
ぱち /八/
ぱちんこ /パチンコ/
ぱちんこや /パチンコ屋/
ぱっく /パック/
ぱっけーじ /パッケージ/
ぱっと /パット/
ぱっど /パッド/
ぱつ /発/發/
ぱなま /巴奈馬/
ぱなまそうもく /パナマソウ目/Cyclanthales/Synanthae/
ぱにっく /パニック/
ぱねりすと /パネリスト/
ぱねる /パネル/
ぱのらま /パノラマ/
ぱぱ /パパ/
ぱふぉーまんす /パフォーマンス/
ぱらぐらふ /パラグラフ/
ぱらびおん /パラビオン/
ぱらめーた /パラメータ/
ぱらめーたー /パラメーター/
ぱららいざー /パラライザー/
ぱられる /パラレル/
ぱり /巴里/
ぱりっこ /パリっ子/
ぱる /パル/
ぱるしぇ /パルシェ/
ぱるすはば /パルス幅/
ぱるぷ /パルプ/
ぱれす /パレス/
ぱれっと /パレット/
ぱろでぃ /パロディ/
ぱわー /パワー/
ぱん /版/パン/搬/板/麺麭/幇/播/
ぱんく /パンク/
ぱんこ /パン粉/
ぱんだ /パンダ/
ぱんつ /パンツ/
ぱんてぃ /パンティ/
ぱんどら /パンドラ/
ぱんふれっと /パンフレット/
ぱんぷきん /パンプキン/
ぱんぷす /パンプス/
ひ /日/非/費/比/火/彼/飛/被/秘/避/扉/樋/陽/肥/皮/緋/罷/否/悲/誹/碑/批/妃/披/痺/卑/斐/庇/匪/泌/疲/檜/灯/砒/脾/腓/干/桧/丕/俾/妣/昜/暃/朏/杼/梭/狒/痞/祕/秕/紕/臂/菲/蓖/蜚/裨/譬/貔/豼/贔/鄙/霏/鞁/鞴/髀/轡/簸/毘/氷/
ひ< /非/
ひ> /被/非/
ひ? /非/
ひーた /ヒータ/
ひーろー /ヒーロー/
ひあい /悲哀/
ひあたり /日当たり/
ひあっしゅく /非圧縮/
ひあっしゅくきろく /非圧縮記録/
ひあっしゅくじ /非圧縮時/
ひあっしゅくせい /非圧縮性/
ひあっしゅくせいきたい /非圧縮性気体/
ひあっしゅくりゅう /非圧縮流/
ひあっしゅくりょういき /非圧縮領域/
ひあぶり /火焙り/
ひあんだ /被安打/
ひい /贔/曾/
ひいき /贔屓/
ひいきめ /贔屓目/
ひいきりきし /贔屓力士/
ひいじじ /曽祖父/
ひいぞん /非依存/
ひいまご /曾孫/
ひいらいしゃ /被依頼者/
ひいらぎ /柊/
ひいれしき /火入式/
ひいろ /緋色/
ひいんがせい /非因果性/
ひいんがてき /非因果的/
ひいんじ /非印字/
ひいんじもじ /非印字文字/
ひう /日宇/
ひうち /火打ち/燧/
ひうちやま /火打山/
ひうちょう /日宇町/
ひうら /樋浦/火浦/日浦/
ひうん /悲運/非運/
ひえ /稗/
ひえい /飛栄/比叡/飛影/
ひえいきょうしゃ /非影響者/
ひえいごけん /非英語圏/
ひえいざん /比叡山/
ひえいざんこうこう /比叡山高校/
ひえいり /非営利/
ひえいりせい /非営利性/
ひえいりだんたい /非営利団体/
ひえいりもくてき /非営利目的/
ひえいりりよう /非営利利用/
ひえき /桧枝岐/裨益/
ひえこみ /冷えこみ/
ひえしょう /冷え症/
ひえじんじゃ /日枝神社/
ひえだ /稗田/檜枝/
ひえづ /日吉津/
ひえぬき /稗貫/
ひえん /飛燕/
ひえんざんすう /被演算数/
ひおうどう /非王道/
ひおき /日置/
ひおとこ /火男/
ひおんせい /非音声/
ひおんせいがくてき /非音声学的/
ひか /皮下/
ひかいいん /非会員/
ひかいいんあて /非会員宛/
ひかいいんがくせい /非会員学生/
ひかいいんりょうきん /非会員料金/
ひかいせき /被解析/
ひかいせきかんすう /被解析関数/
ひかいせきしんごう /被解析信号/
ひかいてん /非回転/
ひかえ /控/控え/
ひかえしつ /控え室/控室/
ひかえめ /控え目/
ひかかい /非可解/
ひかかいせい /非可解性/
ひかかん /非可換/
ひかかんぐん /非可換群/
ひかがくしょ /非科学書/
ひかがくてき /非科学的/
ひかがくてきこんきょ /非科学的根拠/
ひかがくぶんや /非科学分野/
ひかがみ /膕/
ひかき /火掻き/
ひかきん /非課金/
ひかぎゃく /非可逆/
ひかぎゃくあっしゅく /非可逆圧縮/
ひかく /比較/皮革/飛角/
ひかくあいて /比較相手/
ひかくいけん /比較意見/
ひかくえんざんし /比較演算子/
ひかくおん /比較音/
ひかくかのう /比較可能/
ひかくかんすう /比較関数/
ひかくき /比較器/
ひかくきじ /比較記事/
ひかくきゅう /比較級/
ひかくけっか /比較結果/
ひかくけんとう /比較検討/
ひかくげんごがく /比較言語学/
ひかくしげき /比較刺激/
ひかくしちょう /比較視聴/
ひかくじっけん /比較実験/
ひかくたいしょう /比較対象/
ひかくたいしょうれい /比較対象例/
ひかくてい /非確定/
ひかくてき /比較的/
ひかくてきあんか /比較的安価/
ひかくてきあんしん /比較的安心/
ひかくてきかんたん /比較的簡単/
ひかくてきこうか /比較的高価/
ひかくてきこりつ /比較的孤立/
ひかくてきさいきん /比較的最近/
ひかくてきじゆう /比較的自由/
ひかくてきたんきかん /比較的短期間/
ひかくてきていそく /比較的低速/
ひかくてきぶなん /比較的無難/
ひかくてきべんり /比較的便利/
ひかくてきまんなか /比較的真中/
ひかくてきゆうめい /比較的有名/
ひかくてきようい /比較的容易/
ひかくてきらく /比較的楽/
ひかくはんだん /比較判断/
ひかくひょう /比較表/
ひかくほう /比較法/
ひかくろん /比較論/
ひかげ /日陰/日蔭/日影/
ひかげぶぶん /日陰部分/
ひかげもの /日陰者/
ひかげん /火加減/
ひかさん /非可算/
ひかさんむげん /非加算無限/非可算無限/
ひかぜい /非課税/
ひかぜいぎょうしゃ /非課税業者/
ひかた /干潟/
ひかちゅうしゃ /皮下注射/
ひかみ /氷上/
ひかり /光/芒/
ひかりかんれん /光関連/
ひかりきのうざいりょうぶ /光機能材料部/
ひかりきゅうしゅう /光吸収/
ひかりぎじゅつ /光技術/
ひかりぎょうこ /光凝固/
ひかりこうかん /光交換/
ひかりこうかんけんきゅう /光交換研究/
ひかりこうがく /光工学/
ひかりこうがくけんきゅうしつ /光工学研究室/
ひかりこうがくせんこう /光工学専攻/
ひかりしげき /光刺激/
ひかりしゅうせき /光集積工学/
ひかりしゅうせきこうがく /光集積工学/
ひかりしゅつりょく /光出力/
ひかりしんごう /光信号/
ひかりじき /光磁気/
ひかりじゅようき /光受容器/
ひかりじょうほう /光情報/
ひかりじょうほうけんきゅうしつ /光情報研究室/
ひかりそうさ /光走査/
ひかりそうさそうち /光走査装置/
ひかりたんし /光端子/
ひかりだい /光台/
ひかりちゅうせいし /光中性子/
ひかりつうしん /光通信/
ひかりつうしんけんきゅうぶ /光通信研究部/
ひかりつうしんほうしき /光通信方式/
ひかりつうしんりろん /光通信理論/
ひかりでんち /光電池/
ひかりどけい /光時計/
ひかりはつでん /光発電/
ひかりはんのう /光反応/
ひかりふぁいばあ /光ファイバー/
ひかる /光/熈/
ひかわ /氷川/簸川/斐川/
ひかわじんじゃ /火川神社/氷川神社/
ひかわまる /氷川丸/
ひかん /悲観/避寒/
ひかんさいじん /非関西人/
ひかんさん /比換算/
ひかんじ /非漢字/
ひかんじけん /非漢字圏/
ひかんじばん /非漢字版/
ひかんじぶぶん /非漢字部分/
ひかんじぶんかけん /非漢字文化圏/
ひかんじもじ /非漢字文字/
ひかんせいけい /非慣性系/
ひかんせん /非感染/
ひかんぜいしょうへき /非関税障壁/
ひかんつう /非貫通/
ひかんてき /悲観的/
ひかんてきよそう /悲観的予想/
ひかんよう /非寛容/
ひかんり /非管理/
ひかんりさいと /非管理サイト/
ひが /比嘉/此我/彼我/
ひがい /被害/鰉/
ひがいいしき /被害意識/
ひがいがく /被害額/
ひがいがわ /被害側/
ひがいきゅうさい /被害救済/
ひがいきんがく /被害金額/
ひがいしゃ /被害者/
ひがいしゃいしき /被害者意識/
ひがいしゃほご /被害者保護/
ひがいしんこく /被害申告/
ひがいしんせい /被害申請/
ひがいじゅうみん /被害住民/
ひがいじょうきょう /被害状況/
ひがいじんだい /被害甚大/
ひがいたいおう /被害対応/
ひがいとどけ /被害届/
ひがいはっせい /被害発生/
ひがいもうそう /被害妄想/
ひがいもうそうてき /被害妄想的/
ひがえり /日帰り/
ひがき /桧垣/檜垣/
ひがくしゅう /非学習/
ひがけ /日掛け/
ひがさ /日傘/
ひがし /東/干菓子/
ひがしあおもり /東青森/
ひがしあおやま /東青山/
ひがしあわくら /東粟倉/
ひがしいけ /東池/
ひがしいけぶくろ /東池袋/
ひがしいず /東伊豆/
ひがしいずふきん /東伊豆付近/
ひがしいずほうめん /東伊豆方面/
ひがしいずも /東出雲/
ひがしいせざき /東伊勢崎/
ひがしいちき /東市来/
ひがしいちじょう /東一条/
ひがしいばらき /東茨城/
ひがしいややま /東祖谷山/
ひがしいわい /東磐井/
ひがしうすき /東臼杵/
ひがしうめだえき /東梅田駅/
ひがしうら /東浦/
ひがしうわ /東宇和/
ひがしえき /東駅/
ひがしお /東尾/
ひがしおうめ /東青梅/
ひがしおうめかん /東青梅間/
ひがしおおぎじま /東扇島/
ひがしおおさか /東大阪/
ひがしおおさかし /東大阪市/
ひがしおおさかせん /東大阪線/
ひがしおおしまかん /東大島間/
ひがしおおじ /東大路/
ひがしおかざき /東岡崎/
ひがしかいがん /東海岸/
ひがしかいがんちく /東海岸地区/
ひがしかいがんりょうきん /東海岸料金/
ひがしかいがんりょこう /東海岸旅行/
ひがしかぐら /東神楽/
ひがしかすがい /東春日井/
ひがしかぜ /東風/
ひがしかた /東方/
ひがしかつしか /東葛飾/
ひがしかながわ /東神奈川/
ひがしかも /東加茂/
ひがしかるいざわ /東軽井沢/
ひがしかわ /東川/
ひがしかわぐち /東川口/
ひがしかわぐちえき /東川口駅/
ひがしかん /東館/
ひがしかんとう /東関東/
ひがしかんばら /東蒲原/
ひがしがわ /東側/
ひがしがわしゃかい /東側社会/
ひがしがわしょこく /東側諸国/
ひがしがわじんえい /東側陣営/
ひがしきたざわ /東北沢/
ひがしきたざわえき /東北沢駅/
ひがしきゅうしゅうちく /東九州地区/
ひがしきりゅう /東桐生/
ひがしきりゅうえき /東桐生駅/
ひがしぎんざ /東銀座/
ひがしく /東区/
ひがしくしろ /東釧路/
ひがしくち /東口/
ひがしくにさき /東国東/
ひがしくはこざき /東区箱崎/
ひがしくびき /東頚城/
ひがしくるめ /東久留米/
ひがしぐち /東口/
ひがしぐちてん /東口店/
ひがしこう /東高/
ひがしこうえん /東公園/
ひがしこうえんじ /東高円寺/
ひがしこうべ /東神戸/
ひがしこがねい /東小金井/
ひがしこむすび /東小結/
ひがししいじ /東椎路/
ひがししおじり /東塩尻/
ひがししおじりえき /東塩尻駅/
ひがししずおか /東静岡/
ひがししらかわ /東白川/
ひがししりいけ /東尻池/
ひがしじま /東島/
ひがしじゅうじょう /東十条/
ひがしじゅうじょうかん /東十条間/
ひがしじゅうりょう /東十両/
ひがしじょうもんじん /東縄文人/
ひがしすみよし /東住吉/
ひがしせきわけ /東関脇/
ひがしせふり /東背振/
ひがしせんだいかん /東仙台間/
ひがしせんだちく /東千田地区/
ひがしせんだまち /東千田町/
ひがしそのぎ /東彼杵/
ひがしたがわ /東田川/
ひがしたてやま /東館山/
ひがしだ /東田/
ひがしちく /東地区/
ひがしちくま /東筑摩/
ひがしちちぶ /東秩父/
ひがしちば /東千葉/
ひがしちょう /東町/
ひがしつがる /東津軽/
ひがしつの /東津野/
ひがしでぐち /東出口/
ひがしとう /東棟/
ひがしとうきょう /東東京/
ひがしとうきょうたいかい /東東京大会/
ひがしとうきょうだいひょう /東東京代表/
ひがしところざわ /東所沢/
ひがしとつか /東戸塚/
ひがしとつかえき /東戸塚駅/
ひがしとなみ /東砺波/東礪波/
ひがしどうり /東通/
ひがしなか /東中/
ひがしなかす /東中州/
ひがしなかの /東中野/
ひがしなかやま /東中山/
ひがしなかやまかん /東中山間/
ひがしながさきちく /東長崎地区/
ひがしなだ /東灘/
ひがしなだく /東灘区/
ひがしなだしんごうしょ /東灘信号所/
ひがしなだしんごうじょ /東灘信号所/
ひがしなりた /東成田/
ひがしなるせ /東成瀬/
ひがしにほん /東日本/
ひがしにほんいがい /東日本以外/
ひがしにほんけい /東日本系/
ひがしにほんけん /東日本圏/
ひがしにほんじん /東日本人/
ひがしにほんだいひょう /東日本代表/
ひがしにほんへん /東日本編/
ひがしね /東根/
ひがしの /東野/
ひがしのしろ /東能代/
ひがしのしろえき /東能代駅/
ひがしはま /東浜/
ひがしはら /東原/
ひがしはりだしおおぜき /東張出大関/
ひがしはりだしせきわけ /東張出関脇/
ひがしはんきゅう /東半球/
ひがしはんのう /東飯能/
ひがしはんぶん /東半分/
ひがしばる /東原/
ひがしひろしま /東広島/
ひがしひろしまえき /東広島駅/
ひがしひろしまかん /東広島間/
ひがしひろしまし /東広島市/
ひがしふしみ /東伏見/
ひがしふじ /東富士/
ひがしふじけんきゅうじょ /東富士研究所/
ひがしべついん /東別院/
ひがしほんがんじまえ /東本願寺前/
ひがしまいづる /東舞鶴/
ひがしまち /東町/
ひがしまつうら /東松浦/
ひがしまつやま /東松山/
ひがしまつやまし /東松山市/
ひがしむき /東向き/
ひがしむこうじま /東向島/
ひがしむら /東村/
ひがしむらやま /東村山/
ひがしむらやましみん /東村山市民/
ひがしむろ /東牟婁/
ひがしむろらん /東室蘭/
ひがしめいはん /東名阪/
ひがしもろかた /東諸県/
ひがしもん /東門/
ひがしやつしろ /東八代/
ひがしやま /東山/
ひがしやまいまでがわ /東山今出川/
ひがしやまきたおおじ /東山北大路/
ひがしやまこ /東山湖/
ひがしやまごじょう /東山五条/
ひがしやまさんじょう /東山三条/
ひがしやません /東山線/
ひがしやまと /東大和/
ひがしやまとし /東大和市/
ひがしやまなし /東山梨/
ひがしゆり /東由利/
ひがしよか /東与賀/
ひがしよしの /東吉野/
ひがしよどがわ /東淀川/
ひがしりしり /東利尻/
ひがしわかやま /東和歌山/
ひがた /干潟/
ひがら /日柄/
ひがわり /日変わり/
ひがん /悲願/彼岸/
ひがんばな /彼岸花/
ひき /匹/引/疋/比企/悲喜/引き/蟇/蟆/日置/曳/挽/
ひきあい /引合/引合い/
ひきあげ /引き上げ/
ひきあげせん /引上線/
ひきあて /引当/
ひきあてきん /引当金/
ひきい /率い/
ひきうけ /引き受け/引受/引受け/
ひきうけにん /引受人/
ひきおとし /引き落とし/
ひきかえ /引き換え/引換/引替/
ひきかえけん /引き換え券/引換券/引替券/
ひきかえしょう /引換証/
ひきかた /弾き方/
ひきかたり /弾き語り/
ひきがえる /蟇蛙/蟾蜍/
ひきがたり /弾き語り/
ひきがね /引き金/引金/
ひきがわ /日置川/
ひきぐん /比企郡/
ひきげき /悲喜劇/
ひきこみ /引込/引き込み/
ひきこみせん /引込線/
ひきこもごも /悲喜交々/
ひきごう /非記号/
ひきごうしょり /非記号処理/
ひきごうてき /非記号的/
ひきごうてききしつ /非記号的基質/
ひきさげ /引下げ/
ひきざん /引き算/引算/
ひきしお /引き潮/
ひきすう /引数/引き数/
ひきすういじょう /引数異常/
ひきすういち /引数位置/
ひきすうかんすう /引数関数/
ひきすうしていじ /引数指定時/
ひきすうひょうかじ /引数評価時/
ひきた /引田/疋田/
ひきたえき /引田駅/
ひきたて /引立て/
ひきだ /引田/疋田/
ひきだし /引き出し/引出し/抽出/抽斗/
ひきだししき /引出式/
ひきち /引地/
ひきちだい /引地台/
ひきつえん /非喫煙/
ひきつえんうんどう /非喫煙運動/
ひきつえんしゃ /非喫煙者/
ひきつえんじんこう /非喫煙人口/
ひきつぎ /引き継ぎ/引きつぎ/
ひきつぎひん /引き継ぎ品/
ひきつけ /痙/
ひきつづき /引き続き/引続き/
ひきつる /痙/
ひきて /引き手/
ひきでもの /引出物/
ひきとり /引き取り/
ひきとりさき /引取先/
ひきとりじょうけん /引取条件/
ひきとりて /引取手/
ひきとりにん /引取人/
ひきど /引戸/
ひきにく /挽肉/
ひきにげ /ひき逃げ/轢き逃げ/
ひきぬき /引き抜き/
ひきのばし /引き伸ばし/
ひきのばしき /引伸機/
ひきみ /匹見/
ひきめ /蟇目/
ひきゃく /飛脚/
ひきゅうせん /飛球線/
ひきゅうほうこう /飛球方向/
ひきゅうめん /非球面/
ひきょう /卑怯/秘境/
ひきょうかい /非境界/
ひきょうごうてき /非競合的/
ひきょうせいれんこうしゃ /被強制連行者/
ひきょうもの /卑怯者/
ひきょうゆう /非共有/
ひきょうりょくてき /非協力的/
ひきょくしょ /非局所/
ひきょくしょてき /非局所的/
ひきょじゅうしゃ /非居住者/
ひきょり /飛距離/
ひきわけ /引き分け/引分/
ひきわけすう /引分数/
ひきわたし /引渡し/引渡/
ひきん /卑近/
ひきんいつ /非均一/
ひきんえんしゃ /非禁煙車/
ひきんしつ /非均質/
ひきんぞく /非金属/
ひぎ /秘技/秘儀/秘戯/
ひぎしゃ /被疑者/
ひぎょう /罷業/
ひぎんえんしゃしん /非銀塩写真/
ひぎんこう /非銀行/
ひく /低/−/攣/牽/佗/
ひくいどり /火喰鳥/
ひくう /非空/
ひくうてい /飛空艇/飛空挺/
ひくうはくもじ /非空白文字/
ひくつ /卑屈/
ひくて /引く手/
ひくどうがわ /非駆動側/
ひくま /曵馬/
ひくめ /低目/
ひぐち /樋口/樋/
ひぐちいちよう /樋口一葉/
ひぐちうち /火口内/
ひぐちけん /樋口研/
ひぐま /ヒグマ/日熊/羆/
ひぐらし /蜩/日暮/
ひぐれ /日暮れ/
ひぐんじそしき /非軍事組織/
ひぐんじてき /非軍事的/
ひけいけんしゃ /非経験者/
ひけいざいてき /非経済的/
ひけいしき /非形式/
ひけいしきてき /非形式的/
ひけいそくしゃ /被計測者/
ひけいやく /非契約/
ひけぎわ /引け際/
ひけた /引田/
ひけっしょう /非結晶/
ひけってい /非決定/
ひけっていし /非決定子/
ひけっていせい /非決定性/
ひけっていてき /非決定的/
ひけっていてきどうさ /非決定的動作/
ひけっていろん /非決定論/
ひけつ /秘訣/否決/
ひけつほうほう /否決方法/
ひけね /引け値/
ひけん /被験/披見/比肩/
ひけんさく /被検索/
ひけんしゃ /被験者/被検者/
ひけんじゃ /披験者/被験者/被検者/
ひけんせつてき /非建設的/
ひげ /髭/卑下/鬚/髯/
ひげい /秘芸/
ひげいじゅつてき /非芸術的/
ひげき /悲劇/
ひげきせい /悲劇性/
ひげきてき /悲劇的/
ひげそり /髭剃り/
ひげづら /髭面/
ひげね /ひげ根/鬚根/
ひげねけい /ひげ根系/鬚根系/
ひげんごてき /非言語的/
ひげんごてきちしき /非言語的知識/
ひげんしょう /非減少/
ひげんじつ /非現実/
ひげんじつせい /非現実性/
ひげんじつてき /非現実的/
ひげんてい /非限定/
ひこ /彦/比古/曾孫/秘湖/
ひこう /飛行/非行/飛講/飛光/秘孔/肥厚/
ひこうか /非行化/
ひこうかい /非公開/
ひこうかいじょうほう /非公開情報/
ひこうかいぶ /非公開部/
ひこうき /飛行機/飛行/
ひこうきえいこう /飛行機曳航/
ひこうきぐも /飛行機雲/
ひこうきじこ /飛行機事故/
ひこうきじたい /飛行機自体/
ひこうきだい /飛行機代/飛行機台/
ひこうきない /飛行機内/
ひこうきょり /飛行距離/
ひこうきりょこう /飛行機旅行/
ひこうきりようきゃく /飛行機利用客/
ひこうきろく /飛行記録/
ひこうこうど /飛行高度/
ひこうこうばん /飛行甲板/
ひこうさ /非交差/
ひこうし /飛行士/
ひこうしき /非公式/
ひこうしきけんかい /非公式見解/
ひこうしょうねん /非行少年/
ひこうしれい /飛行指令/
ひこうじかん /飛行時間/
ひこうじかんてき /飛行時間的/
ひこうじょう /飛行場/
ひこうじょうあと /飛行場跡/
ひこうじょうたい /飛行状態/
ひこうじょうのうりょく /飛行場能力/
ひこうせいてき /非構成的/
ひこうせき /飛行石/
ひこうせん /飛行船/
ひこうせんこく /非交戦国/
ひこうたい /飛行隊/
ひこうち /非公知/
ひこうちいき /飛行地域/
ひこうちゅう /飛行中/
ひこうてい /飛行艇/
ひこうにん /非公認/
ひこうびん /飛行便/
ひこうふのうじょうたい /飛行不能状態/
ひこうぶったい /飛行物体/
ひこうりつ /非効率/
ひこうりつてき /非効率的/
ひこえ /彦衛/
ひこく /被告/
ひこくがわ /被告側/
ひこくなかま /被告仲間/
ひこくにん /被告人/
ひこくみん /非国民/
ひこくみんあつかい /非国民扱い/
ひこさぶろう /彦三郎/
ひこしまぐち /彦島口/
ひこじま /彦島/
ひこじん /非個人/
ひこたろう /彦太郎/
ひこつ /腓骨/
ひこてい /非固定/
ひこてんてきこうし /非古典的光子/
ひこてんろんり /非古典論理/
ひこね /彦根/
ひこねしりつ /彦根市立/
ひこねひがし /彦根東/
ひこの /彦野/
ひこのじょう /彦之丞/
ひこばえ /蘖/
ひこぼし /彦星/
ひご /肥後/庇護/卑語/飛語/籤/籖/蜚語/
ひごう /非合/
ひごうほう /非合法/
ひごうり /非合理/
ひごうりてき /非合理的/
ひごか /庇護下/
ひごかん /非互換/
ひごかんせい /非互換性/
ひごぎんこう /肥後銀行/
ひごたのうら /肥後田浦/
ひごと /日毎/
ひごばし /肥後橋/
ひごろ /日頃/
ひさ /久/寿/尚/央/壽/
ひさあき /久昭/
ひさい /被災/
ひさいし /久石/
ひさいしゃ /被災者/
ひさいしゅうじょうたい /非最終状態/
ひさいしょういそう /非最小位相/
ひさいち /被災地/
ひさいはいふしゃ /被再配布者/
ひさえ /寿恵/久栄/久恵/寿江/
ひさお /久雄/尚勇/久男/久夫/寿男/尚夫/寿雄/尚生/寿夫/
ひさか /日阪/樋坂/桶坂/
ひさかず /久和/永和/久一/
ひさかた /久方/
ひさかたぶり /久方振/久方振り/
ひさかど /久門/
ひさかわ /久川/
ひさき /寿樹/久木/
ひさきち /久吉/
ひさく /秘策/
ひさくせい /非作成/
ひさくてきがわ /被索敵側/
ひさこ /久子/寿子/比佐子/
ひさご /瓢/匏/瓠/蠡/
ひさし /久/恒/尚/久志/寿/庇/央/寿史/壽/廂/久司/尚志/
ひさした /久下/
ひさしぶり /久し振り/久しぶり/
ひさしま /久島/
ひさたか /尚敬/
ひさだ /久田/
ひさつせん /肥薩線/
ひさと /久人/久登/尚人/尚登/
ひさとし /久敏/尚敏/
ひさとみ /久富/
ひさとめ /久留/
ひさどめ /久留/
ひさなお /久尚/
ひさなが /久永/久長/
ひさの /久野/
ひさのぶ /久信/
ひさのり /久寛/久典/寿憲/寿則/尚典/
ひさはら /久原/
ひさはる /寿春/尚玄/
ひさば /久馬/
ひさひこ /寿彦/
ひさひろ /久寛/久浩/
ひさびさ /久々/
ひさべつ /被差別/
ひさべついしき /被差別意識/
ひさべつしゃ /被差別者/
ひさべつぶらく /被差別部落/
ひさべつぶらくみん /被差別部落民/
ひさま /久馬/
ひさまつ /久松/
ひさみち /久道/
ひさみつ /久光/
ひさみつせいやく /久光製薬/
ひさみどう /久美堂/
ひさむら /久村/
ひさめ /氷雨/
ひさもと /久本/
ひさや /久屋/久弥/
ひさやま /久山/
ひさゆき /尚幸/
ひさよ /久代/
ひさよし /久佳/久吉/
ひさん /悲惨/非惨/飛散/
ひさんいつ /非散逸/
ひざ /膝/
ひざうえ /膝上/
ひざかんせつ /膝関節/
ひざがしら /膝頭/
ひざこぞう /膝小僧/
ひざし /日差し/日ざし/日射し/日差/陽射/陽射し/
ひざした /膝下/
ひざしたていど /膝下程度/
ひざまくら /膝枕/
ひざもと /ひざ元/膝元/
ひし /菱/◇/蔆/
ひしお /醤/
ひしかり /菱刈/
ひしかわ /菱川/
ひしがた /菱形/◇/
ひしきゅうすう /被死球数/
ひししょくぶつ /被子植物/
ひししょくぶつあもん /被子植物亜門/Angiospermae/
ひしせん /皮脂腺/
ひした /菱田/
ひしだ /菱田/
ひしつ /皮質/
ひしつない /皮質内/
ひしつもんしゃ /被質問者/
ひしと /緊と/犇と/
ひしぬま /菱沼/
ひしはいしゃ /被支配者/
ひしひし /緊々/犇々/
ひしまく /皮脂膜/
ひしむろ /西牟婁/
ひしゃ /飛車/扉車/
ひしゃかいしんど /被写界深度/
ひしゃかいてき /非社会的/
ひしゃかく /飛車角/
ひしゃく /柄杓/杓/
ひしゃたい /被写体/
ひしゃたいしんど /被写体深度/
ひしゅ /秘酒/匕首/脾腫/
ひしゅうきてき /非周期的/
ひしゅうぎょうしゃ /非就業者/
ひしゅうたん /非終端/
ひしゅうたんきごう /非終端記号/
ひしょ /秘書/避暑/
ひしょう /飛翔/
ひしょうかいしゃ /被紹介者/
ひしょうがいしゃ /非障害者/
ひしょうざめ /飛翔鮫/
ひしょうしゃ /非照射/
ひしょうたい /飛翔体/
ひしょうよう /非商用/
ひしょか /秘書課/秘書科/
ひしょかん /秘書官/
ひしょきかりょういき /非初期化領域/
ひしょしつ /秘書室/
ひしょじょ /非処女/
ひしょち /避暑地/
ひしん /皮疹/
ひしんしてきこうい /非紳士的行為/
ひしんしゅう /非侵襲/
ひしんしゅうてき /非侵襲的/
ひじ /肘/肱/樋地/日出/
ひじあて /肘当/
ひじうち /肘撃/
ひじかけ /肘掛/
ひじかた /土方/
ひじかたとしぞう /土方歳三/
ひじかわ /肱川/
ひじこ /非自己/
ひじこうげき /肘攻撃/
ひじせいたい /非磁性体/
ひじつようせい /非実用性/
ひじつようてき /非実用的/
ひじつりょくは /非実力派/
ひじつりょくはせんげん /非実力派宣言/
ひじてつ /肘鉄/
ひじでっぽう /肘鉄砲/
ひじどうかけん /非自動化券/
ひじみん /非自民/
ひじみんせいりょく /非自民勢力/
ひじめいかい /非自明解/
ひじゅう /比重/
ひじゅうふく /非重複/
ひじゅうふくわ /非重複和/
ひじゅつ /秘術/
ひじゅん /批准/
ひじゅんきょ /非準拠/
ひじゅんしょ /批准書/
ひじゅんせい /非純正/
ひじゅんせいたいせい /非純正体制/
ひじょ /秘女/
ひじょう /非常/非情/
ひじょうかいだん /非常階段/
ひじょうきん /非常勤/
ひじょうきんぎかん /非常勤技官/
ひじょうきんこうし /非常勤講師/
ひじょうぐち /非常口/
ひじょうしき /非常識/
ひじょうしきにん /非常識人/
ひじょうしゅだん /非常手段/
ひじょうしゅだんよう /非常手段用/
ひじょうしょく /非常食/
ひじょうしょくりょう /非常食糧/
ひじょうじ /非常時/
ひじょうじいがい /非常時以外/
ひじょうじげんそくど /非常時減速度/
ひじょうじたい /非常事態/
ひじょうじよう /非常時用/
ひじょうせいどう /非常制動/
ひじょうせん /非常線/
ひじょうていしゃ /非常停車/
ひじょうとう /非常灯/
ひじょうに /非常に/
ひじょうべる /非常ベル/
ひじょうほう /秘情報/
ひじょうほうけい /非情報系/
ひじょうほうけいがっか /非情報系学科/
ひじょうゆそうたいせい /非常輸送態勢/
ひじょうよう /非常用/
ひじょうようそうび /非常用装備/
ひじょすう /被除数/
ひじり /聖/
ひじりばし /聖橋/
ひじりばしぐち /聖橋口/
ひじんどうてき /非人道的/
ひすい /翡翠/
ひずけ /日付/日付け/
ひずみ /歪/
ひずみりつ /歪率/
ひずみりょう /歪量/
ひせい /悲悽/
ひせいきぐん /非正規軍/
ひせいぎょもじ /非制御文字/
ひせいさんてき /非生産的/
ひせいしょく /非生殖/
ひせいしょくこうい /非生殖行為/
ひせいしょくてき /非生殖的/
ひせいじ /非斉次/
ひせいじん /非成人/
ひせいそく /非正則/
ひせいてき /非静的/
ひせいほう /非正方/
ひせき /飛跡/
ひせきぶん /被積分/
ひせきぶんかんすう /被積分関数/
ひせっしょく /非接触/
ひせっしょくしき /非接触式/
ひせっていしゃしゅ /非設定車種/
ひせつぞくしゃ /被接続者/
ひせつどうこう /非摂動項/
ひせつどうこうか /非摂動効果/
ひせつどうてき /非摂動的/
ひせん /非戦/卑賤/
ひせんぎょうしゅふ /非専業主婦/
ひせんけい /非線型/非線形/
ひせんけいかいろ /非線形回路/
ひせんけいかがく /非線形科学/
ひせんけいかへんらんくほう /非線型可変ランク法/
ひせんけいかほう /非線形加法/
ひせんけいかんすう /非線型関数/
ひせんけいけい /非線型系/
ひせんけいけんきゅう /非線型研究/
ひせんけいげんしょう /非線型現象/
ひせんけいこうたい /非線型後退/
ひせんけいごうせいほうしき /非線型合成方式/
ひせんけいしゃぞう /非線型写像/
ひせんけいしょり /非線形処理/
ひせんけいせい /非線型性/非線形性/
ひせんけいせいきか /非線形正規化/
ひせんけいてき /非線形的/
ひせんけいにんしき /非線型認識/
ひせんけいへんかん /非線形変換/
ひせんけいほかん /非線型補間/
ひせんけいりきがく /非線型力学/
ひせんけいりろん /非線形理論/
ひせんでん /非宣伝/
ひせんとういん /非戦闘員/
ひせんもんか /非専門家/
ひぜに /日銭/
ひぜろ /非ゼロ/非零/
ひぜん /肥前/
ひぜんかしま /肥前鹿島/
ひぜんやまぐち /肥前山口/
ひぜんやまぐちいえん /肥前山口以遠/
ひぜんやまぐちえき /肥前山口駅/
ひそ /砒素/
ひそう /悲愴/悲壮/皮相/悲想/皮層/
ひそうかん /悲愴感/悲壮感/非相関/
ひそうかんざつおん /非相関雑音/
ひそうぞくにん /被相続人/
ひそうたいろんてき /非相対論的/
ひそうちゃく /非装着/
ひそうちゃくしゃ /非装着車/
ひそか /密/
ひそかごうぶつ /砒素化合物/
ひそかに /窃/
ひそすう /非素数/
ひそみ /顰み/
ひそんざい /非存在/
ひぞう /秘蔵/脾臓/
ひぞうか /非増加/
ひぞく /卑俗/匪賊/
ひた /日田/
ひたい /額/
ひたいいくかいけい /非体育会系/
ひたいおう /非対応/
ひたいかく /非対角/
ひたいかくこう /非対角項/
ひたいかくせいぶん /非対角成分/
ひたいしょう /非対称/
ひたいしょううお /非対象魚/
ひたいしょうぎょうれつ /非対称行列/
ひたいしょうせい /非対称性/非対象性/
ひたいしょうほうけいは /非対称方形波/
ひたいしょうまく /非対称膜/
ひたき /鶲/
ひたすら /一向/只管/頓/
ひたち /日立/常陸/肥立/
ひたちいちこう /日立一高/
ひたちえいぞう /日立映像/
ひたちおおた /常陸太田/
ひたちおおたし /常陸太田市/
ひたちかせい /日立化成/
ひたちかせいこうぎょう /日立化成工業/
ひたちきそけん /日立基礎研/
ひたちきんぞく /日立金属/
ひたちくれじっと /日立クレジット/
ひたちけい /日立系/
ひたちけいよう /日立京葉/
ひたちけんきゅうしょ /日立研究所/
ひたちけんきゅうじょ /日立研究所/
ひたちこうき /日立工機/
ひたちし /日立市/
ひたちじょうほう /日立情報/
ひたちじょし /日立女子/
ひたちせい /日立製/
ひたちせいき /日立精機/
ひたちせいさくしょ /日立製作所/
ひたちせいさくじょ /日立製作所/
ひたちぜんしゃ /日立全社/
ひたちぞうせん /日立造船/
ひたちちゅうけん /日立中研/
ひたちでんせん /日立電線/
ひたちとうほく /日立東北/
ひたちにこう /日立二高/
ひたちばん /日立版/
ひたちぶつりゅう /日立物流/
ひたちべん /日立弁/
ひたちまくせる /日立マクセル/
ひたむき /直向/
ひたん /悲嘆/悲歎/
ひたんちょう /非単調/
ひたんちょうすいろん /非単調推論/
ひたんちょうせい /非単調性/
ひたんちょうろんり /非単調論理/
ひだ /飛田/飛騨/樋田/肥田/襞/
ひだい /肥大/
ひだいか /肥大化/
ひだか /日高/肥高/
ひだかがわかん /日高川間/
ひだかけん /日高研/
ひだかちほう /日高地方/
ひだたかやま /飛騨高山/
ひだち /肥立ち/
ひだね /火種/
ひだひこやません /日田彦山線/
ひだまり /陽溜り/
ひだり /左/←/「/『/＜/（/【/
ひだりあごした /左顎下/
ひだりあし /左足/
ひだりいっぱい /左一杯/
ひだりうえ /左上/
ひだりうえすみ /左上隅/
ひだりうしろ /左後/
ひだりうで /左腕/
ひだりえだ /左枝/
ひだりかた /左肩/
ひだりかっこ /左括弧/『/
ひだりかんやくほうそく /左簡約法則/
ひだりがわ /左側/
ひだりがわしゃせん /左側車線/
ひだりがわぜんぽう /左側前方/
ひだりがわつうこう /左側通行/
ひだりがわはし /左側端/
ひだりきんぼう /左近傍/
ひだりこうほう /左後方/
ひだりこうりん /左後輪/
ひだりこし /左腰/
ひだりさいき /左再帰/
ひだりした /左下/
ひだりしたすみ /左下隅/
ひだりしゃせん /左車線/
ひだりず /左図/
ひだりぜんぶ /左前部/
ひだりぜんぽう /左前方/
ひだりぜんりん /左前輪/
ひだりそくほう /左側方/
ひだりだしゃ /左打者/
ひだりだせき /左打席/
ひだりづめ /左詰め/
ひだりて /左手/
ひだりていち /左手位置/
ひだりてくび /左手首/
ひだりてこゆび /左手小指/
ひだりてなかゆび /左手中指/
ひだりてぶ /左手部/
ひだりてまえ /左手前/
ひだりてんかい /左転回/
ひだりとうしゅ /左投手/
ひだりどうろわき /左道路脇/
ひだりどなり /左隣/
ひだりなげ /左投げ/
ひだりのり /左乗/
ひだりはし /左端/
ひだりはじ /左端/
ひだりはんぶん /左半分/
ひだりはんめん /左半面/
ひだりひざ /左膝/
ひだりひじ /左肘/
ひだりふともも /左太股/
ひだりぶぶん /左部分/
ひだりぶんき /左分岐/
ひだりほうこう /左方向/
ひだりほほ /左頬/
ひだりまえ /左前/
ひだりまえあし /左前足/左前脚/
ひだりまわり /左回り/
ひだりみぎはし /左右端/
ひだりみみ /左耳/
ひだりむき /左向き/
ひだりむね /左胸/
ひだりめ /左目/
ひだりめよう /左目用/
ひだりや /←/
ひだりやじるし /左矢印/←/
ひだりよう /左用/
ひだりようそ /左要素/
ひだりよこ /左横/
ひだりより /左寄/左寄り/
ひだりわき /左脇/
ひだん /被弾/
ひだんせい /非弾性/
ひだんせいさんらん /非弾性散乱/
ひだんせいさんらんだんめんせき /非弾性散乱断面積/
ひだんせいしょうとつ /非弾性衝突/
ひちくじょう /肥畜場/
ひちそう /七宗/
ひちゃくよう /非着用/
ひちゅう /秘中/
ひちょうようしゃ /被徴用者/
ひちょくせん /非直線/
ひちょくせんせい /非直線性/
ひちょっこう /非直交/
ひちょっこうきてい /非直交基底/
ひちょっこうけい /非直交系/
ひちりき /篳篥/
ひっ /必/
ひっか /筆禍/
ひっかけ /引っ掛け/
ひっき /筆記/
ひっきぐ /筆記具/
ひっきしけん /筆記試験/
ひっきたい /筆記体/
ひっきょう /畢竟/
ひっきようぐ /筆記用具/
ひっけい /必携/
ひっけいぼん /必携本/
ひっけん /必見/
ひっこし /引越し/引っ越し/引越/
ひっこしさき /引越先/
ひっこしだい /引越し代/
ひっこみ /引込み/
ひっさつ /必殺/
ひっさつしかけにん /必殺仕掛人/
ひっさつしごとにん /必殺仕事人/
ひっさつわざ /必殺技/
ひっさん /筆算/
ひっし /必死/必至/
ひっしゃ /筆者/筆写/
ひっしゅう /必修/必習/
ひっしゅうかもく /必修科目/
ひっしゅうたんい /必修単位/
ひっしゅうなんたんい /必修何単位/
ひっしょう /必勝/
ひっしょうこうざ /必勝講座/
ひっしょうたいせい /必勝体制/
ひっしょうほう /必勝法/
ひっしょうぼん /必勝本/
ひっす /必須/
ひっすい /必衰/
ひっすう /必須/
ひっすかく /必須格/
ひっすじこう /必須事項/
ひっすじょうけん /必須条件/
ひっすじょうしき /必須常識/
ひっせい /畢生/
ひっせき /筆跡/筆迹/
ひっそく /逼塞/
ひっち /筆致/
ひっちゃく /必着/
ひっちゅう /必中/筆誅/
ひっちょう /必聴/
ひっちょうばん /必聴盤/
ひっちょうもの /必聴物/
ひってき /匹敵/
ひっと /ヒット/
ひっとう /筆頭/筆答/
ひっとうしゃ /筆頭者/
ひっぱい /必敗/
ひっぱく /逼迫/
ひっぱつ /必発/
ひっぱり /引張/
ひっぽう /筆法/筆鋒/
ひつ /必/筆/逼/弼/畢/泌/匹/疋/櫃/篳/謐/蹕/
ひつあつ /筆圧/
ひつう /悲痛/
ひつぎ /棺/柩/
ひつけやく /火付け役/
ひつじ /羊/未/日辻/
ひつじかい /羊飼い/
ひつじさる /坤/
ひつじゅ /必需/
ひつじゅひん /必需品/
ひつじゅん /筆順/
ひつじょう /必定/
ひつぜつ /筆舌/
ひつぜん /必然/□/謐然/
ひつぜんか /必然化/
ひつぜんせい /必然性/
ひつぜんてき /必然的/
ひつぜんてきうんめい /必然的運命/
ひつだん /筆談/
ひつどく /必読/
ひつにょう /泌尿/
ひつねい /謐寧/
ひつば /弼馬/
ひつひつ /謐謐/
ひつめい /筆名/
ひつよう /必要/必用/
ひつようあく /必要悪/
ひつようあくてき /必要悪的/
ひつよういじょう /必要以上/
ひつようかんきりょう /必要換気量/
ひつようがく /必要額/
ひつようけいひ /必要経費/
ひつようげんど /必要限度/
ひつようこうせい /必要構成/
ひつようさいしょうげん /必要最小限/
ひつようさいてい /必要最低/
ひつようさいていげん /必要最低限/
ひつようさいていげんど /必要最低限度/
ひつようしょるい /必要書類/
ひつようじこう /必要事項/
ひつようじゅうぶん /必要十分/必要充分/
ひつようじゅうぶんじょうけん /必要十分条件/
ひつようじゅうぶんせい /必要十分性/
ひつようじょう /必要上/
ひつようじょうけん /必要条件/
ひつようせい /必要性/
ひつようど /必要度/
ひつような /必要な/
ひつようなし /必要無/
ひつようふかけつ /必要不可欠/
ひつようぶすう /必要部数/
ひつようぶぶん /必要部分/
ひつようぶん /必要分/
ひつようまいすう /必要枚数/
ひつようようし /必要用紙/
ひつようりょう /必要量/
ひつりつ /篳篥/
ひつりょく /筆力/
ひづけ /日付/日付け/
ひづけいん /日付印/
ひづけしょしき /日付書式/
ひづけじゅん /日付順/
ひづけそうさかんすう /日付操作関数/
ひづけへんこうせん /日付変更線/
ひづけよやく /日付予約/
ひづめ /蹄/
ひてい /否定/¬/飛程/
ひていいけん /否定意見/
ひていきてき /非定期的/
ひていざいりょう /否定材料/
ひていじたい /否定自体/
ひていじょう /非定常/
ひていじょうおん /非定常音/
ひていじょうかんきょうか /非定常環境下/
ひていじょうせい /非定常性/
ひていじょうそうおん /非定常騒音/
ひていじょうてき /非定常的/
ひていてき /否定的/
ひていてきいみ /否定的意味/
ひていてきけつろん /否定的結論/
ひていてきたちば /否定的立場/
ひていてきひょうか /否定的評価/
ひていは /否定派/
ひていひょうじゅんけい /否定標準形/
ひていひょうじゅんけいろんりしき /否定標準形論理式/
ひていぶん /否定文/
ひていろん /否定論/
ひてきごう /非適合/
ひてつ /非鉄/
ひてつづき /非手続き/
ひてんけいかく /飛天計劃/
ひてんしゃりょういき /非転写領域/
ひてんしゅうさ /非点収差/
ひで /英/秀/映/
ひであき /秀昭/英明/秀明/英昭/英亮/秀章/英朗/
ひでいち /秀市/
ひでお /英生/英男/秀雄/英夫/英朗/英雄/秀生/秀男/秀夫/日出男/日出夫/秀郎/周男/映夫/
ひでおき /秀起/
ひでか /秀香/秀加/
ひでかず /秀和/英一/秀一/英和/
ひでかつ /秀勝/英勝/
ひでき /秀樹/英紀/英樹/秀紀/秀記/秀規/秀貴/秀起/偉紀/秀己/
ひできち /秀吉/
ひできよ /英清/
ひでこ /秀子/英子/
ひでさく /秀作/
ひでさち /秀幸/
ひでさと /秀郷/
ひでし /日出志/
ひでじ /秀司/英司/
ひでずみ /秀純/
ひでぞう /秀三/
ひでたか /秀隆/英孝/栄孝/秀孝/秀貴/
ひでただ /秀忠/
ひでたつ /英辰/
ひでつぐ /秀次/秀嗣/
ひでと /秀人/英人/秀仁/日出登/
ひでとし /英俊/秀敏/英敏/秀年/秀利/
ひでとも /秀智/英智/
ひでなお /秀尚/
ひでのぶ /英信/秀信/
ひでのり /英則/秀紀/秀則/英典/英憲/秀典/英紀/
ひではる /英晴/英治/
ひでひこ /英彦/秀彦/
ひでひさ /秀寿/
ひでひと /英仁/秀仁/
ひでひろ /英裕/秀浩/秀宏/秀博/英宏/
ひでふみ /秀文/
ひでまる /秀丸/
ひでみ /秀美/英巳/英美/英実/秀実/
ひでみつ /英光/秀光/
ひでもと /秀基/
ひでや /秀哉/英哉/英也/秀也/日出谷/
ひでやす /秀康/秀育/英育/
ひでゆき /秀之/英之/英幸/英行/秀幸/秀行/
ひでよ /英世/秀世/
ひでよし /秀善/秀吉/
ひでより /秀頼/
ひでり /日照り/旱/魃/
ひでろう /秀郎/
ひでん /秘伝/
ひでんか /非電化/比電荷/
ひでんかく /非電化区/
ひでんかくかん /非電化区間/
ひでんかせんく /非電化線区/
ひでんかろせん /非電化路線/
ひでんこうかい /秘伝公開/
ひでんし /非電子/
ひでんしゃ /被伝者/
ひと /人/一/仁/史/ヒト/壱/女/他人/弌/壹/
ひとあいて /人相手/
ひとあき /仁明/
ひとあし /一足/
ひとあじ /一味/
ひとあせ /一汗/
ひとあつめ /人集め/
ひとあな /一穴/
ひとあんしん /一安心/
ひといがい /人以外/
ひといき /一息/
ひといじょう /人以上/
ひといちばい /人一倍/
ひとう /秘湯/
ひとうか /非透過/
ひとうけつろ /非凍結路/
ひとうじこく /非当時国/
ひとうひょうしゃ /被投票者/
ひとうひょうば /被投票馬/
ひとうぶんへいきんりつ /非等分平均率/
ひとうほうさんらん /非等方散乱/
ひとえ /一重/単/單/
ひとえき /一駅/
ひとえきぶん /一駅分/
ひとかい /人買い/
ひとかげ /人影/
ひとかぞく /一家族/
ひとかど /一廉/
ひとからげ /一絡/
ひとかわ /一皮/
ひとかん /一缶/
ひとがき /人垣/
ひとがた /人型/
ひとがら /人柄/
ひとがんばり /一頑張り/
ひときり /人斬り/
ひとく /秘匿/
ひとくい /人食/非特異/
ひとくいじんしゅ /人喰い人種/
ひとくぎり /一区切り/
ひとくせい /秘匿性/
ひとくち /一口/
ひとくちだい /一口大/
ひとくちめ /一口目/
ひとくふう /一工夫/
ひとくみ /一組/
ひとくら /一庫/
ひとくろう /一苦労/
ひとけ /人気/
ひとけた /一桁/1桁/
ひとけため /1桁目/
ひとこえ /一声/
ひとこきゅう /一呼吸/
ひとこじん /人個人/
ひとこと /一言/
ひとことちゅうい /一言注意/
ひとことふたこと /一言二言/
ひとこま /一齣/
ひところ /一頃/ひと頃/
ひとごころ /人心/
ひとごと /人事/他人事/
ひとごみ /人混み/人混/
ひとさしゆび /人差指/人指し指/人差し指/
ひとさま /人様/
ひとさら /一皿/
ひとざいさん /一財産/
ひとざと /人里/
ひとし /仁/等/均/仁志/準/仁司/斉/倫/斎/仁史/
ひとしい /等しい/
ひとしお /一入/
ひとしごと /一仕事/
ひとしだい /人次第/
ひとしな /一品/
ひとしなみ /等し並み/
ひとしょうぶ /一勝負/
ひとしれず /人知れず/
ひとじしん /人自身/
ひとじたい /人自体/
ひとじち /人質/
ひとじちかいほう /人質解放/
ひとじちしゃくほう /人質釈放/
ひとじちせんじゅつ /人質戦術/
ひとじに /人死/
ひとすじ /一筋/
ひとすじなわ /一筋縄/
ひとせだい /一世代/
ひとせだいまえ /一世代前/
ひとぜんいん /人全員/
ひとぜんたい /人全体/
ひとたち /人達/
ひとたば /一束/
ひとたび /一度/
ひとたま /一玉/
ひとたまり /一溜り/
ひとだかり /人集り/
ひとだすけ /人助け/
ひとだま /人魂/
ひとだんらく /一段落/
ひとちがい /人違い/
ひとつ /一つ/１つ/非凸/1つ/
ひとつき /一月/
ひとつきいじょう /一月以上/
ひとつきいじょうまえ /一月以上前/
ひとつきいない /一月以内/
ひとつきはん /一月半/
ひとつきぶん /一月分/
ひとつきほど /一月程/
ひとつぎ /一木/
ひとつばし /一橋/一ッ橋/一ツ橋/
ひとつばしだい /一橋大/
ひとつばしだいがく /一橋大学/
ひとつばしだいじょきょうじゅ /一橋大助教授/
ひとつひとつ /一つ一つ/１つひとつ/
ひとつぶ /一粒/
ひとつまつ /一松/
ひとつまみ /一摘み/
ひとつめ /一つ目/一つめ/
ひとつら /一行/一列/一連/
ひとづかい /人使い/
ひとづま /人妻/
ひとていど /人程度/
ひとで /人手/人出/
ひとでじょうきょう /人出状況/
ひとでぶそく /人手不足/
ひととおり /一通り/
ひととき /一時/
ひととせ /一年/稘/
ひととなり /為人/
ひとどうし /人同志/人同士/
ひとどおり /人通り/
ひとなど /人等/
ひとなみ /人波/人並/
ひとなみいじょう /人並以上/
ひとなり /仁成/
ひとにぎり /一握り/
ひとのみ /一飲み/
ひとはこ /一箱/
ひとはこぶん /一箱分/
ひとはしり /一走り/
ひとはた /一旗/
ひとはだ /人肌/
ひとはらん /一波乱/
ひとばしら /人柱/
ひとばん /一晩/
ひとばんいじょう /一晩以上/
ひとばんご /一晩後/
ひとばんじゅう /一晩中/
ひとぱっく /一パック/
ひとひとり /人一人/
ひとひねり /一捻り/一ひねり/
ひとひら /一片/一枚/
ひとびと /人々/人びと/
ひとふくろ /一袋/
ひとふで /一筆/
ひとふでがき /一筆書き/一筆書/
ひとぶそく /人不足/
ひとへや /一部屋/
ひとま /一間/
ひとまえ /人前/
ひとまく /一幕/
ひとまね /人真似/
ひとまろ /人麻呂/人麿/一麿/
ひとまわり /一回り/
ひとみ /瞳/仁美/人見/一美/
ひとみきねんかん /人見記念館/
ひとみきねんこうどう /人見記念講堂/
ひとみごくう /人身御供/
ひとみしり /人見知り/
ひとみすいしょう /瞳水晶/
ひとむかし /一昔/
ひとむかしまえ /一昔前/
ひとむね /一棟/
ひとむら /一叢/
ひとめ /人目/一目/ひと眼/
ひとめいわく /人迷惑/
ひとめぼれ /一目惚れ/
ひともじ /一文字/人文字/
ひともなげ /人も無げ/
ひともんちゃく /一悶着/
ひとやく /一役/
ひとやすみ /一休み/
ひとやま /一山/
ひとよ /一夜/
ひとよぎり /一節切/
ひとよし /人吉/
ひとり /一人/１人/独り/独/獨り/1人/
ひとりあそび /一人遊び/
ひとりあたり /一人当/
ひとりあるき /一人歩き/
ひとりいじょう /一人以上/
ひとりいちだい /一人一台/
ひとりいっさつ /一人一殺/
ひとりうき /一人浮き/
ひとりうち /一人打ち/
ひとりがてん /独り合点/
ひとりくらい /一人位/
ひとりぐらし /一人暮らし/
ひとりごと /独り言/一人言/
ひとりしずみ /一人沈み/
ひとりしばい /一人芝居/
ひとりじかんさ /一人時間差/
ひとりじめ /一人占め/独り占め/
ひとりずまい /一人住まい/
ひとりせんよう /一人専任/
ひとりたび /一人旅/
ひとりだち /一人立/
ひとりっこ /一人っ子/
ひとりのり /一人乗り/
ひとりひとり /一人一人/
ひとりぶたい /一人舞台/
ひとりぶん /一人分/
ひとりべや /一人部屋/
ひとりぼっち /一人法師/
ひとりむすこ /一人息子/
ひとりむすめ /一人娘/
ひとりめ /一人目/
ひとりよう /一人用/
ひとりよがり /独り善がり/一人善がり/
ひどう /非道/
ひどうき /非同期/
ひどうきがた /非同期型/
ひどうきしき /非同期式/
ひどうきしきけいさん /非同期式計算/
ひどうきしきつうしん /非同期式通信/
ひどうきしょり /非同期処理/
ひどうきたんまつ /非同期端末/
ひどうきつうしん /非同期通信/
ひどうきてき /非同期的/
ひどうきどうさ /非同期動作/
ひどうさじ /非動作時/
ひどうじ /非同時/
ひどうとくてき /非道徳的/
ひどのらか /ヒドノラ科/Hydnoraceae/
ひどらすちすあか /ヒドラスチス亜科/Hydrastidoideae/
ひどり /日取り/
ひどろすたきすもく /ヒドロスタキス目/Hydrostachydales/
ひな /雛/鄙/
ひない /比内/
ひないどり /比内鶏/
ひながた /雛型/雛形/ひな形/ひな型/
ひなこ /日向子/日名子/比奈子/
ひなずし /雛鮨/
ひなせ /日生/
ひなた /日向/
ひなどり /雛鳥/
ひなまつり /雛祭/
ひなもと /雛元/
ひならず /日ならず/
ひならずして /日ならずして/
ひなわじゅう /火縄銃/
ひなん /非難/避難/
ひなんかのうせい /非難可能性/
ひなんかんこく /避難勧告/
ひなんきじ /非難記事/
ひなんくんれん /避難訓練/
ひなんけつぎ /非難決議/
ひなんごや /避難小屋/
ひなんさき /避難先/
ひなんじょ /避難所/
ひなんばしょ /避難場所/
ひにく /皮肉/髀肉/
ひにくきじ /皮肉記事/
ひにげんてき /非人間的/
ひにち /日々/日日/日にち/
ひにちじょう /非日常/
ひにちじょうせい /非日常性/
ひにちじょうてき /非日常的/
ひにほんご /非日本語/
ひにゅう /泌乳/
ひにん /非人/否認/避妊/
ひにんげん /非人間/
ひにんげんてき /非人間的/
ひにんしょう /非人称/
ひにんほう /避妊法/
ひね /陳/
ひねこびる /陳こびる/
ひねしょうが /陳生姜/
ひねつ /比熱/
ひねの /日根野/
ひねり /捻り/
ひの /日野/火野/樋野/
ひのいり /日入/
ひのうりつてき /非能率的/
ひのえ /丙/
ひのえいぬ /丙戌/
ひのえうま /丙午/
ひのえさる /丙申/
ひのえたつ /丙辰/
ひのえとら /丙寅/
ひのえね /丙子/
ひのえまた /桧枝岐/檜枝岐/
ひのおか /日ノ岡/
ひのかげ /日之影/
ひのき /桧/檜/
ひのきぶたい /桧舞台/
ひのくち /樋ノ口/
ひのくま /日隈/
ひのこ /火の粉/
ひのし /日野市/
ひのじどうしゃ /日野自動車/
ひのたま /火の玉/
ひので /日の出/日出/日之出/
ひのでじょし /日出女子/
ひのでじょしがくえん /日出女子学園/
ひのと /丁/
ひのとい /丁亥/
ひのとう /丁卯/
ひのとうし /丁丑/
ひのととり /丁酉/
ひのとひつじ /丁未/
ひのとみ /丁巳/
ひのとり /火の鳥/
ひのはら /桧原/
ひのはる /日之春/
ひのばし /日野橋/
ひのべ /日延べ/
ひのまる /日の丸/
ひのみさき /日御崎/
ひのめ /日の目/
ひのもと /日の本/
ひはかいけんさ /非破壊検査/
ひはく /皮帛/
ひはなち /樋放/
ひはら /日原/
ひはん /批判/
ひはんいがい /批判以外/
ひはんかくご /批判覚悟/
ひはんきじ /批判記事/
ひはんしゃ /批判者/
ひはんせいしん /批判精神/
ひはんせいりょく /批判勢力/
ひはんたいしょう /批判対象/
ひはんたいは /非反対派/
ひはんてき /批判的/
ひはんてきいけん /批判的意見/
ひはんてきしつもん /批判的質問/
ひはんてきしゅちょう /批判的主張/
ひはんひょう /批判票/
ひはんりゆう /批判理由/
ひはんりょく /批判力/
ひば /比婆/
ひばい /非売/
ひばいひん /非売品/
ひばく /被曝/被爆/飛瀑/被縛/
ひばくしゃ /被曝者/被爆者/
ひばくしゃさべつ /被曝者差別/被爆者差別/
ひばくしゃほご /被爆者保護/
ひばくせんりょうけい /被曝線量計/
ひばくち /被爆地/
ひばくりょう /被曝量/被爆量/
ひばし /火箸/
ひばしら /火柱/
ひばち /火鉢/
ひばな /火花/
ひばら /桧原/檜原/脾腹/
ひばらむら /桧原村/
ひばり /雲雀/
ひばん /非番/
ひひ /狒狒/比比/霏霏/
ひひょう /批評/
ひひょうか /批評家/
ひひょうき /批評器/
ひひょうげんてき /非表現的/
ひひょうし /批評誌/
ひひょうしゃ /批評者/
ひひょうじ /非表示/
ひひょうじゅん /非標準/
ひひょうじゅんかいせき /非標準解析/
ひひょうじゅんろんり /非標準論理/
ひび /日々/日比/日日/皸/皹/罅/
ひびき /響き/響/
ひびの /日比野/
ひびや /日比谷/
ひびやえき /日比谷駅/
ひびやこうえん /日比谷公園/
ひびやこくさい /日比谷国際/
ひびやせん /日比谷線/
ひびやせんちょくつう /日比谷線直通/
ひびやせんない /日比谷線内/
ひびやとしょかん /日比谷図書館/
ひびややおん /日比谷屋音/日比谷野音/
ひびややがいおんがくどう /日比谷野外音楽堂/
ひびようかんこくじん /被徴用韓国人/
ひふ /皮膚/非負/
ひふえん /皮膚炎/
ひふか /皮膚科/
ひふかい /皮膚科医/
ひふかがく /皮膚科学/
ひふかがくしんだん /皮膚科学診断/
ひふがん /皮膚癌/
ひふく /被服/被覆/
ひふくき /被覆木/
ひふくきん /腓腹筋/
ひふくぎ /被覆木/
ひふくざい /被覆材/
ひふくりつ /被覆率/
ひふこう /非負項/
ひふごうご /非符号語/
ひふせいすう /非負整数/
ひふそしき /皮膚組織/
ひふち /非負値/
ひふていち /非不定値/非負定値/
ひふびょう /皮膚病/
ひふみ /一二三/日文/
ひふやく /皮膚薬/
ひふん /悲憤/
ひふんこうがい /悲憤慷慨/
ひぶ /日歩/
ひぶそう /非武装/
ひぶそうちたい /非武装地帯/
ひぶそうちゅうりつ /非武装中立/
ひぶた /火蓋/
ひぶつりてき /非物理的/
ひぶん /非文/碑文/
ひぶんかつ /非分割/
ひぶんかてき /非文化的/
ひぶんさんせい /非分散性/
ひぶんせきてきしゅほう /非分析的手法/
ひぶんは /非文派/
ひぶんめいてき /非文明的/
ひへい /疲弊/
ひへいこう /非平衡/
ひへいこうけい /非平衡系/
ひへいこうじょうたい /非平衡状態/
ひへいそく /非閉塞/
ひへいそくせい /非閉塞性/
ひへいわてきじょうたい /非平和的状態/
ひへん /炸/
ひほう /秘宝/悲報/秘法/
ひほうしゃせい /非放射性/
ひほうわ /非飽和/
ひほけんしゃ /被保険者/
ひほしょく /被補食/
ひほじ /非保持/
ひほんご /日本語/
ひほんしつてき /非本質的/
ひぼう /誹謗/篦棒/
ひぼうちゅうしょう /誹謗中傷/
ひぼうりょく /非暴力/
ひぼうりょくていこう /非暴力抵抗/
ひぼし /日干/
ひぼたん /緋牡丹/
ひぼん /非凡/
ひま /暇/閑/隙/蝦/
ひまく /皮膜/被膜/
ひまし /日増し/
ひましゆ /蓖麻子油/
ひまじん /暇人/閑人/
ひまつ /飛沫/
ひまつぶし /暇潰し/
ひまつり /火祭/
ひまわり /向日葵/
ひまん /肥満/
ひまんがた /肥満型/
ひまんたい /肥満体/
ひまんたんどらか /ヒマンタンドラ科/Himantandraceae/
ひみ /氷見/
ひみこ /卑弥呼;3世紀ごろの邪馬台国の女王/日美子/
ひみせん /氷見線/
ひみつ /秘密/
ひみつかい /秘密会/
ひみつかいだん /秘密会談/
ひみつきち /秘密基地/
ひみつけっしゃ /秘密結社/
ひみつげんしゅ /秘密厳守/
ひみつしゅうかい /秘密集会/
ひみつしゅぎ /秘密主義/
ひみつしれい /秘密指令/
ひみつそうび /秘密装備/
ひみつそしき /秘密組織/
ひみつたいいん /秘密隊員/
ひみつたんてい /秘密探偵/
ひみつちょうさいん /秘密調査員/
ひみつとうひょう /秘密投票/
ひみつど /秘密度/
ひみつへいき /秘密兵器/
ひみつほじけいやく /秘密保持契約/
ひみつぼん /秘密本/
ひみつり /秘密裏/
ひみょう /秘妙/
ひみん /卑民/
ひみんしゅこっか /非民主国家/
ひみんしゅせい /非民主性/
ひみんしゅてき /非民主的/
ひむかい /日向/
ひむら /日村/
ひむろ /氷室/
ひむろさえこ /氷室冴子/
ひめ /姫/媛/
ひめい /悲鳴/
ひめかいどう /姫街道/
ひめかわ /姫川/
ひめがわ /姫川/
ひめき /姫木/
ひめぎみ /姫君/
ひめこ /姫子/
ひめさま /姫様/
ひめしま /姫島/
ひめしんせん /姫新線/
ひめじ /姫路/
ひめじえき /姫路駅/
ひめじかん /姫路間/
ひめじし /姫路市/
ひめじししらはまちょう /姫路市白浜町/
ひめじじょう /姫路城/
ひめじどっきょうだいがく /姫路獨協大学/姫路独協大学/
ひめじはつ /姫路発/
ひめじひがし /姫路東/
ひめじほうめん /姫路方面/
ひめじま /姫嶋/
ひめど /姫戸/
ひめの /姫野/
ひめのき /姫乃樹/
ひめのぎ /姫乃樹/姫丿樹/
ひめみや /姫宮/
ひめん /罷免/
ひめんけん /罷免権/
ひも /紐/綬/
ひもう /被毛/
ひもく /費目/皮目/
ひもくべつ /費目別/
ひもじ /火文字/
ひもじょう /紐状/
ひもち /日持ち/
ひもと /火元/
ひもとせきにんしゃ /火元責任者/
ひもの /干物/
ひもよう /紐用/
ひもんや /碑文谷/
ひゃく /百/岶/襞/辟/珀/
ひゃくい /百位/
ひゃくえん /百円/
ひゃくえんだま /百円玉/
ひゃくえんらいたー /百円ライター/
ひゃくおく /百億/
ひゃくがい /百害/
ひゃくぎょう /百行/
ひゃくげん /百元/
ひゃくごぎんこう /百五銀行/
ひゃくしきしてい /百式司偵/
ひゃくしきゆそうき /百式輸送機/
ひゃくしゅうねん /百周年/
ひゃくしゅつ /百出/
ひゃくしょう /百姓/百勝/
ひゃくしょういっき /百姓一揆/
ひゃくしょうよみ /百姓読み/
ひゃくじゅう /百獣/
ひゃくじゅうおう /百獣王/
ひゃくすうじゅう /百数十/
ひゃくすうじゅうにん /百数十人/
ひゃくせん /百選/百戦/
ひゃくせんれんま /百戦錬磨/百戦練磨/
ひゃくそく /百足/
ひゃくたけ /百武/
ひゃくたたき /百叩き/
ひゃくたろう /百太郎/
ひゃくだいいじょう /百台以上/
ひゃくてんまんてん /百点満点/
ひゃくにじゅうにち /百二十日/
ひゃくにちぜき /百日咳/
ひゃくにん /百人/
ひゃくにんいじょう /百人以上/
ひゃくにんいっしゅ /百人一首/
ひゃくにんぎり /百人斬り/
ひゃくにんちょう /百人町/
ひゃくにんひゃくよう /百人百様/
ひゃくにんりき /百人力/
ひゃくねん /百年/
ひゃくねんまえ /百年前/
ひゃくばい /百倍/
ひゃくぶん /百聞/百分/
ひゃくぶんひ /百分比/
ひゃくぶんりつ /百分率/
ひゃくまい /百枚/
ひゃくまた /百又/
ひゃくまん /百万/
ひゃくまんえん /百万円/
ひゃくまんえんいか /百万円以下/
ひゃくまんえんぜんご /百万円前後/
ひゃくまんかい /百万回/
ひゃくまんごく /百万石/
ひゃくまんだい /百万台/
ひゃくまんにん /百万人/
ひゃくまんねん /百万年/
ひゃくまんべん /百万遍/
ひゃくまんりょう /百万両/百萬両/
ひゃくめいざん /百名山/
ひゃくもじ /百文字/
ひゃくものがたり /百物語/
ひゃくやく /百薬/
ひゃくり /百里/
ひゃくれつ /百裂/
ひゃくれんぱつ /百連発/
ひゃっか /百科/百家/百花/百貨/
ひゃっかい /百回/
ひゃっかじてん /百科事典/百科辞典/
ひゃっかぜんしょ /百科全書/
ひゃっかぜんしょか /百科全書家/
ひゃっかそうめい /百家争鳴/
ひゃっかてん /百貨店/
ひゃっかてんがた /百貨店型/
ひゃっかてんしき /百貨店式/
ひゃっかりょうらん /百花繚乱/
ひゃっかん /百貫/
ひゃっき /百鬼/
ひゃっきえん /百鬼園/
ひゃっきやぎょう /百鬼夜行/
ひゃっきやこう /百鬼夜行/
ひゃっけん /百間/百見/
ひゃっぱつ /百発/
ひゃっぱつひゃくちゅう /百発百中/
ひゃっぴょう /百票/
ひゃっぽ /百歩/
ひやあせ /冷汗/(^_^；/(concat "(^_^\073)")/
ひやく /飛躍/秘薬/
ひやくてき /飛躍的/
ひやくてきしんてん /飛躍的進展/
ひやけ /日焼け/日焼/
ひやけどめ /日焼止め/
ひやとい /日雇い/
ひやま /日山/桧山/樋山/檜山/
ひやみず /冷水/
ひやみづ /冷水/
ひやむぎ /冷麦/
ひややっこ /冷奴/
ひゅーまん /ヒューマン/
ひゅーむかん /ヒューム管/
ひゅうが /日向/
ひゅうま /飛雄馬/
ひゆ /比喩/譬喩/
ひゆうきてき /非有機的/
ひゆうり /非有理/
ひゆてき /比喩的/
ひゆひょうげん /比喩表現/
ひゆりかい /比喩理解/
ひょう /表/票/評/豹/標/氷/瓢/漂/彪/剽/俵/憑/兵/平/雹/冫/冰/凭/嫖/慓/殍/縹/飄/飃/飆/馮/驃/驫/髟/拍/Table/
ひょうあつめ /票集/
ひょうい /表意/憑依/
ひょういきのう /表意機能/
ひょういてき /表意的/
ひょういもじ /表意文字/
ひょういもじてき /表意文字的/
ひょういれ /票入/
ひょうえ /兵衛/
ひょうおん /表音/氷温/
ひょうおんご /表音語/
ひょうおんせい /表音性/
ひょうおんてき /表音的/
ひょうおんぶん /表音文/
ひょうおんもじ /表音文字/
ひょうおんもじせい /表音文字性/
ひょうおんもじてき /表音文字的/
ひょうか /評価/瓢果/氷菓/
ひょうかい /氷解/氷塊/氷海/
ひょうかいがい /評価以外/
ひょうかおち /評価落/
ひょうかかいせき /評価解析/
ひょうかかかく /評価価格/
ひょうかかんきょう /評価環境/
ひょうかかんすう /評価関数/
ひょうかがく /評価学/
ひょうかき /評価器/評価機/評価期/
ひょうかきじ /評価記事/
ひょうかきじゅん /評価基準/
ひょうかきそく /評価規則/
ひょうかぎじゅつ /評価技術/
ひょうかぎほう /評価技法/
ひょうかけい /評価系/
ひょうかけっか /評価結果/
ひょうかけんきゅうしつ /評価研究室/
ひょうかご /評価後/評価語/
ひょうかごさ /評価誤差/
ひょうかしえん /評価支援/
ひょうかしき /評価式/
ひょうかしけん /評価試験/
ひょうかししん /評価指針/
ひょうかしゃ /評価者/
ひょうかしゃくど /評価尺度/
ひょうかじっけん /評価実験/
ひょうかじゅんい /評価順位/
ひょうかじゅんじょ /評価順序/
ひょうかじょうけん /評価条件/
ひょうかず /評価図/
ひょうかせいど /評価制度/
ひょうかたいしょう /評価対象/
ひょうかち /評価値/
ひょうかてき /評価的/
ひょうかてん /評価点/
ひょうかてんすう /評価点数/
ひょうかのうりょく /評価能力/
ひょうかばん /評価版/
ひょうかふのう /評価不能/
ひょうかぶ /評価部/
ひょうかほう /評価法/
ひょうかほうしき /評価方式/
ひょうかほうほう /評価方法/
ひょうかよう /評価用/
ひょうかりょう /評価量/
ひょうが /氷河/
ひょうがき /氷河期/
ひょうがじだい /氷河時代/
ひょうがじょう /氷河上/
ひょうがわ /豹皮/
ひょうき /表記/標記/兵機/氷期/
ひょうきけんきゅうしゅうかい /標記研究集会/
ひょうきこうしゅうかい /標記講習会/
ひょうきじたい /表記自体/
ひょうきじょう /表記上/
ひょうきたいけい /表記体系/
ひょうきほう /表記法/
ひょうきほうほう /表記方法/
ひょうきょ /憑拠/
ひょうきよう /表記用/
ひょうきん /剽軽/標金/
ひょうぎ /評議/評議会/
ひょうぎいいんかい /評議委員会/
ひょうぎいん /評議員/
ひょうぎかい /評議会/
ひょうぎん /兵銀/
ひょうぐ /表具/
ひょうぐみ /表組み/
ひょうけい /表敬/
ひょうけいさん /表計算/
ひょうけいさんきのう /表計算機能/
ひょうけいしき /表形式/
ひょうけつ /氷結/票決/表決/評決/
ひょうけん /憑肩/憑険/
ひょうけんさく /表検索/
ひょうげん /表現/
ひょうげんいぜん /表現以前/
ひょうげんかつどう /表現活動/
ひょうげんかのう /表現可能/
ひょうげんかのうせい /表現可能性/
ひょうげんかのうせいていり /表現可能性定理/
ひょうげんきのう /表現機能/
ひょうげんぎほう /表現技法/
ひょうげんぎょうれつ /表現行列/
ひょうげんけい /表現系/表現型/
ひょうげんけいしき /表現形式/
ひょうげんけいたい /表現形態/
ひょうげんご /表現語/
ひょうげんしき /表現式/
ひょうげんしゃ /表現者/
ひょうげんしゅだん /表現手段/
ひょうげんしゅほう /表現手法/
ひょうげんじたい /表現自体/
ひょうげんじょう /表現上/
ひょうげんぜんたい /表現全体/
ひょうげんだんあつ /表現弾圧/
ひょうげんちょう /表現長/
ひょうげんてき /表現的/
ひょうげんない /表現内/
ひょうげんないよう /表現内容/
ひょうげんのうりょく /表現能力/
ひょうげんふかのう /表現不可能/
ひょうげんほう /表現法/
ひょうげんほうほう /表現方法/
ひょうげんもじれつ /表現文字列/
ひょうげんよく /表現欲/
ひょうげんりょく /表現力/
ひょうげんりょくぶそく /表現力不足/
ひょうげんろん /表現論/
ひょうこう /標高/
ひょうこうさ /標高差/
ひょうご /標語/兵庫/
ひょうごけん /兵庫県/
ひょうごけんかすみちょう /兵庫県香住町/
ひょうごけんたけのちょう /兵庫県竹野町/
ひょうごけんちょう /兵庫県庁/
ひょうごけんにしのみやし /兵庫県西宮市/
ひょうごけんほくぶ /兵庫県北部/
ひょうごけんよせん /兵庫県予選/
ひょうごけんりつ /兵庫県立/
ひょうごふう /標語風/
ひょうごもじ /表語文字/
ひょうさ /票差/
ひょうさくさん /氷酢酸/
ひょうさつ /表札/
ひょうざん /氷山/
ひょうし /表紙/拍子/
ひょうしえ /表紙絵/
ひょうしが /表紙画/
ひょうしき /標識/表式/
ひょうしきつうかじ /標識通過時/
ひょうしきとう /標識灯/
ひょうしきどおり /標識通り/
ひょうしきばんごう /標識番号/
ひょうしぎ /拍子木/
ひょうしけんかんとう /表紙兼巻頭/
ひょうしぬけ /拍子抜け/
ひょうしゃ /評者/
ひょうしゅつ /表出/
ひょうしょう /表彰/表象/標章/氷床/
ひょうしょうきのう /表象機能/
ひょうしょうけいけん /表彰経験/
ひょうしょうしき /表彰式/
ひょうしょうしきしゅうりょうご /表彰式終了後/
ひょうしょうしゅぎ /表象主義/
ひょうしょうじょう /表彰状/
ひょうしょうだい /表彰台/
ひょうじ /表示/票時/憑恃/
ひょうじいき /表示域/
ひょうじいち /表示位置/
ひょうじか /表示可/
ひょうじかかく /表示価格/
ひょうじかのう /表示可能/
ひょうじかのうしょく /表示可能色/
ひょうじかのうせい /表示可能性/
ひょうじかん /表示管/
ひょうじかんけい /表示関係/
ひょうじがめん /表示画面/
ひょうじがめんいどう /表示画面移動/
ひょうじき /表示器/表示機/
ひょうじきかく /表示規格/
ひょうじきじゅん /表示基準/
ひょうじきのう /表示機能/
ひょうじぎむ /表示義務/
ひょうじぎょう /表示行/
ひょうじけい /表示系/
ひょうじけいしき /表示形式/
ひょうじけいたい /表示形態/
ひょうじけたすう /表示桁数/
ひょうじさき /表示先/
ひょうじざか /表示坂/
ひょうじしき /表示式/
ひょうじしきすう /表示色数/
ひょうじしゅうはすう /表示周波数/
ひょうじしょく /表示色/
ひょうじじ /表示時/
ひょうじじかん /表示時間/
ひょうじじょう /表示上/
ひょうじじょうほう /表示情報/
ひょうじせいのう /表示性能/
ひょうじせってい /表示設定/
ひょうじそう /表示相/
ひょうじそうち /表示装置/
ひょうじそくど /表示速度/
ひょうじたいけい /表示体系/
ひょうじち /表示値/
ひょうじちゅう /表示中/
ひょうじてき /表示的/
ひょうじてきいみ /表示的意味/
ひょうじてきいみろん /表示的意味論/
ひょうじとう /表示灯/
ひょうじないよう /表示内容/
ひょうじのうりょく /表示能力/
ひょうじはば /表示幅/
ひょうじはんい /表示範囲/
ひょうじばいりつ /表示倍率/
ひょうじばん /表示板/表示版/表示盤/
ひょうじぶ /表示部/
ひょうじぶつ /表示物/
ひょうじぶぶん /表示部分/
ひょうじほう /表示法/
ひょうじほうほう /表示方法/
ひょうじまど /表示窓/
ひょうじめん /表示面/
ひょうじめんせき /表示面積/
ひょうじもじ /表示文字/
ひょうじもじすう /表示文字数/
ひょうじゅん /標準/
ひょうじゅんあん /標準案/
ひょうじゅんいがい /標準以外/
ひょうじゅんいち /標準位置/
ひょうじゅんおんがくじてん /標準音楽辞典/
ひょうじゅんか /標準化/標準課/
ひょうじゅんかいいんかい /標準化委員会/
ひょうじゅんかいしき /標準化意識/
ひょうじゅんかかく /標準価格/
ひょうじゅんかかくまい /標準価格米/
ひょうじゅんかかつどう /標準化活動/
ひょうじゅんかしぼうりつ /標準化死亡率/
ひょうじゅんかじぎょう /標準化事業/
ひょうじゅんかじたい /標準化自体/
ひょうじゅんかだんたい /標準化団体/
ひょうじゅんかつどう /標準活動/
ひょうじゅんかどうこう /標準化動向/
ひょうじゅんかほうしん /標準化方針/
ひょうじゅんかんきょう /標準環境/
ひょうじゅんかんじ /標準漢字/
ひょうじゅんかんすう /標準関数/
ひょうじゅんがたりろん /標準型理論/
ひょうじゅんき /標準軌/標準機/
ひょうじゅんきか /標準軌化/
ひょうじゅんきかく /標準規格/
ひょうじゅんきかん /標準軌間/
ひょうじゅんきくかん /標準軌区間/
ひょうじゅんきどう /標準軌道/
ひょうじゅんきのう /標準機能/
ひょうじゅんきょく /標準局/
ひょうじゅんきようしゃりん /標準軌用車輪/
ひょうじゅんけい /標準形/標準型/
ひょうじゅんけいしき /標準形式/
ひょうじゅんげんぞう /標準現像/
ひょうじゅんこうせい /標準構成/
ひょうじゅんこうりかかく /標準小売価格/
ひょうじゅんご /標準語/
ひょうじゅんごいがい /標準語以外/
ひょうじゅんさいきょうそうび /標準最強装備/
ひょうじゅんざひょう /標準座標/
ひょうじゅんしげき /標準刺激/
ひょうじゅんしごとりょう /標準仕事量/
ひょうじゅんしてい /標準指定/
ひょうじゅんしゅつりょく /標準出力/
ひょうじゅんしょく /標準色/
ひょうじゅんしよう /標準仕様/
ひょうじゅんじ /標準時/
ひょうじゅんじかん /標準時間/
ひょうじゅんじっそう /標準実装/
ひょうじゅんじん /標準人/
ひょうじゅんせいず /標準星図/
ひょうじゅんぜいりつ /標準税率/
ひょうじゅんそうちゃく /標準装着/
ひょうじゅんそうび /標準装備/
ひょうじゅんたいけい /標準体型/
ひょうじゅんち /標準値/
ひょうじゅんてき /標準的/
ひょうじゅんてききょうかしょ /標準的教科書/
ひょうじゅんてきぶんたい /標準的文体/
ひょうじゅんてつづき /標準手続/標準手続き/
ひょうじゅんてんぷ /標準添付/
ひょうじゅんとうさい /標準搭載/
ひょうじゅんとくてん /標準得点/
ひょうじゅんにほんご /標準日本語/
ひょうじゅんにゅうしゅつりょく /標準入出力/
ひょうじゅんにゅうりょく /標準入力/
ひょうじゅんのう /標準脳/
ひょうじゅんはつおん /標準発音/
ひょうじゅんひょうき /標準表記/
ひょうじゅんひん /標準品/
ひょうじゅんびせいぶつがく /標準微生物学/
ひょうじゅんふく /標準服/
ひょうじゅんふぞく /標準付属/
ひょうじゅんぶったい /標準物体/
ひょうじゅんぶひん /標準部品/
ひょうじゅんへんさ /標準偏差/
ひょうじゅんもけい /標準模型/
ひょうじゅんりろん /標準理論/
ひょうじゅんろしゅつ /標準露出/
ひょうじょう /表情/平調/氷上/
ひょうじょうがわら /評定河原/
ひょうじょうしゅう /評定衆/
ひょうじよう /表示用/
ひょうじようそ /表示要素/
ひょうじらん /表示欄/
ひょうじりょういき /表示領域/
ひょうじれい /表示例/
ひょうじわく /表示枠/
ひょうすう /票数/
ひょうせつ /剽窃/
ひょうぜん /瓢然/
ひょうそう /表層/表装/
ひょうそうかんきょう /表層環境/
ひょうそうてき /表層的/
ひょうそく /表側/
ひょうたん /氷炭/瓢箪/
ひょうたんなまず /瓢箪鯰/
ひょうだい /表題/標題/
ひょうだいきょく /表題曲/
ひょうだいさく /表題作/
ひょうだいぶ /表題部/
ひょうだいらん /表題欄/
ひょうちゃく /漂着/
ひょうちゃくぶったい /漂着物体/
ひょうちゅう /表中/標注/氷柱/標註/氷中/
ひょうちゅうきごう /表中記号/
ひょうちゅうていせい /標註訂正/
ひょうちょう /憑弔/
ひょうてい /評定/標定/
ひょうていしゃくど /評定尺度/
ひょうていしゃくどほう /評定尺度法/
ひょうていそくど /表定速度/
ひょうていそくどひ /表定速度比/
ひょうていち /評定値/
ひょうてき /標的/
ひょうてきかく /標的核/
ひょうてん /氷点/評点/瓢天/
ひょうてんか /氷点下/
ひょうでん /評伝/
ひょうとう /表頭/
ひょうど /表土/
ひょうどう /兵藤/兵頭/
ひょうはく /漂白/漂泊/
ひょうはくざい /漂白剤/
ひょうばん /評判/
ひょうばんごう /表番号/
ひょうひ /表皮/
ひょうひょう /瓢々/
ひょうびょう /縹渺/縹眇/縹緲/
ひょうぶ /兵部/
ひょうへき /表壁/氷壁/
ひょうへん /豹変/
ひょうほう /兵法/
ひょうほん /標本/
ひょうほんか /標本化/
ひょうほんかこうぞう /標本化構造/
ひょうほんかしゅうはすう /標本化周波数/
ひょうほんすう /標本数/
ひょうほんち /標本値/
ひょうほんてん /標本点/
ひょうほんてんすう /標本点数/
ひょうほんてんちょう /標本点長/
ひょうほんびん /標本瓶/
ひょうぼう /標榜/
ひょうま /豹馬/
ひょうめい /表明/
ひょうめいけん /表明権/
ひょうめいしゃ /表明者/
ひょうめいほうほう /表明方法/
ひょうめん /表面/
ひょうめんおんど /表面温度/
ひょうめんおんどさ /表面温度差/
ひょうめんか /表面化/
ひょうめんかこう /表面加工/
ひょうめんきょうかい /表面境界/
ひょうめんけいじょう /表面形状/
ひょうめんしょり /表面処理/
ひょうめんじっそう /表面実装/
ひょうめんじょう /表面上/
ひょうめんじょうたい /表面状態/
ひょうめんせいぎょ /表面制御/
ひょうめんせき /表面積/
ひょうめんちょうりょく /表面張力/
ひょうめんてき /表面的/
ひょうめんは /表面波/
ひょうめんはんのうほう /表面反応法/
ひょうもくひょう /標目表/
ひょうよみ /票読み/
ひょうり /表裏/
ひょうりいったい /表裏一体/
ひょうりゅう /漂流/
ひょうりゅうき /漂流記/
ひょうりゅうしゃ /漂流者/
ひょうりゅうぶつ /漂流物/
ひょうりょう /秤量/兵糧/
ひょうろう /兵糧/
ひょうろん /評論/
ひょうろんか /評論家/
ひょうろんかくちょう /評論家口調/
ひょうろんかつどう /評論活動/
ひょうろんかめい /評論家名/
ひょうろんかやろう /評論家野郎/
ひょうろんかれんちゅう /評論家連中/
ひょうろんき /評論器/
ひょうろんしゃ /評論社/
ひよう /費用/比容/
ひようか /費用化/
ひようしゃ /被用者/
ひようふたん /費用負担/
ひよく /肥沃/
ひよけ /日除け/
ひよし /日吉/日義/
ひよしえき /日吉駅/
ひよしほうめんちょくつう /日吉方面直通/
ひよどり /鵯/
ひより /日和/
ひよりざき /日和崎/
ひよりみ /日和見/
ひら /平/片/衡/比呂/比良/
ひらあやまり /平謝り/
ひらい /平井/飛来/避雷/
ひらいし /平石/
ひらいしん /避雷針/
ひらいずみ /平泉/
ひらいで /平出/
ひらいわ /平岩/
ひらお /平尾/平生/
ひらおか /平岡/
ひらおかえき /平岡駅/
ひらおよぎ /平泳ぎ/
ひらか /平鹿/平賀/
ひらかた /平形/枚方/
ひらかたこうえん /枚方公園/
ひらかたし /枚方市/
ひらかたしえき /枚方市駅/
ひらかたしみん /枚方市民/
ひらかたはつ /枚方発/
ひらかたひがしぐち /枚方東口/
ひらかたふきん /枚方付近/
ひらかな /平仮名/
ひらかなかくていにゅうりょく /平仮名確定入力/
ひらかわ /平川/平河/
ひらかわしゅっぱんしゃ /平河出版社/
ひらが /平賀/
ひらがな /平仮名/平假名/
ひらがなこもじ /平仮名小文字/
ひらき /平木/開/
ひらきかげん /開き加減/
ひらきど /開き戸/
ひらきなおり /開き直り/
ひらきふう /開き封/
ひらく /啓/
ひらこう /平光/
ひらさわ /平沢/平澤/
ひらさん /比良山/
ひらざら /平皿/
ひらざわ /平澤/
ひらしま /平島/平嶋/
ひらしゃいん /平社員/
ひらぞこ /平底/
ひらた /平田/枚田/
ひらたえき /平田駅/
ひらたちょう /平田町/
ひらたに /平谷/
ひらつか /平塚/
ひらつかえき /平塚駅/
ひらつかおき /平塚沖/
ひらつかきょうぎじょう /平塚競技場/
ひらつかし /平塚市/
ひらつかしがい /平塚市街/
ひらつかしちょう /平塚市長/
ひらつかしない /平塚市内/
ひらづみ /平積み/
ひらて /平手/
ひらで /平出/
ひらと /平戸/
ひらとり /平取/
ひらど /平戸/
ひらない /平内/
ひらなか /平中/
ひらなが /平長/
ひらぬま /平沼/
ひらぬまばし /平沼橋/
ひらぬまばしかん /平沼橋間/
ひらの /平野/
ひらのじんじゃ /平野神社/
ひらはら /平原/
ひらば /平場/
ひらばせん /平場戦/
ひらばやし /平林/
ひらばり /平針/
ひらばる /平原/
ひらぶん /平文/
ひらま /平間/
ひらまく /平幕/
ひらまくゆうしょう /平幕優勝/
ひらまくゆうしょうしゃ /平幕優勝者/
ひらまくゆうしょうりきし /平幕優勝力士/
ひらまくりきし /平幕力士/
ひらまつ /平松/
ひらみち /平道/
ひらみつ /平光/
ひらめ /鮃/
ひらめき /閃き/
ひらもと /平本/
ひらや /平屋/平谷/
ひらやま /平山/
ひらゆ /平湯/
ひりき /非力/
ひりつ /比率/
ひりつじょうけん /比率条件/
ひりつてき /比率的/
ひりゅう /飛竜/飛龍/
ひりゅうづ /飛竜頭/
ひりょう /肥料/
ひりょうか /肥料化/
ひりようしゃ /非利用者/
ひりんりてき /非倫理的/
ひる /昼/蛭/蒜/簸/晝/
ひるい /比類/
ひるいじど /非類似度/
ひるいち /昼一/
ひるかわ /比留川/蛭川/
ひるがた /昼型/
ひるげ /昼餉/
ひるこ /蛭子/
ひるころ /昼頃/
ひるごはん /昼御飯/
ひるごろ /昼頃/
ひるさがり /昼下/昼下り/昼下がり/
ひるすぎ /昼過/昼過ぎ/
ひるせん /蒜山/
ひるぜん /蒜山/
ひるぜんご /昼前後/
ひるてい /昼定/
ひるどき /昼時/
ひるね /昼寝/
ひるひなか /昼日中/
ひるま /昼間/晝間/
ひるまえ /昼前/
ひるむしろもく /ヒルムシロ目/Potamogetonales/
ひるめし /昼飯/
ひるめしだい /昼飯代/
ひるやすみ /昼休み/
ひれ /鰭/
ひれい /比例/非礼/∝/
ひれいかんけい /比例関係/
ひれいく /比例区/
ひれいけいすうかん /比例計数管/
ひれいだいひょうせい /比例代表制/
ひれいていすう /比例定数/
ひれいてき /比例的/
ひれいはいぶん /比例配分/
ひれいぼう /非冷房/
ひれいぼうしゃ /非冷房車/
ひれいぼうしゃへんせい /非冷房車編成/
ひれき /披瀝/
ひれつ /卑劣/
ひれにく /ヒレ肉/
ひれん /悲恋/
ひれんけつ /非連結/
ひれんぞくてき /非連続的/
ひろ /裕/広/弘/博/尋/洋/宏/寛/廣/浩/比呂/紘/絋/啓/恕/央/拡/史/太/泰/拓/伯/祐/仞/仭/愽/洪/宥/大/
ひろあき /広章/宏明/博章/博昭/浩晃/弘朗/寛明/宏朗/浩昭/浩明/博明/祐彰/広明/弘明/裕明/宏晃/啓明/広昭/裕昭/裕章/宏昭/浩秋/祐昭/洋晶/洋昭/弘昭/宏顕/洋明/広朗/
ひろあきら /寛晰/
ひろいけ /広池/廣池/
ひろいし /広石/
ひろいもの /拾い物/
ひろう /疲労/披露/疲勞/
ひろうえん /披露宴/
ひろうかい /披露会/
ひろうかいふく /疲勞恢復/疲労回復/
ひろうかん /疲労感/
ひろうこうぎょう /披露興行/
ひろうこっせつ /疲労骨折/
ひろうこんばい /疲労困憊/
ひろうこんぱい /疲労困憊/
ひろうしき /披露式/
ひろうち /浩内/
ひろうど /疲労度/
ひろうひがたしゃかい /非浪費型社会/
ひろえ /広江/弘枝/宏江/浩恵/宏枝/広恵/浩江/裕江/廣江/広絵/
ひろえん /広縁/
ひろお /広尾/博生/洋男/洋夫/宏雄/博雄/
ひろおえき /広尾駅/
ひろおか /広岡/弘岡/
ひろおかかんとく /広岡監督/
ひろか /祥加/裕香/
ひろかず /浩和/泰一/宏和/弘一/博一/大一/博万/博和/裕和/浩一/
ひろかみ /広神/
ひろかわ /広川/紘川/廣川/
ひろかわしょてん /廣川書店/
ひろがわ /広川/
ひろき /広樹/弘樹/洋樹/啓樹/博基/裕樹/浩貴/博紀/博己/宏樹/宏喜/央樹/寛己/弘城/博樹/裕貴/寛紀/弘毅/裕紀/浩基/裕毅/浩喜/
ひろきち /広吉/
ひろく /広く/
ひろくに /裕邦/
ひろぐ /弘具/
ひろこ /浩子/博子/紘子/寛子/ひろ子/弘子/裕子/宏子/欧子/宙子/倫子/広子/
ひろこうじ /広小路/
ひろさか /広坂/
ひろさき /弘前/広崎/
ひろさきし /弘前市/
ひろさきじょう /弘前城/
ひろさきだい /弘前大/
ひろさきだいがく /弘前大学/
ひろさと /浩郷/宏郷/
ひろさわ /廣沢/廣澤/広沢/
ひろし /宏/浩/寛/博史/博/浩史/弘/宏司/宏史/広/大士/啓之/広司/広志/浩志/博司/博士/博志/裕/裕志/洋/熈/弘志/裕史/大史/洋史/比呂志/央/弘史/浩司/裕司/廣/廣志/愽/煕/熙/ひろ志/啓志/宏志/浩士/洋司/広史/弘司/大/大志/
ひろしげ /広重/浩重/博茂/
ひろしま /広島/
ひろしまいがい /広島以外/
ひろしまえき /広島駅/
ひろしまかき /広島牡蛎/
ひろしまかん /広島間/
ひろしまがす /広島ガス/
ひろしまがわ /広島側/
ひろしまきた /広島北/
ひろしまきゅうしない /広島旧市内/
ひろしまきゅうじょう /広島球場/
ひろしまきんぼう /広島近傍/
ひろしまぎんこう /広島銀行/廣島銀行/
ひろしまくうこう /広島空港/
ひろしまくまのどうろ /広島熊野道路/
ひろしまくれどうろ /広島呉道路/
ひろしまけん /広島県/
ひろしまけんせつ /広島建設/
ひろしまけんない /広島県内/
ひろしまけんひろしまし /広島県広島市/
ひろしまけんふくやまし /広島県福山市/
ひろしまけんふちゅうし /広島県府中市/
ひろしまけんふちゅうちょう /広島県府中町/
ひろしまこうだい /広島工大/
ひろしまさん /広島産/
ひろしまし /広島市/
ひろしましがい /広島市街/
ひろしまししゃ /広島支社/
ひろしましだい /広島市大/
ひろしましない /広島市内/
ひろしましみなみく /広島市南区/
ひろしましみんきゅうじょう /広島市民球場/
ひろしましゅうどうだいがく /広島修道大学/
ひろしましゅっしん /広島出身/
ひろしましょうぎょう /広島商業/
ひろしましりつだい /広島市立大/
ひろしましりつだいがく /広島市立大学/
ひろしましんこうつう /広島新交通/
ひろしまじ /広島路/
ひろしまじょがくいん /広島女学院/
ひろしません /広島戦/
ひろしまたいかい /広島大会/
ひろしまだい /広島大/広島大学/
ひろしまだいがく /広島大学/
ひろしまだいがくじょうほう /広島大学情報/
ひろしまちく /広島地区/
ひろしまちほう /広島地方/
ひろしまちゅうしんぶ /広島中心部/
ひろしまちょう /広島町/
ひろしまてん /広島店/
ひろしまでんきだい /広島電機大/
ひろしまでんてつ /広島電鉄/
ひろしまとうよう /広島東洋/
ひろしまなづけ /広島菜漬/
ひろしまひがし /広島東/
ひろしまふう /広島風/
ひろしまべん /広島弁/
ひろしまや /広島屋/
ひろしまやき /広島焼/
ひろしょう /広商/
ひろじ /広治/宏治/
ひろすえ /広末/
ひろすえりょうこ /広末涼子/
ひろせ /広瀬/廣瀬/
ひろせがわ /広瀬川/
ひろせどおり /広瀬通/
ひろぜがわ /広瀬川/
ひろぞう /弘蔵/
ひろた /広田/廣田/
ひろたか /宏隆/宏孝/博孝/浩貴/浩孝/弘隆/宏貴/弘崇/宏高/
ひろたき /広瀧/
ひろたけ /博丈/
ひろただ /博唯/裕忠/
ひろたつ /広達/
ひろたに /広谷/
ひろたまみ /広田まみ/
ひろだい /広大/弘大/広島大学/
ひろだいおうようりきがく /広大応用力学/
ひろだいそうか /広大総科/
ひろつ /広津/
ひろつぐ /博嗣/博次/裕次/
ひろづ /広津/
ひろでん /広電/
ひろでんしないせん /広電市内線/
ひろと /寛人/裕人/浩登/博人/
ひろとし /浩俊/宏寿/
ひろとも /弘具/寛知/
ひろなお /弘尚/弘直/
ひろなか /広中/弘中/弘仲/
ひろなかへいすけ /広中平祐/
ひろなが /広長/
ひろの /広野/
ひろのぶ /宏伸/裕信/博信/博宣/広宣/弘宜/弘宣/
ひろのみや /浩宮/
ひろのり /裕徳/弘法/浩則/博紀/博則/博徳/博典/
ひろはばとびら /広幅扉/
ひろはら /広原/
ひろば /広場/
ひろひこ /恕彦/浩彦/博彦/裕彦/洋彦/飛呂彦/
ひろひさ /裕久/浩久/浩寿/博久/
ひろひと /裕仁/博人/宏仁/裕人/
ひろひとてんのう /裕仁天皇/
ひろびろ /広々/
ひろふみ /寛文/弘文/裕文/博文/宏文/弘史/大史/洋史/廣文/啓文/洋文/博史/
ひろぶみ /弘史/浩史/博文/
ひろべ /広部/
ひろま /広間/
ひろまさ /弘征/弘昌/宏昌/洋正/浩正/裕昌/裕真/弘真/広正/
ひろまつ /廣松/
ひろまど /広窓/
ひろみ /広美/博美/浩美/弘美/ヒロミ/宏美/比呂美/引美/裕美/博己/裕実/洋美/拡稔/弘巳/浩巳/ひろ美/広見/寛美/弘海/
ひろみち /広道/博道/弘道/拓路/寛道/晃道/
ひろみつ /博満/博光/博允/廣光/弘光/宏光/博三/
ひろめ /披露目/
ひろもち /裕望/
ひろや /浩也/博也/
ひろやす /弘安/博康/容靖/浩靖/裕康/浩康/博泰/大和/博保/弘康/
ひろゆき /周行/浩之/博幸/裕之/幸展/広之/洋之/宏行/寛之/弘之/博之/裕幸/裕行/宏幸/宏之/広行/博行/陽之/広幸/弘幸/弘行/弘征/祐之/裕由/浩幸/啓之/弘恭/洋征/
ひろよし /寛善/博芳/浩由/弘恭/敬昌/博喜/浩喜/博義/
ひろんりてき /非論理的/
ひろんりてきこうり /非論理的公理/
ひわ /秘話/悲話/鶸/比和/
ひわい /卑猥/卑わい/鄙猥/
ひわき /樋脇/
ひわきのう /秘話機能/
ひわさ /日和佐/
ひわさき /日和崎/
ひわせい /秘話性/
ひわそうち /秘話装置/
ひわたり /樋渡/日渡/
ひわり /日割/日割り/
ひわりけいさん /日割計算/
ひわれ /干割れ/
ひん /貧/品/頻/賓/瀕/浜/斌/彬/顰/濱/嬪/擯/殯/稟/禀/繽/蘋/牝/
ひんい /品位/
ひんかい /頻回/
ひんかく /品格/
ひんきゃく /賓客/
ひんきゅう /殯宮/貧窮/
ひんぎ /稟議/
ひんけい /牝系/
ひんけつ /貧血/
ひんこう /品行/
ひんこうほうせい /品行方正/
ひんこん /貧困/
ひんこんしゃ /貧困者/
ひんこんしゃかい /貧困社会/
ひんし /品詞/瀕死/
ひんしかん /品詞間/
ひんしかんせつぞく /品詞間接続/
ひんしじゅん /品詞順/
ひんしじょうたい /瀕死状態/
ひんしじょうほう /品詞情報/
ひんしつ /品質/
ひんしついじ /品質維持/
ひんしつかくにん /品質確認/
ひんしつかんり /品質管理/
ひんしつこうじょう /品質向上/
ひんしつさ /品質差/
ひんしつじょう /品質上/
ひんしつじょうほうしつ /品質情報室/
ひんしつてき /品質的/
ひんしつひょうか /品質評価/
ひんしつふりょう /品質不良/
ひんしつほしょう /品質保証/
ひんしつほしょうぶ /品質保証部/
ひんしぶんかい /品詞分解/
ひんしぶんかいずみ /品詞分解済/
ひんしめい /品詞名/
ひんしゅ /品種/
ひんしゅかいりょう /品種改良/
ひんしゅく /顰蹙/
ひんしゅつ /頻出/瀕出/
ひんしゅとうろく /品種登録/
ひんじゃ /貧者/
ひんじゃく /貧弱/
ひんせい /品性/
ひんせいげれつ /品正下劣/品性下劣/
ひんそう /貧相/
ひんだ /貧打/
ひんと /ヒント/
ひんど /頻度/
ひんどじしょ /頻度辞書/
ひんどじゅん /頻度順/
ひんどじょうほう /頻度情報/
ひんどち /頻度値/
ひんどてき /頻度的/
ひんどめい /頻度名/
ひんにゅう /貧乳/
ひんば /牝馬/
ひんばげんていせん /牝馬限定戦/
ひんばにかんば /牝馬二冠馬/
ひんばん /品番/
ひんぱく /頻拍/
ひんぱつ /頻発/
ひんぱん /頻繁/
ひんぴょう /品評/
ひんぴょうかい /品評会/
ひんぷ /貧富/
ひんみん /貧民/
ひんみんがい /貧民街/
ひんめい /品名/
ひんもく /品目/
ひんよう /頻用/
び /美/備/日/鼻/眉/琵/尾/微/毘/枇/媚/火/比/寐/嵋/弭/濔/瀰/糒/糜/縻/麋/靡/贔/未/
び> /微/
びーとるず /ビートルズ/
びーなす /ヴィーナス/ビーナス/
びーる /ビール/麦酒/
びーるけん /ビール券/
びい /微意/
びいしき /美意識/
びいん /鼻音/
びいんか /鼻音化/
びう /眉宇/
びえい /美瑛/
びえん /鼻炎/
びおとーぷ /ビオトープ;野生生物の生育場所。ギリシャ語のBIO(生物)とTOP(場所)の合成語/biotope;英語/Biotop;独語/
びおん /鼻音/微温/
びおんか /鼻音化/
びか /美化/
びかこうどう /美化行動/
びかん /美観/
びがく /美学/
びがくじょう /美学上/
びがん /美顔/
びがんき /美顔器/
びき /匹/引き/引/美姫/
びきょ /美挙/
びきょう /鼻鏡/
びく /魚篭/魚籠/
びくう /鼻腔/
びくしょう /微苦笑/
びくに /比丘尼/
びけい /美形/
びけいすう /微係数/
びけいやく /美形役/
びげいこう /美藝公/
びげん /微減/
びこう /備考/尾行/鼻孔/鼻腔/微光/微香/
びこうけん /美工研/
びこうせい /微光星/
びこうらん /備考欄/
びさ /微差/
びさい /微細/尾西/
びさいか /微細化/
びさいかこう /微細加工/
びさいこうぞう /微細構造/
びさいこうぞうけんきゅう /微細構造研究/
びさん /靡散/
びさんちほう /備讃地方/
びざい /微罪/
びし /微視/
びしてき /微視的/
びしゃもん /毘沙門/
びしゃもんてん /毘沙門天/
びしゅ /美酒/
びしゅう /美醜/
びしゅく /糜粥/
びしょう /微少/微笑/微小/微小運動/
びしょううんどう /微小運動/
びしょうかく /微小角/
びしょうきょり /微小距離/
びしょうくかん /微小区間/
びしょうしんごう /微小信号/
びしょうじしん /微小地震/
びしょうじゅうりょく /微小重力/
びしょうじゅうりょくか /微小重力下/
びしょうじょ /美少女/
びしょうじょせんし /美少女戦士/
びしょうじょまんが /美少女漫画/
びしょうじょまんがか /美少女漫画家/
びしょうせかい /微少世界/微小世界/
びしょうでんきょく /微小電極/
びしょうねん /美少年/
びしょうぶぶん /微小部分/
びしょうへんい /微小変位/
びしょうへんか /微少変化/
びしょうめんせき /微小面積/
びしょうりったいかく /微小立体角/
びしょうりゅうし /微小粒子/
びしょうりょう /微小量/微少量/
びしょく /美食/
びしょくか /美食家/
びしん /微震/美神/
びじ /美辞/
びじく /糜竺/
びじねす /ビジネス/
びじゃく /微弱/
びじゃくでんぱ /微弱電波/
びじゅう /鼻汁/
びじゅうりょく /微重力/
びじゅつ /美術/
びじゅつあいこうか /美術愛好家/
びじゅつか /美術家/
びじゅつかん /美術館/
びじゅつかんいんよう /美術館員用/
びじゅつかんけい /美術関係/
びじゅつかんしょう /美術観賞/
びじゅつかんしょぞう /美術館所蔵/
びじゅつかんちょう /美術館長/
びじゅつかんてん /美術館展/
びじゅつかんとく /美術監督/
びじゅつかんれんぜんぱん /美術関連全般/
びじゅつがっこう /美術学校/
びじゅつきょういく /美術教育/
びじゅつけい /美術系/
びじゅつけいがくぶ /美術系学部/
びじゅつさくひん /美術作品/
びじゅつさっか /美術作家/
びじゅつしか /美術史家/
びじゅつしにゅうもん /美術史入門/
びじゅつしゅっぱんしゃ /美術出版社/
びじゅつしょ /美術書/
びじゅつしょう /美術商/
びじゅつしょせんもんてん /美術書専門店/
びじゅつしょてん /美術書店/
びじゅつじてん /美術辞典/
びじゅつぜんしゅう /美術全集/
びじゅつだい /美術大/
びじゅつてん /美術展/
びじゅつはくぶつかん /美術博物館/
びじゅつひん /美術品/
びじゅつぶ /美術部/
びじょ /美女/
びじょぎ /美女木/
びじょん /ビジョン/
びじれいく /美辞麗句/
びじん /美人/
びじんぞう /美人像/
びじんひしょ /美人秘書/
びじんふう /美人風/
びじんろん /美人論/
びすます /ビスマス/
びせい /美声/美星/
びせいちょう /美星町/
びせいぶつ /微生物/
びせいぶつぞうしょく /微生物増殖/
びせいぶつばいよう /微生物培養/
びせき /微積/
びせきぶん /微積分/
びせきぶんがく /微積分学/
びせん /美泉/
びぜん /備前/靡然/
びぜんやき /備前焼/
びそく /微速/尾側/
びそくぜんしん /微速前進/
びぞう /微増/
びた /鐚/
びたい /媚態/
びだいそつ /美大卒/
びだくおん /鼻濁音/
びだん /美談/
びちく /備蓄/
びちょう /微調/
びちょうせい /微調整/
びっくり /！/吃驚/
びっこ /跛/
びっちゅう /備中/
びっと /ビット/
びつ /謐/
びてき /美的/
びてきかんかく /美的感覚/
びてきはいち /美的配置/
びてきりゆう /美的理由/
びてん /美点/
びでお /ビデオ/
びと /人/
びとう /尾灯/尾藤/
びとく /美徳/
びどう /微動/
びなん /美男/
びなんし /美男子/
びにーる /ビニール/
びねつ /微熱/
びねんまく /鼻粘膜/
びはく /靡薄/
びはっぽうせい /微発泡性/
びばい /美唄/
びひん /備品/美品/
びひんひ /備品費/
びび /微々/靡靡/
びびたる /微々たる/
びびる /ビビる/
びふう /微風/美風/
びふういき /微風域/
びふうじ /微風時/
びふえ /美笛/
びふか /美深/
びぶ /尾部/
びぶん /微分/
びぶんかのう /微分可能/
びぶんかのうせい /微分可能性/
びぶんき /微分器/
びぶんきか /微分幾何/
びぶんきかがく /微分幾何学/
びぶんきかがくてき /微分幾何学的/
びぶんけいしき /微分形式/
びぶんけいすう /微分係数/
びぶんこう /微分項/
びぶんさようそ /微分作用素/
びぶんしょ /美文書/
びぶんしょう /美文章/
びぶんせきぶん /微分積分/
びぶんせきぶんがく /微分積分学/
びぶんせきぶんほう /微分積分法/
びぶんそうさ /微分操作/
びぶんだんめんせき /微分断面積/
びぶんほう /微分法/
びぶんほうそく /微分法則/
びぶんほうていしき /微分方程式/
びへい /靡敝/
びほう /備砲/弥縫/彌縫/
びほうさく /弥縫策/
びほろ /美幌/
びほろちょう /美幌町/
びぼいん /鼻母音/
びぼう /美貌/備忘/
びぼうろく /備忘録/
びまん /瀰漫/靡曼/
びまんせい /瀰漫性/
びみ /美味/
びみょう /微妙/
びめい /美名/
びもく /眉目/
びゃく /白/百/闢/辟/帛/
びゃくい /白衣/
びゃくだん /白檀/
びゃくだんもく /ビャクダン目/Santalales/
びゃくや /白夜/
びゃくやしょぼう /白夜書房/
びゃくやしょぼうばん /白夜書房版/
びゃくやものがたり /白夜物語/
びゃっこ /白虎/
びやく /媚薬/
びゅう /謬/繆/
びょう /秒/病/鋲/錨/苗/平/描/廟/票/″/猫/屏/杪/渺/眇/緲/藐/憑/
びょういん /病院/病因/
びょうかん /秒間/
びょうが /描画/描畫/
びょうがい /病害/
びょうがいち /描画位置/
びょうがいちゅう /病害虫/
びょうがかいしいち /描画開始位置/
びょうがかてい /描画過程/
びょうがかんすう /描画関数/
びょうがきのう /描画機能/
びょうがしょく /描画色/
びょうがじ /描画時/
びょうがじょうほう /描画情報/
びょうがそくど /描画速度/
びょうがへんしゅう /描画編集/
びょうがほうほう /描画方法/
びょうき /病気/病期/
びょうきいぜん /病気以前/
びょうきじたい /病気自体/
びょうきよぼう /病気予防/
びょうきりょうよう /病気療養/
びょうけつ /病欠/
びょうげん /病原/病源/
びょうげんきん /病源菌/病原菌/
びょうげんたい /病原体/病源体/
びょうげんたいかんせん /病原体感染/
びょうこん /病根/
びょうご /秒後/
びょうごと /秒毎/
びょうさ /秒差/
びょうし /拍子/表紙/病死/
びょうししゃ /病死者/
びょうしつ /病室/
びょうしゃ /描写/
びょうしゃせいのう /描写性能/
びょうしゃりょく /描写力/
びょうしょ /廟所/
びょうしょう /病床/
びょうしん /病身/秒針/
びょうじつ /病日/
びょうじゃく /病弱/
びょうじゃくしゃ /病弱者/
びょうじょう /病状/苗条/
びょうすう /秒数/
びょうそう /病巣/
びょうそく /秒速/
びょうぞう /描像/
びょうたい /病態/
びょうたんい /秒単位/
びょうち /錨地/
びょうてき /病的/
びょうとう /病棟/
びょうどう /平等/
びょうどういん /平等院/
びょうどうか /平等化/
びょうどうしゅぎ /平等主義/
びょうにん /病人/
びょうはく /錨泊/
びょうはくちゅう /錨泊中/
びょうびょう /渺渺/眇眇/
びょうぶ /屏風/廟風/病部/
びょうぶえ /屏風絵/
びょうへい /病弊/
びょうへん /病変/
びょうぼつ /病没/
びょうま /病魔/
びょうめい /病名/
びょうよみ /秒読み/秒読/
びょうり /病理/
びょうりい /病理医/
びょうりかいぼう /病理解剖/
びょうりがく /病理学/
びょうりがくきょうしつ /病理学教室/
びょうりがっか /病理学科/
びょうれき /病歴/
びよう /美容/
びよういん /美容院/
びようが /描画/
びようし /美容師/
びよく /尾翼/
びより /日和/
びら /ビラ/
びらん /糜爛/靡爛/
びりやーど /ビリヤード/
びりゅう /微粒/
びりゅうし /微粒子/
びりょう /鼻梁/微量/
びりょうげんそ /微量元素/
びりょく /微力/
びる /ビル/
びるま /緬甸/
びれい /靡麗/美麗/
びろーど /天鵞絨/
びろうど /天鵞絨/
びわ /琵琶/枇杷/
びわかじゅう /枇杷果汁/
びわこ /琵琶湖/
びわこおおはし /琵琶湖大橋/
びわこきせん /琵琶湖汽船/
びわこすいけい /琵琶湖水系/
びわこせん /琵琶湖線/
びわこぞい /琵琶湖沿/
びわことうがん /琵琶湖東岸/
びわこはくぶつかん /琵琶湖博物館/
びわこほうめん /琵琶湖方面/
びわこほくせいぶ /琵琶湖北西部/
びわじま /枇杷島/
びん /便/瓶/敏/憫/秤/貧/壜/岷/愍/旻/梹/檳/泯/紊/緡/罎/閔/鬢/頻/
びんいれ /瓶入/
びんかつ /敏活/
びんかん /敏感/
びんかんはだ /敏感肌/
びんが /頻伽/
びんぐし /鬢櫛/
びんご /備後/
びんごおちあい /備後落合/
びんごふちゅうし /備後府中市/
びんしょう /敏捷/憫笑/
びんしょうせい /敏捷性/
びんじょう /便乗/
びんじょうしつもん /便乗質問/
びんすう /便数/
びんせん /便箋/便船/
びんぜん /愍然/
びんそく /敏速/
びんだい /瓶代/
びんちょうたん /備長炭/
びんづめ /瓶詰/瓶詰め/
びんほう /便法/
びんぼう /貧乏/
びんぼうがくせい /貧乏学生/
びんぼうがみ /貧乏神/
びんぼうくじ /貧乏籤/
びんぼうけん /貧乏県/
びんぼうしょう /貧乏症/貧乏性/
びんぼうしょく /貧乏食/
びんぼうせいかつ /貧乏生活/
びんぼうにん /貧乏人/
びんぼうりょこう /貧乏旅行/
びんめい /便名/
びんらん /便覧/紊乱/
ぴ /日/
ぴーきんぐ /ピーキング/
ぴーく /ピーク/
ぴーす /ピース/
ぴあにすと /ピアニスト/
ぴあの /ピアノ/
ぴか /ピカ/
ぴかいち /光一/
ぴき /匹/
ぴざ /ピザ/
ぴっち /ピッチ/
ぴっぷ /比布/
ぴつ /泌/
ぴょう /憑/票/
ぴらふ /ピラフ/
ぴらみっど /ピラミッド/
ぴりおど /ピリオド/
ぴるびんさん /ピルビン酸/
ぴん /筒/品/ピン/
ぴんあん /平安/
ぴんく /ピンク/
ぴんくれでぃ /ピンクレディ/
ぴんず /筒子/
ぴんせる /ピンセル/
ぴんち /ピンチ/
ぴんと /ピント/
ぴんふ /平和/
ふ /不/負/付/父/布/譜/腐/附/符/普/赴/阜/府/夫/浮/膚/冨/敷/賦/芙/富/怖/婦/扶/斧/歩/埠/生/傅/孚/麸/仆/俘/俛/俯/咐/坿/孵/巫/拊/柎/桴/榑/溥/畉/罘/腑/苻/蜉/訃/誣/賻/趺/郛/鯆/麩/風/鮒/舗/鋪/
ふ< /不/
ふ> /不/負/
ふ? /不/
ふーど /フード/
ふぁーすと /ファースト/
ふぁい /φ/
ふぁいば /ファイバ/
ふぁいる /ファイル/
ふぁいるてんそう /ファイル転送/
ふぁいるめい /ファイル名/
ふぁいんだ /ファインダ/
ふぁくしみり /ファクシミリ/
ふぁくとり /ファクトリ/
ふぁしりてい /ファシリテイ/
ふぁっしょん /ファッション/
ふぁみこん /ファミコン/
ふぁみり /ファミリ/
ふぁん /翻/ファン/飜/
ふぁんくしょん /ファンクション/
ふぁんたじー /ファンタジー/
ふあつ /負圧/
ふあん /不安/
ふあんかん /不安感/
ふあんがお /不安顔/
ふあんげ /不安気/
ふあんざいりょう /不安材料/
ふあんし /不安視/
ふあんてい /不安定/
ふあんていか /不安定化/
ふあんていかい /不安定解/
ふあんていきょうしんき /不安定共振器/
ふあんていせい /不安定性/
ふあんていとくいてん /不安定特異点/
ふあんていよういん /不安定要因/
ふあんない /不案内/
ふあんひょうめい /不安表明/
ふぃーと /フィート/呎/
ふぃーど /フィード/
ふぃーどばっく /フィードバック/
ふぃーるど /フィールド/
ふぃくしょん /フィクション/
ふぃっと /フィット/
ふぃりぴん /比律賓/
ふぃりぴんかい /フィリピン海/
ふぃるたー /フィルター/
ふぃるむ /フィルム/
ふぃんらんど /芬蘭/
ふい /不意/
ふいうち /不意打/不意打ち/
ふいちょう /吹聴/
ふいっち /不一致/
ふう /風/封/楓/夫/富/殕/瘋/諷/
ふうあつ /風圧/
ふういき /風域/
ふういん /封印/風韻/
ふういんじょう /封印城/
ふうう /風雨/
ふううん /風雲/
ふううんきゅう /風雲急/
ふううんじ /風雲児/
ふうえい /風営/
ふうえいてん /風営店/
ふうえいほう /風営法/
ふうえいほういはん /風営法違反/
ふうえいほうかいせい /風営法改正/
ふうか /風化/
ふうかく /風格/
ふうからいでん /風火雷電/
ふうかん /風乾/
ふうが /風雅/
ふうがい /風害/
ふうがわり /風変り/
ふうき /風紀/富貴/
ふうきょう /風狂/
ふうきり /封切り/封切/
ふうぎ /風儀/
ふうぎり /封切り/
ふうけい /風景/
ふうけいが /風景画/
ふうけいしゃしん /風景写真/
ふうけつ /風穴/
ふうげつ /風月/
ふうこう /風光/風向/
ふうこうめいび /風光明媚/
ふうさ /封鎖/
ふうさい /風采/風災/
ふうささくせん /封鎖作戦/
ふうさつ /封殺/
ふうさぼう /封鎖棒/
ふうし /風刺/封止/諷刺/
ふうしえ /風刺絵/
ふうしかでん /風姿花伝/
ふうしゃ /風車/
ふうしゃしき /風車式/
ふうしゅう /風習/
ふうしょ /封書/
ふうしん /風疹/
ふうしんき /風信器/
ふうじん /風神/
ふうすいがい /風水害/
ふうすいし /風水師/風水士/
ふうせい /風勢/風声/
ふうせつ /風雪/風説/
ふうせん /風船/
ふうせんばくだん /風船爆弾/
ふうぜん /風前/
ふうそう /風葬/風霜/風騒/
ふうそく /風速/
ふうそくけい /風速計/
ふうぞく /風俗/
ふうぞくえいぎょうほう /風俗営業法/
ふうぞくえいぎょうよう /風俗営業用/
ふうぞくぎょう /風俗業/
ふうぞくし /風俗史/
ふうぞくつう /風俗通/
ふうぞくようご /風俗用語/
ふうたい /風袋/風帯/
ふうたく /風鐸/
ふうたろう /風太郎/
ふうち /風致/
ふうちょう /風潮/風鳥/
ふうちん /風鎮/
ふうつう /風通/
ふうてい /風体/
ふうてん /瘋癲/
ふうとう /封筒/
ふうとうがた /封筒型/
ふうとうぼく /風倒木/
ふうど /風土/
ふうどう /風洞/
ふうどしょく /風土色/
ふうにゅう /封入/
ふうにゅうざい /封入材/
ふうにゅうしき /封入式/
ふうは /風波/
ふうはく /風伯/
ふうばいか /風媒花/
ふうばぎゅう /風馬牛/
ふうひ /封皮/
ふうひょう /風評/
ふうび /風靡/
ふうふ /夫婦/
ふうふかん /夫婦間/
ふうふかんけい /夫婦関係/
ふうふけいたい /夫婦形態/
ふうふげんか /夫婦喧嘩/
ふうふせいかつ /夫婦生活/
ふうふそうほう /夫婦双方/
ふうふとも /夫婦共/
ふうふどうし /夫婦同士/
ふうふない /夫婦内/
ふうふべっせい /夫婦別姓/
ふうふやく /夫婦役/
ふうふよう /夫婦用/
ふうふりょうほう /夫婦両方/
ふうぶつ /風物/
ふうぶつし /風物詩/
ふうぶん /風聞/
ふうぼう /風貌/風防/
ふうま /風魔/
ふうましゅりけん /風魔手裏剣/
ふうまにんじゃ /風魔忍者/
ふうみ /風味/
ふうみんしゃ /風眠舎/
ふうむ /風夢/
ふうもん /風紋/
ふうゆ /諷諭/
ふうらい /風来/
ふうらいぼう /風来坊/
ふうりゅう /風流/
ふうりゅうじん /風流人/
ふうりょう /風量/
ふうりょく /風力/
ふうりょくけい /風力計/
ふうりょくはつでん /風力発電/
ふうりん /風鈴/
ふうりんかざん /風林火山/
ふうれん /風連/
ふうろう /封蝋/風浪/
ふうろそうか /フウロソウ科/Geraniaceae/
ふうろそうぞく /フウロソウ属/
ふうろそうもく /フウロソウ目/Geraniales/
ふうろそうもくあぐん /フウロソウ目亜群/
ふうん /不運/
ふぇーず /フェーズ/
ふぇあ /フェア/
ふぇいす /フェイス/
ふぇざー /フェザー/
ふぇすてぃばる /フェスティバル/
ふぇっち /フェッチ/
ふぇみにずむ /フェミニズム/
ふぇらちお /フェラチオ/
ふぇりー /フェリー/
ふぇんす /フェンス/
ふえ /笛/不壊/吭/鰾/
ふえい /府営/
ふえいせい /不衛生/
ふえかた /増え方/
ふえき /不易/
ふえきしょうあく /不易掌握/
ふえて /不得手/
ふえふきどうじ /笛吹童子/
ふえん /不縁/敷衍/
ふぉーかす /フォーカス/
ふぉーく /フォーク/
ふぉーとらん /フォートラン/Fortran/
ふぉーど /フォード/
ふぉーまっと /フォーマット/
ふぉーむ /フォーム/
ふぉーらむ /フォーラム/
ふぉあ /フォア/
ふぉあぐら /フォアグラ/
ふぉろー /フォロー/
ふぉわーど /フォワード/
ふぉんと /フォント/
ふおう /不応/
ふおうき /不応期/
ふおうとう /不応答/
ふおん /不穏/
ふおんとう /不穏当/
ふか /負荷/付加/不可/深/孵化/府下/鯊/鱶/負化/賦課/附加/孚化/
ふかい /不快/深い/深井/腐海/渓井/
ふかいかん /不快感/
ふかいし /深石/
ふかいにゅう /不介入/
ふかいり /深入り/
ふかうら /深浦/
ふかうらえき /深浦駅/
ふかえ /深江/
ふかえはま /深江浜/
ふかお /深尾/
ふかかい /不可解/
ふかかいげんしょう /不可解現象/
ふかかいじけん /不可解事件/
ふかかち /付加価値/
ふかかちきょうそう /付加価値競争/
ふかかちぜい /付加価値税/
ふかがわ /深川/負荷側/
ふかがわえいぎょうしょ /深川営業所/
ふかがわしゃこ /深川車庫/
ふかきん /付加金/賦課金/
ふかきんこう /負荷均衡/
ふかきんせいど /賦課金制度/
ふかぎゃく /不可逆/
ふかぎゃくあっしゅく /不可逆圧縮/
ふかぎゃくてき /不可逆的/
ふかぎゃくへんか /不可逆変化/
ふかく /不覚/俯角/
ふかくさ /深草/
ふかくじつ /不確実/
ふかくじつかん /不確実感/
ふかくじつせい /不確実性/
ふかくだい /不拡大/
ふかくだいほうしん /不拡大方針/
ふかくてい /不確定/
ふかくていかんけい /不確定関係/
ふかくていじこう /不確定事項/
ふかくていせい /不確定性/
ふかくていせいかんけい /不確定性関係/
ふかくていせいげんり /不確定性原理/
ふかくていとうこう /不確定投稿/
ふかくていようそ /不確定要素/
ふかけいげん /負荷軽減/
ふかけつ /不可欠/
ふかけつせい /不可欠性/
ふかこう /付加項/
ふかこうりょく /不可抗力/
ふかさ /負荷差/深さ/
ふかさく /深作/
ふかさわ /深沢/深澤/
ふかざけ /深酒/
ふかざつおん /付加雑音/
ふかざわ /深沢/深澤/
ふかし /不可視/
ふかしぎ /不可思議/
ふかしょう /不可称/
ふかしょり /付加処理/
ふかしようま /不可視妖魔/
ふかしん /不可侵/
ふかじょうほう /付加情報/負荷情報/
ふかすぎ /深過ぎ/
ふかせ /深瀬/
ふかせいぎょてん /付加制御点/
ふかそうち /付加装置/
ふかぞうげん /負荷増減/
ふかぞうだい /負荷増大/
ふかぞり /深剃り/
ふかたに /深谷/
ふかだ /深田/
ふかちろん /不可知論/
ふかっせい /不活性/
ふかっせいか /不活性化/
ふかっぱつ /不活発/
ふかつ /深津/賦活/
ふかつか /不活化/
ふかづめ /深爪/
ふかてき /付加的/
ふかてん /付加点/
ふかでんあつ /負荷電圧/
ふかなせん /深名線/
ふかの /深野/
ふかのう /不可能/
ふかのうせい /不可能性/
ふかのうせいていり /不可能性定理/
ふかはた /深畑/
ふかひ /不可避/
ふかひれ /フカヒレ/
ふかぶか /深々/
ふかぶかと /深々と/
ふかぶん /不可分/
ふかぶんさん /負荷分散/
ふかぶんさんほうしき /負荷分散方式/
ふかへんどう /負荷変動/
ふかまち /深町/
ふかみ /深海/深見/深み/
ふかみず /深水/
ふかや /深谷/
ふかやし /深谷市/
ふかやま /深山/
ふかようりょう /負荷容量/
ふかよみ /深読み/
ふかりつ /孵化率/
ふかりょう /負荷量/
ふかわ /布川/府川/
ふかん /不感/不完/俯瞰/
ふかんしょう /不干渉/不感症/
ふかんぜん /不完全/
ふかんぜんぎょう /不完全行/
ふかんぜんさく /不完全作/
ふかんぜんじょうほう /不完全情報/
ふかんぜんせい /不完全性/
ふかんぜんせいていり /不完全性定理/
ふかんぜんせきぶんき /不完全積分器/
ふかんぜんねんしょう /不完全燃焼/
ふかんぜんばん /不完全版/
ふかんぜんほかん /不完全補完/
ふかんび /不完備/
ふかんよう /不寛容/
ふがく /富嶽/
ふがね /府金/
ふき /付記/蕗/葺/附記/吹/苳/不期/
ふきあげ /吹上/
ふきかえ /吹替え/吹替/
ふきげん /不機嫌/
ふきそ /不起訴/
ふきそく /不規則/
ふきそくか /不規則化/
ふきそくがた /不規則型/
ふきそくがたきこう /不規則型気孔/
ふきそくぶぶん /不規則部分/
ふきそくへんどう /不規則変動/
ふきそしょぶん /不起訴処分/
ふきだし /吹き出し/吹出/
ふきつ /不吉/
ふきでもの /吹出物/吹き出物/
ふきぬけ /吹抜け/吹抜/
ふきの /吹野/
ふきのとう /蕗の薹/
ふきはつ /不揮発/
ふきはつせい /不揮発性/
ふきゃがく /不可逆/
ふきや /吹矢/蕗谷/
ふきゅう /普及/不休/不朽/不急/腐朽/
ふきゅういいん /普及委員/
ふきゅうかつどう /普及活動/
ふきゅうき /普及機/
ふきゅうしき /普及式/
ふきゅうだいすう /普及台数/
ふきゅうど /普及度/
ふきゅうどあい /普及度合/
ふきゅうばん /普及版/
ふきゅうりつ /普及率/
ふきょう /布教/不況/不協/不興/富強/
ふきょうか /不況下/
ふきょうかつどう /布教活動/
ふきょうこうえん /布教公演/
ふきょうじ /不況時/
ふきょうたいさく /不況対策/
ふきょうわ /不協和/
ふきょうわおん /不協和音/
ふきょか /不許可/
ふきょくせい /負極性/
ふきん /付近/布巾/附近/
ふきんいつ /不均一/
ふきんこう /不均衡/
ふきんしつ /不均質/
ふきんしん /不謹慎/
ふきんじゅうみん /付近住民/
ふきんとう /不均等/
ふぎ /不義/付議/府議/
ふぎかい /府議会/
ふぎり /不義理/
ふく /副/服/福/幅/覆/復/複/伏/腹/輻/含/富久/吹/匐/愎/箙/茯/蔔/蝠/袱/輹/馥/
ふく> /副/複/
ふくあん /腹案/
ふくい /福井/福居/
ふくいいんちょう /副委員長/
ふくいえき /福井駅/
ふくいぎんこう /福井銀行/
ふくいくうこう /福井空港/
ふくいけん /福井県/
ふくいけんしぞく /福井県士族/
ふくいけんちょう /福井県庁/
ふくいけんりつだいがく /福井県立大学/
ふくいし /福井市/
ふくいしゅっしん /福井出身/
ふくいたいかい /福井大会/
ふくいだい /福井大/
ふくいだいがく /福井大学/
ふくいほうそう /福井放送/
ふくいん /福音/復員/幅員/
ふくいんかん /福音館/
ふくいんかんしょてん /福音館書店/
ふくいんしょ /福音書/
ふくうりば /服売場/
ふくえ /福江/福栄/
ふくえき /服役/
ふくえん /復縁/
ふくえんせん /福塩線/
ふくおう /福王/
ふくおか /福岡/
ふくおかあさひほうそう /福岡朝日放送/
ふくおかえき /福岡駅/
ふくおかかん /福岡間/
ふくおかきょういくだいがく /福岡教育大学/
ふくおかきんこう /福岡近郊/
ふくおかきんこうくかん /福岡近郊区間/
ふくおかぎじゅつ /福岡技術/
ふくおかぎんこう /福岡銀行/
ふくおかくうこう /福岡空港/
ふくおかけん /福岡県/
ふくおかけんいいづかし /福岡県飯塚市/
ふくおかけんない /福岡県内/
ふくおかこう /福岡校/
ふくおかこうぎょうだいがく /福岡工業大学/
ふくおかこうたんだい /福岡工短大/
ふくおかこうだい /福岡工大/
ふくおかこうだいふ /福岡工大附/
ふくおかし /福岡市/
ふくおかしない /福岡市内/
ふくおかしないせん /福岡市内線/
ふくおかしみん /福岡市民/
ふくおかせん /福岡線/
ふくおかだい /福岡大/
ふくおかだいがく /福岡大学/
ふくおかちく /福岡地区/
ふくおかちさい /福岡地裁/
ふくおかちゃく /福岡着/
ふくおかてんじん /福岡天神/
ふくおかとしこうそく /福岡都市高速/
ふくおかはつ /福岡発/
ふくおかばしょ /福岡場所/
ふくおかびん /福岡便/
ふくおかほうそう /福岡放送/
ふくおん /複音/
ふくおんせい /副音声/
ふくか /複果/
ふくかいちょう /副会長/
ふくかわ /福川/
ふくかん /副官/
ふくかんきょう /複環境/
ふくかんりにん /副管理人/
ふくが /腹臥/
ふくがく /復学/
ふくがくちょう /副学長/
ふくがじょう /覆瓦状/
ふくがん /複眼/
ふくがんいがい /複眼以外/
ふくがんてき /複眼的/
ふくきょうざい /副教材/
ふくきょうだい /福教大/
ふくぎ /副木/
ふくぎょう /副業/
ふくくう /腹腔/
ふくくっせつ /複屈折/
ふくくみあいちょう /副組合長/
ふくけいしき /副形式/
ふくけん /復権/
ふくげん /復元/復原/
ふくげんえんそう /復原演奏/
ふくげんこうか /復元効果/
ふくげんさぎょう /復元作業/
ふくげんそうち /復元装置/
ふくげんばん /復元版/
ふくげんほうほう /復元方法/
ふくげんりつ /復元率/
ふくげんりょう /副原料/
ふくげんりょく /復元力/
ふくこう /腹腔/
ふくこうだいふ /福工大附/
ふくこうまえ /福高前/
ふくごう /復号/複合/複号/
ふくごうえきめい /複合駅名/
ふくごうおせん /複合汚染/
ふくごうおん /複合音/
ふくごうか /復号化/複合化/
ふくごうかく /複合核/
ふくごうかこ /複合過去/
ふくごうがた /複合型/
ふくごうきごうこうぞう /複合記号構造/
ふくごうきのう /複合機能/
ふくごうきょうどうじゅうたく /複合共同住宅/
ふくごうきょくせん /複合曲線/
ふくごうこう /複合項/
ふくごうこうげき /複合攻撃/
ふくごうご /複合語/
ふくごうごぜんへんかん /複合語全変換/
ふくごうごゆうせん /複合語優先/
ふくごうざい /複合材/
ふくごうざいけんきゅうじょ /複合材研究所/
ふくごうじんたいそんしょう /複合靭帯損傷/
ふくごうせいさんぶつ /複合生産物/
ふくごうそうこう /複合装甲/
ふくごうたい /複合体/
ふくごうたんぱく /複合蛋白/
ふくごうてき /複合的/
ふくごうどうきしんごう /複合同期信号/復号同期信号/
ふくごうひょうげん /複合表現/
ふくごうびょうし /複合拍子/
ふくごうふきょう /複合不況/
ふくごうほう /復号法/
ふくごうまく /複合膜/
ふくごうりょういき /複合領域/
ふくさ /副査/袱紗/帛紗/
ふくさいぼう /副細胞/
ふくさや /福砂屋/
ふくさよう /副作用/
ふくさようてき /副作用的/
ふくさわ /福澤/
ふくさんぶつ /副産物/
ふくざ /複座/
ふくざい /伏在/
ふくざがた /複座型/
ふくざき /福崎/
ふくざつ /複雑/
ふくざつか /複雑化/
ふくざつかいき /複雑怪奇/
ふくざつけい /複雑系/
ふくざつさ /複雑さ/
ふくざつせい /複雑性/
ふくざつたき /複雑多岐/
ふくざつたりょう /複雑多量/
ふくざつど /複雑度/
ふくざつどりろん /複雑度理論/
ふくざわ /福沢/福澤/
ふくし /福祉/副詞/福士/福司/
ふくしか /福祉課/
ふくしかんけい /福祉関係/
ふくしがっか /福祉学科/
ふくしき /複式/腹式/
ふくしきこきゅう /腹式呼吸/複式呼吸/
ふくしきぼき /複式簿記/
ふくしく /副詞句/
ふくしげ /福重/
ふくしこうがく /福祉工学/
ふくしこっか /福祉国家/
ふくしししゅつ /福祉支出/
ふくししゃちょう /副支社長/
ふくしじぎょう /福祉事業/
ふくしぜい /福祉税/
ふくしぞうしん /福祉増進/
ふくしだい /福祉大/
ふくしだんたい /福祉団体/
ふくしつしき /副室式/
ふくしどう /副指導/
ふくしま /福島/福嶋/副島/
ふくしまいやくだい /福島医薬大/
ふくしまいらい /福島以来/
ふくしまえき /福島駅/
ふくしまきねん /福島記念/
ふくしまきょく /福島局/
ふくしまけん /福島県/
ふくしまけんなんぶ /福島県南部/
ふくしまこうこう /福島高校/
ふくしまこうつう /福島交通/
ふくしまざいじゅう /福島在住/
ふくしまし /福島市/
ふくしましゅっしん /福島出身/
ふくしまだい /福島大/
ふくしまだいにげんぱつ /福島第二原発/
ふくしまてつどう /福島鉄道/
ふくしまみんぽうはい /福島民報杯/福島民放杯/
ふくしゃ /複写/輻射/
ふくしゃおんど /輻射温度/
ふくしゃき /複写機/
ふくしゃきじぎょうぶ /複写機事業部/
ふくしゃさいはいふ /複写再配布/
ふくしゃし /複写紙/
ふくしゃしつ /複写室/
ふくしゃせん /輻射線/
ふくしゃちょう /副社長/
ふくしゃてん /輻射点/
ふくしゃねつ /輻射熱/
ふくしゃりょう /複写料/
ふくしゅ /副手/
ふくしゅう /復習/復讐/
ふくしゅうき /復讐鬼/
ふくしゅうきじ /復習記事/
ふくしゅうげき /復讐劇/
ふくしゅうしん /復讐心/
ふくしゅうせん /復讐戦/
ふくしゅうにゅう /副収入/
ふくしゅかん /副主幹/
ふくしゅしつ /副手室/
ふくしゅしょう /副首相/
ふくしゅじんこう /副主人公/
ふくしゅせき /副主席/
ふくしょう /複勝/復唱/副賞/復勝/副将/復誦/副章/
ふくしょうぐん /副将軍/
ふくしょうしき /復勝式/複勝式/
ふくしょうそうひょうすう /複勝総票数/
ふくしょうひょうすう /複勝票数/
ふくしょく /復職/服飾/副食/
ふくしょくこうぼう /服飾工房/
ふくしょくぶつ /副食物/
ふくしょちょう /副署長/副所長/
ふくしりょういき /福祉領域/
ふくしん /腹心/
ふくじ /副次/福治/服地/
ふくじこうか /副次効果/
ふくじしょう /副時称/
ふくじてき /副次的/
ふくじてきこうか /副次的効果/
ふくじもんだい /副次問題/
ふくじゅう /服従/複重/
ふくじん /副腎/副神/
ふくじんづけ /福神漬/副神漬け/
ふくじんひしつ /副腎皮質/
ふくすい /覆水/腹水/
ふくすう /複数/
ふくすうおん /複数音/
ふくすうか /複数可/
ふくすうかい /複数回/
ふくすうかいとうか /複数解答可/複数回答可/
ふくすうかしょ /複数箇所/
ふくすうかん /複数艦/
ふくすうかんりにんせい /複数管理人制/
ふくすうがいしゃ /複数会社/
ふくすうきしゅ /複数機種/
ふくすうきどう /複数起動/
ふくすうきぼう /複数希望/
ふくすうぎょう /複数行/
ふくすうけい /複数形/
ふくすうけいとう /複数系統/
ふくすうこ /複数個/
ふくすうこうほ /複数候補/
ふくすうごうぎせい /複数合議制/
ふくすうごび /複数語尾/
ふくすうさんか /複数参加/
ふくすうしてい /複数指定/
ふくすうしていか /複数指定可/
ふくすうしゃせん /複数車線/
ふくすうしゅ /複数種/
ふくすうしゅるい /複数種類/
ふくすうしんにん /複数信任/
ふくすうじ /複数持/
ふくすうせんたく /複数選択/
ふくすうせんたくか /複数選択可/
ふくすうそうさ /複数走査/
ふくすうそんざい /複数存在/
ふくすうだい /複数台/
ふくすうだんらく /複数段落/
ふくすうちょくれつ /複数直列/
ふくすうとうひょう /複数投票/
ふくすうとくひょう /複数得票/
ふくすうどうさ /複数動作/
ふくすうどうじ /複数同時/
ふくすうにゅうりょく /複数入力/
ふくすうにん /複数人/
ふくすうにんいいん /複数人委員/
ふくすうねんじ /複数年次/
ふくすうひょう /複数票/
ふくすうひょうき /複数表記/
ふくすうひょうとうひょう /複数票投票/
ふくすうへんすう /複数変数/
ふくすうほゆう /複数保有/
ふくすうほん /複数本/
ふくすうまい /複数枚/
ふくすうめい /複数名/
ふくすうもじ /複数文字/
ふくすうようい /複数用意/
ふくすうりょう /複数両/
ふくすうれい /複数例/
ふくすうろ /複数路/
ふくすけ /福助/
ふくずみ /福住/
ふくせい /複製/
ふくせいいらい /複製依頼/
ふくせいか /複製可/
ふくせいかん /複製間/
ふくせいけん /複製権/
ふくせいけんしゃ /複製権者/
ふくせいけんしんがい /複製権侵害/
ふくせいげんがしゅう /複製原画集/
ふくせいし /複製子/
ふくせいとうかせい /複製透過性/
ふくせいはんが /複製版画/
ふくせいひん /複製品/
ふくせいぶつ /複製物/
ふくせいもと /複製元/
ふくせいわざ /複製技/
ふくせってん /副節点/
ふくせつ /副節/
ふくせん /伏線/複線/
ふくせんか /複線化/
ふくせんかかんせい /複線化完成/
ふくせんかこうじ /複線化工事/
ふくせんかんかく /複線間隔/
ふくせんくかん /複線区間/
ふくせんでんか /複線電化/
ふくそ /複素/
ふくそいそうくうかん /複素位相空間/
ふくそう /服装/輻輳/複層/副層/
ふくそうかく /輻輳角/
ふくそうさ /副走査/
ふくそうり /副総理/
ふくそうりん /複層林/
ふくそかいせき /複素解析/
ふくそかんすう /複素関数/
ふくそかんすうろん /複素関数論/
ふくそきょうやく /複素共役/
ふくそく /腹側/
ふくそしゅうはすう /複素周波数/
ふくそすう /複素数/
ふくそすうえんざん /複素数演算/
ふくそすうがた /複素数型/
ふくそすうたい /複素数体/
ふくそすうち /複素数値/
ふくそせいげんは /複素正弦波/
ふくそせきぶん /複素積分/
ふくそたようたい /複素多様体/
ふくそぶぶん /複素部分/
ふくそへいめん /複素平面/
ふくそへいめんじょう /複素平面上/
ふくそへいめんぜんたい /複素平面全体/
ふくそへんすう /複素変数/
ふくそりきがくけい /複素力学系/
ふくそりょういき /複素領域/
ふくぞう /福蔵/腹蔵/
ふくぞく /服属/
ふくたい /複体/
ふくたけ /福武/
ふくたけしょてん /福武書店/
ふくたけぶんこ /福武文庫/
ふくたに /福谷/
ふくたろう /福太郎/
ふくだ /福田/
ふくだい /副題/福大/
ふくだいとうりょう /副大統領/
ふくだいひょう /副代表/
ふくだんちょう /副団長/
ふくち /福地/
ふくちやま /福知山/
ふくちやまかん /福知山間/
ふくちやましない /福知山市内/
ふくちやません /福知山線/
ふくちょう /復調/副長/
ふくちょうじく /復調軸/
ふくつ /不屈/
ふくつう /腹痛/
ふくで /福田/
ふくでん /復電/
ふくとうこう /複投稿/
ふくとく /副読/福徳/
ふくとしん /副都心/
ふくとみ /福富/
ふくとめ /福留/
ふくどく /服毒/
ふくどくほん /副読本/
ふくどみ /福富/
ふくなが /福永/
ふくにし /福西/
ふくの /福野/
ふくはい /復配/腹背/
ふくはら /福原/復原/
ふくはんぎゃくどうめい /服反逆同盟/
ふくはんそう /副搬送/
ふくはんそうは /副搬送波/
ふくはんのう /副反応/
ふくばんごう /副番号/
ふくひょうじようそ /副表示要素/
ふくびき /福引/
ふくびこうえん /副鼻腔炎/
ふくふくせん /複複線/複々線/
ふくぶ /腹部/
ふくぶくろ /福袋/
ふくぶちょう /副部長/
ふくぶん /複文/副文/
ふくぶんせつ /複文節/
ふくぷろぐらむ /副プログラム/
ふくへい /伏兵/
ふくへいせい /副兵装/
ふくへき /腹壁/
ふくへんそくき /副変速機/
ふくべ /福部/
ふくべっぷ /福別府/
ふくほう /副砲/
ふくほうとう /副砲塔/
ふくほん /副本/複本/
ふくま /福間/
ふくまかいがん /福間海岸/
ふくまく /腹膜/
ふくまくえん /腹膜炎/
ふくまさ /福政/
ふくまさむね /福正宗/
ふくます /福桝/
ふくまつ /福松/
ふくまでん /伏魔殿/
ふくみ /含み/
ふくみつ /福光/
ふくみみ /福耳/
ふくむ /服務/
ふくむいん /服務員/
ふくむら /福村/
ふくめい /復命/
ふくめん /覆面/
ふくめんよう /覆面用/
ふくもと /福本/福元/
ふくもり /福盛/
ふくや /福家/福屋/
ふくやく /服薬/
ふくやしょてん /福屋書店/
ふくやす /福安/
ふくやま /福山/富久山/
ふくやまえき /福山駅/
ふくやまし /福山市/
ふくやまつううん /福山通運/
ふくよう /服用/複葉/
ふくようき /複葉機/
ふくようじ /服用時/
ふくようちゅう /服用中/
ふくようりょう /服用量/
ふくよか /脹よか/膨よか/
ふくらい /福来/
ふくらはぎ /脹脛/腓/
ふくり /福利/複利/
ふくりこうせい /福利厚生/
ふくりこうせいしせつ /福利厚生施設/
ふくりこうせいてき /福利厚生的/
ふくりこうせいひ /福利厚生費/
ふくりじちょう /副理事長/
ふくりゅうえん /副流煙/
ふくりょう /伏竜/
ふくりょうちょう /副寮長/
ふくりょうりちょう /副料理長/
ふくろ /袋/復路/嚢/副露/
ふくろあみ /袋網/
ふくろい /袋井/
ふくろいり /袋入/
ふくろう /梟/フクロウ/
ふくろおび /袋帯/
ふくろこうじ /袋小路/
ふくろじょう /袋状/
ふくろたに /袋谷/
ふくろだ /袋田/
ふくろだおんせん /袋田温泉/
ふくろだたき /袋叩/袋だたき/
ふくろとじ /袋閉じ/袋とじ/袋綴じ/
ふくろはり /袋貼り/
ふくろばら /袋原/
ふくろばり /袋貼り/
ふくろんぶん /副論文/
ふくわじゅつ /腹話術/
ふぐ /河豚/鰒/
ふぐあい /不具合/
ふぐあいてん /不具合点/
ふぐう /不遇/
ふぐか /不具化/
ふぐごうかく /複合核/
ふぐしゃ /不具者/
ふぐたいてん /不倶戴天/
ふぐり /睾丸/
ふぐりょうり /河豚料理/
ふけ /普家/冨家/冨宅/
ふけい /父兄/婦警/父系/不敬/府警/
ふけいかい /父兄会/
ふけいき /不景気/
ふけいざい /不経済/不敬罪/
ふけいせき /父兄席/
ふけいどうはん /父兄同伴/
ふけいべつはんだん /父系別判断/
ふけつ /不潔/
ふけやく /老役/
ふけん /府県/父権/
ふけんきょうかい /府県協会/
ふけんこう /不健康/
ふけんぜん /不健全/
ふけんぜんせい /不健全性/
ふげん /付言/不言/
ふげんだけ /普賢岳/
ふげんだけしゅうへん /普賢岳周辺/
ふこ /巫蠱/
ふこう /不幸/附高/不孝/不興/
ふこうしん /負更新/
ふこうせい /不公正/
ふこうせいとりひき /不公正取引/
ふこうちゅう /不幸中/
ふこうへい /不公平/
ふこうへいかん /不公平感/
ふこうへいせい /不公平性/
ふこうよう /不効用/
ふこく /布告/
ふこくきょうへい /富國強兵/富国強兵/
ふこころえ /不心得/
ふこころえもの /不心得者/
ふごう /符号/負号/符合/富豪/
ふごうか /符号化/符合化/
ふごうかく /不合格/
ふごうかくしゃ /不合格者/
ふごうかくちょうほう /符合拡張法/符号拡張法/
ふごうかくちょうほうしき /符合拡張方式/
ふごうかほう /符合化法/
ふごうかほうしき /符号化方式/
ふごうかほうほう /符号化方法/
ふごうき /符号器/
ふごうけい /符号系/
ふごうご /符号語/
ふごうそくど /符号速度/
ふごうちょう /符号長/符号帳/
ふごうなし /符号無し/
ふごうひょう /符号表/
ふごうほう /不合法/
ふごうり /不合理/
ふごうりいぜん /不合理以前/
ふごうりせい /不合理性/
ふごうりろん /符号理論/
ふさ /総/房/總/絃/惣/
ふさい /夫妻/負債/不採/負載/
ふさいごうけい /負債合計/
ふさいたく /不採択/
ふさいよう /不採用/
ふさいろく /不採録/
ふさがる /閼/
ふさきち /房吉/
ふさく /不作/
ふさくい /不作為/
ふさぐ /閼/
ふさこ /房子/夫査子/扶佐子/
ふさざくらか /フサザクラ科/Eupteleaceae/
ふさじょう /ふさ状/
ふさん /不讃/
ふさんか /不参加/
ふさんかしゃ /不参加者/
ふさんせい /不賛成/
ふさんはつ /釜山発/
ふざ /趺坐/
ふざい /不在/
ふざいしゃ /不在者/
ふざいしゃとうひょう /不在者投票/
ふざいじ /不在時/
ふざいちゅう /不在中/
ふざん /釜山/
ふざんけいゆ /釜山経由/
ふし /節/伏/不死/父子/臥/
ふしあな /節穴/
ふしあわせ /不幸せ/
ふしかてい /父子家庭/
ふしぎ /不思議/
ふしぎえいこく /不思議英国/
ふしじ /不支持/
ふしじしゃ /不支持者/
ふしじひょうめい /不支持表明/
ふしぜん /不自然/
ふしたに /伏谷/
ふしちょう /不死鳥/
ふしつ /不悉/
ふしつりょう /負質量/
ふしつりょうぶっしつ /負質量物質/
ふしづけ /罧/
ふしてん /節点/
ふしぶし /節々/
ふしまつ /不始末/
ふしまわし /節回し/
ふしみ /伏見/
ふしみく /伏見区/
ふしみこう /伏見工/
ふしめ /伏し目/節目/
ふしゅ /浮腫/
ふしゅう /腐臭/
ふしゅうぎ /不祝儀/
ふしゅつ /不出/
ふしゅつじょう /不出場/
ふしゅび /不首尾/
ふしょう /負傷/不詳/不精/不肖/父称/
ふしょうけつじょう /負傷欠場/
ふしょうしゃ /負傷者/
ふしょうじ /不祥事/
ふしょうじき /不正直/
ふしょうたいじょう /負傷退場/
ふしょうち /不承知/
ふしょうちゅう /負傷中/
ふしょうにん /不承認/
ふしょうはんてい /負傷判定/
ふしょうぶしょう /不承不承/
ふしょうわたくし /不肖私/
ふしょく /不食/腐食/腐蝕/
ふしょくざい /腐蝕剤/
ふしょくふ /不織布/
ふしょくふひょうめん /不織布表面/
ふしよう /不使用/
ふしん /不信/不審/腐心/普請/不振/
ふしんかん /不信感/
ふしんしゃ /不審者/
ふしんせつ /不親切/
ふしんてん /不審点/
ふしんにん /不信任/
ふしんにんあん /不信任案/
ふしんにんいけん /不信任意見/
ふしんにんひょう /不信任票/
ふしんにんひょうめい /不信任表明/
ふしんび /不審火/
ふじ /富士/藤/不二/不時/不治/冨士/
ふじい /藤井/
ふじいち /富士市/
ふじいでら /藤井寺/
ふじいでらきゅうじょう /藤井寺球場/
ふじいろ /藤色/
ふじう /藤生/
ふじうつぎか /フジウツギ科/Buddlejaceae/
ふじうら /藤浦/
ふじえ /藤江/
ふじえだ /藤枝/
ふじえだえき /藤枝駅/
ふじえだし /藤枝市/
ふじえだひがし /藤枝東/
ふじお /富士夫/藤雄/富士雄/冨士雄/藤尾/不二雄/不二夫/
ふじおか /藤岡/富士岡/
ふじおかえき /富士岡駅/
ふじおやま /富士小山/
ふじか /藤花/
ふじかけ /藤掛/
ふじかわ /藤川/富士川/
ふじがおか /藤が丘/藤ヶ丘/
ふじがわ /富士川/
ふじがわふきん /富士川付近/
ふじき /藤木/藤城/
ふじきゅう /富士急/
ふじきゅうこう /富士急行/
ふじぎん /富士銀/
ふじぎんこう /富士銀行/
ふじくら /藤倉/
ふじくらでんせん /藤倉電線/
ふじけい /フジ系/
ふじげんがっき /富士弦楽器/
ふじこ /藤子/不二子/富士子/冨士子/
ふじこし /不二越/藤越/
ふじこふじお /藤子不二雄/藤子不二夫/
ふじごこ /富士五湖/
ふじさき /藤崎/
ふじさく /藤咲/
ふじさと /藤里/
ふじさわ /藤沢/藤澤/
ふじさわいこう /藤沢以降/
ふじさわえき /藤沢駅/
ふじさわし /藤沢市/
ふじさわしみんまつり /藤沢市民祭/
ふじさわばし /藤沢橋/
ふじさわゆき /藤沢行/
ふじさん /富士山/
ふじさんがた /富士山型/
ふじさんごう /富士参號/
ふじさんごごうめ /富士山五合目/
ふじさんちょう /富士山頂/
ふじさんちょうじょう /富士山頂上/
ふじさんへん /富士山編/
ふじさんろく /富士山麓/
ふじし /富士市/
ふじしえいきゅうじょう /富士市営球場/
ふじしま /藤島/藤嶋/
ふじしまべや /藤島部屋/
ふじしゃしん /富士写真/
ふじしゃりょう /富士車輌/
ふじしろ /藤代/藤城/
ふじじゅうこう /富士重工/
ふじせ /藤瀬/
ふじぜろっくす /富士ゼロックス/
ふじそうけん /富士総研/
ふじた /藤田/冨士田/
ふじたか /藤孝/
ふじたかんこう /藤田観光/
ふじたに /藤谷/
ふじだな /藤棚/
ふじちゃく /不時着/
ふじっこう /不実行/
ふじつ /藤津/不実/
ふじつう /富士通/
ふじつうあいち /富士通愛知/
ふじつうあつぎけん /富士通厚木研/
ふじつうおおいた /富士通大分/
ふじつうけいれつ /富士通系列/
ふじつうけん /富士通研/
ふじつうけんきゅうしょ /富士通研究所/
ふじつうこくさいけん /富士通国際研/
ふじつうごたんだ /富士通五反田/
ふじつうじょうほうけん /富士通情報研/
ふじつうせい /富士通製/
ふじつうぜねらる /富士通ゼネラル/
ふじつうほっかいどう /富士通北海道/
ふじつか /藤塚/
ふじつぼ /藤壷/
ふじでんき /富士電機/
ふじと /藤戸/
ふじなが /藤永/
ふじなみ /藤波/
ふじの /藤野/
ふじのうらば /藤裏葉/
ふじのみや /富士宮/藤ノ宮/
ふじのみやし /富士宮市/
ふじのもり /藤森/
ふじはし /藤橋/
ふじはら /冨士原/
ふじばかま /藤袴/
ふじばなさんそう /藤花山荘/
ふじばやし /藤林/
ふじひこ /不二彦/
ふじひろ /不二洋/
ふじへいげん /富士平原/
ふじほうめん /富士方面/
ふじま /藤間/
ふじまき /藤巻/
ふじまつ /藤松/
ふじまりゅう /藤間流/
ふじみ /富士見/富士美/不死身/
ふじみがおか /富士見丘/
ふじみこうこう /富士見高校/
ふじみこうじょう /富士見工場/
ふじみしゅっぱん /富士美出版/富士見出版/
ふじみしょぼう /富士見書房/
ふじみだい /富士見台/
ふじみちょう /富士見町/
ふじみぶんこ /富士見文庫/
ふじむら /藤村/
ふじむらじょしこうこう /藤村女子高校/
ふじむらみき /藤村美樹/
ふじもと /藤本/藤元/
ふじもり /藤森/
ふじゃくしんみょう /不惜身命/
ふじや /不二家/富士屋/不二屋/藤屋/
ふじやま /藤山/
ふじやまかんび /藤山寛美/
ふじゅう /藤生/
ふじゅうぶん /不十分/不充分/
ふじゅうぶんせい /不十分性/
ふじゅうりょくじょう /負重力場/
ふじゅん /不順/不純/
ふじゅんいせいこうゆう /不純異性交遊/
ふじゅんぶつ /不純物/
ふじゆう /不自由/
ふじょ /婦女/扶助/巫女/
ふじょう /浮上/不浄/
ふじょうそうち /浮上装置/
ふじょうちゅう /浮上中/
ふじょうほうほう /浮上方法/
ふじょうり /不条理/
ふじょうりにっき /不条理日記/
ふじょうりょく /浮上力/
ふじょし /婦女子/
ふじょりょう /扶助料/
ふじよし /藤吉/
ふじよしだ /富士吉田/
ふじよしだえき /富士吉田駅/
ふじよしだがわ /富士吉田側/
ふじよしだひまつり /富士吉田火祭/
ふじれい /負事例/
ふじわか /藤若/
ふじわら /藤原/冨士原/
ふじん /夫人/婦人/布陣/
ふじんけいかん /婦人警官/
ふじんしゃ /婦人車/
ふじんだんたい /婦人団体/
ふじんふく /婦人服/
ふすう /負数/
ふすま /襖/衾/
ふすまえ /襖絵/
ふず /付図/
ふずい /付随/附随/不随/
ふずいい /不随意/
ふずいいこきゅう /不随意呼吸/
ふずいか /付随果/
ふずいご /付随語/
ふずいしゃ /付随車/
ふずいてき /付随的/
ふせ /防/布施/
ふせい /不正/不整/負性/夫姓/
ふせいかい /不正解/
ふせいかいぞう /不正改造/
ふせいかく /不正確/
ふせいかくせい /不正確性/
ふせいかんきょう /不整環境/
ふせいき /不正規/
ふせいけい /不整形/
ふせいげんり /父性原理/
ふせいこう /不成功/
ふせいこうい /不正行為/
ふせいごう /不整合/
ふせいしゅつ /不世出/
ふせいしよう /不正使用/
ふせいじつ /不誠実/
ふせいじつせい /不誠実性/
ふせいじょうしゃ /不正乗車/
ふせいせき /不成績/
ふせいち /不整地/
ふせいてき /父性的/
ふせいとうひょう /不正投票/
ふせいび /不整備/
ふせいほんのう /父性本能/
ふせいみゃく /不整脈/
ふせいゆうし /不正融資/
ふせいりつ /不成立/
ふせいりよう /不正利用/
ふせき /布石/
ふせじ /伏せ字/ふせ字/伏字/×××/○○○/□□□/△△△/
ふせっせい /不摂生/
ふせつ /敷設/付設/布設/負節/
ふせつてんじかい /付設展示会/
ふせん /不戦/付箋/附箋/
ふせんし /付箋紙/
ふせんしょう /不戦勝/
ふせんぱい /不戦敗/
ふせんめい /不鮮明/
ふぜい /風情/
ふぜん /不全/
ふそう /扶桑/
ふそうおう /不相応/
ふそうしゃ /扶桑社/
ふそく /不足/附則/不測/付則/
ふそくかん /不足感/
ふそくがく /不足額/
ふそくぎみ /不足気味/
ふそくじ /不足時/
ふそくぶん /不足分/
ふそびょう /腐蛆病/
ふそん /不遜/
ふそんざい /不存在/
ふぞく /附属/付属/
ふぞくきのう /付属機能/
ふぞくけんきゅうじょ /付属研究所/
ふぞくこう /附属校/
ふぞくこうこう /付属高校/附属高校/
ふぞくこうこうしゅっしん /付属高校出身/
ふぞくこうじょう /付属工場/
ふぞくご /付属語/附属語/
ふぞくごじしょ /付属語辞書/附属語辞書/
ふぞくしょ /附属書/
ふぞくじしょ /付属辞書/
ふぞくてき /付属的/
ふぞくひん /付属品/附属品/
ふぞくひんとも /付属品共/
ふぞくひんめい /付属品名/
ふぞくびょういん /附属病院/
ふぞくぶつ /付属物/附属物/
ふぞくへんせい /付属編成/附属編成/
ふぞくめいさいひょう /付属明細表;財務諸表の1つ/
ふぞろい /不揃い/
ふた /二/蓋/双/弍/盖/葢/
ふたあし /二足/
ふたあじ /二味/
ふたい /付帯/
ふたいおう /不対応/
ふたいけつぎ /付帯決議/
ふたいじこう /付帯事項/
ふたいじょうけん /付帯条件/
ふたいてき /付帯的/
ふたいてん /不退転/
ふたえ /二重/
ふたえき /二駅/
ふたかた /二方/
ふたかみ /二上/
ふたかわ /二川/
ふたがみ /二上/二神/
ふたがわ /二川/
ふたく /付託/負託/
ふたくみ /二組/
ふたけた /二桁/
ふたこ /二子/
ふたこしんち /二子新地/
ふたこたまがわ /二子玉川/
ふたこと /二言/
ふたことみこと /二言三言/
ふたことめ /二言目/
ふたご /双子/
ふたござ /双子座/
ふたござりゅうせいぐん /双子座流星群/
ふたごしまい /双子姉妹/
ふたごたまがわ /二子玉川/二子多摩川/
ふたごたまがわえん /二子玉川園/
ふたごたまがわえんえき /二子玉川園駅/
ふたごやま /二子山/
ふたごやまおやかた /二子山親方/
ふたごやまぜい /二子山勢/
ふたごやまべや /二子山部屋/
ふたごよう /双子用/
ふたせ /二瀬/
ふたたび /再び/
ふたたま /二玉/
ふたつ /二つ/二/2つ/２つ/双/弍/不達/
ふたつい /二ツ井/
ふたつき /二月/
ふたつぎ /二木/
ふたつざわ /二ツ沢/
ふたつつうち /不達通知/
ふたつめ /二つ目/二つめ/
ふたつや /二ッ谷/
ふたて /二手/
ふたとおり /二通り/2通り/
ふたなり /二形/
ふたはこ /二箱/
ふたば /双葉/二葉/雙葉/
ふたばがおか /双葉ヶ丘/
ふたばこうこう /雙葉高校/
ふたばしゃ /双葉社/
ふたばやま /双葉山/
ふたばん /二晩/
ふたへや /二部屋/
ふたま /二間/
ふたませ /二間瀬/
ふたまた /二股/二又/
ふたまたがわ /二俣川/
ふたまたじょう /二又状/
ふたまたじょうかじくぶんし /二又状仮軸分枝/
ふたまたせん /二俣線/
ふたまたぶんし /二又分枝/
ふたまたみゃく /二又脈/
ふたまたみゃくけい /二又脈系/
ふたみ /二見/二美/双三/双海/
ふたむかしまえ /二昔前/
ふたむら /二村/
ふたもじ /二文字/
ふたり /二人/２人/2人/
ふたりいじょう /二人以上/
ふたりかぞく /二人家族/
ふたりぐみ /二人組/
ふたりしばい /二人芝居/
ふたりじょうしゃ /二人乗車/
ふたりたび /二人旅/
ふたりとも /二人共/
ふたりどうじ /二人同時/
ふたりのり /二人乗/
ふたりぶん /二人分/
ふたりべや /２人部屋/二人部屋/
ふたりまえ /二人前/
ふたりめ /二人目/
ふたりよう /二人用/
ふたわ /二和/
ふたん /負担/
ふたんかん /負担感/
ふたんがく /負担額/
ふたんきん /負担金/
ふたんけいしき /負担形式/
ふたんげん /負担減/
ふたんしゃ /負担者/
ふたんじゅうりょう /負担重量/
ふたんぞう /負担増/
ふたんほうほう /負担方法/
ふたんぽ /不担保/
ふたんりつ /負担率/
ふだ /札/簡/布田/
ふだい /府大/譜代/普代/
ふだしょ /札所/
ふだつき /札付/
ふだどめ /札止/
ふだらく /補陀洛/
ふだん /普段/不断/
ふだんいしき /普段意識/
ふだんぎ /普段着/
ふだんしよう /普段使用/
ふち /淵/縁/渕/付置/負値/渊/扶持/付値/附置/布置/
ふちかざり /縁飾り/
ふちがみ /渕上/
ふちけん /付置研/
ふちざき /渕崎/
ふちじ /府知事/
ふちの /渕野/
ふちのべ /淵野辺/渕野辺/
ふちまい /扶持米/
ふちゃく /付着/不着/
ふちゃくぶつ /付着物/
ふちゅう /府中/不忠/婦中/
ふちゅうい /不注意/
ふちゅうえき /府中駅/
ふちゅうかいどう /府中街道/
ふちゅうし /府中市/
ふちゅうしけんじょう /府中試験場/
ふちゅうしみん /府中市民/
ふちゅうひんとく /府中牝特/
ふちゅうほんまち /府中本町/
ふちょう /不調/符牒/府庁/婦長/符丁/
ふちょうきかん /不調期間/
ふちょうしゃ /府庁舎/
ふちょうわ /不調和/
ふちん /浮沈/不沈/
ふちんかん /不沈艦/
ふちんくうぼ /不沈空母/
ふちんせんかん /不沈戦艦/
ふっか /フッ化/
ふっかい /復改/
ふっかつ /復活/
ふっかつげき /復活劇/
ふっかつご /復活後/
ふっかつさい /復活祭/
ふっかつしゃ /復活者/
ふっかつしゅほう /復活手法/
ふっかつじ /復活時/
ふっかつせつ /復活説/
ふっかつせんげん /復活宣言/
ふっかつちょくご /復活直後/
ふっかつばん /復活盤/
ふっかん /復刊/
ふっき /復帰/
ふっきいらい /復帰以来/
ふっきしょせん /復帰初戦/
ふっきじょうほう /復帰情報/
ふっきせつ /復帰説/
ふっきせん /復帰戦/
ふっきち /復帰値/
ふっきほうほう /復帰方法/
ふっきゅう /復旧/復仇/
ふっきゅうさぎょう /復旧作業/
ふっきゅうしゃ /復旧車/
ふっきゅうじょうきょう /復旧状況/
ふっきゅうほうほう /復旧方法/
ふっきよてい /復帰予定/
ふっきん /腹筋/
ふっきんうんどう /腹筋運動/
ふっけん /復権/
ふっけんご /福建語/
ふっこ /復古/
ふっこう /復興/復交/腹腔/復航/
ふっこうだい /福工大/
ふっこく /復刻/覆刻/
ふっこくしょ /復刻書/
ふっこくばん /復刻版/覆刻版/
ふっこしゅ /復古酒/
ふっこしゅぎ /復古主義/
ふっこしゅぎしゃ /復古主義者/
ふっさ /福生/
ふっさし /福生市/
ふっしょく /払拭/
ふっせき /沸石/
ふった /フッタ/
ふっつ /富津/
ふってい /払底/
ふってん /沸点/
ふっとう /沸騰/拂騰/
ふっとうせき /沸騰石/
ふっとうてん /沸騰点/拂騰点/
ふっとぼーる /フットボール/
ふつ /沸/払/弗/仏/彿/佛/怫/拂/祓/髴/黻/布津/
ふついん /仏印/
ふつう /普通/不通/ふつ〜/
ふつううんちん /普通運賃/
ふつううんちんよう /普通運賃用/
ふつううんちんりょきゃく /普通運賃旅客/
ふつううんよう /普通運用/
ふつうおおがた /普通大型/
ふつうか /普通科/不通過/
ふつうがた /普通型/
ふつうがっきゅう /普通学級/
ふつうきっぷ /普通切符/
ふつうきょういく /普通教育/
ふつうこう /普通校/
ふつうこうざ /普通口座/
ふつうこうにゅう /普通購入/
ふつうし /普通紙/
ふつうしゃ /普通車/
ふつうしゃきんえんせき /普通車禁煙席/
ふつうしゃしていせき /普通車指定席/
ふつうしゃしよう /普通車使用/
ふつうしゃじゆうせき /普通車自由席/
ふつうしゃめんきょ /普通車免許/
ふつうしゅうゆうけん /普通周遊券/
ふつうじどうしゃ /普通自動車/
ふつうじょうしゃけん /普通乗車券/
ふつうじょうよう /普通乗用/
ふつうじょうようしゃ /普通乗用車/
ふつうじん /普通人/
ふつうせき /普通席/
ふつうせんきょ /普通選挙/
ふつうだんたい /普通団体/
ふつうていど /普通程度/
ふつうでんしゃ /普通電車/
ふつうどうろ /普通道路/
ふつうにゅうじょうけん /普通入場券/
ふつうば /普通馬/
ふつうばん /普通盤/
ふつうめいし /普通名詞/
ふつうめんきょ /普通免許/
ふつうめんきょしゅとく /普通免許取得/
ふつうもり /普通盛り/
ふつうゆうびん /普通郵便/
ふつうよきん /普通預金/
ふつうりょうきん /普通料金/
ふつうりょきゃくうんちん /普通旅客運賃/
ふつうれっしゃ /普通列車/
ふつか /２日/二日/2日/
ふつかいち /二日市/
ふつかかん /二日間/2日間/
ふつかご /二日後/
ふつかすいそさん /弗化水素酸/
ふつかまち /二日町/
ふつかめ /二日目/
ふつかよい /二日酔い/二日酔/宿酔/
ふつかれんぞく /二日連続/
ふつぎょう /払暁/
ふつぐん /仏軍/
ふつご /仏語/
ふつごう /不都合/
ふつごうてん /不都合点/
ふつごやく /仏語訳/
ふつごよみ /仏語読み/
ふつしゃ /仏車/
ふつつか /不束/
ふつふつ /勿勿/
ふつぶん /仏文/
ふつりあい /不釣合い/不釣合/
ふつれき /仏暦/
ふつわ /仏和/
ふづき /文月/
ふづくえ /文机/
ふてい /不定/不貞/不逞/不弟/不悌/婦弟/
ふていかんし /不定冠詞/
ふていき /不定期/
ふていきかんこう /不定期刊行/
ふていきてき /不定期的/
ふていきひょうじ /不定期表示/
ふていきれんさい /不定期連載/
ふていけい /不定形/
ふていこうせいさく /不抵抗政策/
ふていこん /不定根/
ふていし /不定詞/
ふていせい /不定性/
ふていせきぶん /不定積分/
ふていち /不定値/
ふていのやから /不逞の輩/
ふていほう /不定法/
ふてき /不適/不敵/
ふてきおう /不適応/
ふてきかく /不適格/
ふてきごう /不適合/
ふてきせい /不適正/
ふてきせつ /不適切/
ふてきちゅう /不的中/
ふてきとう /不適当/
ふてきにん /不適任/
ふてぎわ /不手際/
ふてくされる /不貞腐れる/
ふてってい /不徹底/
ふてん /符点/
ふてんはちぶ /符点八分/
ふで /筆/
ふでいれ /筆入れ/
ふでが /筆画/
ふでき /不出来/
ふでさき /筆先/
ふでたて /筆立て/
ふでづかい /筆遣い/
ふではこび /筆運び/
ふでばこ /筆箱/
ふでぶしょう /筆無精/
ふでぺん /筆ペン/
ふでもじ /筆文字/
ふと /太/不図/富戸/
ふとう /不当/不倒/埠頭/不等/不撓/不凍/不党/
ふとういつ /不統一/
ふとうえき /不凍液/
ふとうおう /不倒翁/
ふとうがた /不等型/
ふとうがたきこう /不等型気孔/
ふとうきょり /不倒距離/
ふとうこう /不凍港/
ふとうごう /不等号/＞/＜/
ふとうしき /不等式/
ふとうしょぶん /不当処分/
ふとうせい /不当性/
ふとうはんけつ /不当判決/
ふとうふくつ /不撓不屈/不倒不屈/
ふとうめい /不透明/
ふとうめいかん /不透明感/
ふとうめいけっちゃく /不透明決着/
ふとうれんばい /不当廉売/
ふとがき /太書き/
ふとく /不徳/
ふとくい /不得意/
ふとくてい /不特定/
ふとくていたすう /不特定多数/
ふとくていわしゃ /不特定話者/
ふとぐち /太口/
ふところ /懐/懷/
ふところがたな /懐刀/
ふところぐあい /懐具合/
ふとし /太/太司/
ふとじ /太字/
ふとせん /太線/
ふとせんか /太線化/
ふとっぱら /太っ腹/太腹/
ふとどき /不届き/不届/
ふとまき /太巻/
ふとめ /太め/太目/
ふともじ /太文字/
ふともも /太もも/太股/
ふともももく /フトモモ目/Myrtales/
ふともももくあぐん /フトモモ目亜群/
ふとわく /太枠/
ふとわくない /太枠内/
ふとん /布団/蒲団/
ふとんかんそうき /布団乾燥機/
ふどう /浮動/不同/不動/府道/
ふどうい /不同意/
ふどうさん /不動産/
ふどうさんがいしゃ /不動産会社/
ふどうさんぎょう /不動産業/
ふどうさんぎょうしゃ /不動産業者/
ふどうさんこうこく /不動産広告/
ふどうさんしゅとくぜい /不動産取得税/
ふどうさんじぎょう /不動産事業/
ふどうさんちゅうかい /不動産仲介/
ふどうさんとうきほう /不動産登記法/
ふどうさんぶもん /不動産部門/
ふどうさんや /不動産屋/
ふどうしょうすう /浮動小数/
ふどうしょうすうがた /浮動小数型/
ふどうしょうすうてん /浮動小数点/
ふどうしょうすうてんがた /浮動小数点型/
ふどうしょうすうてんすう /浮動小数点数/
ふどうしょうすうてんち /浮動小数点値/
ふどうしょうすうてんていすう /浮動小数点定数/
ふどうせい /浮動性/
ふどうそう /浮動層/
ふどうたい /不導体/
ふどうてん /不動点/浮動点/
ふどうてんていり /不動点定理/
ふどうとうげ /不動峠/
ふどうとく /不道徳/
ふどうとくしゃ /不道徳者/
ふどうにゅうりょく /浮動入力/
ふどうにょざん /不動如山/
ふどうひょう /浮動票/
ふどうまえ /不動前/
ふどうみょうおう /不動明王/
ふどき /風土記/
ふな /鮒/船/舟/舩/
ふなあし /船脚/船足/
ふない /船井/府内/
ふないり /舟入/
ふないりなかまち /舟入中町/
ふないりまち /舟入町/
ふなうた /舟歌/
ふなおか /船岡/
ふなか /不仲/
ふなかた /船方/
ふながいしゃ /船会社/
ふながた /船形/舟形/
ふなき /船木/舟木/
ふなくぼ /舟久保/
ふなぐら /船倉/船蔵/艙/
ふなこう /船高/
ふなこし /船越/
ふなぞこ /船底/
ふなたび /船旅/
ふなだ /船田/
ふなちん /船賃/
ふなつ /船津/舟津/
ふなつきば /船着場/船付場/
ふなづみ /船積み/
ふなづみこう /船積港/
ふなづり /船釣/舟釣/船釣り/
ふなで /船出/
ふなと /舟渡/船渡/
ふなど /船戸/
ふなに /船荷/
ふなぬし /船主/
ふなのり /船乗り/舟乗/船乗/
ふなはし /船橋/舟橋/
ふなばし /船橋/舟橋/
ふなばしえき /船橋駅/
ふなばしかん /船橋間/
ふなばしけいばじょう /船橋競馬場/
ふなばしざいじゅう /船橋在住/
ふなばしし /船橋市/
ふなばししちょう /船橋市長/
ふなばしつうか /船橋通過/
ふなばしていしゃ /船橋停車/
ふなばた /舷端/
ふなびき /船曳/
ふなびと /舟人/
ふなびん /船便/
ふなべり /舷縁/
ふなほ /船穂/
ふなま /船間/
ふなみず /船水/
ふなむら /舟村/
ふなやど /船宿/
ふなやま /船山/舟山/舩山/
ふなよい /船酔い/船酔/
ふなり /不成/
ふなれ /不慣れ/
ふなわ /舟和/
ふにく /腐肉/
ふにゅう /船生/腐乳/
ふにょい /不如意/
ふにん /赴任/不妊/
ふにんか /不妊化/
ふにんき /不人気/
ふにんききしゅ /不人気機種/
ふにんきしゃ /不人気車/
ふにんさき /赴任先/
ふにんしょう /不妊症/
ふにんちゅう /赴任中/
ふにんてあて /赴任手当/
ふにんてい /不認定/
ふぬけ /腑抜け/
ふね /船/舟/艦/舩/
ふねかんけい /船関係/
ふねひき /船引/
ふねや /船屋/
ふねよう /船用/
ふねようしんしつ /船用寝室/
ふねん /不燃/不稔/
ふねんか /不燃化/
ふねんせい /不燃性/
ふねんぶつ /不燃物/
ふの /布野/
ふのあたい /負の値/
ふのう /不能/
ふのうこう /不能項/
ふのうしゃ /不能者/
ふのうしょう /不能症/
ふは /不破/
ふはい /腐敗/不敗/
ふはいしゅう /腐敗臭/
ふはいしんわ /不敗神話/
ふはいぶつ /腐敗物/
ふはいぼうし /腐敗防止/
ふはく /浮薄/布帛/
ふはつ /不発/
ふはついく /不発育/
ふはつだん /不発弾/
ふはつだんしょり /不発弾処理/
ふばい /不買/
ふばいうんどう /不買運動/
ふばらい /不払い/
ふばん /符番/
ふばんたいけい /付番体系/
ふひつよう /不必要/
ふひょう /付表/不評/浮標/附票/
ふび /不備/
ふびょうどう /不平等/
ふびょうどうじょうやく /不平等条約/
ふびん /不憫/不便/不敏/
ふふく /不服/
ふふくじゅう /不服従/
ふぶ /布武/
ふぶき /吹雪/風吹/
ふぶん /腑分/
ふぶんりつ /不文律/
ふへい /不平/
ふへいこう /不平衡/
ふへいこうかん /不平衡間/
ふへいふまん /不平不満/
ふへん /不変/普遍/不偏/不遍/
ふへんか /普遍化/
ふへんしき /不変式/
ふへんしゅうきょう /普遍宗教/
ふへんせい /不変性/普遍性/
ふへんてき /普遍的/不変的/
ふへんてきほうそく /普遍的法則/
ふへんてきりっぽう /普遍的立法/
ふへんてきりろん /普遍的理論/
ふへんねっと /不変ネット/
ふへんぱたあんにんしき /不変パターン認識/
ふへんひふくしゃぞう /普遍被覆写像/
ふへんふとう /不偏不党/
ふへんぶんさん /不偏分散/
ふへんほうそく /普遍法則/
ふへんりょう /不変量/
ふへんろんそう /普遍論争/
ふべん /不便/
ふべんきょう /不勉強/
ふべんきょうもの /不勉強者/
ふほ /付保/
ふほう /不法/訃報/
ふほうかいぞう /不法改造/
ふほうぎょうしゃ /不法業者/
ふほうこうい /不法行為/
ふほうこういせきにん /不法行為責任/
ふほうしよう /不法使用/
ふほうせい /不法性/
ふほうちたい /不法地帯/
ふほうとうき /不法投棄/
ふほうらん /訃報欄/
ふほんい /不本意/
ふぼ /父母/
ふぼかい /父母会/
ふぼん /不犯/
ふまい /不昧/
ふまじめ /不真面目/不まじめ/
ふまん /不満/
ふまんかいしょう /不満解消/
ふまんがお /不満顔/
ふまんすいじゅん /不満水準/
ふまんぞく /不満足/
ふまんてん /不満点/
ふみ /文/踏み/史/郁/章/二三/
ふみあき /文昭/史光/文明/
ふみあけ /文朱/
ふみえ /踏み絵/文絵/踏絵/
ふみお /文男/文夫/文雄/二三男/史緒/史男/文郎/史夫/郁雄/
ふみか /史佳/
ふみかず /文一/
ふみきり /踏切/踏み切り/
ふみきりじこ /踏切事故/
ふみきりじこたいさく /踏切事故対策/
ふみきりせいぎょ /踏切制御/
ふみきりたいさく /踏切対策/
ふみきりない /踏切内/
ふみきりもんだい /踏切問題/
ふみこ /富美子/冨美子/文子/史子/ふみ子/
ふみこみ /踏み込み/踏みこみ/踏込み/
ふみし /二三四/
ふみたか /文隆/文孝/
ふみたけ /文武/
ふみただ /文忠/
ふみだい /踏台/踏み台/
ふみづき /文月/
ふみと /文人/史人/
ふみとし /文敏/文俊/
ふみとよ /文豊/
ふみのぶ /文信/
ふみのり /文典/
ふみひこ /文彦/郁彦/史彦/
ふみひで /文秀/
ふみひと /文仁/史人/
ふみひろ /史裕/文博/文浩/文礼/
ふみまさ /章雅/
ふみや /郁也/文也/
ふみやす /文康/文保/
ふみゆき /文之/文行/
ふみよ /文代/扶三代/
ふみよし /文良/文嘉/文義/
ふみん /不眠/府民/
ふみんしょう /不眠症/
ふみんふきゅう /不眠不休/
ふむき /不向き/
ふめい /不明/
ふめいかい /不明解/不明快/
ふめいかく /不明確/
ふめいしゃ /不明者/
ふめいてん /不明点/
ふめいよ /不名誉/
ふめいりょう /不明瞭/
ふめつ /不滅/
ふめん /譜面/符面/
ふめんいんさつ /譜面印刷/
ふめんじょう /譜面上/
ふめんひょうき /譜面表記/
ふもう /不毛/
ふもうか /不毛化/
ふもと /麓/梺/
ふもん /不問/
ふやじょう /不夜城/
ふゆ /冬/
ふゆいがい /冬以外/
ふゆいらい /冬以来/
ふゆう /浮遊/富裕/富有/浮有/
ふゆうかん /浮遊感/
ふゆうせき /浮遊石/
ふゆうたいりく /浮遊大陸/
ふゆうぶつ /浮遊物/
ふゆうれい /浮遊霊/
ふゆかい /不愉快/
ふゆがた /冬型/
ふゆがっしゅく /冬合宿/
ふゆがれ /冬枯れ/
ふゆき /冬樹/冬木/
ふゆきとどき /不行届き/
ふゆげ /冬毛/
ふゆげしき /冬景色/
ふゆこ /冬子/
ふゆこみ /冬コミ/
ふゆごう /冬号/
ふゆごし /冬越し/
ふゆごろ /冬頃/
ふゆしょうぐん /冬将軍/
ふゆじかん /冬時間/
ふゆじたく /冬支度/
ふゆとうらい /冬到来/
ふゆねこ /冬猫/
ふゆば /冬場/
ふゆひこ /冬彦/
ふゆび /冬日/
ふゆふく /冬服/
ふゆみ /冬美/
ふゆみち /冬道/
ふゆもの /冬物/
ふゆものがたり /冬物語/
ふゆやすみ /冬休み/
ふゆやま /冬山/
ふゆやまや /冬山屋/
ふゆやまよう /冬山用/
ふゆよう /冬用/
ふよ /付与/賦与/
ふよう /不要/扶養/不用/芙容/浮揚/芙蓉/
ふようい /不用意/
ふようかきゅう /扶養加給/
ふようかぞく /扶養家族/
ふようかぞくてあて /扶養家族手当/
ふようしゃ /扶養者/
ふようしゃこうじょ /扶養者控除/
ふようしゃてあて /扶養者手当/
ふようじょう /不養生/
ふようじょうほう /不用情報/
ふようせい /不溶性/
ふようだい /芙容台/
ふようど /腐葉土/
ふようひん /不用品/不要品/
ふようふきゅう /不要不急/
ふようふくしゃ /不要輻射/
ふようぶつ /不要物/
ふようぶぶん /不要部分/
ふようりょく /浮揚力/
ふようろん /不用論/
ふらい /フライ/
ふらいと /フライト/
ふらいぱん /フライパン/
ふらいんぐ /フライング/
ふらぐ /フラグ/
ふらち /不埓/不埒/
ふらっしゅ /フラッシュ/
ふらっと /♭/フラット/
ふらの /富良野/
ふらのえき /富良野駅/
ふらのこくどう /富良野国道/
ふらわー /フラワー/
ふらん /不乱/腐乱/腐爛/孵卵/
ふらんす /フランス/仏蘭西/佛蘭西/仏/
ふらんすご /フランス語/
ふり /不利/振/
ふりー /フリー/
ふりーきしゃ /フリー記者/
ふりーく /フリーク/
ふりーそふと /フリーソフト/
ふりあて /振り当て/
ふりえき /不利益/
ふりかえ /振替/
ふりかえきゅうじつ /振替休日/
ふりかえてすうりょう /振替手数料/
ふりかえひょう /振替票/
ふりかえゆそう /振替輸送/
ふりかた /振り方/
ふりがな /振仮名/振り仮名/
ふりこ /振り子/振子/
ふりこう /不履行/
ふりこきき /振子機器/
ふりこぐるま /振子車/
ふりこつうきんしゃ /振子通勤車/
ふりこでんしゃ /振子電車/
ふりこみ /振込み/振込/振り込み/
ふりこみき /振り込み機/
ふりこみさき /振込先/
ふりこみしゃめい /振込者名/
ふりこみてすうりょう /振込手数料/
ふりこみにん /振込人/
ふりこみび /振込日/
ふりこみようし /振込用紙/
ふりこみよていび /振込予定日/
ふりこれっしゃ /振子列車/
ふりごま /振り駒/
ふりすびー /フリスビー/
ふりそで /振り袖/振袖/
ふりだし /振出/
ふりだしきょく /振出局/
ふりだしにん /振出人/
ふりつ /府立/振津/
ふりつけ /振り付け/振付け/振付/
ふりつこうこう /府立高校/
ふりつだいがく /府立大学/
ふりてん /振聴/
ふりなじょうけん /不利な条件/
ふりはた /降籏/
ふりびしゃ /振り飛車/
ふりむき /振り向き/
ふりょ /不慮/俘慮/俘虜/
ふりょう /不良/不漁/
ふりょうかいいん /不良会員/
ふりょうかしょ /不良箇所/
ふりょうかりつ /不良化率/
ふりょうこうこうせい /不良高校生/
ふりょうさいけん /不良債権/
ふりょうさいけんか /不良債権化/
ふりょうざいこ /不良在庫/
ふりょうしゃかいじん /不良社会人/
ふりょうしょうじょ /不良少女/
ふりょうせくた /不良セクタ/
ふりょうとうこうしゃ /不良投稿者/
ふりょうばば /不良馬場/
ふりょうひん /不良品/
ふりょうぶっけん /不良物件/
ふりょうりつ /不良率/
ふりょく /浮力/
ふりょくくどう /浮力駆動/
ふりわけ /振り分け/振分/
ふりん /不倫/
ふりんあいて /不倫相手/
ふる /古/フル/
ふるーつ /フルーツ/
ふるい /古井/古い/篩/
ふるいち /古市/
ふるいど /古井戸/
ふるう /古宇/
ふるうち /古内/
ふるえ /震え/古恵/古江/
ふるおや /古尾谷/
ふるかぶ /古株/
ふるかわ /古川/古河/
ふるかわえきにしぐち /古河駅西口/
ふるかわこうぎょう /古河鉱業/
ふるかわし /古川市/
ふるかわちょう /古川町/
ふるかわでんきこうぎょう /古河電気工業/
ふるかわでんこう /古河電工/
ふるかわでんち /古河電池/
ふるがっき /古楽器/
ふるき /古木/
ふるきず /古傷/
ふるぎ /古着/
ふるぎって /古切手/
ふるぎや /古着屋/
ふるくさい /古臭い/
ふるこおり /古郡/
ふるごう /古国府/
ふるごおり /古郡/
ふるさか /古坂/
ふるさと /故郷/古里/故里/
ふるさわ /古沢/古澤/
ふるざけ /古酒/
ふるざっし /古雑誌/
ふるしま /古島/
ふるしんぶん /古新聞/
ふるす /古巣/
ふるせ /古瀬/
ふるそう /古荘/
ふるた /古田/
ふるたか /古鷹/
ふるたち /古館/古舘/
ふるたちいちろう /古舘伊知郎/
ふるたて /古舘/
ふるたに /古谷/
ふるだち /古舘/
ふるだて /古舘/
ふるだぬき /古狸/
ふるつわもの /古強者/古兵/
ふるて /古手/
ふるでら /古寺/
ふると /古戸/
ふるとり /隹/
ふるどうぐ /古道具/
ふるどけい /古時計/
ふるどの /古殿/
ふるどり /隹/
ふるの /古野/
ふるはうす /フルハウス/
ふるはし /古橋/
ふるはた /古畑/古籏/
ふるびら /古平/
ふるほん /古本/
ふるほんいち /古本市/
ふるほんかい /古本界/
ふるほんや /古本屋/
ふるほんやがい /古本屋街/
ふるまい /振舞い/振舞/
ふるまち /古町/
ふるむら /古村/
ふるもと /古本/
ふるもの /古物/
ふるや /古屋/古谷/古矢/古家/
ふるやま /古山/
ふれ /振れ/
ふれーく /フレーク/
ふれあい /ふれ合い/
ふれい /譜例/布令/負例/
ふれかく /振れ角/
ふれはば /振れ幅/
ふれる /振れる/
ふれんけつせい /不連結性/
ふれんぞく /不連続/
ふれんぞくせい /不連続性/
ふれんぞくちょうやく /不連続跳躍/
ふれんぞくてき /不連続的/
ふれんぞくてん /不連続点/
ふれんち /フレンチ/
ふれんど /普連土/
ふれんどがくえん /普連土学園/
ふろ /風呂/風炉/
ふろあ /フロア/
ふろあがり /風呂あがり/
ふろう /不老/不労/浮浪/
ふろうしゃ /浮浪者/
ふろうしょとく /不労所得/
ふろうちょう /不老町/
ふろうちょうじゅ /不老長寿/
ふろうふし /不老不死/
ふろうりん /不老林/
ふろおけ /風呂桶/
ふろく /付録/附録/
ふろくいっさつ /付録一冊/
ふろくほんたい /付録本体/
ふろしき /風呂敷/
ふろっぴー /フロッピー/
ふろば /風呂場/
ふろや /風呂屋/
ふろんと /フロント/
ふろんり /負論理/
ふろんりしき /負論理式/
ふわ /不和/不破/付和/
ふわく /不惑/
ふわけ /腑分け/
ふわたり /不渡り/
ふわらいどう /付和雷同/
ふわり /譜割/
ふん /分/糞/雰/紛/粉/奮/噴/焚/扮/憤/墳/吻/′/刎/吩/忿/枌/氛/汾/濆/芬/賁/
ふんあつ /分圧/
ふんい /雰囲/
ふんいき /雰囲気/氛圍氣/
ふんいきてき /雰囲気的/
ふんいんき /雰囲気/
ふんえん /噴煙/
ふんか /噴火/
ふんかこう /噴火口/
ふんかさいがい /噴火災害/
ふんかわん /噴火湾/
ふんかん /分間/
ふんかんかく /分間隔/
ふんがい /憤慨/
ふんき /奮起/
ふんきゅう /紛糾/
ふんぎ /紛議/
ふんけい /刎頚;頚(くび)を刎(は)ねること/刎頸;頸(くび)を刎(は)ねること/
ふんげき /憤激/
ふんころ /分頃/
ふんご /分後/
ふんごう /吻合/
ふんごと /分毎/
ふんさい /粉砕/
ふんさつ /焚殺/
ふんし /憤死/
ふんしつ /紛失/粉失/
ふんしつきゅう /紛失球/
ふんしつじ /紛失時/
ふんしつとどけ /紛失届/
ふんしゃ /噴射/
ふんしゃしき /噴射式/
ふんしゃねんりょう /噴射燃料/
ふんしゃまえ /噴射前/
ふんしゃりょう /噴射量/
ふんしゅうは /分周波/
ふんしゅつ /噴出/
ふんしゅつおん /噴出音/
ふんしょ /焚書/
ふんしょく /粉飾/
ふんしょこうじゅ /焚書坑儒/
ふんしん /分針/
ふんじん /粉塵/
ふんじんきせい /粉塵規制/
ふんすい /噴水/
ふんせん /奮戦/
ふんせんき /奮戦記/
ふんぜん /奮然/憤然/
ふんそう /扮装/紛争/粉争/
ふんそうちいき /紛争地域/
ふんそく /分速/吻側/
ふんたい /粉体/
ふんたいこうがく /粉体工学/
ふんたいこうがっかい /粉体工学会/
ふんたんい /分単位/
ふんとう /奮闘/
ふんとうき /奮闘記/
ふんど /憤怒/忿怒/
ふんどう /分銅/
ふんどし /褌/
ふんにゅう /粉乳/
ふんにょう /糞尿/
ふんぬ /憤怒/忿怒/
ふんはん /分半/
ふんぱつ /奮発/
ふんぱん /噴飯/
ふんびょう /分秒/
ふんぷん /紛々/
ふんべつ /分別/
ふんぼ /墳墓/
ふんまえ /分前/
ふんまつ /粉末/
ふんまつせんざい /粉末洗剤/
ふんまん /憤懣/忿懣/
ふんみまん /分未満/
ふんむ /噴霧/
ふんむき /噴霧器/
ふんめつ /焚滅/
ふんりゅう /噴流/粉瘤;医学用語/
ふんりゅうしき /噴流式/
ふんりゅうすいしんき /噴流推進機/
ふんれい /奮励/
ぶ /部/分/無/武/蕪/舞/葡/撫/侮/不/歩/蒲/嘸/廡/憮/毋/誣/錻/悔/奉/
ぶーす /ブース/
ぶーすた /ブースタ/
ぶーつ /ブーツ/
ぶーむ /ブーム/
ぶあい /歩合/部合/
ぶあいきゅう /歩合給/
ぶあいそ /無愛想/不愛想/
ぶあいそう /無愛想/
ぶあく /武悪/
ぶあつい /ぶ厚い/
ぶあんない /不案内/
ぶい /部位/
ぶいち /武一/
ぶいん /部員/
ぶいんすう /部員数/
ぶえ /笛/
ぶえんりょ /無遠慮/
ぶおとこ /醜男/
ぶおんぷ /分音符/
ぶか /部下/深/部科/部課/
ぶかい /部会/
ぶかいしゅさい /部会主催/
ぶかいせい /部会制/
ぶかたち /部下達/
ぶかちょう /部課長/
ぶかっこう /不格好/
ぶかつ /部活/
ぶかつどう /部活動/
ぶかめい /部課名/
ぶかん /武官/武漢/
ぶがい /部外/
ぶがいしゃ /部外者/
ぶがいひ /部外秘/
ぶき /武器/
ぶきえんじょ /武器援助/
ぶきか /武器化/
ぶきかんれんゆしゅつ /武器関連輸出/
ぶききんゆ /武器禁輸/
ぶきしょうにん /武器商人/
ぶきてん /武器店/
ぶきとりひき /武器取引/
ぶきはかい /武器破壊/
ぶきみ /不気味/
ぶきや /武器屋/
ぶきゆしゅつ /武器輸出/
ぶきゆしゅつこく /武器輸出国/
ぶきょく /部局/舞曲/
ぶきょくかん /部局間/
ぶきょくじゅん /部局順/
ぶきょくちょう /部局長/
ぶきよう /不器用/
ぶきるい /武器類/
ぶぎ /部議/
ぶぎょう /奉行/
ぶく /伏/
ぶくうじゅつ /舞空術/
ぶくろ /袋/
ぶくん /武勲/
ぶぐ /武具/
ぶぐいがい /武具以外/
ぶけ /武家/
ぶけさま /武家様/
ぶけしゃかい /武家社会/
ぶけん /武見/
ぶげい /武芸/
ぶげいちょう /武芸帳/
ぶげいひゃっぱん /武芸百般/
ぶげん /無限/
ぶこう /武功/
ぶこうやわ /武功夜話/
ぶこく /誣告/
ぶこつ /武骨/無骨/
ぶさいく /不細工/
ぶさく /部作/
ぶさた /無沙汰/
ぶさつ /撫擦/
ぶさほう /無作法/不作法/
ぶざー /ブザー/
ぶざい /部材/ξ/
ぶざま /不様/無様/
ぶし /武士/節/部誌/
ぶしかいきゅう /武士階級/
ぶしつ /部室/物質/
ぶしつけ /不しつけ/不躾/
ぶしどう /武士道/
ぶしゅ /部首/
ぶしゅうぎ /不祝儀/
ぶしゅさくいん /部首索引/
ぶしゅにゅうりょく /部首入力/
ぶしゅべつさくいん /部首別索引/
ぶしゅめい /部首名/
ぶしょ /部署/部所/
ぶしょう /不精/無精/武将/
ぶしょうひげ /不精髭/無精髭/
ぶしょうもの /不精者/
ぶしょがい /部署外/
ぶしょない /部署内/
ぶしょめい /部署名/部所名/
ぶじ /無事/
ぶじかいけつ /無事解決/
ぶじきかん /無事帰還/
ぶじきこく /無事帰国/
ぶじこれめいば /無事是名馬/
ぶじさいこうふ /無事再交付/
ぶじしゅうりょう /無事終了/
ぶじつうか /無事通過/
ぶじとうちゃく /無事到着/
ぶじとっぱ /無事突破/
ぶじに /無事に/
ぶじにゅうしゅ /無事入手/
ぶじはっけん /無事発見/
ぶじょく /侮辱/
ぶじょくいがい /侮辱以外/
ぶじょくこうい /侮辱行為/
ぶじょくざい /侮辱罪/
ぶじょくてき /侮辱的/
ぶじょくてきひょうげん /侮辱的表現/
ぶじん /武人/
ぶす /ブス/
ぶすい /不粋/無粋/
ぶすう /部数/
ぶすじま /毒島/
ぶせい /部制/
ぶぜい /無勢/
ぶぜん /豊前/憮然/
ぶそう /武装/
ぶそうかいじょ /武装解除/
ぶそうがったい /武装合体/
ぶそく /不足/
ぶそん /武尊/
ぶぞく /部族/
ぶた /豚/蓋/盖/葢/
ぶたい /部隊/舞台/
ぶたいあいさつ /舞台挨拶/
ぶたいいしょう /舞台衣装/
ぶたいいっきせい /部隊一期生/
ぶたいうら /舞台裏/
ぶたいおんきょう /舞台音響/
ぶたいがわ /舞台側/
ぶたいげいじゅつ /舞台芸術/
ぶたいげき /舞台劇/
ぶたいこうえん /舞台公演/
ぶたいさつえい /舞台撮影/
ぶたいじょう /舞台上/
ぶたいすう /部隊数/
ぶたいせってい /舞台設定/
ぶたいぜんたい /舞台全体/
ぶたいそうち /舞台装置/
ぶたいそで /舞台袖/
ぶたいたんい /部隊単位/
ぶたいちゅうおう /舞台中央/
ぶたいちゅうけい /舞台中継/
ぶたいちょう /部隊長/
ぶたいはいゆう /舞台俳優/
ぶたいはつおん /舞台発音/
ぶたいびじゅつ /舞台美術/
ぶたいへんせい /部隊編成/
ぶたいゆか /舞台床/
ぶたいよう /舞台用/
ぶたごや /豚小屋/
ぶたじる /豚汁/
ぶたじるふう /豚汁風/
ぶたたま /豚玉/
ぶたたまてん /豚玉天/
ぶたどん /豚丼/
ぶたにく /豚肉/
ぶたばこ /豚箱/
ぶたまんや /豚饅屋/
ぶだいか /舞台化/
ぶち /淵/渕/斑/渊/ブチ/
ぶちょう /部長/
ぶちょうかい /部長会/
ぶちょうしつ /部長室/
ぶちょうせき /部長席/
ぶちょうづき /部長付/
ぶちょうほう /不調法/
ぶちょうほさ /部長補佐/
ぶっか /物価/
ぶっかかんかく /物価感覚/
ぶっかく /仏閣/物覚/
ぶっかじじょう /物価事情/
ぶっかだか /物価高/
ぶっきょう /仏教/佛教/
ぶっきょういせき /仏教遺跡/
ぶっきょうがく /仏教学/
ぶっきょうきょうてん /仏教教典/
ぶっきょうけい /仏教系/
ぶっきょうこく /仏教国/
ぶっきょうし /仏教史/
ぶっきょうしき /仏教式/
ぶっきょうせいてん /仏教聖典/
ぶっきょうぜんぱん /仏教全般/
ぶっきょうだい /仏教大/
ぶっきょうと /仏教徒/
ぶっきょうようご /仏教用語/
ぶっく /ブック/
ぶっくす /ブックス/
ぶっくまーと /ブックマート/
ぶっけん /物件/物研/
ぶっけんこうにゅうしゃ /物件購入者/
ぶっけんひ /物件費/
ぶっけんほう /物権法/
ぶっこ /物故/
ぶっこう /物工/
ぶっさん /物産/
ぶっし /物資/仏師/
ぶっしき /仏式/
ぶっしつ /物質/
ぶっしつか /物質化/
ぶっしつかがく /物質科学/
ぶっしつかん /物質間/
ぶっしつけん /物質研/
ぶっしつげんしょう /物質現象/
ぶっしつこうぞう /物質構造/
ぶっしつせいめいかがく /物質生命科学/
ぶっしつたいしゃ /物質代謝/
ぶっしつちゅう /物質中/
ぶっしつてき /物質的/
ぶっしつてきじゅうそく /物質的充足/
ぶっしつてきほしょう /物質的補償/
ぶっしつば /物質場/
ぶっしつふくせいき /物質複製機/
ぶっしつぶんぷ /物質分布/
ぶっしつめい /物質名/
ぶっしつゆそう /物質輸送/
ぶっしでんそう /物質伝送/
ぶっしょう /物証/
ぶっしょうい /仏正意/
ぶっしょく /物色/
ぶっしょくちゅう /物色中/
ぶっしん /物心/
ぶっせい /物性/仏性/
ぶっせいかがくせんこう /物性科学専攻/
ぶっせいがく /物性学/
ぶっせいがくせんこう /物性学専攻/
ぶっせいきそろん /物性基礎論/
ぶっせいけい /物性系/
ぶっせいけん /物性研/
ぶっせいけんきゅう /物性研究/
ぶっせいぶつりがく /物性物理学/
ぶっせいや /物性屋/
ぶっせいりろん /物性理論/
ぶっせいろん /物性論/
ぶっそう /物騒/
ぶっそん /物損/
ぶっそんじこ /物損事故/
ぶったい /物体/
ぶったいがわ /物体側/
ぶったいない /物体内/
ぶったいないぶ /物体内部/
ぶったいにんしき /物体認識/
ぶったいひょうめん /物体表面/
ぶっだ /仏陀/
ぶっだしゃくそん /仏陀釈尊/
ぶっちょうずら /仏頂面/
ぶっちょうづら /仏頂面/
ぶってき /物的/
ぶってきしょうこ /物的証拠/
ぶってん /仏典/
ぶってんちゅう /仏典中/
ぶっとう /仏塔/
ぶっぴん /物品/
ぶっぴんぜい /物品税/
ぶっぴんだい /物品代/
ぶっぽう /仏法/
ぶっぽうそう /仏法僧/
ぶつ /物/仏/勿/佛/
ぶつえん /仏縁/
ぶつえんほう /仏炎苞/
ぶつぎ /物議/
ぶつぎり /ぶつ切り/
ぶつじ /仏事/
ぶつぜん /仏前/
ぶつぞう /仏像/
ぶつだい /仏大/
ぶつだん /仏壇/
ぶつのう /物納/
ぶつぶつ /物々/勿勿/
ぶつぶつこうかん /物々交換/
ぶつま /仏間/
ぶつめつ /仏滅/
ぶつもう /勿罔/
ぶつもん /仏門/
ぶつよく /物欲/
ぶつり /物理/
ぶつりあいこうしゃ /物理愛好者/
ぶつりいがい /物理以外/
ぶつりか /物理科/
ぶつりかい /物理界/
ぶつりかがく /物理化学/
ぶつりかてい /物理過程/
ぶつりかんけい /物理関係/
ぶつりがく /物理学/物理學/
ぶつりがくえんしゅう /物理学演習/
ぶつりがくきょういく /物理学教育/
ぶつりがくきょうしつ /物理学教室/
ぶつりがくけんきゅう /物理学研究/
ぶつりがくけんきゅうかい /物理学研究会/
ぶつりがくけんきゅうしょ /物理学研究所/
ぶつりがくし /物理学史/
ぶつりがくしゃ /物理学者/
ぶつりがくしゃたち /物理学者達/
ぶつりがくしょ /物理学書/
ぶつりがくじっけん /物理学実験/
ぶつりがくじてん /物理学辞典/
ぶつりがくてき /物理学的/
ぶつりがくてきそくていほう /物理学的測定法/
ぶつりがくてきほうそく /物理学的法則/
ぶつりがっか /物理学科/
ぶつりがっかい /物理学会/
ぶつりがっかいし /物理学会誌/
ぶつりがっかいゆうし /物理学会有志/
ぶつりきじ /物理記事/
ぶつりきょういく /物理教育/
ぶつりきょうしつ /物理教室/
ぶつりぎょうかい /物理業界/
ぶつりけい /物理系/
ぶつりけいさん /物理計算/
ぶつりけいせんこう /物理系専攻/
ぶつりけん /物理研/
ぶつりけんきゅうぶ /物理研究部/
ぶつりげんしょう /物理現象/
ぶつりげんそく /物理原則/
ぶつりげんり /物理原理/
ぶつりこうぎ /物理講義/
ぶつりこうげき /物理攻撃/
ぶつりさよう /物理作用/
ぶつりしりょうしつ /物理資料室/
ぶつりじっけん /物理実験/
ぶつりじっけんしつ /物理実験室/
ぶつりじっけんや /物理実験屋/
ぶつりじょうすう /物理定数/
ぶつりじょうたい /物理状態/
ぶつりじょうほうぶ /物理情報部/
ぶつりすうがく /物理数学/
ぶつりせい /物理性/
ぶつりせいげん /物理制限/
ぶつりせいぶつ /物理生物/
ぶつりせかい /物理世界/
ぶつりせんこう /物理専攻/
ぶつりそう /物理層/
ぶつりそんざい /物理存在/
ぶつりちゅうしん /物理中心/
ぶつりていこくしゅぎ /物理帝国主義/
ぶつりていすう /物理定数/
ぶつりてき /物理的/
ぶつりてきあんていせい /物理的安定性/
ぶつりてきいち /物理的位置/
ぶつりてきいみ /物理的意味/
ぶつりてきかいしゃく /物理的解釈/
ぶつりてきかこう /物理的加工/
ぶつりてきかてい /物理的過程/
ぶつりてきかんきょう /物理的環境/
ぶつりてききょり /物理的距離/
ぶつりてきけいぞくじかん /物理的継続時間/
ぶつりてきけいたい /物理的形態/
ぶつりてきげんかい /物理的限界/
ぶつりてきげんしょう /物理的現象/
ぶつりてきこうい /物理的行為/
ぶつりてきこうぞう /物理的構造/
ぶつりてきさいげんせい /物理的再現性/
ぶつりてきさよう /物理的作用/
ぶつりてきしせつ /物理的施設/
ぶつりてきしてん /物理的視点/
ぶつりてきしひょう /物理的指標/
ぶつりてきしょうがい /物理的障害/
ぶつりてきじげん /物理的次元/
ぶつりてきじったい /物理的実体/
ぶつりてきじつざい /物理的実在/
ぶつりてきじょうきょう /物理的状況/
ぶつりてきじょうけん /物理的条件/
ぶつりてきじょうしき /物理的常識/
ぶつりてきせいげん /物理的制限/
ぶつりてきそんざい /物理的存在/
ぶつりてきたいしょう /物理的対象/
ぶつりてきたいしょうせい /物理的対称性/
ぶつりてきとくせい /物理的特性/
ぶつりてきほうそく /物理的法則/
ぶつりてきよういん /物理的要因/
ぶつりとくせい /物理特性/
ぶつりにゅうもん /物理入門/
ぶつりぶ /物理部/
ぶつりほうそく /物理法則/
ぶつりめい /物理名/
ぶつりもんだい /物理問題/
ぶつりや /物理屋/
ぶつりゅう /物流/
ぶつりゅうぶもん /物流部門/
ぶつりゅうめん /物流面/
ぶつりょう /物量/物療/
ぶつりようご /物理用語/
ぶつりりょう /物理量/
ぶつりりろん /物理理論/
ぶつりりろんか /物理理論家/
ぶてぃっく /ブティック/
ぶてい /武帝/
ぶでん /舞殿/
ぶと /太/
ぶとう /舞踏/舞踊/
ぶとうおんがく /舞踏音楽/
ぶとうか /武闘家/舞踊家/
ぶとうかい /舞踊会/舞踏会/武闘会/
ぶとうたいかい /武闘大会/
ぶとうだん /舞踊団/舞踏団/
ぶとうてき /舞踏的/
ぶどう /葡萄/武道/
ぶどうか /ブドウ科/武道家/
ぶどうかん /武道舘/武道館/
ぶどうかんこうえん /武道館公演/
ぶどうかんたいかい /武道館大会/
ぶどうかんとも /武道館共/
ぶどうじょ /武道所/
ぶどうじょう /武道場/
ぶどうたいかい /武道大会/
ぶどうとう /葡萄糖/
ぶどうばたけ /葡萄畑/
ぶどまり /歩留まり/
ぶな /樗/
ぶない /部内/
ぶないしゃ /部内者/
ぶないりょこう /部内旅行/
ぶなもく /ブナ目/Fagales/
ぶなもくあぐん /ブナ目亜群/
ぶなもくぐん /ブナ目群/
ぶなん /無難/武南/
ぶね /船/
ぶばいがわら /分倍河原/
ぶばいがわらえき /分倍河原駅/
ぶひ /部費/
ぶひん /部品/
ぶひんか /部品化/
ぶひんかかく /部品価格/
ぶひんきょうきゅう /部品供給/
ぶひんきょうはん /部品共販/
ぶひんこうかん /部品交換/
ぶひんごかん /部品互換/
ぶひんさいりようほう /部品再利用法/
ぶひんすう /部品数/
ぶひんたんい /部品単位/
ぶひんだい /部品代/
ぶひんだいきん /部品代金/
ぶひんていきょう /部品提供/
ぶひんてんすう /部品点数/
ぶひんひょう /部品表/
ぶひんめい /部品名/
ぶひんや /部品屋/
ぶひんゆそうりょう /部品輸送料/
ぶびき /歩引き/
ぶぶん /部分/
ぶぶんいがい /部分以外/
ぶぶんいったい /部分一体/
ぶぶんいんよう /部分引用/
ぶぶんおん /部分音/
ぶぶんおんれつ /部分音列/
ぶぶんかいぎょう /部分開業/
ぶぶんかいつう /部分開通/
ぶぶんかいてい /部分改訂/部分改定/
ぶぶんかくてい /部分確定/
ぶぶんかんすう /部分関数/
ぶぶんきょうか /部分強化/
ぶぶんぎ /部分木/
ぶぶんくうかん /部分空間/
ぶぶんくうかんほう /部分空間法/
ぶぶんぐん /部分群/
ぶぶんけい /部分系/
ぶぶんけいさん /部分計算/
ぶぶんけいさんき /部分計算器/
ぶぶんけいさんほう /部分計算法/
ぶぶんけいろ /部分経路/
ぶぶんけっか /部分結果/
ぶぶんこう /部分項/
ぶぶんこうぞう /部分構造/
ぶぶんし /部分枝/
ぶぶんしき /部分式/
ぶぶんしてい /部分指定/
ぶぶんしゅうごう /部分集合/
ぶぶんしょく /部分食/
ぶぶんしんくう /部分真空/
ぶぶんせいげん /部分制限/
ぶぶんぜんたい /部分全体/
ぶぶんそうかんけいすう /部分相関係数/
ぶぶんそっこう /部分測光/
ぶぶんてき /部分的/
ぶぶんてきさいてきか /部分的最適化/
ぶぶんでんかかいぎょう /部分電化開業/
ぶぶんどうし /部分同士/
ぶぶんどうちかんけい /部分同値関係/
ぶぶんにっしょく /部分日食/
ぶぶんはいしご /部分廃止後/
ぶぶんはいれつ /部分配列/
ぶぶんひてい /部分否定/
ぶぶんひょうか /部分評価/
ぶぶんひん /部分品/
ぶぶんぶぶん /部分部分/
ぶぶんへんこう /部分変更/
ぶぶんほうき /部分放棄/
ぶぶんもじれつ /部分文字列/
ぶぶんもんだい /部分問題/
ぶぶんりょういき /部分領域/
ぶぶんりろん /部分理論/
ぶぶんれつ /部分列/
ぶぶんろんりしき /部分論理式/
ぶぶんわ /部分和/
ぶぶんを /部分/
ぶべつ /侮蔑/
ぶめい /部名/
ぶめん /部面/
ぶもん /部門/武門/
ぶもんかん /部門間/
ぶもんごと /部門毎/
ぶもんすう /部門数/
ぶもんせつりつ /部門設立/
ぶもんたんにん /部門担任/
ぶもんない /部門内/
ぶもんにんきとうひょう /部門人気投票/
ぶもんひ /部門費/
ぶもんべつ /部門別/
ぶもんめい /部門名/
ぶもんゆうしょう /部門優勝/
ぶゆ /蚋/
ぶゆう /武勇/
ぶゆうでん /武勇伝/
ぶよ /蚋/
ぶよう /舞踊/
ぶようじん /不用心/
ぶようどう /武揚堂/
ぶらい /無頼/
ぶらいんど /ブラインド/
ぶらうす /ブラウス/
ぶらうんかん /ブラウン管/
ぶらく /部落/
ぶらくかいほううんどう /部落解放運動/
ぶらくかいほうどうめい /部落解放同盟/
ぶらくさべつ /部落差別/
ぶらくしゅっしん /部落出身/
ぶらくしゅっしんしゃ /部落出身者/
ぶらくもんだい /部落問題/
ぶらじゃー /ブラジャー/
ぶらじる /伯剌西爾/
ぶらっく /ブラック/
ぶらんく /ブランク/
ぶらんでー /ブランデー/
ぶらんど /ブランド/
ぶり /鰤/
ぶりっじ /ブリッジ/
ぶりつてき /物理的/
ぶりょく /武力/
ぶりょくかいにゅう /武力介入/
ぶりょくかくめい /武力革命/
ぶりょくかんしょう /武力干渉/
ぶりょくこうげき /武力攻撃/
ぶりょくこうし /武力行使/
ぶりょくこうしけつぎ /武力行使決議/
ぶりょくしんこう /武力進攻/武力侵攻/
ぶりょくせいさい /武力制裁/
ぶりょくふんそう /武力紛争/
ぶるー /ブルー/
ぶるーちーず /ブルーチーズ/
ぶるい /部類/
ぶるがりあ /勃牙利/
ぶれーき /ブレーキ/
ぶれい /無礼/
ぶれいこう /無礼講/
ぶれいもの /無礼者/
ぶろ /風呂/
ぶろーか /ブローカ/
ぶろっく /ブロック/
ぶろっくか /ブロック化/
ぶわり /歩割/
ぶん /分/文/聞/紊/馼/蚊/
ぶんあつ /分圧/
ぶんあん /文案/
ぶんい /文意/
ぶんいき /分域/
ぶんいち /文一/
ぶんいちそうごうしゅっぱん /文一総合出版/
ぶんいん /分院/
ぶんえいどう /文永堂/
ぶんえん /分煙/分園/
ぶんえんか /分煙化/分煙可/
ぶんえんしせつ /分煙施設/
ぶんえんどう /文苑堂/
ぶんか /文化/分科/分化/文科/文華/分果/
ぶんかい /分解/分会/分界/
ぶんかいかいしゅう /分解回収/
ぶんかいかくにん /分解確認/
ぶんかいかのう /分解可能/
ぶんかいげんり /分解原理/
ぶんかいこうてい /分解工程/
ぶんかいさぎょう /分解作業/
ぶんかいしき /文化意識/
ぶんかいしゃしん /分解写真/
ぶんかいしゅうり /分解修理/
ぶんかいせい /分解性/
ぶんかいせいび /分解整備/
ぶんかいせき /文解析/
ぶんかいそうじ /分解掃除/
ぶんかいてん /分界点/
ぶんかいのう /分解能/
ぶんかいほう /分解法/
ぶんかいほうほう /分解方法/
ぶんかかい /分科会/文化会/
ぶんかかいいん /分科会員/
ぶんかかいかつどう /分科会活動/
ぶんかかいかん /文化会館/文化会舘/
ぶんかかいほうこく /分科会報告/
ぶんかがっか /文化学科/
ぶんかきごう /文化記号/
ぶんかく /文革/分画/
ぶんかくんしょう /文化勲章/
ぶんかけい /文化系/文科系/
ぶんかけいがくせい /文科系学生/
ぶんかけいだいがく /文科系大学/
ぶんかけん /文化圏/
ぶんかげんしょう /文化現象/
ぶんかこゆう /文化個有/
ぶんかさ /文化差/
ぶんかさい /文化祭/
ぶんかざい /文化財/
ぶんかし /文化史/文化誌/
ぶんかしはい /文化支配/
ぶんかしゃったー /文化シャッター/
ぶんかしょう /文化賞/
ぶんかしんりゃく /文化侵略/
ぶんかじたい /文化自体/
ぶんかじょうほう /文化情報/
ぶんかじょし /文華女子/
ぶんかじょしこうこう /文華女子高校/
ぶんかじょしだい /文化女子大/
ぶんかじょしだいすぎなみ /文化女子大杉並/
ぶんかじょしだいすぎなみこうこう /文化女子大杉並高校/
ぶんかじん /文化人/
ぶんかたいいくかん /文化体育館/
ぶんかだいかくめい /文化大革命/
ぶんかちょう /文化庁/
ぶんかちょうちょうかん /文化庁長官/
ぶんかつ /分割/
ぶんかつあん /分割案/
ぶんかついがい /分割以外/
ぶんかついどう /分割移動/
ぶんかつうんよう /分割運用/
ぶんかつがた /分割型/
ぶんかつがわ /分割側/
ぶんかつきじ /分割記事/
ぶんかつぎろん /分割議論/
ぶんかつご /分割後/
ぶんかつさき /分割先/
ぶんかつさんせい /分割賛成/
ぶんかつさんせいは /分割賛成派/
ぶんかつしんぎちゅう /分割審議中/
ぶんかつじかん /分割時間/
ぶんかつじたい /分割自体/
ぶんかつじょうしゃけん /分割乗車券/
ぶんかつじょうほう /分割情報/
ぶんかつすう /分割数/
ぶんかつず /分割図/
ぶんかつぜんご /分割前後/
ぶんかつたいしょう /分割対象/
ぶんかつていあん /分割提案/
ぶんかつていこう /分割抵抗/
ぶんかつてん /分割点/
ぶんかつは /分割派/
ぶんかつはんたい /分割反対/
ぶんかつはんたいは /分割反対派/
ぶんかつばらい /分割払い/
ぶんかつへいごう /分割併合/
ぶんかつほう /分割法/
ぶんかつほうしき /分割方式/
ぶんかつほうほう /分割方法/
ぶんかつみんえいか /分割民営化/
ぶんかつめい /分割名/
ぶんかつもんだい /分割問題/
ぶんかつりゆう /分割理由/
ぶんかつろんぎ /分割論議/
ぶんかてき /文化的/
ぶんかてきさい /文化的差異/
ぶんかてきせいかつ /文化的生活/
ぶんかてきはいけい /文化的背景/
ぶんかてきふうしゅう /文化的風習/
ぶんかてきよういん /文化的要因/
ぶんかてきよっきゅう /文化的欲求/
ぶんかどう /文化堂/文華堂/
ぶんかはいけい /文化背景/
ぶんかぶ /文化部/
ぶんかほうそう /文化放送/
ぶんかまさつ /文化摩擦/
ぶんかまち /文化町/
ぶんかむら /文化村/
ぶんかめん /文化面/
ぶんからん /文化欄/
ぶんかろん /文化論/
ぶんかん /分館/文官/
ぶんかんすう /文関数/
ぶんがく /文学/文學/
ぶんがくかい /文学界/
ぶんがくこうぎ /文学講義/
ぶんがくさいにゅうもん /文学再入門/
ぶんがくさくひん /文学作品/
ぶんがくざっし /文学雑誌/
ぶんがくし /文学誌/
ぶんがくしゃ /文学者/
ぶんがくしょう /文学賞/
ぶんがくしょうねん /文学少年/
ぶんがくせいねん /文学青年/
ぶんがくぜんしゅう /文学全集/
ぶんがくてき /文学的/
ぶんがくてきひゆ /文学的比喩/
ぶんがくはかせ /文学博士/
ぶんがくぶ /文学部/
ぶんがくぶしゅっしん /文学部出身/
ぶんがくぶせんよう /文学部専用/
ぶんがくろん /文学論/
ぶんがっか /文学科/
ぶんき /分岐/
ぶんきえき /分岐駅/
ぶんきかいせん /分岐回線/
ぶんきき /分岐器/
ぶんきげんしょう /分岐現象/
ぶんきさき /分岐先/
ぶんきすう /分岐数/
ぶんきせん /分岐線/
ぶんきせんたく /分岐選択/
ぶんきそうち /分岐装置/
ぶんきてん /分岐点/
ぶんきひ /分岐比/
ぶんきぶ /分岐部/
ぶんきめいれい /分岐命令/
ぶんきゅう /文久/
ぶんきょう /文京/文教/
ぶんきょうかんけい /文教関係/
ぶんきょうがくえん /文京学園/
ぶんきょうく /文京区/文教区/
ぶんきょうくおおつか /文京区大塚/
ぶんきょうくほんごう /文京区本郷/
ぶんきょうくみん /文京区民/
ぶんきょうじょしたんだい /文京女子短大/
ぶんきょうぞく /文教族/
ぶんきょうだい /文教大/
ぶんきょうだいがく /文教大学/
ぶんきょうちょう /文京町/
ぶんきょうぶ /文教部/
ぶんきょく /分極/
ぶんきょくか /分極化/
ぶんきよう /分岐用/
ぶんきよそく /分岐予測/
ぶんきりろん /分岐理論/
ぶんきん /分近/
ぶんぎ /分木/
ぶんぎょう /分業/
ぶんぎょうか /分業化/
ぶんぎょうせい /分業制/
ぶんぎょうたいせい /分業体制/
ぶんく /分区/
ぶんぐ /文具/
ぶんぐかん /文具館/
ぶんぐてん /文具店/
ぶんけ /分家/
ぶんけい /文系/文型/
ぶんけいがっか /文系学科/
ぶんけいしょくば /文系職場/
ぶんけいりけい /文系理系/
ぶんけん /文献/分権/
ぶんけんあんない /文献案内/
ぶんけんがく /文献学/
ぶんけんけんさく /文献検索/
ぶんけんさんしょう /文献参照/
ぶんけんしゅう /文献集/
ぶんけんしょうかい /文献紹介/
ぶんけんじょうほう /文献情報/
ぶんけんちず /分県地図/
ぶんけんちょうさ /文献調査/
ぶんけんてき /分権的/
ぶんけんとう /文献等/
ぶんけんなど /文献等/
ぶんけんひょう /文献表/
ぶんけんもくろく /文献目録/
ぶんげい /文芸/文藝/
ぶんげいえいが /文芸映画/
ぶんげいか /文芸家/
ぶんげいがくぶ /文芸学部/
ぶんげいさくひん /文芸作品/
ぶんげいざ /文芸坐/文芸座/
ぶんげいし /文芸誌/
ぶんげいしゅんじゅう /文藝春秋/文芸春秋/
ぶんげいしゅんじゅうしゃ /文芸春秋社/
ぶんげいしょ /文芸書/
ぶんげいぶ /文芸部/
ぶんげん /分限/
ぶんこ /文庫/
ぶんこいがい /文庫以外/
ぶんこう /分光/分校/
ぶんこうがく /分光学/
ぶんこうがくてき /分光学的/
ぶんこうぞう /文構造/
ぶんこうほう /分光法/
ぶんこか /文庫化/
ぶんこかん /文庫刊/
ぶんことも /文庫共/
ぶんこばん /文庫版/文庫判/
ぶんこぼん /文庫本/
ぶんこめい /文庫名/
ぶんこもくろく /文庫目録/
ぶんご /文語/豊後/
ぶんごう /文豪/
ぶんごたい /文語体/
ぶんごたかだ /豊後高田/
ぶんごふう /文語風/
ぶんごやく /文語訳/
ぶんさい /文才/
ぶんさく /文作/
ぶんさつ /分冊/
ぶんさん /分散/
ぶんさんえいぞく /分散永続/
ぶんさんか /分散化/
ぶんさんかそうきおく /分散仮想記憶/
ぶんさんかんきょう /分散環境/
ぶんさんかんきょうちゅう /分散環境中/
ぶんさんかんけい /分散関係/
ぶんさんかんけいしき /分散関係式/
ぶんさんかんり /分散管理/
ぶんさんかんりほうしき /分散管理方式/
ぶんさんがた /分散型/
ぶんさんきおく /分散記憶/
ぶんさんきのう /分散機能/
ぶんさんきょうちょう /分散協調/
ぶんさんきょうぶんさんぎょうれつ /分散共分散行列/
ぶんさんきょうゆう /分散共有/
ぶんさんきょうゆうめもり /分散共有メモリ/
ぶんさんけいさん /分散計算/
ぶんさんけん /分散研/
ぶんさんこうぞう /分散構造/
ぶんさんしすてむ /分散システム/
ぶんさんしょり /分散処理/
ぶんさんしょりかんきょう /分散処理環境/
ぶんさんしょりきのう /分散処理機能/
ぶんさんしょりこうぞう /分散処理構造/
ぶんさんしょりてき /分散処理的/
ぶんさんしょりもでる /分散処理モデル/
ぶんさんじんこうちのう /分散人工知能/
ぶんさんせい /分散性/
ぶんさんせいぎょ /分散制御/
ぶんさんそうじき /分散掃除機/
ぶんさんたじゅうか /分散多重化/
ぶんさんだい /分散大/
ぶんさんち /分散値/
ぶんさんてき /分散的/
ぶんさんでんげん /分散電源/
ぶんさんとうかせい /分散透過性/
ぶんさんとうめいせい /分散透明性/
ぶんさんど /分散度/
ぶんさんどうりょく /分散動力/
ぶんさんはいち /分散配置/
ぶんさんひょうげん /分散表現/
ぶんさんひょうげんもでる /分散表現モデル/
ぶんさんぶんせき /分散分析/
ぶんさんへいれつしょり /分散並列処理/
ぶんさんほうこう /分散方向/
ぶんさんめもり /分散メモリ/
ぶんさんれんそうきおく /分散連想記憶/
ぶんざい /分際/
ぶんし /分子/分詞/文士/分枝/
ぶんしうんどう /分子運動/
ぶんしかがくこうざ /分子科学講座/
ぶんしかん /分子間/
ぶんしきどう /分子軌道/
ぶんしきどうほう /分子軌道法/
ぶんしきどうりろん /分子軌道理論/
ぶんしけん /分子研/
ぶんしげんし /分子原子/
ぶんしこうがく /分子工学/
ぶんしこうぞう /分子構造/
ぶんしこうぞうず /分子構造図/
ぶんしこうぶん /分詞構文/
ぶんししき /分子式/
ぶんししゅうごうたい /分子集合体/
ぶんししんけいせいぶつがく /分子神経生物学/
ぶんししんどう /分子振動/
ぶんしじょうたい /分子状態/
ぶんしせいぎょ /分子制御/
ぶんしせいぶつがく /分子生物学/
ぶんしせいぶつじょうほう /分子生物情報/
ぶんしせっけい /分子設計/
ぶんしつ /分室/
ぶんしでんし /分子電子/
ぶんしでんしこうがく /分子電子工学/
ぶんしどうし /分子同士/
ぶんしどうりょくがく /分子動力学/
ぶんしないしんどう /分子内振動/
ぶんしめい /分子名/
ぶんしめんえきがく /分子免疫学/
ぶんしもけい /分子模型/
ぶんしゃか /分社化/
ぶんしゅう /分周/文集/
ぶんしゅうりつ /分周率/
ぶんしゅく /分宿/
ぶんしゅつ /分出/
ぶんしゅつこうり /分出公理/
ぶんしゅん /文春/
ぶんしゅんぶんこ /文春文庫/
ぶんしゅんまんがしょう /文春漫画賞/
ぶんしょ /文書/文章/
ぶんしょいがい /文書以外/
ぶんしょいんさつきのう /文書印刷機能/
ぶんしょう /文章/分掌/文相/
ぶんしょうか /文章化/
ぶんしょうぎじゅつきょういく /文章技術教育/
ぶんしょうげんご /文章言語/
ぶんしょうご /文章語/
ぶんしょうじょう /文章上/
ぶんしょうぜんたい /文章全体/
ぶんしょうだい /文章題/
ぶんしょうちゅう /文章中/
ぶんしょうちゅうしん /文章中心/
ぶんしょうない /文章内/
ぶんしょうないよう /文章内容/
ぶんしょうはつおん /文章発音/
ぶんしょうひょうげん /文章表現/
ぶんしょうひょうげんりょく /文章表現力/
ぶんしょうもんだい /文章問題/
ぶんしょうりかい /文章理解/
ぶんしょうりかいのうりょく /文章理解能力/
ぶんしょうりょう /文章量/
ぶんしょうりょく /文章力/
ぶんしょか /文書化/
ぶんしょがぞう /文書画像/
ぶんしょがぞうしょり /文書画像処理/
ぶんしょがたていぎ /文書型定義/
ぶんしょく /文飾/
ぶんしょけい /文書型/
ぶんしょけんさくほうしき /文書検索方式/
ぶんしょこ /文書庫/
ぶんしょこうかん /文書交換/
ぶんしょこうぞう /文書構造/
ぶんしょこうぞうかきやく /文書構造化規約/
ぶんしょごかん /文書互換/
ぶんしょさくせい /文書作成/
ぶんしょさくせいかんきょう /文書作成環境/
ぶんしょさくせいちゅう /文書作成中/
ぶんしょしそう /文書思想/
ぶんしょしょり /文書処理/
ぶんしょせいしょ /文書清書/
ぶんしょぜんたい /文書全体/
ぶんしょちゅう /文書中/
ぶんしょでんしか /文書電子化/
ぶんしょない /文書内/
ぶんしょぶんるい /文書分類/
ぶんしょへんしゅう /文書編集/
ぶんしょへんしゅうちゅう /文書編集中/
ぶんしょりょく /文書力/
ぶんしょわりつけ /文書割付け/
ぶんしりょう /分子量/
ぶんしん /分身/
ぶんじ /文治/文二/
ぶんじたい /文自体/
ぶんじょう /分乗/分譲/
ぶんじょうしゃ /分乗車/
ぶんじょうち /分譲地/
ぶんじん /文人/
ぶんじんぼっかく /文人墨客/
ぶんすい /分水/
ぶんすいかい /分水界/
ぶんすいれい /分水嶺/
ぶんすう /分数/
ぶんすうしき /分数式/
ぶんせいせい /文生成/
ぶんせいどう /文盛堂/
ぶんせき /分析/文責/
ぶんせきかがく /分析化学/
ぶんせきかのう /分析可能/
ぶんせきがく /分析学/
ぶんせきき /分析器/
ぶんせききこう /分析機構/
ぶんせききじ /分析記事/
ぶんせきけっか /分析結果/
ぶんせきごうせいふごうか /分析合成符号化/
ぶんせきしゃ /文責者/分析者/
ぶんせきじすう /分析次数/
ぶんせきじたい /分析自体/
ぶんせきじっけん /分析実験/
ぶんせきそうち /分析装置/
ぶんせきてき /分析的/
ぶんせきてきしゅほう /分析的手法/
ぶんせきほう /分析法/
ぶんせきほうほう /分析方法/
ぶんせきりょく /分析力/
ぶんせつ /文節/分節/
ぶんせついどう /文節移動/
ぶんせつがくしゅう /文節学習/
ぶんせつぎり /文節切/
ぶんせつしゅうたん /文節終端/
ぶんせつすう /文節数/
ぶんせつせい /分節性/文節性/
ぶんせつちゅう /文節中/分節中/
ぶんせつちょう /文節長/
ぶんせつへんかん /文節変換/
ぶんせつゆうせん /文節優先/
ぶんせん /文選/
ぶんせんどう /文泉堂/
ぶんせんめい /文鮮明/
ぶんぜんたい /文全体/
ぶんそう /分奏/
ぶんそうおう /分相応/
ぶんそん /分損/
ぶんたい /文体/分隊/
ぶんたいおう /文対応/
ぶんたいし /分隊士/
ぶんたいちょう /分隊長/
ぶんたん /分担/
ぶんたんきん /分担金/
ぶんたんしゃ /分担者/
ぶんたんしゃかいぎ /分担者会議/
ぶんたんせい /分担制/
ぶんたんはんい /分担範囲/
ぶんたんひょう /分担表/
ぶんたんほうしき /分担方式/
ぶんたんりつ /分担率/
ぶんだい /分大/
ぶんだん /分断/文壇/分団/
ぶんだんかしょ /分断箇所/
ぶんだんせいかつ /分断生活/
ぶんちゅう /文中/分注/
ぶんちゅうじょ /分駐所/
ぶんちょう /文鳥/文調/
ぶんちん /文鎮/文珍/
ぶんつう /文通/
ぶんてん /分点/
ぶんでん /分電/
ぶんでんばん /分電盤/
ぶんとう /文頭/
ぶんとん /分屯/
ぶんどき /分度器/
ぶんのいち /分の１/
ぶんのう /分納/
ぶんは /分派/
ぶんばい /分売/
ぶんばんごう /文番号/
ぶんぱ /分派/分波/
ぶんぱい /分配/
ぶんぱいかんすう /分配関数/
ぶんぱいき /分配器/
ぶんぱいきしゅつりょく /分配器出力/
ぶんぱいそく /分配束/
ぶんぱいひ /分配比/
ぶんぱいほうそく /分配法則/
ぶんぱいほうほう /分配方法/
ぶんぱいりつ /分配律/
ぶんぱき /分波器/
ぶんぴ /分泌/
ぶんぴつ /分泌/文筆/分筆/
ぶんぴつえき /分泌液/
ぶんぴつきこう /分泌機構/
ぶんぴつぎょう /文筆業/
ぶんぴつこうぞう /分泌構造/
ぶんぴつせいかつ /文筆生活/
ぶんぴぶつ /分泌物/
ぶんぶ /文武/
ぶんぶつ /文物/
ぶんぶりょうどう /文武両道/
ぶんぷ /分布/
ぶんぷかんすう /分布関数/
ぶんぷけいじょう /分布形状/
ぶんぷず /分布図/
ぶんぷちょうさ /分布調査/
ぶんぷとくせい /分布特性/
ぶんぷらんすう /分布乱数/
ぶんべつ /分別/
ぶんべつけいすう /分別係数/
ぶんべん /分娩/
ぶんぺい /文平/
ぶんぼ /分母/
ぶんぼうぐ /文房具/
ぶんぼうぐがかり /文房具係/
ぶんぼうぐてん /文房具店/
ぶんぼうぐや /文房具屋/
ぶんぼぶんりけい /分母分離形/
ぶんぽう /文法/
ぶんぽういしき /文法意識/
ぶんぽうか /文法化/
ぶんぽうかいせき /文法解析/
ぶんぽうがくしゅうきのう /文法学習機能/
ぶんぽうきごう /文法記号/
ぶんぽうきじゅつ /文法記述/
ぶんぽうきそく /文法規則/
ぶんぽうこうぞう /文法構造/
ぶんぽうごうりか /文法合理化/
ぶんぽうしこう /文法指向/
ぶんぽうしょ /文法書/
ぶんぽうじょう /文法上/
ぶんぽうぞくせい /文法属性/
ぶんぽうていぎ /文法定義/
ぶんぽうてき /文法的/
ぶんぽうてききじゅつ /文法的記述/
ぶんぽうてきせっきん /文法的接近/
ぶんぽうてきたいおう /文法的対応/
ぶんぽうとうろく /文法登録/
ぶんぽうようご /文法用語/
ぶんぽうりろん /文法理論/
ぶんぽうろん /文法論/
ぶんまつ /文末/
ぶんみゃく /文脈/
ぶんみゃくいぞん /文脈依存/
ぶんみゃくいぞんせい /文脈依存性/
ぶんみゃくいぞんぶんぽう /文脈依存文法/
ぶんみゃくこうか /文脈効果/
ぶんみゃくしょり /文脈処理/
ぶんみゃくじゆう /文脈自由/
ぶんみゃくじゆうげんご /文脈自由言語/
ぶんみゃくじゆうぶんぽう /文脈自由文法/
ぶんみゃくじょう /文脈上/
ぶんみゃくじょうほう /文脈情報/
ぶんみゃくてき /文脈的/
ぶんみゃくどくりつ /文脈独立/
ぶんみん /文民/
ぶんみんほご /文民保護/
ぶんめい /文明/
ぶんめいか /文明化/
ぶんめいかいか /文明開化/
ぶんめいこく /文明国/
ぶんめいし /文明史/
ぶんめいしゃかい /文明社会/
ぶんめいじん /文明人/
ぶんめいてき /文明的/
ぶんめいどう /文明堂/
ぶんめいひはん /文明批判/
ぶんめいひひょう /文明批評/
ぶんめいふうし /文明風刺/
ぶんめん /文面/
ぶんめんいじょう /文面以上/
ぶんめんじたい /文面自体/
ぶんめんじょう /文面上/
ぶんや /分野/
ぶんやかん /分野間/
ぶんやがい /分野外/
ぶんやたんとう /分野担当/
ぶんやべつ /分野別/
ぶんやみてい /分野未定/
ぶんやめい /分野名/
ぶんよ /分与/
ぶんよう /文葉/
ぶんらく /文楽/
ぶんらん /紊乱/
ぶんり /分離/文理/
ぶんりあん /分離案/
ぶんりか /分離果/
ぶんりかぜい /分離課税/
ぶんりかのう /分離可能/
ぶんりがた /分離型/
ぶんりき /分離器/分離機/
ぶんりきそく /分離規則/
ぶんりきゅうゆ /分離給油/
ぶんりきゅうゆよう /分離給油用/
ぶんりこうり /分離公理/
ぶんりさくせい /分離作成/
ぶんりしんぎ /分離審議/
ぶんりじゅちょう /分離受聴/
ぶんりすう /分離数/
ぶんりせい /分離性/
ぶんりたい /分離帯/
ぶんりだい /文理大/
ぶんりつ /分立/分率/
ぶんりていすう /分離定数/
ぶんりど /分離度/
ぶんりどくりつ /分離独立/
ぶんりのう /分離脳/
ぶんりのうりょく /分離能力/
ぶんりは /分離派/
ぶんりふかのう /分離不可能/
ぶんりふかのうせい /分離不可能性/
ぶんりふのう /分離不能/
ぶんりぶんかつ /分離分割/
ぶんりほうこう /分離方向/
ぶんりまえ /分離前/
ぶんりもじ /分離文字/
ぶんりもんだい /分離問題/
ぶんりゅう /分留/分流/分溜/
ぶんりょう /分量/
ぶんりょうてき /分量的/
ぶんりよう /分離用/
ぶんるい /分類/
ぶんるいか /分類化/
ぶんるいがく /分類学/
ぶんるいがくしゅう /分類学習/
ぶんるいがくじょう /分類学上/
ぶんるいき /分類器/
ぶんるいきじゅん /分類基準/
ぶんるいぎ /分類木/
ぶんるいぐん /分類群/
ぶんるいけい /分類系/
ぶんるいこうもく /分類項目/
ぶんるいこんなん /分類困難/
ぶんるいぜんたい /分類全体/
ぶんるいばんごう /分類番号/
ぶんるいふめい /分類不明/
ぶんるいぶぶん /分類部分/
ぶんるいほう /分類法/
ぶんるいほうほう /分類方法/
ぶんるいめい /分類名/
ぶんるいもんだい /分類問題/
ぶんれい /文例/
ぶんれつ /分裂/分列/
ぶんれつか /分裂果/
ぶんれつこうしん /分列行進/
ぶんれつしょう /分裂症/
ぶんれつしょうきしつ /分裂症気質/
ぶんれつせい /分裂性/
ぶんれつそしき /分裂組織/
ぶんれつびょう /分裂病/
ぶんれつまえ /分裂前/
ぷ /腐/布/
ぷーと /ブート/
ぷーどる /プードル/
ぷーる /プール/
ぷう /風/
ぷさん /釜山/
ぷらいばし /プライバシ/
ぷらいばしー /プライバシー/
ぷらいべーと /プライベート/
ぷらぐ /プラグ/
ぷらざ /プラザ/
ぷらす /プラス/＋/
ぷらすちっく /プラスチック/
ぷらすまいなす /±/
ぷらちな /プラチナ/
ぷらっと /プラット/
ぷらっとふぉーむ /プラットフォーム/
ぷらまい /±/
ぷらん /プラン/
ぷらんくていすう /プランク定数/
ぷらんと /プラント/
ぷらんにんぐ /プランニング/
ぷりずむ /プリズム/
ぷりぷり /プリプリ/
ぷりんす /プリンス/
ぷりんすほてる /プリンスホテル/
ぷりんせす /プリンセス/
ぷりんた /プリンタ/
ぷりんたー /プリンター/
ぷりんと /プリント/
ぷりんときばん /プリント基板/
ぷるとにうむ /プルトニウム/
ぷれー /プレー/
ぷれーと /プレート/
ぷれーにんぐ /プレーニング/
ぷれーやー /プレーヤー/
ぷれい /プレイ/
ぷれいや /プレイヤ/
ぷれいやー /プレイヤー/
ぷれじでんと /プレジデント/
ぷれす /プレス/
ぷれぜんと /プレゼント/
ぷれっしゃー /プレッシャー/
ぷろ /プロ/
ぷろぐらま /プログラマ/
ぷろぐらみんぐ /プログラミング/
ぷろぐらむ /プログラム/
ぷろぐらむげんごりろん /プログラム言語理論/
ぷろぐらむごうせい /プログラム合成/
ぷろしあ /普魯西/
ぷろじぇくと /プロジェクト/
ぷろせす /プロセス/
ぷろせすかん /プロセス間/
ぷろそう /プロ相/
ぷろだくしょん /プロダクション/
ぷろだくと /プロダクト/
ぷろった /プロッタ/
ぷろてくと /プロテクト/
ぷろでゅーさ /プロデューサ/
ぷろでゅーす /プロデュース/
ぷろとこる /プロトコル/
ぷろとたいぷ /プロトタイプ/
ぷろぱてぃ /プロバティ/
ぷろぱん /プロパン/
ぷろふぃーる /プロフィール/
ぷろふぇっしょなる /プロフェッショナル/
ぷろぺら /プロペラ/
ぷろぽーざる /プロポーザル/
ぷろぽーず /プロポーズ/
ぷろもうと /プロモウト/
ぷん /分/
ぷんかん /分間/
ぷんはん /分半/
ぷんぴつえき /分泌液/
ぷんまえ /分前/
へ /屁/戸/辺/経/邊/邉/
へーべー /平米/
へい /平/閉/兵/併/陛/並/蔽/弊/柄/塀/幣/丙/聘/娉/嬖/幤/并/敝/斃/睥/竝/閇/炳/坪/瓶/箆/餅/病/
へい> /閉/
へいあん /平安/
へいあんきょう /平安京/
へいあんこうこう /平安高校/
へいあんじだい /平安時代/
へいあんどう /平安堂/
へいい /平易/
へいいき /閉域/
へいいち /平一/
へいいど /平易度/
へいいん /兵員/
へいえい /併映/兵営/
へいえき /兵役/
へいえん /閉宴/閉園/
へいおん /平穏/平温/併音/
へいおんせつ /閉音節/
へいおんひょうき /併音表記/
へいおんぶじ /平穏無事/
へいか /陛下/平価/兵科/閉架/閉果/
へいかい /閉会/
へいかいあいさつ /閉会挨拶/
へいかいしき /閉会式/
へいかいろ /閉回路/
へいかしき /閉架式/
へいかつ /平滑/
へいかつか /平滑化/
へいかつかいろ /平滑回路/
へいかつかぶん /平滑化分/
へいかつきん /平滑筋/
へいかとしょ /閉架図書/
へいかん /閉管/閉館/
へいかんご /閉館後/
へいかんまぎわ /閉館間際/
へいがい /弊害/
へいがっこう /兵学校/
へいき /平気/併記/兵器/並記/
へいきせいぎょ /兵器制御/
へいきち /平吉/
へいきばいばい /兵器売買/
へいきゅう /閉球/
へいきょくせん /閉曲線/
へいきょくせんていり /閉曲線定理/
へいきょくせんない /閉曲線内/
へいきょくめん /閉曲面/
へいきん /平均/
へいきんあやまりりつ /平均誤り率/
へいきんいか /平均以下/
へいきんおうとうじかん /平均応答時間/
へいきんか /平均化/
へいきんかいすう /平均回数/
へいきんかいつうび /平均開通日/
へいきんかぶか /平均株価/
へいきんきつえんほんすう /平均喫煙本数/
へいきんきょくりつ /平均曲率/
へいきんきょり /平均距離/
へいきんしゅうにゅう /平均収入/
へいきんしゅつりょく /平均出力/
へいきんしんちょう /平均身長/
へいきんしんぷく /平均振幅/
へいきんじじょう /平均二乗/平均2乗/
へいきんじじょうごさ /平均二乗誤差/平均2乗誤差/
へいきんじじょうよそうごさ /平均二乗予想誤差/
へいきんじそく /平均時速/
へいきんじゅみょう /平均寿命/
へいきんじゅんい /平均順位/
へいきんじゆうこうてい /平均自由行程/
へいきんじょうしゃりつ /平均乗車率/
へいきんすいみんじかん /平均睡眠時間/
へいきんすうまん /平均数万/
へいきんそくど /平均速度/
へいきんだい /平均台/
へいきんち /平均値/
へいきんちょう /平均長/
へいきんちょくりゅうでんあつ /平均直流電圧/
へいきんてき /平均的/
へいきんてきせたい /平均的世帯/
へいきんてん /平均点/
へいきんとくてん /平均得点/
へいきんどうにゅうだいすう /平均導入台数/
へいきんにっしょうじかん /平均日照時間/
へいきんねつそくど /平均熱速度/
へいきんねんしゅう /平均年収/
へいきんねんぼう /平均年棒/
へいきんねんれい /平均年齢/
へいきんば /平均場/
へいきんひきょり /平均飛距離/
へいきんまちじかん /平均待ち時間/
へいきんりつ /平均律/平均率/
へいきんりゅう /平均流/
へいきんりようきゃくすう /平均利用客数/
へいきんれんさすう /平均連鎖数/
へいくうかん /閉空間/
へいくかん /閉区間/
へいけ /平家/
へいけい /閉経/
へいけいしき /閉形式/
へいけつ /併結/
へいけつうんてんじ /併結運転時/
へいけつさぎょう /併結作業/
へいけつじ /併結時/
へいけつへんせい /併結編成/
へいけものがたり /平家物語/
へいげい /睥睨/辟睨/
へいげん /平原/
へいこう /並行/閉口/平行/平衡/平向/閉項/併行/閉校/敝垢/
へいこういどう /平行移動/
へいこういぬしょり /平行犬処理/
へいこうかくかんきょり /平衡核間距離/
へいこうかんかく /平衡感覚/
へいこうがた /並行型/平行型/
へいこうがたきこう /平行型気孔/
へいこうぎ /平衡木/
へいこうくかん /並行区間/
へいこうけい /平衡系/
へいこうけいさん /並行計算/
へいこうけいさんりろん /並行計算理論/
へいこうこう /平行光/
へいこうこうぶん /並行構文/
へいこうざいらいせん /並行在来線/
へいこうし /平行視/
へいこうしへんけい /平行四辺形/
へいこうしょり /並行処理/
へいこうしんか /平行進化/並行進化/
へいこうじっこう /並行実行/
へいこうじょうたい /平衡状態/平衡常態/
へいこうせい /並行性/
へいこうせいぎょ /並行制御/
へいこうせん /平行線/並行線/
へいこうせんじょうたい /平行線状態/
へいこうていすう /平衡定数/
へいこうてき /並行的/
へいこうてん /平衡点/
へいこうど /平行度/並行度/
へいこうどうさ /並行動作/
へいこうはんのう /平衡反応/
へいこうひん /並行品/
へいこうぶんぷ /平衡分布/
へいこうへき /平行壁/
へいこうほうこう /平行方向/
へいこうぼう /平行棒/
へいこうみゃく /平行脈/
へいこうみゃくよう /平行脈葉/
へいこうゆにゅう /並行輸入/平行輸入/
へいこうゆにゅうぎょうしゃ /並行輸入業者/
へいこうゆにゅうひん /並行輸入品/
へいこうゆにゅうぶつ /平行輸入物/
へいごう /併合/并合;「併」を使う熟語は「并」で置きかえ可/
へいごうかつどう /併合活動/
へいさ /閉鎖/
へいさい /併催/
へいさく /平朔/
へいさけい /閉鎖系/
へいさこうか /閉鎖効果/
へいさこうじ /閉鎖工事/
へいさしき /閉鎖式/
へいさせい /閉鎖性/
へいさちゅう /閉鎖中/
へいさつ /併殺/
へいさつだ /併殺打/
へいさてき /閉鎖的/
へいさぶ /閉鎖部/
へいさようみゃくけい /閉鎖葉脈系/
へいざん /閉山/
へいし /兵士/瓶子/平氏/弊紙/弊誌/閉止/斃死/
へいしき /閉式/
へいしきあいさつ /閉式挨拶/
へいしたち /兵士達/
へいしつかいぞう /閉室改造/
へいしゃ /弊社/
へいしゃがい /弊社外/
へいしゃぞう /閉写像/
へいしゃない /弊社内/
へいしゅ /兵種/
へいしゅうごう /閉集合/
へいしん /並進/
へいしんうんどう /並進運動/
へいしんていとう /平身低頭/平身抵当/
へいじ /平時/平次/
へいじつ /平日/
へいじつあさ /平日朝/
へいじつしんや /平日深夜/
へいじつじょせい /平日女性/
へいじつはんにち /平日半日/
へいじつよう /平日用/
へいじゅんか /平準化/
へいじょう /平常/閉場/平城/平壌/
へいじょううんてん /平常運転/
へいじょうしん /平常心/
へいじょうじ /平常時/
へいじん /敝人/
へいすいめん /平水面/
へいすう /兵数/
へいすけ /平祐/
へいせい /平成/平静/
へいせい#ねん /平成#0年/平成#1年/平成#2年/平成#3年/(skk-gengo-to-ad "" "年")/(skk-gengo-to-ad "西暦" "年")/
へいせい#ねんど /平成#0年度/
へいせいいしん /平成維新/
へいせいがんねん /平成元年/
へいせいしょたい /平成書体/
へいせいちくほうてつどう /平成筑豊鉄道/
へいせいちょう /平成町/
へいせいばん /平成版/
へいせいふきょう /平成不況/
へいせかい /閉世界/
へいせき /平積/
へいせつ /併設/
へいせつこうしゅうかい /併設講習会/
へいぜい /平生/
へいぜいごうじょう /平生業成/
へいぜん /平然/
へいそ /平素/
へいそう /並走/併走/兵装/
へいそうしゃりょう /並走車両/
へいそうじかん /並走時間/
へいそく /閉塞/
へいそくかん /閉塞感/
へいそくじょうたい /閉塞状態/
へいそくもう /閉塞網/
へいそつ /兵卒/
へいそん /併存/並存/
へいぞん /併存/並存/
へいたい /兵隊/
へいたいたち /兵隊達/
へいたん /平坦/兵站/
へいたんか /平坦化/
へいたんち /平坦地/
へいだん /兵団/
へいち /平地/並置/併置/
へいちきょうそう /平地競走/
へいちょう /兵長/閉庁/敝腸/
へいてい /平定/閉廷/
へいてん /閉店/弊店/
へいてんじ /閉店時/
へいてんちゅう /閉店中/
へいてんまぎわ /閉店間際/
へいどく /併読/
へいどん /併呑/
へいにん /併任/
へいねつ /平熱/
へいねん /平年/
へいねんなみ /平年並/
へいのうぶんり /兵農分離/
へいのうみぶんり /兵農未分離/
へいはく /幣帛/
へいはち /平八/
へいはちろう /平八郎/
へいはつ /併発/
へいはん /平版/
へいばん /平板/
へいばんか /平板化/
へいふ /敝賦/
へいふく /平服/平伏/
へいふくさいぼう /平伏細胞/
へいふくほうしゃそしきさいぼう /平伏放射組織細胞/
へいぶ /弊部/
へいぶん /平文/
へいへい /平平/
へいへいぼんぼん /平平凡凡/
へいべい /平米/
へいほう /閉包/平方/兵法/
へいほうこん /平方根/
へいほうじょうよ /平方剰余/
へいほうせい /閉包性/
へいほうとくせい /閉包特性/
へいほうめーとる /平方米/
へいぼん /平凡/
へいぼんしゃ /平凡社/
へいぼんしゃはっこう /平凡社発行/
へいまく /閉幕/
へいみん /平民/
へいめい /平明/
へいめん /平面/
へいめんきか /平面幾何/
へいめんきょう /平面鏡/
へいめんけい /平面系/平面型/
へいめんげいじゅつ /平面芸術/
へいめんこうさ /平面交差/
へいめんこうせい /平面構成/
へいめんしゃしん /平面写真/
へいめんじょう /平面上/平面状/
へいめんじょうにさぶんし /平面状二叉分枝/
へいめんじょうふたまたぶんし /平面状二又分枝/
へいめんず /平面図/
へいめんずけい /平面図形/
へいめんせい /平面性/
へいめんてき /平面的/
へいめんど /平面度/
へいめんは /平面波/
へいめんばん /平面板/
へいめんふたまたぶんし /平面二又分枝/
へいもん /閉門/
へいや /平野/
へいやぶ /平野部/
へいゆ /平癒/
へいゆう /併有/
へいよう /併用/並用/
へいようきょう /併用橋/
へいようばし /併用橋/
へいよん /海永/
へいり /弊履/
へいりつ /並立/
へいりつせい /並立制/
へいりょういき /閉領域/
へいりょく /兵力/
へいりょくさ /兵力差/
へいりょくしよう /兵力使用/
へいりょくぞうきょう /兵力増強/
へいりょくてき /兵力的/
へいれつ /並列/
へいれつか /並列化/
へいれつがくしゅう /並列学習/
へいれつがた /並列型/
へいれつき /並列機/
へいれつきおく /並列記憶/
へいれつきこう /並列機構/
へいれつきでん /並列饋電/
へいれつけい /並列系/
へいれつけいさん /並列計算/
へいれつけいさんき /並列計算機/
へいれつけいてきおう /並列形適応/
へいれつげんご /並列言語/
へいれつこうぶん /並列構文/
へいれつごうせい /並列合成/
へいれつしき /並列式/
へいれつしょり /並列処理/
へいれつしょりぎじゅつ /並列処理技術/
へいれつしょりけんきゅう /並列処理研究/
へいれつしょりげんご /並列処理言語/
へいれつじたい /並列自体/
へいれつじっこう /並列実行/
へいれつじゅうでん /並列充電/
へいれつすいろん /並列推論/
へいれつせい /並列性/
へいれつたんさく /並列探索/
へいれつてき /並列的/
へいれつでえたひょうげん /並列データ表現/
へいれつど /並列度/
へいれつどうさ /並列動作/
へいれつはんぷくほう /並列反復法/
へいれつひょうか /並列評価/
へいれつびょうがきのう /並列描画機能/
へいれつふかぶんさん /並列負荷分散/
へいれつぶったいにんしき /並列物体認識/
へいれつぶんさん /並列分散/
へいれつぶんさんがた /並列分散型/
へいれつぶんさんしょり /並列分散処理/
へいれつほうしき /並列方式/
へいれつましん /並列マシン/
へいれつもでる /並列モデル/
へいれつろんり /並列論理/
へいれつろんりがた /並列論理型/
へいろ /閉路/平炉/
へいろく /併録/
へいろでんりゅう /閉路電流/
へいろんりしき /閉論理式/
へいわ /平和/
へいわいじかつどう /平和維持活動/
へいわいじぐん /平和維持軍/
へいわかいほうじょうやく /平和解放条約/
へいわきねんこうえん /平和記念公園/
へいわきねんどう /平和祈念堂/
へいわきょうてい /平和協定/
へいわけんぽう /平和憲法/
へいわこうえん /平和公園/
へいわしゅぎ /平和主義/
へいわしゅぎしゃ /平和主義者/
へいわじま /平和島/
へいわじょうやく /平和条約/
へいわだい /平和台/
へいわてき /平和的/
へいわてきかいけつ /平和的解決/
へいわとう /平和党/
へいわどおり /平和通り/
へいわふどうさん /平和不動産/
へいわりよう /平和利用/
へいわろん /平和論/
へき /壁/癖/碧/僻/璧/劈/甓/躄/辟/闢/日置/
へきえき /へき易/辟易/
へきえん /僻遠/
へきかい /碧海/劈開/
へきかん /壁間/
へきが /壁画/
へきがん /碧眼/
へきくう /碧空/
へきこういき /壁孔域/
へきすう /僻陬/
へきたい /壁体/
へきち /僻地/隔地/
へきちゅう /壁中/
へきとう /劈頭/
へきない /壁内/
へきなん /碧南/
へきはく /璧帛/
へきめん /壁面/
へきる /椎名へきる/
へきれき /霹靂/
へくたーる /ヘクタール/
へくとぐらむ /瓸/
へくとめーとる /粨/
へくとりっとる /竡/
へぐり /平群/
へさき /舳/舳先/
へそ /臍/
へそのお /臍の緒/
へた /下手/蒂/蔕/戸田/
へたくそ /下手糞/
へだ /戸田/
へだたり /隔/
へちま /糸瓜/
へっだ /ヘッダ/
へっど /ヘッド/
へっどほん /ヘッドホン/
へつ /丿/暼/
へなちょこ /埴猪口/
へび /蛇/
へびどく /蛇毒/
へぶ /ヘブ/
へぼんしき /ヘボン式/
へみ /逸見/
へや /部屋/廳/廰/
へやかず /部屋数/
へやぎ /部屋着/
へやじゅう /部屋中/
へやすう /部屋数/
へやぜんたい /部屋全体/
へやだい /部屋代/
へやわり /部屋割/
へら /箆/
へらい /戸来/
へらずぐち /減らず口/
へり /辺/縁/邊/邉/
へりうむ /ヘリウム/
へりくつ /屁理屈/
へるめっと /ヘルメット/
へん /変/辺/編/片/返/遍/篇/偏/邊/扁/變/翩/胼/蝙/褊/諞/貶/邉/駢/騙/
へんあつ /変圧/
へんあつき /変圧器/
へんあつきそうおん /変圧器騒音/
へんい /変位/偏移/変移/偏位/変異/
へんいき /変域/
へんいせい /変位性/変移性/
へんいせいぶん /変位成分/
へんいたん /変異譚/
へんえん /辺縁/
へんえんけい /辺縁系/
へんおん /変温/変音/
へんおんどうぶつ /変温動物/
へんか /変化/返歌/
へんかきゅう /変化球/
へんかく /変革/偏角/変格/
へんかぐあい /変化具合/
へんかけい /変化形/
へんかず /変化図/
へんかせい /変化性/
へんかてん /変化点/
へんかはんい /変化範囲/
へんかぶぶん /変化部分/
へんかぶん /変化分/
へんかりつ /変化率/
へんかりょう /変化量/
へんかん /変換/返還/返環/
へんかんかいしいち /変換開始位置/
へんかんかいしてん /変換開始点/
へんかんかてい /変換過程/
へんかんかのう /変換可能/
へんかんかんすう /変換関数/
へんかんき /変換器/変換機/
へんかんききこうざ /変換機器講座/
へんかんきぐ /変換器具/
へんかんきじゅつし /変換記述子/
へんかんきそく /変換規則/
へんかんきのう /変換機能/
へんかんぎじゅつ /変換技術/
へんかんぎょう /変換行/
へんかんぎょうれつ /変換行列/
へんかんけい /変換系/
へんかんけいすう /変換係数/
へんかんけっか /変換結果/
へんかんこうがく /変換工学/
へんかんこうがくせんこう /変換工学専攻/
へんかんこうほ /変換候補/
へんかんこうりつ /変換効率/
へんかんご /変換後/返還後/
へんかんさき /変換先/
へんかんさぎょうご /変換作業後/
へんかんし /変換史/
へんかんしき /変換式/
へんかんしっぱい /変換失敗/
へんかんしゅほう /変換手法/
へんかんじ /変換時/
へんかんじしょ /変換辞書/
へんかんじょうたい /変換状態/
へんかんすう /偏関数/
へんかんせいど /変換精度/
へんかんそうさ /変換操作/
へんかんそうち /変換装置/
へんかんそくど /変換速度/
へんかんたいしょう /変換対象/
へんかんたんい /変換単位/
へんかんち /変換値/
へんかんちゅう /変換中/
へんかんてん /変換点/
へんかんのうりょく /変換能力/
へんかんひょう /変換表/
へんかんふのう /変換不能/
へんかんぶ /変換部/
へんかんぶぶん /変換部分/
へんかんほう /変換法/
へんかんほうしき /変換方式/
へんかんほうほう /変換方法/
へんかんまえ /変換前/返還前/
へんかんよう /変換用/
へんかんりつ /変換率/
へんかんれつ /変換列/
へんき /偏倚/
へんきゃく /返却/
へんきゃくきげん /返却期限/
へんきゃくじかん /返却時間/
へんきゃくち /返却値/
へんきゃくび /返却日/
へんきゅう /返球/
へんきょう /偏狭/辺境/
へんきょうけいび /辺境警備/
へんきょく /編曲/偏極/
へんきょくしゃ /編曲者/
へんきょくしょう /編曲賞/
へんきょくたんとう /編曲担当/
へんきょくてん /変曲点/
へんきょくでんしせん /偏極電子線/
へんきょくばん /編曲版/
へんきん /返金/
へんきんたいしょう /返金対象/
へんくつ /偏屈/
へんくつやろう /偏屈野郎/
へんけい /変形/辺形/変型/
へんけいご /変形後/
へんけいじざい /変形自在/
へんけいたい /変形体/
へんけいはんけい /変形半径/
へんけいばん /変形版/
へんけいほう /変形法/
へんけん /偏見/
へんけんし /偏見視/
へんけんてき /偏見的/
へんげ /変化/
へんこう /変更/偏光/偏向/変光/
へんこうあん /変更案/
へんこういらい /変更依頼/
へんこうか /変更可/
へんこうかしょ /変更箇所/
へんこうかのう /変更可能/
へんこうかんりひょう /変更管理票/
へんこうくかん /変更区間/
へんこうこう /偏向光/
へんこうご /変更後/
へんこうさき /変更先/
へんこうさぎょう /変更作業/
へんこうし /偏光子/
へんこうしょ /変更書/
へんこうしようしょ /変更仕様書/
へんこうしんせい /変更申請/
へんこうしんせいしょ /変更申請書/
へんこうしんせいちゅう /変更申請中/
へんこうじ /変更時/
へんこうじゆう /変更自由/
へんこうせい /変光星/
へんこうせいかんそく /変光星観測/
へんこうせいぎょ /変更制御/
へんこうせいぶんかかい /変光星分科会/
へんこうそうさ /偏向走査/
へんこうそち /変更措置/
へんこうたいしょう /変更対象/
へんこうちゅう /変更中/
へんこうてん /変更点/
へんこうとくせい /偏光特性/
へんこうとどけ /変更届/
へんこうないよう /変更内容/
へんこうはんどうたい /偏向半導体/
へんこうばん /偏光板/変更版/
へんこうひょうじ /変更表示/
へんこうび /変更日/
へんこうふかのう /変更不可能/
へんこうふのう /変更不能/
へんこうぶぶん /変更部分/
へんこうぶん /変更分/
へんこうほうどう /偏向報道/
へんこうほうほう /変更方法/
へんこうまえ /変更前/
へんこうまく /偏光膜/
へんこうよう /変更用/
へんこうようきゅう /変更要求/
へんこうようし /変更用紙/
へんこうりょう /変更量/
へんこうりれき /変更履歴/
へんごう /辺合/
へんさ /偏差/
へんさい /返済/
へんさち /偏差値/
へんさん /編纂/
へんざい /遍在/偏在/
へんざいせい /遍在性/
へんし /変死/返詩/
へんしつ /変質/偏執/
へんしつきょう /偏執狂/
へんしつきょうてき /偏執狂的/
へんしつきょうてきせいかく /偏執狂的性格/
へんしつしゃ /変質者/
へんしつてき /変質的/
へんしゃ /編者/
へんしゃぞう /偏写像/
へんしゃちゅう /編者注/
へんしゅ /変種/騙取/
へんしゅう /編集/編修/偏執/編輯/
へんしゅういいん /編集委員/
へんしゅういいんかい /編集委員会/
へんしゅういいんちょう /編集委員長/
へんしゅういと /編集意図/
へんしゅういん /編集員/
へんしゅうかい /編集会/
へんしゅうかのう /編集可能/
へんしゅうかんきょう /編集環境/
へんしゅうがめん /編集画面/
へんしゅうがわ /編集側/
へんしゅうき /編集機/
へんしゅうきのう /編集機能/
へんしゅうきょう /偏執狂/
へんしゅうきょうてき /偏執狂的/
へんしゅうきょく /編集局/
へんしゅうきょくちょう /編集局長/
へんしゅうけっか /編集結果/
へんしゅうけん /編集権/
へんしゅうこうい /編集行為/
へんしゅうこうき /編集後記/
へんしゅうご /編集後/
へんしゅうさぎょう /編集作業/
へんしゅうしつ /編集室/
へんしゅうしゃ /編集者/編輯者/
へんしゅうしゃかいぎ /編集者会議/
へんしゅうしゃちゅう /編集者注/
へんしゅうしゅかん /編集主幹/
へんしゅうしゅにん /編集主任/
へんしゅうじ /編集時/
へんしゅうじょう /編集上/
へんしゅうずみ /編集済/
へんしゅうせいど /編集精度/
へんしゅうせきにんしゃ /編集責任者/
へんしゅうそしき /編集組織/
へんしゅうたいしょう /編集対象/
へんしゅうちゅう /編集中/
へんしゅうちょう /編集長/
へんしゅうちょさく /編集著作/
へんしゅうちょさくけん /編集著作権/
へんしゅうちょさくぶつ /編集著作物/
へんしゅうとちゅう /編集途中/
へんしゅうないがい /編集内外/
へんしゅうないよう /編集内容/
へんしゅうはっこうにん /編集発行人/
へんしゅうばん /編集盤/
へんしゅうびょう /偏執病/
へんしゅうぶ /編集部/
へんしゅうぶへん /編集部編/
へんしゅうほうしん /編集方針/
へんしゅうまえ /編集前/
へんしゅうめいれい /編集命令/
へんしゅうもの /編集物/
へんしゅうや /編集屋/
へんしゅうよう /編集用/
へんしょ /返書/
へんしょく /変色/偏食/
へんしん /返信/変身/偏心/変心/
へんしんきのう /変身機能/
へんしんご /変身後/
へんしんさき /返信先/
へんしんさきめいき /返信先明記/
へんしんじ /変身時/返信時/
へんしんちゅう /変身中/
へんしんのうりょく /変身能力/
へんしんまえ /変身前/
へんしんよう /返信用/
へんしんようきって /返信用切手/
へんしんようふうとう /返信用封筒/
へんじ /返事/変事/
へんじこ /偏自己/
へんじまち /返事待/
へんじゃ /編者/
へんじゅんいそうかん /偏順位相関/
へんじょう /返上/辺上/
へんじん /変人/變人/
へんすう /変数/
へんすうかんきょう /変数環境/
へんすうかんすう /変数関数/
へんすうきごう /変数記号/
へんすうけい /変数型/
へんすうじょうけん /変数条件/
へんすうじょうほう /変数情報/
へんすうせんげん /変数宣言/
へんすうそくばく /変数束縛/
へんすうつうばん /変数通番/
へんすうていぎ /変数定義/
へんすうてんかい /変数展開/
へんすうひょう /変数表/
へんすうめい /変数名/
へんすうめいほかん /変数名補完/
へんずつう /偏頭痛/
へんせい /編成/変成/編制/遍性/変性/
へんせいがん /変成岩/
へんせいき /変声期/
へんせいぜんたい /編成全体/
へんせいぜんぶ /編成全部/
へんせいぞうきょう /編成増強/
へんせいたん /編成端/
へんせいたんい /編成単位/
へんせいちゅう /編成中/
へんせいちょう /編成長/
へんせいばんごう /編成番号/
へんせいひょう /編成表/
へんせいふ /変成譜/
へんせいふう /偏西風/
へんせいへんこう /編成変更/
へんせいもの /編成物/
へんせつ /変節/
へんせん /変遷/
へんせんし /変遷史/
へんそ /辺素/
へんそう /返送/変装/変奏/
へんそうきげん /返送期限/
へんそうきのう /返送機能/
へんそうきょく /変奏曲/
へんそうけっか /返送結果/
へんそうさき /返送先/
へんそうじ /返送時/
へんそうほうしき /返送方式/
へんそうよう /返送用/
へんそうりょうきん /返送料金/
へんそく /変則/変速/
へんそくき /変速機/
へんそくきこう /変速機構/
へんそくきのう /変速機能/
へんそくしゃそく /変速車速/
へんそくじ /変速時/
へんそくせいのう /変速性能/
へんそくそうさ /変速操作/
へんそくちゅう /変速中/
へんそくてき /変則的/
へんそくひ /変速比/
へんぞう /変造/
へんたい /変態/変体/編隊/
へんたいおんがく /変態音楽/
へんたいがな /変体仮名/
へんたいこうい /変態行為/
へんたいごと /編隊毎/
へんたいちょくご /変態直後/
へんたいてき /変態的/
へんたいひこうき /編隊飛行機/
へんたいやろう /変態野郎/
へんち /辺地/
へんちゅう /編注/
へんちょ /編著/
へんちょう /変調/偏重/変長/
へんちょうおん /変調音/
へんちょうき /変調器/
へんちょうそくど /変調速度/
へんちょうど /変調度/
へんちょうどとくせい /変調度特性/
へんちょうは /変調波/
へんちょうほうしき /変調方式/
へんてつ /変哲/
へんてん /変転/
へんでん /変電/返電/
へんでんしょ /変電所/
へんでんしょない /変電所内/
へんでんじょ /変電所/
へんとう /返答/扁桃/
へんとうえん /扁桃炎/
へんとうせん /扁桃腺/
へんどう /変動/
へんどうえがら /変動絵柄/
へんどうおん /変動音/
へんどうかん /変動感/
へんどうかんすう /偏導関数/
へんどうちゅう /変動中/
へんどうはば /変動幅/
へんどうひ /変動費/
へんどうりょう /変動量/
へんなひと /變な人/
へんにゅう /編入/
へんにゅうがく /編入学/
へんにゅうしかく /編入資格/
へんにゅうしけん /編入試験/
へんにゅうせい /編入生/
へんのう /返納/
へんば /偏頗/
へんばい /変倍/
へんばいけいすう /変倍係数/
へんばいりつ /変倍率/
へんぱ /偏波/偏頗/
へんびぶん /偏微分/
へんびぶんけいしき /偏微分形式/
へんびぶんけいすう /偏微分係数/
へんびぶんほうていしき /偏微分方程式/
へんびぶんほうていしきもんだい /偏微分方程式問題/
へんびょうし /変拍子/
へんぴ /辺鄙/
へんぴん /返品/
へんぴんかのう /返品可能/
へんふく /蝙蝠/
へんふくちょう /変復調/
へんぶん /変分/
へんぶんほう /変分法/
へんぷ /返付/
へんぺい /扁平/
へんぺいそく /偏平足/扁平足/
へんぺいりつ /偏平率/
へんぺん /辺々/
へんぼう /変貌/
へんぽう /返報/偏法/
へんぽん /返本/
へんぽんりつ /返本率/
へんまもう /偏摩耗/
へんみ /辺見/逸見/
へんめい /変名/
へんよう /変容/遍用/
へんりょう /変量/
へんりん /片鱗/辺燐/
へんれい /返礼/返戻/
へんれき /遍歴/
へんろ /遍路/
べ /辺/部/倍/邊/邉/
べーこん /ベーコン/
べーす /ベース/
べーた /β/
べーたせん /β線/
べーたは /β波/
べーまが /ベーマガ/
べあ /ベア/
べい /米/
べいえい /米英/
べいえいが /米映画/
べいえいぐん /米英軍/
べいえいらん /米英蘭/
べいか /米価/米菓;煎餅などのこと。/
べいかんたい /米艦隊/
べいがわ /米側/
べいくうぼ /米空母/
べいぐん /米軍/
べいぐんあいて /米軍相手/
べいぐんあとち /米軍跡地/
べいぐんき /米軍機/
べいぐんきち /米軍基地/
べいぐんきちあと /米軍基地跡/
べいぐんしせつない /米軍施設内/
べいぐんしゅくしゃ /米軍宿舎/
べいぐんとうちか /米軍統治下/
べいぐんへいし /米軍兵士/
べいぐんよう /米軍用/
べいこく /米国/米穀/
べいこくえいが /米国映画/
べいこくおろししょう /米穀卸商/
べいこくかがくがっかい /米国科学学会/
べいこくがい /米国外/
べいこくがた /米国型/
べいこくがわ /米国側/
べいこくきかく /米国規格/
べいこくきしゃ /米国記者/
べいこくぎかい /米国議会/
べいこくけい /米国系/
べいこくけんぽう /米国憲法/
べいこくこくぼうそうしょう /米国国防総省/
べいこくご /米国語/
べいこくさん /米国産/
べいこくしき /米国式/
べいこくしゅっこくじ /米国出国時/
べいこくしゅどう /米国主導/
べいこくしょてんめい /米国書店名/
べいこくしよう /米国仕様/
べいこくしんぞうきょうかい /米国心臓協会/
べいこくじん /米国人/
べいこくせい /米国製/
べいこくせいふ /米国政府/
べいこくせんしゅ /米国選手/
べいこくだい /米国大/
べいこくだいひょう /米国代表/
べいこくてき /米国的/
べいこくない /米国内/
べいこくないしゅうゆう /米国内周遊/
べいこくないせん /米国内線/
べいこくなんぶ /米国南部/
べいこくにゅうこくじ /米国入国時/
べいこくにゅうしゅっこくじ /米国入出国時/
べいこくはつ /米国発/
べいこくばん /米国盤/米国版/
べいこくほうじん /米国法人/
べいこくほうめん /米国方面/
べいこくほんど /米国本土/
べいこくほんどけいゆ /米国本土経由/
べいこくぼうしょう /米国防省/
べいこくりょこうちゅう /米国旅行中/
べいご /米語/
べいさく /米作/
べいさくのうか /米作農家/
べいさん /米産/
べいさんち /米産地/
べいしきしゅうきゅう /米式蹴球/
べいしゃ /米車/
べいしゅう /米収/
べいしゅん /米春/
べいしょく /米食/
べいじゅ /米寿/
べいじょういん /米上院/
べいじょうほうぶ /米情報部/
べいじん /米人/
べいせいせんそう /米西戦争/
べいせいふ /米政府/
べいそ /米ソ/
べいだいがく /米大学/
べいだいとうりょう /米大統領/
べいちゅう /米駐/
べいちょう /米朝/
べいてい /米帝/
べいはん /米飯/
べいはんきゅうしょく /米飯給食/
べいふん /米粉/
べいへい /米兵/
べいべつ /袂別/
べいほんごく /米本国/
べえ /兵衛/
べえた /β/
べき /羃/巾/冖/冪/幎/汨/覓/
べきしゅうごう /冪集合/
べきじょう /羃乗/べき乗/巾乗/冪乗/
べきすう /冪数/
べく /可/
べくさかずき /可杯/
べくとる /ベクトル/
べくとるか /ベクトル化/
べくとるち /ベクトル値/
べすと /ベスト/
べすとせらー /ベストセラー/
べすとでんき /ベスト電器/
べすとばん /ベスト盤/
べっかい /別解/
べっかく /別格/
べっかん /別館/別巻/
べっき /別記/
べっきょ /別居/
べっけん /別件/瞥見/
べっこ /別個/別箇/
べっこう /別項/鼈甲/別敲/
べっこひつよう /別個必要/
べっさつ /別冊/
べっさつごう /別冊号/
べっさつたからじま /別冊宝島/
べっさつてき /別冊的/
べっさつふろく /別冊付録/
べっさつほうせき /別冊宝石/
べっさつもの /別冊物/
べっし /別紙/蔑視/別使/
べっしいしき /蔑視意識/
べっしつ /別室/
べっしやま /別子山/
べっしゅ /別種/
べっしょ /別所/
べっしょう /別称/別証/蔑称/
べっせい /別姓/
べっせいけっこん /別姓結婚/
べっせかい /別世界/
べっせつ /別節/
べっせる /ベッセル/
べっせん /別線/
べっせんくかん /別線区間/
べっそう /別荘/別送/
べっそうち /別荘地/
べっそうひん /別送品/
べったい /別体/
べったく /別宅/
べっちゃく /別役/
べっちゅう /別注/
べってい /別定/別邸/
べってん /別添/
べってんち /別天地/
べってんようしき /別添様式/
べっと /別途/
べっとう /別当/
べっとうや /別当家/
べっときょうぎ /別途協議/
べっとぎろん /別途議論/
べっとこうにゅう /別途購入/
べっとさんしょう /別途参照/
べっとそうだん /別途相談/
べっととうこう /別途投稿/
べっとにゅうしゅ /別途入手/
べっとひつよう /別途必要/
べっとひょうじ /別途表示/
べっとふたん /別途負担/
べっとれんらく /別途連絡/
べっど /ベッド/
べっぴょう /別表/
べっぴん /別嬪/
べっぷ /別府/
べっぷう /別封/
べっぽう /別報/別法/
べつ /別/蔑/瞥/韈/鼈/捌/
べつあつかい /別扱い/
べつあん /別案/
べついけん /別意見/
べつうちゅう /別宇宙/
べつうり /別売/
べつかい /別海/
べつかいけい /別会計/
べつかいひ /別会費/
べつかんり /別管理/
べつがいしゃ /別会社/
べつがいねん /別概念/
べつがっこう /別学校/
べつきかく /別規格/
べつきじ /別記事/
べつきじさんしょう /別記事参照/
べつぎ /別儀/
べつぎょうしゅ /別業種/
べつくち /別口/
べつけいえい /別経営/
べつけいしき /別形式/
べつけいとう /別系統/
べつけいやく /別契約/
べつけいゆ /別経由/
べつけいろ /別経路/
べつこう /別稿/
べつこうどう /別行動/
べつこうほち /別候補地/
べつさくひん /別作品/
べつしほん /別資本/
べつしゃしゅ /別車種/
べつしょうひん /別商品/
べつしょり /別処理/
べつしんごう /別信号/
べつしんぱん /別審判/
べつじ /別字/
べつじげん /別次元/
べつじゅうしょ /別住所/
べつじょう /別状/
べつじん /別人/
べつじんかく /別人格/
べつじんぶつ /別人物/
べつすじ /別筋/
べつず /別図/
べつずり /別刷/別刷り/
べつずりだい /別刷代/
べつせかい /別世界/
べつせっけい /別設計/
べつせんめい /別線名/
べつそしき /別組織/
べつそんざい /別存在/
べつたいけい /別体系/
べつたいしき /別体式/
べつだい /別大/
べつだいまいにち /別大毎日/
べつだん /別段/
べつだんたい /別団体/
べつとうこう /別投稿/
べつとうひょう /別投票/
べつどうたい /別動隊/
べつどり /別録り/
べつに /別に/
べつにゅうじょう /別入場/
べつのう /別納/
べつばい /別売/
べつばんぐみ /別番組/
べつばんごう /別番号/
べつびん /別便/
べつふ /別布/
べつぶんしょ /別文書/
べつぶんや /別分野/
べつべつ /別々/
べつべや /別部屋/
べつほうこう /別方向/
べつみや /別宮/
べつむね /別棟/
べつめい /別名/
べつめいあて /別名宛/
べつめいれい /別命令/
べつめん /別面/
べつもじ /別文字/
べつもの /別物/
べつもんだい /別問題/
べつやく /別役/
べつようそ /別要素/
べつり /別離/
べつりょうきん /別料金/
べつりょうきんたいけい /別料金体系/
べつれっしゃ /別列車/
べつろく /別録/
べつろせん /別路線/
べつわく /別枠/
べてらん /ベテラン/
べとなむ /ベトナム/
べとなむせんそう /ベトナム戦争/
べに /紅/
べにいろ /紅色/
べにお /紅緒/
べにくじらだん /紅鯨団/
べにしゃけ /紅鮭/
べにじゃけ /紅鮭/
べにじゃけいろ /紅鮭色/
べにはぎ /紅萩/
べにばな /紅花/
べにばなゆ /紅花油/
べにばやし /紅林/
べにまる /紅丸/
べびー /ベビー/
べふ /別府/
べや /部屋/
べらぼう /箆棒/
べらんだ /ベランダ/
べりーず /ベリーズ/
べる /ベル/
べるぎー /白耳義/
べるけん /ベル研/
べると /ベルト/
べるりん /伯林/
べん /弁/勉/便/鞭/娩/冕/辨/辧/卞/宀/抃/汳/湎/瓣/眄/辮/辯/采/
べんい /便意/
べんえき /便益/
べんかい /弁解/
べんがく /勉学/
べんき /便器/
べんきょう /勉強/
べんきょうか /勉強家/
べんきょうかい /勉強会/
べんきょうきかんちゅう /勉強期間中/
べんきょうじかん /勉強時間/
べんきょうちゅう /勉強中/
べんきょうねっしん /勉強熱心/
べんきょうふじゅうぶん /勉強不十分/
べんきょうぶそく /勉強不足/
べんきょうほう /勉強法/
べんきょうほうほう /勉強方法/
べんきょうよう /勉強用/
べんぎ /便宜/便宣/
べんぎじょう /便宜上/
べんぎそち /便宜措置/
べんぎてき /便宜的/
べんぎてきていぎ /便宜的定義/
べんけい /弁慶/
べんげい /眄睨/
べんご /弁護/
べんごがわ /弁護側/
べんごし /弁護士/
べんごしかい /弁護士会/
べんごしひよう /弁護士費用/
べんごだん /弁護団/
べんごにん /弁護人/
べんさい /弁済/
べんざ /便座/
べんざいてん /弁財天/
べんし /弁士/
べんしつ /弁室/
べんしょう /弁償/
べんしょうきん /弁償金/
べんしょうほう /弁証法/
べんじょ /便所/
べんぜつ /弁舌/
べんぞう /勉三/
べんたつ /鞭撻/
べんだ /ベンダ/
べんだー /ベンダー/
べんちまーく /べんちまーく/
べんちゃ /ベンチャ/
べんちゃー /ベンチャー/
べんつう /便通/
べんてん /弁天/
べんてんじま /弁天島/
べんてんちょう /弁天町/
べんとう /弁当/
べんとうがいしゃ /弁当会社/
べんとうじさん /弁当持参/
べんとうだい /弁当代/
べんとうばこ /弁当箱/
べんとうぶくろ /弁当袋/
べんとうや /弁当屋/
べんとうりょう /弁当料/
べんぱつ /弁髪/辮髪/
べんぴ /便秘/
べんぴしょう /便秘症/
べんぴやく /便秘薬/
べんべつ /弁別/
べんべつきのう /弁別機能/
べんべつげん /弁別限/
べんべつじっけん /弁別実験/
べんべつたいしょう /弁別対象/
べんべつてき /弁別的/
べんべつのうりょく /弁別能力/
べんぽう /便法/
べんむかん /弁務官/
べんめい /弁明/
べんもう /鞭毛/
べんらん /便覧/
べんり /便利/弁理/
べんりきのう /便利機能/
べんりし /弁理士/
べんりじむしょ /弁理事務所/
べんりちょう /便利帳/便利帖/
べんりひん /便利品/
べんりや /便利屋/
べんれい /勉励/
べんろん /弁論/
べんろんたいかい /弁論大会/
ぺーじ /頁/ページ/
ぺーじばんごう /ページ番号/
ぺーす /ペース/
ぺーすと /ペースト/
ぺーぱー /ペーパー/
ぺあ /ペア/
ぺい /平/閉/併/蔽/閇/北/
ぺいがん /頁岩/
ぺいじ /頁/
ぺえ /北/
ぺえじ /頁/
ぺがさす /ペガサス/
ぺき /北/
ぺきん /北京/
ぺきんご /北京語/
ぺきんにっぽう /北京日報/
ぺけ /×/
ぺけぺけ /××/
ぺこ /(_o_)/
ぺこり /(_0_)/_0_/(_o_)/
ぺしみすと /ペシミスト/
ぺってぃんぐ /ペッティング/
ぺっと /ペット/
ぺとりさら /ペトリ皿/
ぺなるてぃ /ペナルティ/
ぺにーれいん /ペニーレイン/
ぺふちょう /別府町/
ぺるー /祕魯/祕露/
ぺるしあ /波斯/
ぺるしゃ /ペルシャ/
ぺるしゃわん /ペルシャ湾/
ぺれっと /ペレット/
ぺん /片/辺/ペン/邊/邉/
ぺんき /ペンキ/
ぺんぎん /ペンギン/
ぺんさき /ペン先/
ぺんしょん /ペンション/
ぺんでぃんぐ /ペンディング/
ぺんときしろんあこう /ペントキシロン亜綱/Pentoxylidae/
ぺんとはうす /ペントハウス/
ぺんねーむ /ペンネーム/
ほ /穂/保/補/歩/甫/輔/捕/帆/圃/鋪/舗/哺/匍/埔/堡/穗/脯/舖/葆/逋/餔/鯆/黼/浦/蒲/畝/葡/火/
ほーていらおゆい /河底撈魚/
ほーみんぐ /ホーミング/
ほーむ /ホーム/
ほーる /ホール/
ほあん /保安/
ほあんかん /保安官/
ほあんきじゅん /保安基準/
ほあんしゅにん /保安主任/
ほあんじょう /保安上/
ほあんせつび /保安設備/
ほあんそうち /保安装置/
ほあんちょう /保安庁/
ほあんぶ /保安部/
ほあんぶいん /保安部員/
ほあんぶない /保安部内/
ほあんぶひん /保安部品/
ほあんぶぶちょう /保安部部長/
ほあんよう /保安用/
ほあんよういん /保安要員/
ほあんりん /保安林/
ほい /補遺/
ほいく /保育/哺育/
ほいくえん /保育園/
ほいくか /保育科/
ほいくしせつ /保育施設/
ほいくしゃ /保育社/保育者/
ほいくしょ /保育所/
ほいくしょしょくいん /保育所職員/
ほいくしょにゅうしょ /保育所入所/
ほいくじょ /保育所/
ほいくよさん /保育予算/
ほいくりょう /保育料/
ほいこうろう /回鍋肉/
ほいだ /穂井田/
ほう /方/法/報/放/泡/砲/邦/崩/豊/訪/鵬/胞/蓬/朋/抱/鳳/飽/鋒/芳/包/褒/蜂/萌/呆/峯/宝/捧/烹/倣/庖/俸/彷/峰/奉/寳/烽/逢/保/勹/匏/匚/咆/垉/堋/寶/幇/弸/彭/怦/抔/抛/枋/泙/澎/炮/焙/琺/疱/皰/硼/磅/篷/繃/舫/苞/萠/袍/褓/襃/豐/迸/髣/魴/麭/縫/瀑/鞄/蔀/鴇/棒/朴/棚/膀/封/
ほうあん /法案/
ほうあんか /法案化/
ほうあんせいりつ /法案成立/
ほうあんていしゅつ /法案提出/
ほうい /方位/包囲/法衣/
ほういかいぼう /法医解剖/
ほういかく /方位角/
ほういがく /法医学/
ほういがくきょうしつ /法医学教室/
ほういけん /放医研/
ほういさ /方位差/
ほういせん /包囲戦/
ほういつ /放逸/
ほうえい /放映/訪英/
ほうえいえんちょう /放映延長/
ほうえいきかん /放映期間/
ほうえいきんし /放映禁止/
ほうえいけん /放映権/
ほうえいご /放映後/
ほうえいしゅうりょうちょくご /放映終了直後/
ほうえいじ /放映時/
ほうえいじかん /放映時間/
ほうえいじかんいがい /放映時間以外/
ほうえいじかんやく /放映時間約/
ほうえいじき /放映時期/
ほうえいじゅん /放映順/
ほうえいじゅんじょ /放映順序/
ほうえいじょうきょう /放映状況/
ほうえいちいき /放映地域/
ほうえいちゅう /放映中/
ほうえいちゅうし /放映中止/
ほうえいちょくご /放映直後/
ほうえいとうじ /放映当時/
ほうえいにちじ /放映日時/
ほうえいび /放映日/
ほうえいふっかつ /放映復活/
ほうえいぶん /放映分/
ほうえいまえ /放映前/
ほうえいよう /放映用/
ほうえいよてい /放映予定/
ほうえいりょう /放映料/
ほうえいわすう /放映話数/
ほうえつ /法悦/
ほうおう /法王/法皇/鳳王/訪欧/鳳凰/
ほうか /放火/法科/邦貨/烽火/放課/法家/砲火/
ほうかい /崩壊/崩解/崩潰/
ほうかいいん /法界院/
ほうかいけいれつ /崩壊系列/
ほうかいしゃく /法解釈/
ほうかいじょうたい /崩壊状態/
ほうかいず /崩壊図/
ほうかいせい /法改正/
ほうかいせき /方解石/
ほうかいていすう /崩壊定数/
ほうかいねつ /崩壊熱/
ほうかいまえ /崩壊前/
ほうかいれい /崩壊例/
ほうかご /放課後/
ほうかだて /邦貨建/
ほうかつ /包括/
ほうかついにんじょう /包括委任状/
ほうかつきょうぎ /包括協議/
ほうかつせいど /包括制度/
ほうかつてき /包括的/
ほうかつめんきょ /包括免許/
ほうかつめんきょせい /包括免許制/
ほうかん /奉還/訪韓/幇間/
ほうかんじょう /法感情/
ほうが /奉賀/邦画/萌芽/萠芽/芳賀/
ほうがい /法外/
ほうがいねん /法概念/
ほうがく /方角/邦楽/法学/
ほうがくか /法学科/
ほうがくけい /邦楽系/
ほうがくぶ /法学部/
ほうがくぶしゅっしんしゃ /法学部出身者/
ほうがっか /法学科/
ほうがっき /邦楽器/
ほうがてき /胞芽的/
ほうがん /包含/方眼/砲丸/
ほうがんかんけい /包含関係/
ほうがんし /方眼紙/
ほうがんせい /包含性/
ほうがんなげ /砲丸投げ/
ほうき /放棄/法規/伯耆/蜂起/帚/彗/箒/箏/筝/菷/抛棄/
ほうきかんれい /法規慣例/
ほうきせい /法規制/
ほうきはん /法規班/
ほうきぼし /彗星/箒星/
ほうきゅう /俸給/
ほうきょう /法橋/
ほうきん /宝金/
ほうぎょ /崩御/
ほうぎょく /宝玉/
ほうけい /包茎/方形/法経/
ほうけいけいがくぶ /法経系学部/
ほうけいさいぼう /方形細胞/
ほうけいじかんまど /方形時間窓/
ほうけいは /方形波/
ほうけいほうしゃそしきさいぼう /方形放射組織細胞/
ほうけん /封建/
ほうけんしゃかい /封建社会/
ほうけんじだい /封建時代/
ほうけんてき /封建的/
ほうけんてきせいど /封建的制度/
ほうげ /放下/
ほうげき /砲撃/崩撃/
ほうげきしゅ /砲撃手/
ほうげきせん /砲撃戦/
ほうげん /方言/放言/
ほうげんぶんがく /方言文学/
ほうこ /宝庫/
ほうこう /方向/奉行/芳香/奉公/放校/咆哮/彷徨/
ほうこうあわせ /方向合わせ/
ほうこういどう /方向移動/
ほうこうおんち /方向音痴/
ほうこうかん /方向感/
ほうこうかんてき /報交換的/
ほうこうけっていたいいき /方向決定帯域/
ほうこうこてい /方向固定/
ほうこうざい /芳香剤/
ほうこうしじき /方向指示機/方向指示器/
ほうこうしゅう /芳香臭/
ほうこうしゅうせい /方向修正/
ほうこうじ /方広寺/
ほうこうせい /方向性/
ほうこうせいやく /方向制約/
ほうこうせんそ /方向線素/
ほうこうだ /方向舵/
ほうこうていい /方向定位/
ほうこうてき /方向的/
ほうこうてんかん /方向転換/
ほうこうにん /奉公人/
ほうこうへんかん /方向変換/
ほうこうべつ /方向別/
ほうこうべつか /方向別化/
ほうこうべつはいせん /方向別配線/
ほうこうまく /方向幕/
ほうこく /報告/報国/豊国/
ほうこくかい /報告会/
ほうこくき /報告記/
ほうこくきじ /報告記事/
ほうこくぎむ /報告義務/
ほうこくしゃ /報告者/
ほうこくしゅう /報告集/
ほうこくしょ /報告書/
ほうこくじこう /報告事項/
ほうこくひょう /報告票/
ほうこくぶん /報告文/
ほうこくぶんしょ /報告文書/
ほうごう /縫合/抱合/
ほうさい /朋斎/
ほうさか /逢坂/
ほうさく /方策/豊作/
ほうさん /放散/硼酸/ホウ酸/
ほうざ /砲座/
ほうざい /包材/
ほうざわ /寶澤/
ほうし /包子/奉仕/法師/胞子/芳志/
ほうしき /方式/
ほうしきかん /方式間/
ほうしきけん /方式研/
ほうしきけんとう /方式検討/
ほうしきしゅぎ /方式主義/
ほうしきじょう /方式上/
ほうしきぞうせつ /方式増設/
ほうしきちがい /方式違い/
ほうしきへんかん /方式変換/
ほうししゃ /奉仕者/
ほうしひん /奉仕品/
ほうしゃ /放射/
ほうしゃおん /放射音/
ほうしゃか /放射化/
ほうしゃかいがく /法社会学/
ほうしゃかいへん /放射壊変/
ほうしゃかっせい /放射活性/
ほうしゃかどうかん /放射仮導管/
ほうしゃかんすう /放射関数/
ほうしゃき /放射器/
ほうしゃきど /放射輝度/
ほうしゃげん /放射源/
ほうしゃこう /放射光/
ほうしゃじょう /放射状/
ほうしゃせい /放射性/
ほうしゃせいかくしゅ /放射性核種/
ほうしゃせいかごうぶつ /放射性化合物/
ほうしゃせいげんそ /放射性元素/
ほうしゃせいこうかぶつ /放射性降下物/
ほうしゃせいはいきぶつ /放射性廃棄物/
ほうしゃせいぶっしつ /放射性物質/
ほうしゃせん /放射線/
ほうしゃせんかんりけんきゅうぶ /放射線管理研究部/
ほうしゃせんけんきゅうしつ /放射線研究室/
ほうしゃせんげん /放射線源/
ほうしゃせんしょうい /放射線照射/
ほうしゃせんしょうがい /放射線障害/
ほうしゃせんしょり /放射線処理/
ほうしゃせんじっけん /放射線実験/
ほうしゃせんそくてい /放射線測定/
ほうしゃせんたい /放射線帯/
ほうしゃせんたいさく /放射線対策/
ほうしゃせんひばく /放射線被曝/
ほうしゃせんりょうほう /放射線療法/
ほうしゃそうしょう /放射相称/
ほうしゃそくてい /放射測定/
ほうしゃそしき /放射組織/
ほうしゃそしきかどうかん /放射組織仮導管/
ほうしゃそしきさいぼう /放射組織細胞/
ほうしゃたいりゅうへいこう /放射対流平衡/
ほうしゃち /放射値/
ほうしゃてん /放射点/
ほうしゃとくせい /放射特性/
ほうしゃのう /放射能/
ほうしゃのうおせん /放射能汚染/
ほうしゃのうそくてい /放射能測定/
ほうしゃのうひばく /放射能被曝/
ほうしゃりょう /放射量/
ほうしゅう /報酬/
ほうしゅうせいきゅうけん /報酬請求権/
ほうしゅく /奉祝/
ほうしゅつ /放出/法出/
ほうしゅつかてい /放出過程/
ほうしゅつきゅうしゅう /放出吸収/
ほうしゅつめん /放出面/
ほうしゅつりゅうし /放出粒子/
ほうしゅつりゆう /放出理由/
ほうしゅつりょう /放出量/
ほうしゅやま /宝珠山/
ほうしょ /邦書/
ほうしょう /放縦/宝生/褒賞/宝商/報償/報奨/報賞/法相/褒章/
ほうしょうきん /報償金/報奨金/
ほうしょうじ /宝生寺/
ほうしょうめい /褒賞名/
ほうしょうりゅう /宝生流/
ほうしょがみ /奉書紙/
ほうしょく /奉職/飽食/
ほうしん /方針/放心/砲身/庖疹/疱疹/
ほうしんけってい /方針決定/
ほうしんしょ /方針書/
ほうしんじょうたい /放心状態/
ほうしんてんかん /方針転換/
ほうしんへんこう /方針変更/
ほうじ /法事/
ほうじちゃ /焙じ茶/
ほうじゅう /放銃/放縦/放縱/
ほうじゅく /豊熟/
ほうじゅつ /砲術/
ほうじゅつちょう /砲術長/
ほうじゅん /芳醇/
ほうじょ /幇助/
ほうじょう /北條/宝条/北条/方乗/豊穣/豊穰/豊饒/方城/蓬生/
ほうじょうえ /放生会/
ほうじょうけ /北条家/
ほうじょうし /北条氏/
ほうじょうちょう /北条町/
ほうじょうまさむね /北条正宗/
ほうじょうや /放生会/
ほうじん /法人/邦人/
ほうじんかいいん /法人会員/
ほうじんかく /法人格/
ほうじんぜい /法人税/
ほうじんなど /法人等/
ほうじんめい /法人名/
ほうすい /放水/豊水/
ほうすいき /豊水期/
ほうすいしゃ /放水車/
ほうすいろ /放水路/
ほうすう /砲数/鳳雛/
ほうすけ /保介/
ほうすん /方寸/
ほうせい /方正/法政/法制/縫製/砲声/
ほうせいか /法制化/
ほうせいきょく /法制局/
ほうせいしんぎかい /法制審議会/
ほうせいだい /法政大/
ほうせいだいがく /法政大学/
ほうせいだいこう /法政大工/
ほうせいど /法制度/
ほうせいどがい /法制度外/
ほうせいにこう /法政二高/
ほうせいび /法整備/
ほうせき /宝石/
ほうせきしょう /宝石商/
ほうせきてん /宝石店/
ほうせきばこ /宝石箱/
ほうせきるい /宝石類/
ほうせつ /包摂/
ほうせつかごうぶつ /包接化合物/
ほうせん /豊泉/法線/芳泉/奉先/砲戦/
ほうせんいん /宝泉院/
ほうせんか /鳳仙花/
ほうせんがくえん /宝仙学園/
ほうせんべくとる /法線ベクトル/
ほうせんほうこう /法線方向/
ほうせんほうこうそくど /法線方向速度/
ほうそ /硼素/
ほうそう /放送/包装/法曹/疱瘡/法曽/
ほうそういがい /放送以外/
ほうそうえいせい /放送衛星/
ほうそうえんちょう /放送延長/
ほうそうかい /法曹界/
ほうそうかいし /放送開始/
ほうそうかんけい /放送関係/
ほうそうがた /放送型/
ほうそうききてん /放送機器展/
ほうそうきざい /放送機材/
ほうそうきゅうし /放送休止/
ほうそうきょう /放送響/
ほうそうきょうかい /放送協会/
ほうそうきょく /放送局/
ほうそうきょくめい /放送局名/
ほうそうきょくよう /放送局用/
ほうそうきょくようきき /放送局用機器/
ほうそうきんし /放送禁止/
ほうそうきんしようご /放送禁止用語/
ほうそうぎじゅつ /放送技術/
ほうそうぎょうかい /放送業界/
ほうそうけいたい /放送形態/
ほうそうけん /放送権/
ほうそうけんりょう /放送権料/
ほうそうこうきょうがくだん /放送交響楽団/
ほうそうさんぎょう /放送産業/
ほうそうし /包装紙/
ほうそうしゅうはすう /放送周波数/
ほうそうしゅうりょう /放送終了/
ほうそうしゅうりょうご /放送終了後/
ほうそうしゅうりょうじ /放送終了時/
ほうそうしゅっぱん /放送出版/
ほうそうしょう /放送賞/
ほうそうじ /放送時/
ほうそうじかん /放送時間/
ほうそうじかんたい /放送時間帯/
ほうそうじかんない /放送時間内/
ほうそうじき /放送時期/
ほうそうじぎょうしゃ /放送事業者/
ほうそうじこ /放送事故/
ほうそうじこく /放送時刻/
ほうそうじゅん /放送順/
ほうそうじゅんじょ /放送順序/
ほうそうせいど /放送制度/
ほうそうせき /放送席/
ほうそうせつび /放送設備/
ほうそうだいがく /放送大学/
ほうそうだいがくこうざ /放送大学講座/
ほうそうちゅう /放送中/
ほうそうでんぱ /放送電波/
ほうそうとうじ /放送当時/
ほうそうとうじつ /放送当日/
ほうそうとうむき /放送塔向/
ほうそうないよう /放送内容/
ほうそうにちじ /放送日時/
ほうそうは /放送波/
ほうそうはん /放送班/
ほうそうばんぐみ /放送番組/
ほうそうび /放送日/
ほうそうぶ /放送部/
ほうそうぶん /放送分/
ほうそうぶんかなど /放送文化等/
ほうそうほう /放送法/
ほうそうほうしき /放送方式/
ほうそうまえ /放送前/
ほうそうみてい /放送未定/
ほうそうもくろく /放送目録/
ほうそうよう /放送用/
ほうそうようご /放送用語/
ほうそうよてい /放送予定/
ほうそうよていじかん /放送予定時間/
ほうそうよていび /放送予定日/
ほうそうろくが /放送録画/
ほうそうわく /放送枠/
ほうそく /法則/
ほうそくじょう /法則上/
ほうそくせい /法則性/
ほうそくてき /法則的/
ほうぞう /包蔵/法蔵/
ほうぞうかん /法蔵館/
ほうたい /包帯/方体/胞体/繃帯/
ほうたいけい /法体系/
ほうたく /飽託/
ほうだ /法田/
ほうだい /放題/砲台/邦題/法大/
ほうだん /放談/砲弾/砲彈/
ほうだんかい /放談会/
ほうだんかいほうこく /放談会報告/
ほうだんがた /砲弾型/
ほうち /放置/法治/報知/
ほうちき /報知器/報知機/
ほうちきかん /放置期間/
ほうちく /放逐/
ほうちこく /法治国/
ほうちこっか /法治国家/
ほうちしき /法知識/
ほうちしゃ /放置車/
ほうちしゃかい /法治社会/
ほうちしゅぎ /法治主義/
ほうちしゅぎこく /法治主義国/
ほうちしんぶん /報知新聞/
ほうちちゅうしゃ /放置駐車/
ほうちにりん /放置二輪/
ほうちゃく /逢着/縫着/
ほうちゅう /訪中/
ほうちょう /包丁/庖丁/
ほうてい /法廷/法定/
ほうていがいもくてきぜい /法定外目的税;自治体の独自課税/
ほうていきじゅん /法定基準/
ほうていけい /法定刑/
ほうていしき /方程式/
ほうていしきけい /方程式系/
ほうていしきりろん /方程式理論/
ほうていじゅんびきん /法定準備金;資本準備金、利益準備金の2つ/
ほうていせいげんそくど /法定制限速度/
ほうていそくど /法定速度/
ほうていだいりにん /法定代理人/
ほうていでんせんびょう /法定伝染病/
ほうていない /法定内/
ほうていひよう /法定費用/
ほうていりそく /法定利息/
ほうてき /法的/放擲/
ほうてきいち /法的位置/
ほうてききせい /法的規制/
ほうてきぎむ /法的義務/
ほうてきけんげん /法的権限/
ほうてきけんち /法的見地/
ほうてきけんり /法的権利/
ほうてきこうそくりょく /法的拘束力/
ほうてきこんきょ /法的根拠/
ほうてきしゅだん /法的手段/
ほうてきせきにん /法的責任/
ほうてきちい /法的地位/
ほうてきばつ /法的罰/
ほうてきひょうか /法的評価/
ほうてきほご /法的保護/
ほうてきめん /法的面/
ほうてつがく /法哲学/
ほうてん /法典/宝典/奉天/方転/
ほうでん /放電/宝殿/
ほうでんかこう /放電加工/
ほうでんき /放電器/
ほうでんきのう /放電機能/
ほうでんしゅうりょうじ /放電終了時/
ほうでんじ /放電時/
ほうと /方途/
ほうとう /宝刀/放蕩/砲塔/
ほうとうない /砲塔内/
ほうとくがくえん /報徳学園/
ほうとり /放取/
ほうど /封土/
ほうどう /報道/報導/
ほうどうかくしゃ /報道各社/
ほうどうかんけいしゃ /報道関係者/
ほうどうきかん /報道機関/
ほうどうきせい /報道規制/
ほうどうきょうてい /報道協定/
ほうどうきょく /報道局/
ほうどうさつえいよう /報道撮影用/
ほうどうしせい /報道姿勢/
ほうどうしゃしん /報道写真/
ほうどうしゃしんか /報道写真家/
ほうどうじん /報道陣/
ほうどうせいしん /報道精神/
ほうどうばんぐみ /報道番組/
ほうどうぶもん /報道部門/
ほうどく /奉読/
ほうなん /豊南/方南/
ほうなんこうこう /豊南高校/
ほうなんちょう /方南町/
ほうにち /訪日/
ほうにょう /放尿/
ほうにん /放任/
ほうにんしゅぎ /放任主義/
ほうにんじょうたい /放任状態/
ほうねつ /放熱/
ほうねつき /放熱器/
ほうねつこうか /放熱効果/
ほうねつたいさく /放熱対策/
ほうねつばん /放熱板/
ほうねん /放念/豊年/法然/
ほうねんせいゆ /豊年製油/
ほうのう /奉納/
ほうのうきん /奉納金/
ほうはく /鵬搏/
ほうば /放馬/
ほうばい /傍輩/
ほうひ /放屁/豊肥/
ほうひほんせん /豊肥本線/
ほうび /褒美/
ほうふ /豊富/抱負/豊冨/防府/豊府/飽負/
ほうふく /報復/抱腹/
ほうふくこうい /報復行為/
ほうふくこうげき /報復攻撃/
ほうふくじ /豊福寺/
ほうふくぜっとう /抱腹絶倒/
ほうふくそち /報復措置/
ほうふつ /彷彿/髣髴/
ほうぶつ /放物/
ほうぶつうんどう /放物運動/
ほうぶつせん /放物線/抛物線/
ほうぶつめん /放物面/
ほうぶん /邦文/報文/法文/
ほうぶんか /法文化/
ほうぶんしゃ /芳文社/
ほうへい /砲兵/
ほうへきざん /豊碧山/
ほうへん /褒貶/
ほうべい /訪米/
ほうべいちゅう /訪米中/
ほうべん /方便/
ほうほう /方法/
ほうほういがい /方法以外/
ほうほうじたい /方法自体/
ほうほうじょせつ /方法序説/
ほうほうなど /方法等/
ほうほうろん /方法論/
ほうほうろんじしん /方法論自身/
ほうほうろんじたい /方法論自体/
ほうほうろんてきいみ /方法論的意味/
ほうほく /豊北/
ほうぼう /方々/方方/宝坊/蜂房/鋒鋩/魴ボウ/竹麦魚/謗法/
ほうぼく /放牧/
ほうぼくちゅう /放牧中/
ほうまつ /泡沫/
ほうまん /放漫/豊満/
ほうみょう /法名/
ほうむ /法務/放夢/
ほうむきょく /法務局/
ほうむしょう /法務省/
ほうむだいじん /法務大臣/
ほうむちょうけんかい /法務庁見解/
ほうめい /芳名/法明/邦名/
ほうめいちょう /芳名帳/
ほうめいぼ /芳名簿/
ほうめん /方面/放免/
ほうめんぐん /方面軍/
ほうめんたい /方面隊/
ほうめんべつ /方面別/
ほうもう /法網/
ほうもつ /宝物/
ほうもん /訪問/砲門/
ほうもんかのう /訪問可能/
ほうもんき /訪問記/
ほうもんきゃく /訪問客/
ほうもんぎ /訪問着/
ほうもんこく /訪問国/
ほうもんさき /訪問先/
ほうもんしゃ /訪問者/
ほうもんじ /訪問時/
ほうもんとし /訪問都市/
ほうもんはんばい /訪問販売/
ほうもんはんばいほう /訪問販売法/
ほうもんび /訪問日/
ほうや /保谷/
ほうやく /邦訳/
ほうやくずみ /邦訳済/
ほうやくはっぴょうじゅん /邦訳発表順/
ほうやし /保谷市/
ほうゆう /朋友/邦友/
ほうよう /抱擁/包容/法要/包葉/放鷹/苞葉/
ほうようりょく /包容力/
ほうら /和了/
ほうらい /宝来/蓬莱/寳来/鳳来/
ほうらいけん /宝来研/
ほうらいじ /鳳来寺/
ほうらく /包絡/崩落/炮烙/
ほうらくせん /包絡線/
ほうらくのうたげ /炮烙之宴/炮烙の宴/
ほうらくのけい /炮烙之刑/
ほうらくまんじゅう /蜂楽饅頭/
ほうらくめん /包絡面/
ほうらけい /和了形/
ほうらつ /放埒/
ほうり /宝利/法理/
ほうりき /法力/
ほうりつ /法律/
ほうりつあん /法律案/
ほうりついはん /法律違反/
ほうりつか /法律家/法律化/
ほうりつかいせい /法律改正/
ほうりつかんけい /法律関係/
ほうりつがく /法律学/
ほうりつがくしゃ /法律学者/
ほうりつぎけつ /法律議決/
ほうりつこん /法律婚/
ほうりつご /法律語/
ほうりつじしん /法律自身/
ほうりつじほう /法律時報/
ほうりつじむしょ /法律事務所/
ほうりつじょう /法律上/
ほうりつじょういほう /法律上違法/
ほうりつじょうかのう /法律上可能/
ほうりつじょうほご /法律上保護/
ほうりつせいど /法律制度/
ほうりつせいれい /法律政令/
ほうりつそうだん /法律相談/
ほうりつそうだんばんぐみ /法律相談番組/
ほうりつそうだんぶ /法律相談部/
ほうりつてき /法律的/
ほうりつてきぎじゅつ /法律的技術/
ほうりつてきこんきょ /法律的根拠/
ほうりつてきせいやく /法律的制約/
ほうりつてきもんだい /法律的問題/
ほうりつはんだん /法律判断/
ほうりつもんだい /法律問題/
ほうりつようご /法律用語/
ほうりつろん /法律論/
ほうりつろんそう /法律論争/
ほうりゃく /方略/
ほうりゅう /放流/
ほうりゅうぎょ /放流魚/
ほうりゅうじ /法隆寺/
ほうりょう /豊漁/
ほうりろん /法理論/
ほうりろんてき /法理論的/
ほうりん /法林/
ほうりんどうしょてん /芳林堂書店/
ほうるい /堡塁/
ほうれい /法令/法例/
ほうれいしゅう /法令集/
ほうれきほん /宝暦本/
ほうれん /法蓮/
ほうれんそう /法蓮草/ほうれん草/菠薐草/
ほうろう /放浪/琺瑯/
ほうろうき /放浪記/
ほうろうしゃ /放浪者/
ほうろうへき /放浪癖/
ほうろうわくせい /放浪惑星/
ほうろく /焙烙/
ほうろん /放論/
ほうわ /飽和/法話/豊和/
ほうわがた /飽和型/
ほうわしき /飽和式/
ほうわじそくみつど /飽和磁束密度/
ほうわじょうきあつ /飽和蒸気圧/
ほうわじょうたい /飽和状態/
ほうわすいじょうきあつ /飽和水蒸気圧/
ほうわすいじょうきりょう /飽和水蒸気量/
ほうわすいようえき /飽和水溶液/
ほうわてん /飽和点/
ほえづら /吠面/
ほお /頬/
ほおずり /ほお擦り/頬擦り/
ほおづえ /頬杖/
ほおひげ /髯/
ほおべに /頬紅/
ほおぼね /頬骨/
ほおん /保温/
ほおんき /保温機/保温器/
ほおんじょうたい /保温状態/
ほおんせい /保温性/
ほおんせいのう /保温性能/
ほおんなべ /保温鍋/
ほおんよう /保温用/
ほおんりょく /保温力/
ほか /他/外/
ほかいちめい /他一名/
ほかおおぜい /他大勢/他多勢/
ほかく /保革/捕獲/
ほかくだんめんせき /捕獲断面積/
ほかげ /灯かげ/帆影/
ほかすうめい /他数名/
ほかたすう /他多数/
ほかなんにん /他何人/
ほかに /他に/
ほかの /他の/
ほかふたり /他二人/
ほかぶり /頬被り/
ほかん /保管/補完/補間/
ほかんかいすう /補間回数/
ほかんかへん /補間可変/
ほかんきげん /保管期限/
ほかんきのう /補完機能/
ほかんきょくせん /補間曲線/
ほかんくうこう /補完空港/
ほかんこてい /補間固定/
ほかんしょり /補完処理/
ほかんじょ /保管所/
ほかんじょうきょう /保管状況/
ほかんじょうたい /保管状態/
ほかんせってい /補間設定/
ほかんち /補間値/
ほかんちゅう /保管中/
ほかんていり /補間定理/
ほかんてき /補完的/
ほかんばしょ /保管場所/
ほかんほう /補間法/
ほかんほうほう /補間方法/
ほかんほぞんほうほう /保管保存方法/
ほかんよう /保管用/
ほかんれっしゃ /補完列車/
ほかんわりあい /補間割合/
ほがい /補外/
ほがた /保型/
ほがらか /朗らか/
ほき /補記/補機/
ほきもと /保木本/
ほきゅう /補給/捕球/
ほきゅうしゅだん /補給手段/
ほきゅうじ /補給時/
ほきゅうじょうたい /補給状態/
ほきゅうせん /補給線/
ほきゅうち /補給値/
ほきゅうぶっし /補給物資/
ほきゅうぶつ /補給物/
ほきゅうへい /補給兵/
ほきゅうほうほう /補給方法/
ほきゅうもくてき /補給目的/
ほきゅうよう /補給用/
ほきゅうりょう /補給量/
ほきょう /補強/
ほきょうけいかく /補強計画/
ほきょうざい /補強材/
ほきょうしょうこ /補強証拠/
ほきょうしんごう /補強信号/
ほきょうせん /補強線/
ほきょうせんしゅ /補強選手/
ほきょうようぶひん /補強用部品/
ほきるい /補機類/
ほきん /保菌/
ほきんしゃ /保菌者/
ほぎうた /寿歌/
ほく /北/攴/攵/殕/蹼/瀑/
ほくい /北緯/
ほくうかん /補空間/
ほくえい /北瑛/
ほくえつ /北越/
ほくえつぎんこう /北越銀行/
ほくえつせいし /北越製紙/
ほくえつほくせん /北越北線/
ほくおう /北欧/
ほくおうけい /北欧系/
ほくおうしょこく /北欧諸国/
ほくおうしんわ /北欧神話/
ほくおうてき /北欧的/
ほくがん /北岸/
ほくげん /北限/
ほくこう /北興/
ほくさい /北斎/
ほくさつほうげん /北薩方言/
ほくしゅう /北州/
ほくしん /北辰/
ほくしんえつ /北信越/
ほくしんきゅうこう /北神急行/
ほくじょう /北上/
ほくせい /北西/北勢/北星/
ほくせいがわ /北西側/
ほくせいせん /北勢線/
ほくせいそう /北誠荘/
ほくせいほうこう /北西方向/
ほくせつ /北摂/
ほくせん /北線/
ほくそ /樮/
ほくそうかいはつてつどう /北総開発鉄道/
ほくそうせん /北総線/
ほくそうせんない /北総線内/
ほくそうちいき /北総地域/
ほくそうてつどう /北総鉄道/
ほくたん /北端/
ほくたんてつどう /北丹鉄道/
ほくだい /北大/北海道大学/
ほくだいおうぶつ /北大応物/
ほくだいきょうようぶ /北大教養部/
ほくだいこうがくぶ /北大工学部/
ほくだいこうどうかがく /北大行動科学/
ほくだいじょうほう /北大情報/
ほくだいじょうほうこう /北大情報工/
ほくだいすうがく /北大数学/
ほくだいせいきょう /北大生協/
ほくだいない /北大内/
ほくだいびょういん /北大病院/
ほくだん /北淡/
ほくちょう /北朝/
ほくてき /北狄/
ほくてつ /北鉄/
ほくてん /北天/
ほくてんゆう /北天佑/
ほくと /北斗/
ほくとう /北東/
ほくとうがわ /北東側/
ほくとうぶ /北東部/
ほくとうみ /北勝海/
ほくとき /北斗旗/
ほくとせい /北斗星/
ほくとのけん /北斗の拳/
ほくばく /北爆/
ほくぶ /北部/
ほくぶきゅうしゅう /北部九州/
ほくぶこうない /北部構内/
ほくぶほうめん /北部方面/
ほくへき /北壁/
ほくべい /北米/
ほくべいいがい /北米以外/
ほくべいきょじゅうしゃ /北米居住者/
ほくべいさん /北米産/
ほくべいしよう /北米仕様/
ほくべいばん /北米版/
ほくべいほうめん /北米方面/
ほくほくせい /北北西/
ほくほくとう /北北東/北々東/
ほくぼう /北房/
ほくめい /北溟/
ほくよう /北洋/
ほくようだい /北陽台/
ほくりく /北陸/
ほくりくきんぺん /北陸近辺/
ほくりくぎんこう /北陸銀行/
ほくりくさんけん /北陸三県/
ほくりくしぶ /北陸支部/
ほくりくしんかんせん /北陸新幹線/
ほくりくじ /北陸路/
ほくりくじどうしゃどう /北陸自動車道/
ほくりくせん /北陸線/
ほくりくせんたん /北陸先端/
ほくりくせんたんかがくぎじゅつだいがくいんだいがく /北陸先端科学技術大学院大学/
ほくりくせんたんだい /北陸先端大/
ほくりくだいひょう /北陸代表/
ほくりくちく /北陸地区/
ほくりくてつどう /北陸鉄道/
ほくりくでんりょく /北陸電力/
ほくりくどう /北陸道/
ほくりくほうそう /北陸放送/
ほくりくほうめん /北陸方面/
ほくりくほんせん /北陸本線/
ほくりくほんせんとっきゅう /北陸本線特急/
ほくりじ /北陸路/
ほくりゅう /北竜/北龍/
ほくりょう /北陵/
ほくりょなんわ /北虜南倭/
ほけきょう /法華経/
ほけつ /補欠/
ほけつば /補欠馬/
ほけん /保険/保健/
ほけんいりょう /保険医療/
ほけんえいせい /保健衛生/
ほけんかんゆういん /保険勧誘員/
ほけんがい /保険外/
ほけんがいこういん /保険外交員/
ほけんがいしゃ /保険会社/
ほけんがく /保険額/
ほけんがっか /保健学科/
ほけんきん /保険金/
ほけんきんがく /保険金額/
ほけんけいやく /保険契約/
ほけんし /保健師;保健婦助産婦看護婦法一部改正による呼称変更/
ほけんしつ /保険室/保健室/
ほけんしゃ /保険者/
ほけんしょ /保健所/
ほけんしょう /保険証/
ほけんしょうひん /保険商品/
ほけんしんりょう /保険診療/
ほけんじょ /保健所/保険所/
ほけんせいきゅう /保険請求/
ほけんせいど /保健制度/保険制度/
ほけんたいいく /保健体育/
ほけんだい /保険代/
ほけんふ /保健婦/
ほけんや /保険屋/
ほけんやく /保険薬/
ほけんやっかん /保険約款/
ほけんやっきょく /保険薬局/
ほけんりょう /保険料/
ほけんりょうきん /保険料金/
ほけんりょうりつ /保険料率/
ほげい /捕鯨/
ほげいせん /捕鯨船/
ほげいもんだい /捕鯨問題/
ほげん /補元/
ほこ /鉾/矛/桙/盾/
ほこう /歩行/補講/
ほこうきつえん /歩行喫煙/
ほこうきつえんしゃ /歩行喫煙者/
ほこうきょり /歩行距離/
ほこうしゃ /歩行者/
ほこうしゃせんよう /歩行者専用/
ほこうしゃてんごく /歩行者天国/
ほこうしゃゆうせん /歩行者優先/
ほこうしゃよう /歩行者用/
ほこうしゃようしんごう /歩行者用信号/
ほこうそ /補酵素/
ほこさき /矛先/鋒先/鋒/
ほこた /鉾田/
ほこてん /歩行者天国/
ほこら /叢祠/祠/
ほこり /ホコリ/埃/誇り/
ほこりたいさく /埃対策/
ほご /保護/補語/反古/反故/
ほごえき /保護液/
ほごかいろ /保護回路/
ほごかのう /保護可能/
ほごきかん /保護期間/
ほごきこう /保護機構/
ほごきてい /保護規定/
ほごきのう /保護機能/
ほごく /保護区/
ほごこく /保護国/
ほごさく /保護策/
ほごしゃ /保護者/
ほごせいさく /保護政策/
ほごせつび /保護設備/
ほごぞくせい /保護属性/
ほごたんい /保護単位/
ほごでんち /保護電池/
ほごどうぶつ /保護動物/
ほごのうりょく /保護能力/
ほごはんい /保護範囲/
ほごまく /保護膜/
ほごよう /保護用/
ほごようでんち /保護用電池/
ほごりん /保護林/
ほごわく /保護枠/
ほさ /補佐/輔佐/保佐/
ほさいん /補佐員/
ほさか /保坂/
ほさかん /補佐官/
ほさき /穂先/芒/
ほさく /補作/
ほさたい /補佐隊/
ほさやく /補佐役/
ほざわ /保沢/
ほし /星/☆/★/※/＊/干し/
ほしあい /星合/
ほしい /欲しい/星井/
ほしいってつ /星一徹/
ほしいまま /恣/
ほしおき /星置/
ほしかげ /星影/
ほしかわ /星川/
ほしがおか /星ヶ丘/
ほしがた /星型/
ほしくさ /干し草/
ほしくさもく /ホシクサ目/Eriocaulales/
ほしくず /星屑/
ほしくら /星倉/
ほしぐみ /星組/
ほしさと /星里/
ほしざわ /星沢/
ほししいたけ /干椎茸/
ほししば /星芝/
ほししんいち /星新一/
ほしじし /干肉/
ほしじるし /星印/
ほしぞら /星空/
ほしたに /星谷/
ほしつえき /保湿液/
ほしつりょく /保湿力/
ほしで /星出/
ほしとり /星取/
ほしとりひょう /星取表/
ほしな /保科/星名/
ほしの /星野/
ほしのおんせん /星野温泉/
ほしば /干場/保志場/
ほしひょうめん /星表面/
ほしぼし /星々/
ほしみや /星宮/
ほしもと /星本/
ほしゃく /保釈/
ほしや /星矢/星谷/
ほしやま /星山/
ほしゅ /保守/捕手/補手/
ほしゅいん /保守員/
ほしゅう /補修/補習/捕囚/
ほしゅうごう /補集合/
ほしゅうひ /補修費/
ほしゅうぶひん /補修部品/
ほしゅうよう /補修用/
ほしゅうようぶひん /補修用部品/
ほしゅおうこく /保守王国/
ほしゅかかく /保守価格/
ほしゅかんり /保守管理/
ほしゅけい /保守系/
ほしゅけいやく /保守契約/
ほしゅけいやくりょう /保守契約料/
ほしゅさぎょう /保守作業/
ほしゅしゅぎ /保守主義/
ほしゅせい /保守性/
ほしゅたいおう /保守対応/
ほしゅてき /保守的/
ほしゅてんけん /保守点検/
ほしゅとう /保守党/
ほしゅは /保守派/
ほしゅひ /保守費/
ほしゅび /保守日/
ほしゅぶひん /保守部品/
ほしゅよう /保守用/
ほしゅようしゃ /保守用車/
ほしゅりょう /保守料/
ほしゅりょうきん /保守料金/
ほしょう /保証/保障/補償/堡礁/歩哨/
ほしょうかいろ /補償回路/
ほしょうかのう /保証可能/
ほしょうかんすう /補償関数/
ほしょうかんすうせってい /補償関数設定/
ほしょうがく /保証額/
ほしょうがた /補償型/
ほしょうがたほちょうき /補償型補聴器/
ほしょうきかん /保証期間/
ほしょうきかんない /保証期間内/
ほしょうきげん /保証期限/
ほしょうきん /保証金/補償金/
ほしょうきんがく /補償金額/
ほしょうぎれ /保証切れ/
ほしょうげんどがく /保障限度額/
ほしょうしょ /保証書/
ほしょうしょり /補償処理/
ほしょうじつげん /補償実現/
ほしょうじょうけん /補償条件/
ほしょうせいきゅうけん /補償請求権/
ほしょうせいど /補償制度/保証制度/
ほしょうせんでん /保証宣伝/
ほしょうそち /補償措置/
ほしょうち /保証値/
ほしょうでんりょくげん /補償電力源/
ほしょうないよう /補償内容/
ほしょうにん /保証人/
ほしょうにんてい /保証認定/
ほしょうにんていばんごう /保証認定番号/
ほしょうぶん /補償分/
ほしょうほけん /補償保険/
ほしょうもんだい /補償問題/保障問題/
ほしょく /補食/捕食/補色/
ほしょくちゅう /補食中/
ほしよう /補仕様/
ほしん /保身/
ほじ /保持/
ほじしゃ /保持者/
ほじゅう /補充/
ほじゅうえき /補充液/
ほじゅうげんしょう /補充現象/
ほじゅうぶつ /補充物/
ほじょ /補助/
ほじょいん /補助員/
ほじょかんじ /補助漢字/
ほじょかんじじしょ /補助漢字辞書/
ほじょかんすう /補助関数/
ほじょきおく /補助記憶/
ほじょきおくそうち /補助記憶装置/
ほじょきごう /補助記号/
ほじょきん /補助金/
ほじょきんがく /補助金額/
ほじょきんせいど /補助金制度/
ほじょぐ /補助具/
ほじょけん /補助券/
ほじょこう /補助光/
ほじょしつもん /補助質問/
ほじょしんごう /補助信号/
ほじょじっけん /補助実験/
ほじょじょうけん /補助条件/
ほじょせき /補助席/
ほじょせん /補助線/
ほじょそうび /補助装備/
ほじょたんい /補助単位/
ほじょていり /補助定理/
ほじょてき /補助的/
ほじょとう /補助灯/
ほじょねんりょう /補助燃料/
ほじょひょうしき /補助標識/
ほじょへんすう /補助変数/
ほじょよう /補助用/
ほじょよさん /補助予算/
ほじょれっしゃ /補助列車/
ほじょろ /補助路/
ほじりょく /保磁力/保持力/
ほすい /保水/
ほすう /補数/歩数/
ほすうひょうげん /補数表現/
ほすてす /ホステス/
ほすと /ホスト/
ほずみ /穂積/
ほせい /補正/補整/
ほせいいた /補正板/
ほせいかいろ /補正回路/
ほせいかくど /補正角度/
ほせいかじょう /補正過剰/補性過剰/
ほせいかのう /補正可能/
ほせいがかく /補正画角/
ほせいきのう /補正機能/
ほせいけいすう /補正係数/
ほせいこう /補正項/
ほせいしゅだん /補正手段/
ほせいしょり /補正処理/
ほせいじょうきょう /補正状況/
ほせいち /補正値/
ほせいとくせい /補正特性/
ほせいへんさほう /補正偏差法/
ほせいよう /補正用/
ほせいよさん /補正予算/
ほせいりょう /補正量/
ほせつ /補説/補綴/
ほせん /補選/保線/
ほせんさぎょう /保線作業/
ほぜい /保税/
ほぜん /保全/
ほそ /細/
ほそい /細井/
ほそいり /細入/
ほそう /舗装/鋪装/
ほそうこうじ /舗装工事/
ほそうどう /舗装道/
ほそうどうろ /舗装道路/
ほそうろ /舗装路/
ほそえ /細江/
ほそえちょう /細江町/
ほそおか /細岡/
ほそかわ /細川/
ほそかわはん /細川藩/
ほそがい /細貝/
ほそき /細木/
ほそぎ /細木/
ほそく /補足/補則/捕捉/歩測/歩速/
ほそくざい /捕捉剤/
ほそくしりょう /補足資料/
ほそくじっけん /補足実験/
ほそくじょうほう /補足情報/
ほそくせつめい /補足説明/
ほそくていせい /補足訂正/
ほそくていど /補足程度/
ほそくてき /補足的/
ほそくら /細倉/
ほそざわ /細澤/
ほそじ /細字/
ほそせん /細線/
ほそだ /細田/
ほその /細野/
ほそはら /細原/
ほそぶち /細渕/
ほそべ /細部/
ほそぼそ /細々/
ほそまる /細丸/
ほそみ /細身/細見/
ほそみち /細道/
ほそみんちょうたい /細明朝体/
ほそめ /細目/
ほそめん /細麺/
ほそや /細谷/細矢/
ほそよこちょう /細横町/
ほぞ /臍/
ほぞく /保続/
ほぞくてき /保続的/
ほぞん /保存/
ほぞんうんどう /保存運動/
ほぞんおんど /保存温度/
ほぞんかのう /保存可能/
ほぞんかんり /保存管理/
ほぞんきかん /保存期間/
ほぞんけいしき /保存形式/
ほぞんけいたい /保存形態/
ほぞんこ /保存庫/
ほぞんしゃ /保存車/
ほぞんしょく /保存食/
ほぞんじ /保存時/
ほぞんじっせき /保存実績/
ほぞんじょうたい /保存状態/
ほぞんせい /保存性/
ほぞんせいきょうか /保存性強化/
ほぞんそく /保存則/
ほぞんてき /保存的/
ほぞんにちじ /保存日時/
ほぞんばしょ /保存場所/
ほぞんばん /保存版/
ほぞんほう /保存法/
ほぞんほうほう /保存方法/
ほぞんよう /保存用/
ほぞんりょう /保存量/保存料/
ほぞんりよう /保存利用/
ほぞんろくが /保存録画/
ほたい /保体/補体/
ほたか /穂高/
ほたて /帆立/ホタテ/
ほたに /保谷/
ほたる /蛍/螢/火垂る/
ほたるいし /蛍石/
ほたるがいけ /蛍池/蛍ケ池/
ほたるがわ /蛍川/
ほたるじゃや /蛍茶屋/
ほたるぞく /蛍族/
ほたるまつり /蛍祭/
ほだい /補題/
ほだか /穂高/
ほだかおんせん /穂高温泉/
ほちゅう /補注/
ほちょう /歩調/補聴/
ほちょうかいろ /補聴回路/
ほちょうかんすう /補聴関数/
ほちょうき /補聴器/
ほちょうこうか /補聴効果/
ほちょうしょり /補聴処理/
ほっ /発/法/(concat "(^_^\073)")/發/
ほっかい /北海/法界/
ほっかいがくえんだいがく /北海学園大学/
ほっかいこうこう /北海高校/
ほっかいどう /北海道/
ほっかいどういき /北海道行/
ほっかいどうえんがん /北海道沿岸/
ほっかいどうおたるし /北海道小樽市/
ほっかいどうげんてい /北海道限定/
ほっかいどうご /北海道語/
ほっかいどうさっぽろし /北海道札幌市/
ほっかいどうさん /北海道産/
ほっかいどうさんまい /北海道産米/
ほっかいどうししゃ /北海道支社/
ほっかいどうしぶ /北海道支部/
ほっかいどうしほん /北海道資本/
ほっかいどうしゅっしん /北海道出身/
ほっかいどうしよう /北海道仕様/
ほっかいどうしれとこ /北海道知床/
ほっかいどうじゅうだん /北海道縦断/
ほっかいどうじん /北海道人/
ほっかいどうだいがく /北海道大学/
ほっかいどうちほう /北海道地方/
ほっかいどうつうしん /北海道通信/
ほっかいどうてん /北海道展/
ほっかいどうとうぶ /北海道東部/
ほっかいどうとくしゅう /北海道特集/
ほっかいどうどくじ /北海道独自/
ほっかいどうにっき /北海道日記/
ほっかいどうほんぶ /北海道本部/
ほっかいどうみなみ /北海道南/
ほっかいどうゆき /北海道行/
ほっかいどうようご /北海道用語/
ほっかいどうりょこう /北海道旅行/
ほっかいどうろせん /北海道路線/
ほっき /発起/
ほっきしゃ /発起者/
ほっきにん /発起人/
ほっきにんいちどう /発起人一同/
ほっきょく /北極/
ほっきょくかん /北極冠/
ほっきょくけん /北極圏/
ほっきょくせい /北極星/
ほっきょくてん /北極点/
ほっけ /法華/
ほっけー /ホッケー/
ほっこく /北国/
ほっこくぎんこう /北国銀行/北國銀行/
ほっこくしんぶん /北国新聞/
ほっさ /発作/
ほっさてき /発作的/
ほっしん /発心/発疹/
ほっす /払子/法子/法主/
ほっせき /発赤/
ほっそく /発足/
ほっそくいらい /発足以来/
ほっそくかい /発足会/
ほっそくきねんしゅうかい /発足記念集会/
ほっそくじ /発足時/
ほっそくとうじ /発足当時/
ほった /堀田/掘田/
ほったて /掘建/
ほったん /発端/
ほっちきす /ホッチキス/
ほっと /ホット/
ほっぽう /北方/
ほっぽうけい /北方系/
ほっぽうけいげんご /北方系言語/
ほっぽうせん /北方線/
ほっぽうみんぞく /北方民族/
ほっぽうよんとうえんがん /北方四島沿岸/
ほっぽうりょうど /北方領土/
ほつ /発/
ほつうきょう /保通協/
ほつうきょうかい /保通協会/
ほづ /保津/
ほづがわ /保津川/
ほづきょう /保津峡/
ほづみ /穂積/
ほてい /布袋/補綴/保定/
ほていか /補綴科/
ほてつ /補綴/
ほてる /ホテル/
ほてん /補填/保典/
ほとぎ /缶/
ほとけ /仏/佛/
ほとけさま /仏様/
ほととぎす /杜鵑/蜀魂/不如帰/子規/
ほとり /辺/畔/滸/邊/邉/
ほとんど /殆ど/幾ど/殆/殆んど/
ほど /程/
ほどあい /程合/
ほどう /補導/歩道/舗道/舖道/
ほどうがわ /歩道側/
ほどうきょう /歩道橋/補導協/
ほどうれき /補導歴/
ほどがや /保土が谷/保土ヶ谷/
ほどがやく /保土ヶ谷区/
ほどこし /施し/
ほどの /程野/
ほどほど /程々/
ほない /保内/
ほなが /保永/
ほなみ /保奈美/穂波/
ほにゅう /哺乳/
ほにゅうどうぶつ /哺乳動物/
ほにゅうびん /哺乳瓶/
ほにゅうるい /哺乳類/
ほね /骨/
ほねおり /骨折り/
ほねかわ /骨川/
ほねぐみ /骨組み/骨組/
ほねざかな /骨魚/
ほねつぎ /骨接ぎ/
ほねつりょく /保熱力/
ほねぬき /骨抜/骨抜き/
ほねぶと /骨太/
ほねみ /骨身/
ほねやすみ /骨休み/
ほねやすめ /骨休め/
ほのお /炎/焔/
ほのか /仄か/
ほのぼの /仄々/仄仄/
ほはば /歩幅/
ほばしら /帆柱/檣/艢/
ほばら /保原/
ほひつ /補筆/補弼/
ほびー /ホビー/
ほふ /保父/
ほふく /匍匐/
ほふくぜんしん /匍匐前進/
ほへい /歩兵/
ほべつ /穂別/
ほほ /頬/
ほほえみ /微笑み/微笑/
ほほずゑ /頬杖/
ほほづえ /頬杖/
ほぼ /保母/保姆/
ほまえ /帆前/
ほまれ /誉れ/誉/
ほむら /焔/
ほめことば /褒め言葉/
ほやがらす /保谷硝子/
ほやなぎ /保柳/
ほゆう /保有/
ほゆうき /保有機/
ほゆうしゃ /保有者/
ほゆうすう /保有数/
ほゆうぜい /保有税/
ほゆうねんすう /保有年数/
ほゆうりょう /保有量/
ほよう /保養/歩容/
ほようしょ /保養所/
ほようじょ /保養所/
ほようち /保養地/
ほら /洞/法螺/
ほらー /ホラー/
ほらあな /洞穴/
ほらがい /法螺貝/
ほらがとうげ /洞ヶ峠/
ほらど /洞戸/
ほり /堀/壕/濠/
ほりい /堀井/堀居/
ほりいけ /堀池/
ほりうち /堀内/
ほりえ /堀江/
ほりお /堀尾/
ほりかわ /堀川/堀河/
ほりがね /堀金/
ほりぐち /堀口/
ほりげん /堀玄/
ほりこし /堀越/
ほりこしこうこう /堀越高校/
ほりごめ /堀込/堀米/
ほりさき /堀崎/
ほりた /堀田/
ほりたつお /堀辰雄/
ほりだし /掘り出し/
ほりだしもの /掘り出し物/
ほりの /堀野/
ほりのうち /堀之内/
ほりのくち /堀之口/
ほりば /堀場/
ほりばせいさくしょ /堀場製作所/
ほりばた /堀端/
ほりべ /堀部/堀辺/
ほりまつ /堀松/
ほりもと /堀本/
ほりもの /彫物/
ほりゅう /保留/
ほりゅうおん /保留音/
ほりゅうきん /保留金/
ほりゅうじかん /保留時間/
ほりゅうじこう /保留事項/
ほりゅうじょうたい /保留状態/
ほりゅうぶん /保留分/
ほりょ /捕虜/
ほるい /堡塁/
ほれい /保冷/
ほれいざい /保冷材/
ほれいよう /保冷用/
ほろ /幌/袰/
ほろいずみ /幌泉/
ほろいわやまてんぼうだい /幌岩山展望台/
ほろかない /幌加内/
ほろぐらふぃ /ホログラフィ/
ほろつき /幌付き/
ほろのべ /幌延/
ほろばしゃ /幌馬車/
ほろべつ /幌別/
ほわいと /ホワイト/
ほわんちゅー /黄酒/
ほん /本/翻/奔/犇/畚/笨/飜/叛/反/
ほん< /本/
ほん> /本/
ほんあざ /本字/
ほんあつぎ /本厚木/
ほんあつぎいえん /本厚木以遠/
ほんあつぎいき /本厚木行/
ほんあつぎいせい /本厚木以西/
ほんあつぎかん /本厚木間/
ほんあつぎゆき /本厚木行/
ほんあん /本案/翻案/
ほんあんぶつ /翻案物/
ほんい /本位/本意/翻意/
ほんいいんかい /本委員会/
ほんいいんかいほっそく /本委員会発足/
ほんいがい /本以外/
ほんいだ /本位田/
ほんいでん /本位田/
ほんいん /本因/本院/
ほんいんぼう /本因坊/
ほんいんぼうせん /本因坊戦/
ほんうんよう /本運用/
ほんえい /本営/本影/
ほんえんそうかい /本演奏会/
ほんか /本科/本歌/
ほんかい /本会/本懐/
ほんかいぎ /本会議/
ほんかいほう /本会報/
ほんかく /本格/
ほんかくうんよう /本格運用/
ほんかくか /本格化/
ほんかくさくひん /本格作品/
ほんかくさんか /本格参加/
ほんかくすいり /本格推理/
ほんかくすいりしょうせつ /本格推理小説/
ほんかくてき /本格的/
ほんかくてきさんせん /本格的参戦/
ほんかくは /本格派/
ほんかくはとうしゅ /本格派投手/
ほんかくもの /本格物/
ほんかせい /本科生/
ほんかわ /本革/
ほんかわごえはつ /本川越発/
ほんかわね /本川根/
ほんかん /本館/本艦/本官/本管/
ほんかんすう /本関数/
ほんがかり /本係/
ほんがく /本学/
ほんがくしゅうほうほう /本学習方法/
ほんがくだいがくいん /本学大学院/
ほんがっかい /本学会/
ほんがわ /本川/
ほんがん /本願/
ほんがんじ /本願寺/
ほんき /本気/本期/本機/
ほんきかく /本企画/
ほんきしゅ /本機種/
ほんきじ /本記事/
ほんきそく /本規則/
ほんきてい /本規定/
ほんきゅう /本給/
ほんきょ /本拠/本挙/
ほんきょく /本局/
ほんきょち /本拠地/
ほんきょちいがい /本拠地以外/
ほんきょちいてん /本拠地移転/
ほんきょちきゅうじょう /本拠地球場/
ほんぎ /本義/
ほんぎまり /本決まり/
ほんぎょう /本業/
ほんくげぬま /本鵠沼/
ほんくげぬまえき /本鵠沼駅/
ほんぐう /本宮/
ほんぐうさん /本宮山/
ほんけ /本家/
ほんけい /本慧/
ほんけいさい /本掲載/
ほんけいやく /本契約/
ほんけかいらんもと /本家回覧元/
ほんけってい /本決定/
ほんけつ /本決/
ほんけほんもと /本家本元/
ほんけん /本件/本券/
ほんけんきゅう /本研究/
ほんけんきゅうかい /本研究会/
ほんけんきゅうしつ /本研究室/
ほんけんきゅうしゅうかい /本研究集会/
ほんけんきゅうじょ /本研究所/
ほんけんきゅうじょない /本研究所内/
ほんけんきゅじょ /本研究所/
ほんけんさそうち /本検査装置/
ほんけんとう /本検討/
ほんげい /本芸/
ほんげつ /本月/
ほんこう /本稿/本項/本校/
ほんこうえん /本講演/
ほんこうざ /本講座/
ほんこく /翻刻/
ほんこまごめ /本駒込/
ほんこん /香港/
ほんこんえいが /香港映画/
ほんこんえいがたいかい /香港映画大会/
ほんこんおうふく /香港往復/
ほんこんかんりちく /港湾管理地区/
ほんこんけいとくくうこう /香港啓徳空港/
ほんこんけいゆ /香港経由/
ほんこんこくさいけいさつ /香港国際警察/
ほんこんごぜんはつ /香港午前発/
ほんこんせい /香港製/
ほんこんせん /香港線/
ほんこんちゅうどく /香港中毒/
ほんこんつう /香港通/
ほんこんとう /香港島/
ほんこんとうきょうかん /香港東京間/
ほんこんなりたかん /香港成田間/
ほんこんはつ /香港発/
ほんこんぶたい /香港部隊/
ほんこんもの /香港物/
ほんこんゆき /香港行/
ほんこんりょこう /香港旅行/
ほんご /本語/
ほんごう /本郷/本号/
ほんごうさんちょうめ /本郷三丁目/
ほんごうそうもく /ホンゴウソウ目/Triuridales/
ほんごうだい /本郷台/
ほんごうどおり /本郷通り/
ほんごうゆうびんきょく /本郷郵便局/
ほんごく /本国/
ほんごくしよう /本国仕様/
ほんごくばん /本国版/
ほんごくむけ /本国向け/
ほんごし /本腰/
ほんさい /本妻/
ほんさいよう /本採用/
ほんさく /本作/
ほんさくひん /本作品/
ほんさん /本三/
ほんざん /本山/
ほんし /本誌/本旨/本紙/本四/
ほんしおがま /本塩釜/
ほんしおがまふきん /本塩釜付近/
ほんしき /本式/
ほんしけいさい /本誌掲載/
ほんしけん /本試験/
ほんしこう /本施行/
ほんしつ /本質/
ほんしつてき /本質的/
ほんしつてきかいけつ /本質的解決/
ほんしつてきけんり /本質的権利/
ほんしつてきぶぶん /本質的部分/
ほんしつてきもんだい /本質的問題/
ほんしびさんせん /本四備讃線/
ほんしゃ /本社/
ほんしゃがわ /本社側/
ほんしゃきのう /本社機能/
ほんしゃきんむ /本社勤務/
ほんしゃぎじゅつぶもん /本社技術部門/
ほんしゃこうじょう /本社工場/
ほんしゃしょざいち /本社所在地/
ほんしゃべっかん /本社別館/
ほんしゃまえ /本社前/
ほんしゃまえはつ /本社前発/
ほんしゅいしょ /本趣意書/
ほんしゅう /本州/
ほんしゅういなん /本州以南/
ほんしゅうがわ /本州側/
ほんしゅうじょうりく /本州上陸/
ほんしゅうじん /本州人/
ほんしゅうせい /本修正/
ほんしゅうせいし /本州製紙/
ほんしゅつ /本出/奔出/
ほんしゅほう /本手法/
ほんしょ /本書/本署/本所/
ほんしょう /本章/本性/本省/本賞/本症/本荘/
ほんしょうきん /本賞金/
ほんしょく /本職/
ほんしょまつび /本書末尾/
ほんしよう /本仕様/
ほんしようきょだく /本使用許諾/
ほんしれんさい /本誌連載/
ほんしん /本心/本審/本震/本審 /
ほんしんさ /本審査/
ほんしんさかい /本審査会/
ほんじ /本字/
ほんじぎょう /本事業/
ほんじしょ /本辞書/
ほんじしょう /本時称/
ほんじたい /本自体/
ほんじっけん /本実験/
ほんじつ /本日/
ほんじつちゅう /本日中/
ほんじつはつばい /本日発売/
ほんじつよなか /本日夜中/
ほんじつよる /本日夜/
ほんじゅつしき /本術式/
ほんじょあずまばし /本所吾妻橋/
ほんじょう /本庄/本城/本条/本状/本匠/
ほんじょうこう /本条項/
ほんじょうぞう /本醸造/
ほんじょうほう /本情報/
ほんじん /本陣/
ほんすう /本数/
ほんすうせいげん /本数制限/
ほんすじ /本筋/
ほんずき /本好き/
ほんせい /本性/本制/
ほんせいひん /本製品/
ほんせき /本籍/
ほんせきち /本籍地/
ほんせつ /本節/
ほんせん /本線/本船/本戦/
ほんせんうんよう /本線運用/
ほんせんかい /本選会/
ほんせんがわ /本線側/
ほんせんぎふ /本線岐阜/
ほんせんけいとう /本線系統/
ほんせんこう /本専攻/
ほんせんしゅつじょう /本戦出場/
ほんせんしゅつじょうけん /本戦出場権/
ほんせんじょう /本線上/
ほんせんそうこう /本線走行/
ほんせんぞい /本線沿い/
ほんせんとっきゅう /本線特急/
ほんせんみなみがわ /本線南側/
ほんせんもけい /帆船模型/
ほんせんもんてん /本専門店/
ほんぜん /本然/
ほんそう /奔走/本送/
ほんそうち /本装置/
ほんそく /本則/
ほんぞん /本尊/
ほんたい /本体/本隊/
ほんたいいがい /本体以外/
ほんたいいしき /本体意識/
ほんたいかい /本大会/
ほんたいかかく /本体価格/
ほんたいかん /本体間/
ほんたいがわ /本体側/
ほんたいきばん /本体基盤/
ほんたいこうぶ /本体後部/
ほんたいこしょう /本体故障/
ほんたいじゅうりょう /本体重量/
ほんたいない /本体内/
ほんたいないぞう /本体内蔵/
ほんたいないぶ /本体内部/
ほんたいひだりした /本体左下/
ほんたいよう /本体用/
ほんたく /本宅/
ほんたて /本立/
ほんだ /本田/本多/誉田/
ほんだい /本題/本代/
ほんだいがく /本大学/
ほんだかついち /本多勝一/
ほんだぎけん /本田技研/
ほんだげきじょう /本多劇場/
ほんだそういちろう /本田宗一郎/
ほんだて /本立/
ほんだな /本棚/
ほんだなせいり /本棚整理/
ほんだひこうじょう /本田飛行場/
ほんち /本地/
ほんちすいしゃくせつ /本地垂迹説/
ほんちすいじゃくせつ /本地垂迹説/
ほんちば /本千葉/
ほんちゅう /本中/
ほんちょう /本町/本庁/本朝/
ほんちょうさ /本調査/
ほんちょうし /本調子/
ほんづけ /本付/
ほんて /本手/
ほんていあん /本提案/
ほんてき /本的/
ほんてん /本店/
ほんてんちか /本店地下/
ほんてんまえ /本店前/
ほんでん /本殿/
ほんでんわき /本電話機/
ほんと /本当/
ほんとう /本当/奔騰/本島/本棟/
ほんとうこう /本投稿/
ほんとうない /本島内/
ほんとくしゅう /本特集/
ほんど /本土/本渡/
ほんどう /本道/本堂/
ほんどおり /本通り/
ほんどく /本読/
ほんどけいゆ /本土経由/
ほんどけっせん /本土決戦/本土決戰/
ほんどせん /本土線/
ほんどないけいゆ /本土内経由/
ほんどほうめん /本土方面/
ほんどぼうえいたい /本土防衛帯/
ほんないしきょう /本内視鏡/
ほんないよう /本内容/
ほんにん /本人/
ほんにんあて /本人宛/
ほんにんいがい /本人以外/
ほんにんしだい /本人次第/
ほんにんたち /本人達/
ほんにんどうし /本人同士/
ほんね /本音/
ほんねん /本年/
ほんねんど /本年度/
ほんねんどさいご /本年度最後/
ほんねんどぶん /本年度分/
ほんのう /本能/
ほんのうじ /本能寺/
ほんのうてき /本能的/
ほんのうてきよっきゅう /本能的欲求/
ほんのまち /本の街/
ほんはすぬま /本蓮沼/
ほんはっぴょう /本発表/
ほんはつめい /本発明/
ほんば /本場/
ほんばこ /本箱/
ほんばしょ /本場所/
ほんばば /本馬場/
ほんばばにゅうじょう /本馬場入場/
ほんばばほうこう /本馬場方向/
ほんばもの /本場物/
ほんばん /本番/
ほんばんちゅう /本番中/
ほんばんまえ /本番前/
ほんばんよう /本番用/
ほんぱん /紅幇/
ほんひょうしき /本標識/
ほんびき /本引/
ほんぴん /本品/
ほんぶ /本部/
ほんぶこうしゃ /本部校舎/
ほんぶこうない /本部構内/
ほんぶしざい /本部資材/
ほんぶせき /本部席/
ほんぶちいき /本部地域/
ほんぶちょう /本部長/
ほんぶっけん /本物件/
ほんぶない /本部内/
ほんぶふめい /本部不明/
ほんぶん /本文/本分/
ほんぶんかかい /本分科会/
ほんぶんさんしょう /本文参照/
ほんぶんしょ /本文書/
ほんぶんしょうりゃく /本文省略/
ほんぶんぜんぶしょうりゃく /本文全部省略/
ほんぶんちゅう /本文中/
ほんぶんまつ /本文末/
ほんぶんりゃく /本文略/
ほんぷ /本譜/
ほんべつ /本別/
ほんぺん /本編/本篇/
ほんぺんしゅうりょうご /本編終了後/
ほんぺんちゅう /本編中/
ほんほうえい /本放映/
ほんほうえいちゅう /本放映中/
ほんほうえいちょくご /本放映直後/
ほんほうこく /本報告/
ほんほうしき /本方式/
ほんほうそう /本放送/
ほんほうそうじ /本放送時/
ほんほうそうじだい /本放送時代/
ほんほうそうだい /本放送第/
ほんほうそうとうじ /本放送当時/
ほんほうほう /本方法/
ほんぽ /本舗/
ほんぽう /奔放/本邦/本俸/本報/
ほんぽうはつ /本邦初/
ほんま /本間/
ほんまち /本町/
ほんまつ /本末/
ほんまつてんとう /本末転倒/
ほんまる /本丸/
ほんみょう /本名/
ほんむ /本務/
ほんめ /本目/
ほんめい /本命/本名/
ほんめいし /本命視/
ほんめいば /本命馬/
ほんもう /本望/
ほんもく /本牧/
ほんもくきんぺん /本牧近辺/
ほんもくちょう /本牧町/
ほんもくほうめん /本牧方面/
ほんもと /本元/
ほんもの /本物/
ほんもん /本問/本文/
ほんや /本屋/
ほんやかんけい /本屋関係/
ほんやがい /本屋街/
ほんやく /翻訳/飜訳/
ほんやくか /翻訳化/翻訳家/
ほんやくき /翻訳機/
ほんやくきかく /翻訳規格/
ほんやくきじ /翻訳記事/
ほんやくけい /翻訳系/
ほんやくけん /翻訳権/
ほんやくさぎょう /翻訳作業/
ほんやくしゃ /翻訳者/
ほんやくしょ /翻訳書/
ほんやくじ /翻訳時/
ほんやくじょう /翻訳上/
ほんやくちゅう /翻訳中/
ほんやくばん /翻訳版/
ほんやくぶん /翻訳文/
ほんやくもの /翻訳物/
ほんやばけい /本耶馬渓/
ほんやめい /本屋名/
ほんよさん /本予算/
ほんよみ /本読み/
ほんらい /本来/
ほんらいてき /本来的/
ほんらいべつ /本来別/
ほんらん /本欄/
ほんりゅう /本流/奔流/
ほんりゅういき /本流域/
ほんりょう /本領/
ほんりょうはっき /本領発揮/
ほんるい /本塁/
ほんるいだ /本塁打/
ほんるいだおう /本塁打王/
ほんれんさい /本連載/
ほんろう /翻弄/
ほんろせん /本路線/
ほんろん /本論/
ほんろんぶん /本論文/
ぼ /簿/母/暮/慕/菩/募/戊/模/保/墓/牡/姆/拇/謨/姥/
ぼーい /ボーイ/
ぼーかる /ボーカル/
ぼーだーらいん /ボーダーライン/
ぼーと /ボート/
ぼーなす /ボーナス/
ぼーりんぐ /ボーリング/
ぼーる /ボール/
ぼーるぺん /ボールペン/
ぼいこっと /ボイコット/
ぼいす /ボイス/
ぼいど /ボイド/
ぼいどりつ /ボイド率/
ぼいん /母音/拇印/
ぼいんおんせつ /母音音節/
ぼいんかん /母音間/
ぼいんきごう /母音記号/
ぼいんじ /母音字/
ぼいんだつらく /母音脱落/
ぼいんちょう /母音長/
ぼいんにんしき /母音認識/
ぼいんぶ /母音部/
ぼいんぶぶん /母音部分/
ぼう /某/防/妨/棒/鉾/貌/忙/貿/暴/房/坊/望/忘/冒/帽/傍/亡/謀/紡/肪/膨/剖/乏/呆/茫/抱/胞/氓/膀/芒/儚/厖/尨/惘/懋/旁/旄/榜/滂/瑁/甍/眸/网/冐/茆/蒡/蠎/蟒/袤/謗/鋩/髦/黽/鵬/瀑/罔/虻/卯/茅/牟/妄/
ぼう> /某/
ぼうあいがんどうぶつ /某愛玩動物/
ぼうい /暴威/
ぼういざかや /某居酒屋/
ぼういん /暴飲/
ぼうえい /防衛/
ぼうえいいだい /防衛医大/
ぼうえいうんてん /防衛運転/
ぼうえいきせい /防衛期成/
ぼうえいぐん /防衛軍/
ぼうえいさく /防衛策/
ぼうえいしせつちょう /防衛施設庁/
ぼうえいせいこう /防衛成功/
ぼうえいせいさく /防衛政策/
ぼうえいせん /防衛戦/防衛線/
ぼうえいせんりゃく /防衛戦略/
ぼうえいそうち /防衛装置/
ぼうえいたい /防衛隊/
ぼうえいたいしょう /防衛対象/
ぼうえいだい /防衛大/
ぼうえいだいがっこう /防衛大学校/
ぼうえいだいそつ /防衛大卒/
ぼうえいちょう /防衛庁/
ぼうえいちょうかいはつ /防衛庁開発/
ぼうえいはくしょ /防衛白書/
ぼうえいひ /防衛費/
ぼうえいもう /防衛網/
ぼうえいよう /防衛用/
ぼうえき /貿易/某駅/防疫/
ぼうえきあかじ /貿易赤字/
ぼうえきかんけい /貿易関係/
ぼうえききゅうすいぶ /防疫給水部/
ぼうえきくろじ /貿易黒字/
ぼうえきしゅだん /貿易手段/
ぼうえきしょう /貿易商/
ぼうえきしょうにん /貿易商人/
ぼうえきしょうへき /貿易障壁/
ぼうえきせいげん /貿易制限/
ぼうえきふう /貿易風/
ぼうえきふうさ /貿易封鎖/
ぼうえきまさつ /貿易摩擦/
ぼうえん /望遠/
ぼうえんがわ /望遠側/
ぼうえんきょう /望遠鏡/
ぼうえんきょうぶぶん /望遠鏡部分/
ぼうえんきょうや /望遠鏡屋/
ぼうえんけい /望遠系/
ぼうえんさつえい /望遠撮影/
ぼうえんしゃ /暴煙者/
ぼうえんぞく /暴煙族/
ぼうおおてきぎょう /某大手企業/
ぼうおん /防音/忘恩/
ぼうおんこうか /防音効果/
ぼうおんざい /防音材/
ぼうおんしつ /防音室/
ぼうおんせい /防音性/
ぼうおんたいさく /防音対策/
ぼうおんだい /某音大/
ぼうおんへき /防音壁/
ぼうか /防火/膨化/
ぼうかいしゃ /某会社/
ぼうかでん /某家電/
ぼうかとびら /防火扉/
ぼうかふく /防火服/
ぼうかへき /防火壁/
ぼうかん /傍観/防寒/望観/暴漢/
ぼうかんぎ /防寒着/
ぼうかんぐ /防寒具/
ぼうかんしゃ /傍観者/
ぼうかんたいさく /防寒対策/
ぼうかんちょう /某官庁/
ぼうかんふく /防寒服/
ぼうかんぼうすい /防寒防水/
ぼうがい /妨害/望外/
ぼうがいおん /妨害音/
ぼうがいこうい /妨害行為/
ぼうがいこうさく /妨害工作/
ぼうがいざつおん /妨害雑音/
ぼうがいしんごう /妨害信号/
ぼうがくしゃ /某学者/
ぼうがっかい /某学会/
ぼうがっきてん /某楽器店/
ぼうがっけん /某学研/
ぼうきぎょう /某企業/
ぼうきじ /某記事/
ぼうきゃく /忘却/
ぼうきゅうだん /某球団/
ぼうきょ /暴挙/
ぼうきょう /望郷/防共/
ぼうきょうじゅ /某教授/
ぼうきょく /某局/
ぼうぎ /謀議/
ぼうぎゃく /暴虐/
ぼうぎゃくてき /暴虐的/
ぼうぎょ /防御/防禦/
ぼうぎょがわ /防御側/
ぼうぎょきこう /防御機構/
ぼうぎょこうどう /防御行動/
ぼうぎょご /防御後/
ぼうぎょじ /防御時/
ぼうぎょてん /防御点/
ぼうぎょのうりょく /防御能力/
ぼうぎょよういん /防御要員/
ぼうぎょりつ /防御率/
ぼうぎょりょく /防御力/
ぼうぎん /棒銀/
ぼうぎんこう /某銀行/
ぼうくう /防空/
ぼうくうがた /防空型/
ぼうくうごう /防空壕/
ぼうくうのうりょく /防空能力/
ぼうくん /暴君/某君/
ぼうぐ /防具/
ぼうぐみ /棒組/
ぼうけい /傍系/
ぼうけいけつぞく /傍系血族/
ぼうけん /冒険/剖検/
ぼうけんおう /冒険王/
ぼうけんか /冒険家/
ぼうけんき /冒険記/
ぼうけんきゅうしょ /某研究所/
ぼうけんしゃ /冒険者/
ぼうけんしゃたち /冒険者達/
ぼうけんしょうせつ /冒険小説/
ぼうけんしん /冒険心/
ぼうけんたん /冒険譚/
ぼうけんてき /冒険的/
ぼうけんもの /冒険物/
ぼうけんやろう /冒険野郎/
ぼうけんりつだい /某県立大/
ぼうけんりょこう /冒険旅行/
ぼうげいにん /某芸人/
ぼうげつ /某月/
ぼうげん /暴言/
ぼうげんしゃ /暴言者/
ぼうこう /暴行/膀胱/
ぼうこうえん /膀胱炎/
ぼうこうこう /某高校/
ぼうこうざい /暴行罪/
ぼうこうざた /暴行沙汰/
ぼうこうじけん /暴行事件/
ぼうこく /某国/亡国/亡國/
ぼうこくりつだいがく /某国立大学/
ぼうことう /澎湖島/
ぼうご /防護/
ぼうごししん /防護指針/
ぼうごてん /防護点/
ぼうごへき /防護壁/
ぼうごむせん /防護無線/
ぼうさ /防砂/
ぼうさい /防災/
ぼうさいかぎけん /防災科技研/
ぼうさいくんれん /防災訓練/
ぼうさいじょうほう /防災情報/
ぼうさくひん /某作品/
ぼうさっか /某作家/
ぼうさつ /忙殺/謀殺/
ぼうさま /坊様/
ぼうさりん /防砂林/
ぼうざっし /某雑誌/
ぼうざっしじょう /某雑誌上/
ぼうし /防止/帽子/某氏/某誌/某紙/望祀/
ぼうしかのう /防止可能/
ぼうしきこう /防止機構/
ぼうしきのう /防止機能/
ぼうしさく /防止作/防止策/
ぼうしざい /防止剤/
ぼうしそう /防止層/
ぼうしたいさく /防止対策/
ぼうしつ /亡失/忘失/防湿/
ぼうしほう /防止法/
ぼうしゃ /某社/
ぼうしや /帽子屋/
ぼうしゅ /忙種/
ぼうしゅう /防臭/
ぼうしゅうかんし /某週刊誌/
ぼうしゅうざい /防臭剤/
ぼうしゅっぱんしゃ /某出版社/
ぼうしょ /某所/防暑/
ぼうしょう /傍証/
ぼうしょうよう /某商用/
ぼうしょく /暴食/望蜀/紡織/
ぼうしょくざい /防食剤/
ぼうしょてん /某書店/
ぼうしよう /防止用/
ぼうしん /冒進/防振/
ぼうしんぶん /某新聞/
ぼうしんぶんしゃ /某新聞社/
ぼうじ /防磁/
ぼうじつ /某日/
ぼうじどうしゃがいしゃ /某自動車会社/
ぼうじむしょ /某事務所/
ぼうじゃくぶじん /傍若無人/
ぼうじゅ /傍受/
ぼうじょ /防除/
ぼうじょう /棒状/坊城/
ぼうじょうれん /某常連/
ぼうじん /防塵/
ぼうすい /紡錘/防水/
ぼうすいえき /防水液/
ぼうすいかこう /防水加工/
ぼうすいけい /紡錘型/
ぼうすいこうか /防水効果/
ぼうすいしよう /防水仕様/
ぼうすいせい /防水性/
ぼうすいせいのう /防水性能/
ぼうすいたいさく /防水対策/
ぼうすいだんねつせい /防水断熱性/
ぼうすいふ /防水布/
ぼうすいぼうかん /防水防寒/
ぼうすじ /某筋/
ぼうず /坊主/坊子/
ぼうずあたま /坊主頭/
ぼうせい /暴政/防錆/
ぼうせいしょり /防錆処理/
ぼうせいとう /某政党/
ぼうせいまる /望星丸/
ぼうせき /紡績/
ぼうせつ /防雪/
ぼうせつりん /防雪林/
ぼうせん /防戦/傍線/棒線/
ぼうせんいっぽう /防戦一方/
ぼうせんぱい /某先輩/
ぼうぜん /呆然/茫然/
ぼうぜんじしつ /呆然自失/茫然自失/
ぼうそう /暴走/房総/
ぼうそううんてん /暴走運転/
ぼうそうかいし /暴走開始/
ぼうそうかくせん /房総各線/
ぼうそうきじ /暴走記事/
ぼうそうしゃ /暴走車/
ぼうそうじこ /暴走事故/
ぼうそうじょうたい /暴走状態/
ぼうそうそし /暴走阻止/
ぼうそうぞく /暴走族/
ぼうそうぞくいがい /暴走族以外/
ぼうそうぞくよう /暴走族用/
ぼうそうとうせん /房総東線/
ぼうそうとっきゅう /房総特急/
ぼうそうはんとう /房総半島/
ぼうそうほうめん /房総方面/
ぼうたいしゅう /某大衆/
ぼうたかとび /棒高飛び/
ぼうたて /棒立て/
ぼうだい /膨大/某大/防大/厖大/尨大/
ぼうだいがく /某大学/
ぼうだいがくこうがくぶ /某大学工学部/
ぼうだち /棒立ち/
ぼうだん /防弾/
ぼうだんよう /防弾用/
ぼうちほうとくさん /某地方特産/
ぼうちゅう /傍注/防虫/忙中/
ぼうちゅうおうりん /某中央輪/
ぼうちゅうがく /某中学/
ぼうちゅうざい /防虫剤/
ぼうちょう /膨張/傍聴/膨脹/防諜/
ぼうちょうせき /傍聴席/
ぼうちょうへき /防潮壁/
ぼうちょうりつ /膨張率/
ぼうてつ /耄耋/
ぼうてん /傍点/某店/
ぼうでんき /某電器/
ぼうでんきてん /某電気店/
ぼうと /暴徒/
ぼうとう /冒頭/暴騰/暴投/
ぼうとうぶぶん /冒頭部分/
ぼうとく /冒涜/
ぼうどう /暴動/
ぼうどうじんし /某同人誌/
ぼうどうすんぜん /暴動寸前/
ぼうどく /防毒/
ぼうねん /忘年/
ぼうねんかい /忘年会/
ぼうの /坊野/房野/
ぼうのつ /坊津/
ぼうはい /暴牌/
ぼうはつ /暴発/
ぼうはてい /防波堤/
ぼうはん /防犯/
ぼうはんしそう /防犯思想/
ぼうはんじょう /防犯上/
ぼうはんたいさく /防犯対策/
ぼうはんだいがく /某阪大学/
ぼうはんとう /防犯灯/
ぼうはんばいてん /某販売店/
ぼうはんれんらくじょ /防犯連絡所/
ぼうばく /茫漠/
ぼうばんぐみ /某番組/
ぼうひと /某人/
ぼうび /防備/
ぼうびき /棒引き/
ぼうふ /亡夫/亡父/防腐/
ぼうふう /暴風/防風/
ぼうふうう /暴風雨/
ぼうふうけん /暴風圏/
ぼうふうせい /防風性/
ぼうふうりん /防風林/
ぼうふざい /防腐剤/
ぼうへき /防壁/
ぼうほうめん /某方面/
ぼうぼう /某々/茫茫/
ぼうまい /茫昧/
ぼうまんがか /某漫画家/
ぼうめい /亡命/
ぼうめいしゃ /亡命者/
ぼうめいじけん /亡命事件/
ぼうや /坊や/
ぼうゆうじん /某友人/
ぼうゆうめい /某有名/
ぼうゆうめいじん /某有名人/
ぼうよう /望洋/滂洋/茫洋/
ぼうようりょう /望洋寮/
ぼうよみ /棒読み/棒読/
ぼうらく /暴落/
ぼうり /暴利/
ぼうりゃく /謀略/
ぼうりゃくせつ /謀略説/某略説/
ぼうりゅう /傍流/
ぼうりょく /暴力/
ぼうりょくざた /暴力沙汰/
ぼうりょくしょうせつ /暴力小説/
ぼうりょくせい /暴力性/
ぼうりょくだん /暴力団/
ぼうりょくだんいん /暴力団員/
ぼうりょくだんしきん /暴力団資金/
ぼうりょくだんしんぽう /暴力団新法/
ぼうりょくてき /暴力的/
ぼうる /ボウル/
ぼうれい /亡霊/暴戻/
ぼうれいしゃしん /亡霊写真/
ぼうれいたち /亡霊達/
ぼうろう /望楼/
ぼうろく /俸禄/
ぼうろん /暴論/
ぼおん /母音/
ぼか /簿価/
ぼかい /暮改/
ぼかん /母艦/母管/
ぼかんすう /母関数/
ぼかんすうけいすう /母関数係数/
ぼかんない /母艦内/
ぼがい /簿外;(会計)「簿外債務」「簿外資産」など、計算書類に計上されない権利義務/
ぼき /簿記/
ぼきかいけい /簿記会計/
ぼきしき /簿記式/
ぼきょくせん /母曲線/
ぼきょくめん /母曲面/
ぼきん /募金/
ぼきんかつどう /募金活動/
ぼきんがく /募金額/
ぼく /僕/睦/牧/木/穆/朴/撲/墨/卜/目/攴/攵/樸/濮/瀑/
ぼくあて /僕宛/
ぼくいがい /僕以外/
ぼくこう /墨攻/
ぼくこじん /僕個人/
ぼくさつ /撲殺/
ぼくし /牧師/墨子/
ぼくしゃ /牧舎/
ぼくしんぐ /ボクシング/
ぼくじしん /僕自身/
ぼくじゅう /墨汁/
ぼくじょう /牧場/
ぼくじょうかんけいしゃ /牧場関係者/
ぼくじょうちょう /牧場長/
ぼくすい /牧水/
ぼくせき /木石/
ぼくせん /卜占/
ぼくそう /牧草/
ぼくそうち /牧草地/
ぼくたく /木鐸/
ぼくたち /僕達/
ぼくちく /牧畜/木竹/
ぼくちくみんぞく /牧畜民族/
ぼくとう /木刀/墨東/
ぼくとつ /朴訥/
ぼくどう /牧童/
ぼくねんじん /朴念仁/
ぼくは /僕は/
ぼくひとり /僕一人/
ぼくめつ /撲滅/
ぼくら /僕等/僕ら/
ぼけ /惚け/ボケ/木瓜/
ぼけい /母系/母型/
ぼけつ /墓穴/
ぼこう /母校/母港/
ぼこく /母国/
ぼこくご /母国語/
ぼご /母語/
ぼごいがい /母語以外/
ぼごわしゃ /母語話者/
ぼさつ /菩薩/
ぼさん /墓参/
ぼし /母子/星/母指;手の親指/拇指;手の親指/母趾;足の親指/拇趾;足の親指/
ぼしかてい /母子家庭/
ぼしき /母式/
ぼしづれ /母子連れ/
ぼしゅう /募集/
ぼしゅうきかん /募集期間/
ぼしゅうきじ /募集記事/
ぼしゅうけっかほうこく /募集結果報告/
ぼしゅうこうこく /募集広告/
ぼしゅうこくち /募集告知/
ぼしゅうしめきり /募集締切/
ぼしゅうじょうけん /募集条件/
ぼしゅうじんいん /募集人員/
ぼしゅうたいしょう /募集対象/
ぼしゅうだん /母集団/
ぼしゅうちゅう /募集中/
ぼしゅうていいん /募集定員/
ぼしゅうにんずう /募集人数/
ぼしゅうようこう /募集要項/募集要綱/
ぼしゅうようこうせいきゅう /募集要項請求/
ぼしゅうようこうちゅう /募集要項中/
ぼしゅうようりょう /募集要領/
ぼしゅうよてい /募集予定/
ぼしん /戊辰/
ぼしんせんそう /戊辰戦争/
ぼじょう /慕情/
ぼす /ボス/
ぼすう /母数/
ぼせい /母星/母性/
ぼせいげんり /母性原理/
ぼせいてき /母性的/
ぼせき /墓石/
ぼせん /母船/母線/
ぼぜん /墓前/
ぼたい /母体/
ぼたいない /母体内/
ぼたもち /牡丹餅/
ぼたん /釦/ボタン/牡丹/鈕/
ぼたんか /ボタン科/Paeoniaceae/
ぼたんどうろう /牡丹灯籠/
ぼたんもく /ボタン目/Paeoniales/
ぼだい /菩提/
ぼだいじゅ /菩提樹/
ぼち /墓地/
ぼっ /没/坊/沒/
ぼっか /牧歌/
ぼっかい /渤海/
ぼっかく /墨客/
ぼっかてき /牧歌的/
ぼっき /勃起/
ぼっきゃく /没却/
ぼっくす /ボックス/
ぼっこう /勃興/
ぼっこうき /勃興期/
ぼっこせい /没個性/
ぼっこせいてき /没個性的/
ぼっこん /墨痕/
ぼっしゅう /没収/
ぼっしょ /没書/
ぼっちゃん /坊っちゃん/
ぼっとう /没頭/
ぼっぱつ /勃発/
ぼつ /没/勃/歿/沒/渤/
ぼつこうしょうてき /没交渉的/
ぼつご /没後/歿後/
ぼつにゅう /没入/
ぼつねん /歿年/
ぼつらく /没落/
ぼつれきしてき /没歴史的/
ぼてん /母点/
ぼてんたい /母天体/
ぼでぃ /ボディ/
ぼとる /ボトル/
ぼどう /母堂/
ぼにゅう /母乳/
ぼば /牡馬/
ぼひ /墓碑/
ぼひめい /墓碑銘/墓碑名/
ぼひょう /墓標/
ぼふ /母父/
ぼぶんさん /母分散/
ぼへいきん /母平均/
ぼや /小火/
ぼら /鯔/鰡/
ぼらんてぃあ /ボランティア/
ぼり /堀/
ぼりょう /墓陵/
ぼると /ボルト/
ぼろ /ボロ/襤褸/
ぼろくず /ボロ屑/
ぼん /盆/凡/本/煩/梵/
ぼんおどり /盆踊り/
ぼんくれ /盆暮/
ぼんご /梵語/
ぼんさい /盆栽/凡才/
ぼんさく /凡作/
ぼんしょう /梵鐘/
ぼんじ /梵字/
ぼんじひっけい /梵字必携/
ぼんじん /凡人/
ぼんせん /凡戦/
ぼんそう /凡走/
ぼんぞく /凡俗/
ぼんたい /凡退/
ぼんだて /盆点/
ぼんち /盆地/
ぼんてん /梵天/
ぼんてんたいしゃく /梵天帝釈/
ぼんど /ボンド/
ぼんのう /煩悩/
ぼんべい /孟買/
ぼんぺい /凡平/
ぼんよう /凡庸/
ぼんわじてん /梵和辞典/
ぽ /舗/歩/舖/
ぽーず /ポーズ/
ぽーたぶる /ポータブル/
ぽーらんど /波蘭/
ぽあれ /ポアレ/
ぽいんた /ポインタ/
ぽいんたがた /ポインタ型/
ぽいんと /ポイント/
ぽう /包/報/烹/砲/方/法/
ぽけっと /ポケット/
ぽじしょん /ポジション/
ぽすたー /ポスター/
ぽすと /ポスト/
ぽち /・/
ぽっと /ポット/
ぽっぷあっぷ /ポップアップ/
ぽっぷす /ポップス/
ぽつ /・/
ぽてと /ポテト/
ぽぴゅらー /ポピュラー/
ぽぴんず /ポピンズ/
ぽりしー /ポリシー/
ぽりぺぷちどさ /ポリペプチド鎖/
ぽりぽり /(^-^)ゞ/
ぽるとがる /葡萄牙/
ぽん /本/椪/
ぽんかん /椪柑/
ぽんず /ポン酢/
ぽんちえ /ポンチ絵/
ぽんとちょう /先斗町/
ぽんど /£/磅/
ま /間/真/魔/目/麻/摩/磨/馬/眞/万/満/嘛/墹/媽/麼/痲/茉/
ま> /真/
まーく /マーク/
まーけっと /マーケット/
まーけてぃんぐ /マーケティング/
まーじ /マージ/
まーじゃん /麻雀/マージャン/
まーじゃんきょうしつ /麻雀教室/
まーじゃんよう /麻雀用/
まーじん /マージン/
まーちす /マーチス/
まーぼ /麻婆/
まーぼーどうふ /麻婆豆腐/
まーぼどーふ /麻婆豆腐/
まあい /間合い/
まあこ /真亜子/
まあじゃん /麻雀/
まあじゃんげきが /麻雀劇画/
まあじゃんたいかい /麻雀大会/
まあじゃんほうろうき /麻雀放浪記/
まあじゃんまんが /麻雀漫画/
まあぼうどうふ /麻婆豆腐/
まい /枚/毎/妹/昧/舞/埋/米/麻衣/瑁/眛/邁/真衣/舞衣/
まい< /毎/
まい> /毎/
まいあきら /舞アキラ/
まいあさ /毎朝/
まいいがい /枚以外/
まいおか /舞岡/
まいかー /マイカー/
まいかい /毎回/
まいかいおうぼ /毎回応募/
まいかいそくてい /毎回測定/
まいかいとくてん /毎回得点/
まいかいはっぴょう /毎回発表/
まいかいまいかい /毎回毎回/
まいかたし /枚方市/
まいき /毎期/
まいきょ /枚挙/
まいきょかのう /枚挙可能/
まいきょかのうせい /枚挙可能性/
まいく /マイク/
まいくろ /マイクロ/μ/
まいくろは /マイクロ波/
まいぐみ /枚組/
まいげつ /毎月/
まいげつだい /毎月第/
まいこ /舞子/麻衣子/舞姑/舞妓/磨衣子/
まいこかいがん /舞子海岸/
まいこん /マイコン/
まいご /迷子/
まいごう /毎号/
まいさか /舞阪/
まいしあい /毎試合/
まいしゅう /毎週/
まいしゅうかようび /毎週火曜/
まいしゅうきんようび /毎週金曜日/
まいしゅうしゅうけいけっか /毎週集計結果/
まいしゅうすいようび /毎週水曜日/
まいしゅうどよう /毎週土曜/
まいしゅうどようび /毎週土曜日/
まいしゅうなんようび /毎週何曜日/
まいしゅうにちよう /毎週日曜/
まいしゅうにちようび /毎週日曜日/
まいしゅうはっこう /毎週発行/
まいしゅうはっぴょう /毎週発表/
まいしゅうひとり /毎週一人/
まいしゅうほうそう /毎週放送/
まいしゅうまいつき /毎週毎月/
まいしゅうまつ /毎週末/
まいしょく /毎食/
まいしん /邁進/
まいじ /毎時/
まいじかん /毎時間/
まいすう /枚数/
まいせいじ /毎正時/
まいせつ /埋設/
まいせつぶつ /埋設物/
まいそう /埋葬/
まいそうきろく /埋葬記録/
まいそうたい /埋葬隊/
まいそうち /埋葬地/
まいぞう /埋蔵/
まいぞうひん /埋蔵品/
まいぞうぶつ /埋蔵物/
まいた /毎田/
まいたけ /舞茸/
まいだ /枚田/
まいつき /毎月/
まいつきなんにち /毎月何日/
まいつきはっこう /毎月発行/
まいづる /舞鶴/
まいづるこうこう /舞鶴高校/
まいづるせん /舞鶴線/
まいとし /毎年/
まいとしいっかい /毎年一回/
まいとしけいぞく /毎年継続/
まいとしこうしん /毎年更新/
まいとしこうれい /毎年恒例/
まいとしさんか /毎年参加/
まいとしなんがつごろ /毎年何月頃/
まいとしはっこう /毎年発行/
まいとしひとり /毎年一人/
まいとしほうそう /毎年放送/
まいど /毎度/
まいどようびしんや /毎土曜日深夜/
まいなー /マイナー/
まいなす /マイナス/−/
まいなつ /毎夏/
まいにち /毎日/
まいにちいっかい /毎日一回/
まいにちうんてん /毎日運転/
まいにちおうかん /毎日王冠/
まいにちごご /毎日午後/
まいにちごぜん /毎日午前/
まいにちしんぶん /毎日新聞/
まいにちしんぶんしゃまえ /毎日新聞社前/
まいにちつうきん /毎日通勤/
まいにちはい /毎日杯/
まいにちほうそう /毎日放送/
まいにちほうそうきょく /毎日放送局/
まいにちりよう /毎日利用/
まいねん /毎年/
まいねんかいさい /毎年開催/
まいのうみ /舞の海/
まいはま /舞浜/
まいはら /米原/
まいばしょ /毎場所/
まいばら /米原/
まいばらえき /米原駅/
まいばらていしゃ /米原停車/
まいばん /毎晩/
まいひめ /舞姫/
まいびょう /毎秒/
まいふん /毎分/
まいぺーす /マイペース/
まいほーむ /マイホーム/
まいぼつ /埋没/
まいまい /毎々/
まいめ /枚目/
まいや /毎夜/米谷/
まいよ /毎夜/
まいよう /枚葉/
まいる /哩/マイル/
まうえ /真上/
まうしろ /真後/真後ろ/
まうす /マウス/
まうすぽいんた /マウスポインタ/
まうら /真裏/
まうんてん /マウンテン/
まえ /前/
まえあし /前足/前脚/
まえいわい /前祝い/
まえうけ /前受/
まえうり /前売/前売り/
まえうりかいしび /前売開始日/
まえうりけん /前売券/
まえうりちゅう /前売中/
まえお /前尾/
まえおか /前岡/
まえおき /前置き/前置/
まえかわ /前川/
まえかんじょう /前勘定/
まえがき /前書き/前垣/
まえがし /前貸し/
まえがしきん /前貸金/
まえがしらかい /前頭下位/
まえがしらじょうい /前頭上位/
まえがしらひっとう /前頭筆頭/
まえがみ /前髪/
まえがり /前借り/
まえがりきん /前借金/
まえがわ /前側/前川/
まえきん /前金/
まえこうか /前効果/
まえこうかしょり /前効果処理/
まえこうてい /前工程/
まえさと /前里/
まえさわ /前沢/
まえさんしょう /前参照/
まえざわ /前沢/前澤/
まえしま /前島/
まえしょうとう /前照灯/
まえしょり /前処理/
まえしょりぶ /前処理部/
まえじ /前地/
まえじま /前島/前嶋/
まえじゅんび /前準備/
まえすうれつ /前数列/
まえずもう /前相撲/
まえずり /前刷/前刷り/
まえせんでん /前宣伝/
まえぜつ /前説/
まえだ /前田/前多/
まえだおし /前倒し/
まえち /前地/
まえつえ /前津江/
まえとびらふきん /前扉付近/
まえどうさ /前動作/
まえどなり /前隣/
まえどまり /前泊/
まえどり /前録り/
まえの /前野/
まえのひ /前の日/
まえのぶ /前信/
まえのり /前ノリ/
まえはし /前橋/
まえはた /前畑/
まえはら /前原/
まえば /前歯/前場/
まえばし /前橋/
まえばしし /前橋市/
まえばししりつ /前橋市立/
まえばらい /前払い/前払/
まえばらいきん /前払金/
まえばり /前貼り/
まえばる /前原/
まえばんぐみ /前番組/
まえひょうばん /前評判/
まえび /前日/
まえびろ /前広/
まえふり /前振/
まえぶれ /前触れ/
まえほ /前穂/
まえほうこう /前方向/
まえほり /前堀/
まえまえ /前々/
まえみ /真恵美/
まえむき /前向き/
まえもって /豫て/前もって/
まえやく /前厄/
まえやち /前谷地/
まえやま /前山/
まえやまだ /前山田/
まえわたし /前渡し/
まえわたしきん /前渡金/
まお /真央/
まおう /魔王/
まおたいちゅー /茅台酒/
まおとこ /間男/
まか /摩可/摩訶/
まかい /魔界/
まかいじん /魔界人/
まかいとし /魔界都市/
まかいの /馬飼野/
まかいむら /魔界村/
まかお /澳門/
まかふしぎ /摩訶不思議/摩可不思議/
まかべ /真壁/
まかまか /摩可摩可/
まかり /真狩/
まがい /擬/紛/
まがいもの /擬物/紛物/
まがお /真顔/
まがき /籬/
まがし /間貸し/
まがじん /マガジン/
まがた /澗潟/
まがたま /勾玉/
まがどり /凶鳥/
まがら /真柄/
まがり /間借り/
まがりかど /曲り角/
まき /牧/巻/槙/薪/真貴/真樹/麻紀/真紀/真木/麻貴/槇/卷/真城/麻希/蒔/真希/真季/
まきあげ /巻上/巻揚/捲揚/
まきえ /蒔絵/
まきお /牧朗/牧尾/真樹夫/真紀夫/
まきおか /牧岡/牧丘/
まきおとし /巻き落とし/
まきかえし /巻き返し/
まきかわ /巻川/
まきがみ /巻紙/
まきぐち /牧口/
まきげ /巻き毛/
まきこ /麻起子/満喜子/マキ子/真紀子/真樹子/正希子/麻紀子/万紀子/満紀子/真貴子/真喜子/真木子/真生子/牧子/真希子/眞紀子/
まきしー /マキシー/
まきしま /槙島/牧島/
まきしょてん /槇書店/
まきじた /巻舌/
まきじゃく /巻尺/
まきすう /巻数/
まきせ /牧瀬/
まきせん /巻き線/巻線/
まきせんすう /巻線数/
まきそのちょう /牧園町/
まきぞえ /巻き添え/巻添/
まきぞの /牧園/
まきた /真北/牧田/
まきつき /巻き付き/巻きつき/
まきつけ /巻き付け/巻きつけ/
まきとり /巻取/
まきの /牧野/槙野/
まきのうち /牧之内/
まきのお /槇尾/
まきのこう /牧之郷/牧の郷/
まきのせ /牧之瀬/
まきのはら /牧の原/
まきはら /槙原/槇原/牧原/
まきば /牧場/牧葉/
まきばしら /真木柱/
まきひげ /巻ひげ/巻鬚/巻きひげ/
まきひこ /眞木彦/
まきびと /牧人/
まきぼー /まきボー/
まきむら /牧村/槙村/
まきもと /牧本/
まきもどし /巻き戻し/
まきもの /巻物/
まきゅう /魔球/
まきょう /魔境/魔鏡/
まきょうでんせつ /魔境伝説/
まきょうものがたり /魔境物語/
まきりん /マキリン/
まぎょう /マ行/
まぎわ /間際/真際/
まく /膜/幕/
まくあい /幕合/幕間/
まくあいげき /幕合劇/
まくあけ /幕開け/
まくあつ /膜厚/
まくうち /幕内/
まくうちかい /幕内下位/
まくうちじょうい /幕内上位/
まくうちりきし /幕内力士/
まくうちりきしめい /幕内力士名/
まくぎれ /幕切れ/幕切/
まくしき /幕式/
まくした /幕下/
まくしたこうかく /幕下降格/
まくしたじだい /幕下時代/
まくつ /魔窟/
まくでんい /膜電位/
まくない /膜内/
まくのうち /幕の内/
まくはり /幕張/
まくはりてん /幕張店/
まくはりでんしゃく /幕張電車区/
まくはりほんごう /幕張本郷/
まくはりほんごうえき /幕張本郷駅/
まくべつ /幕別/
まくま /幕間/
まくら /枕/
まくらぎ /枕木/鍖/
まくらことば /枕詞/枕言葉/
まくらざき /枕崎/
まくらざきせん /枕崎線/
まくらのそうし /枕草子/
まくらもと /枕元/
まくろ /マクロ/
まぐさ /秣/芻/蒭/
まぐち /間口/
まぐまだまり /マグマ溜り/
まぐろ /鮪/
まぐわ /耙/
まけ /負け/敗け/
まけいぬ /負犬/負け犬/
まけん /魔剣/
まげ /曲/髷/
まげごうせい /曲げ剛性/
まげしんどう /曲げ振動/
まげは /曲げ波/
まこ /麻子/真子/魔子/眞子/マコ/
まこう /磨香/
まこと /誠/真/真琴/眞/誠人/信/真人/真湖人/純/亮/
まご /孫/馬子/
まごうた /馬子唄/
まごおり /馬郡/
まごこ /孫子/
まごころ /真心/
まごでし /孫弟子/
まごびき /孫引き/
まごむすめ /孫娘/
まごめ /馬込/馬籠/
まごめえき /馬込駅/
まさ /正/雅/柾/昌之/昌/政/真/征/麻早/匡/将/成/眞/マサ/
まさあき /正明/昌晃/正彰/雅昭/昌明/正章/雅明/正晃/正昭/政昭/政秋/雅章/昌昭/昌之/真昭/政明/
まさいち /政一/正一/
まさいちろう /雅一郎/
まさえ /雅恵/正恵/優江/雅江/昌枝/正江/
まさお /正雄/政夫/昌生/雅男/雅勇/昌夫/正男/雅夫/将生/政雄/正夫/真夫/征男/昌男/雅雄/希男/誠夫/方夫/政男/眞生/
まさおか /政岡/
まさおき /正興/
まさおみ /正臣/
まさか /雅香/
まさかず /正和/正一/賢和/雅和/昌一/政和/
まさかつ /政勝/正勝/誠勝/
まさかど /将門/
まさかね /斉加年/
まさかり /鉞/
まさがね /正金/
まさき /正樹/政樹/正輝/真咲/雅樹/仁樹/正木/正規/真樹/正喜/正揮/正毅/昌己/政輝/眞希/雅基/公輝/真先/昌樹/政木/正紀/正宣/松前/真幸/正記/眞幸/誠樹/正基/昌毅/
まさきち /政吉/
まさきよ /政清/
まさこ /雅子/正子/昌子/正沙子/真佐子/政子/真沙子/真砂子/眞砂子/まさ子/晶子/真紗子/誠子/
まさこひ /雅子妃/
まさご /真砂/
まさし /仁/雅司/正史/政司/正志/雅史/雅志/将/昌士/昌志/匡/匡史/将司/将史/昌史/政資/正司/祐史/將/政志/昌/昌嗣/正/真志/真史/雅士/
まさしく /正しく/
まさしげ /正成/雅重/正茂/政重/
まさしち /政七/
まさじ /政次/政治/正次/正治/雅二/政司/
まさすけ /正祐/
まさずみ /正純/
まさたか /昌孝/正高/政孝/正孝/正隆/政隆/雅隆/政敬/誠孝/政貴/真隆/
まさたけ /正武/
まさつ /摩擦/
まさつおん /摩擦音/
まさつぐ /正継/雅紹/仁継/
まさつけいすう /摩擦係数/
まさつげんかい /摩擦限界/
まさつそくど /摩擦速度/
まさつていこう /摩擦抵抗/
まさつね /正恒/
まさつぶ /摩擦部/
まさつぶぶん /摩擦部分/
まさつりょく /摩擦力/
まさてつ /正哲/
まさてる /雅照/政輝/正輝/
まさと /正人/政人/雅人/真人/雅斗/雅刀/昌人/
まさとし /正敏/雅俊/正俊/昌利/政利/正利/盛敏/雅敏/真俊/眞利/
まさとみ /正美/正富/政富/
まさな /雅名/
まさなお /正直/政直/正尚/雅尚/
まさなり /正成/政成/正業/
まさの /雅野/
まさのぶ /正伸/正信/昌信/政信/雅修/匡伸/正亘/昌延/雅信/雅宣/
まさのり /公則/政典/昌則/昌典/正紀/正典/雅則/正範/雅典/成憲/政宣/正則/正徳/正規/真典/
まさはる /正晴/正治/正春/雅春/昌治/政春/
まさひこ /雅彦/真彦/正彦/昌彦/政彦/允彦/眞彦/
まさひさ /昌久/真久/
まさひで /昌英/正英/正秀/
まさひと /雅仁/正人/正仁/昌人/賢人/
まさひろ /雅洋/正裕/雅弘/正宏/雅裕/昌宏/正洋/正博/雅博/昌弘/政宏/政広/政弘/正広/正弘/雅浩/征洋/正寛/真弘/雅宏/政浩/正央/正浩/誠広/匡弘/昌寛/昌広/将容/
まさふさ /政房/
まさふみ /正文/真詞/将文/雅文/昌文/将史/雅史/
まさぶみ /正文/
まさみ /昌己/正美/雅巳/雅美/公美/昌美/昌未/雅己/雅実/眞美/昌巳/雅三/政美/正己/正実/正巳/真己/
まさみち /正道/雅道/真理/
まさみつ /正光/真光/昌光/
まさむね /政宗/正宗/
まさめ /正目/
まさもと /理元/政本/
まさや /雅也/雅哉/昌也/昌哉/正哉/正也/匡哉/正弥/
まさやす /雅保/正康/昌泰/政康/誠康/雅康/正泰/
まさゆき /昌之/政幸/雅之/理之/正之/正行/政之/雅祐/昌幸/政行/正幸/雅行/雅幸/真幸/政征/誠之/将行/真之/
まさゆめ /正夢/
まさよ /雅代/昌代/
まさよう /将容/
まさよし /正義/昌吉/政義/正好/昌義/正善/正良/正芳/雅義/正元/
まさより /政頼/
まさる /勝/優/賢/秀/太/大/
まし /増/
ましかく /真四角/
ましき /益城/
ましけ /増毛/
ましこ /益子/増子/
ましこちょう /益子町/
ました /真下/間下/
まして /況して/
ましど /益戸/
ましば /間柴/
ましも /真下/
ましゃく /間尺/
ましゅう /摩周/
ましゅうえき /摩周駅/
ましゅうこ /摩周湖/
ましょう /魔性/
ましょうねん /魔少年/
ましょうめん /真正面/
ましら /猿/
ましん /マシン/麻疹/真芯/
ましんご /マシン語/
まじ /マジ/真風/
まじか /真近;人名/間近/
まじきり /間仕切り/
まじっく /マジック/
まじま /間嶋/間島/
まじめ /真面目/
まじめやろう /真面目野郎/
まじゅう /魔獣/
まじゅつ /魔術/
まじゅつし /魔術師/
まじゅつしょ /魔術書/
まじゅつてき /魔術的/
まじょ /魔女/
まじょおう /魔女王/
まじり /交じり/
まじわり /交わり/∩/
まじん /魔神/魔人/
ます /鱒/桝/益/増/升/舛/マス/枡/
ますい /増井/麻酔/桝井/
ますいか /麻酔科/
ますいかい /麻酔科医/
ますいこうか /麻酔効果/
ますいさよう /麻酔作用/
ますいち /増市/
ますいやく /麻酔薬/
ますお /益夫/満寿夫/増尾/満洲雄/
ますおか /益岡/増岡/舛岡/
ますおかけん /舛岡研/
ますかわ /増川/
ますき /増木/
ますきんぐ /マスキング/
ますこ /益子/増子/万寿子/
ますこみ /マスコミ/
ますざわ /増沢/増澤/
ますじ /鱒二/
ますじろう /益治郎/
ますずし /鱒寿司/
ますせき /桝席/
ますぞう /益造/
ますぞえ /桝添/舛添/
ますた /マスタ/
ますたー /マスター/
ますたーべーしょん /マスターベーション/
ますたつ /倍達/
ますたに /増谷/升谷/益谷/
ますだ /増田/益田/桝田/升田/舛田/
ますだきいとん /益田喜頓/
ますだや /増田屋/
ますづり /鱒釣/
ますとみおんせん /増富温泉/
ますど /益戸/
ますなが /増永/
ますの /増野/
ますはら /増原/
ますひこ /益彦/
ますぶち /増淵/
ますほ /増穂/
ますます /益々/
ますみ /萬純/真澄/真寿/増実/眞澄/真純/満寿美/益美/
ますめ /升目/桝目/枡目/
ますめでぃあ /マスメディア/
ますもと /升本/増本/桝本/
ますや /升谷/
ますやま /増山/益山/
ますらお /益荒男/丈夫/
まず /先ず/
ませ /間瀬/真瀬/
ませき /魔石/
まぜ /馬瀬/
まそん /摩損/
また /又/股/俣/亦/
またがし /又貸し/
またがり /又借り/
またぎき /又聞き/
またさぶろう /又三朗/又三郎/
またした /股下/
またぞろ /又候/
またたくま /瞬く間/
またたびもの /股旅者/
またの /俣野/
または /又は/
またま /真玉/
またもの /陪臣/又者/
またわり /股割/
まだ /未だ/
まだい /真鯛/
まだこ /真蛸/
まだし /未だし/
まだむ /マダム/
まだら /斑/真鱈/
まだらお /斑尾/
まち /町/街/真知/万智/甼/襠/待ち/
まちあい /待合/
まちあいしつ /待合い室/待合室/
まちあるき /街歩き/
まちあわせ /待ち合わせ/待合/
まちい /町井/
まちいしゃ /町医者/
まちかど /街角/
まちかね /待兼/
まちかねやま /待兼山/
まちかねやまちょう /待兼山町/
まちがい /間違い/
まちぎょうれつ /待ち行列/待行列/
まちこ /眞智子/真知子/街子/満智子/麻知子/
まちこうじょう /町工場/
まちこうば /町工場/
まちざわ /町沢/町澤/
まちしゅうへん /町周辺/
まちじかん /待ち時間/待時間/
まちじゅう /街中/町中/
まちじょうたい /待ち状態/
まちぜんたい /町全体/
まちだ /町田/
まちだえき /町田駅/
まちだおだきゅう /町田小田急/
まちだかいどう /町田街道/
まちだかん /町田間/
まちだがくえん /町田学園/
まちだし /町田市/
まちだししゅうへん /町田市周辺/
まちだしたいいくかん /町田市体育館/
まちだしみん /町田市民/
まちだてん /町田店/
まちだほうめん /町田方面/
まちぢゅう /町中/
まちっこ /町っ子/
まちでら /待寺/
まちなか /街中/町中/
まちなみ /街並/町並み/町並/
まちの /町野/
まちはずれ /町外れ/
まちぼうけ /待ちぼうけ/
まちまち /区々/区区/
まちむすめ /街娘/
まちや /町谷/町屋/
まちやくば /町役場/
まちんか /マチン科/Loganiaceae/
まぢか /真近/間近/
まっか /真赤/真っ赤/
まっかっか /真赤っか/
まっかり /真狩/
まっき /末期/末岐/
まっきかんじゃ /末期患者/
まっきがん /末期癌/
まっきしょうじょう /末期症状/
まっきしょうじょうてき /末期症状的/
まっきてき /末期的/
まっきゃく /末脚/
まっくら /真っ暗/真暗/
まっくらやみ /真暗闇/
まっくろ /真っ黒/真黒/
まっこう /真っ向/真向/
まっさいちゅう /真最中/真っ最中/
まっさお /真っ青/真青/
まっさかさま /真っ逆さま/
まっさかり /真っ盛り/
まっさき /真っ先/真先/
まっさつ /抹殺/
まっさつそうどう /抹殺騒動/
まっさら /真っ新/
まっし /末子/
まっしゅう /末秋/
まっしょう /抹消/末梢/
まっしょうけい /末梢系/
まっしょうけっかん /末梢血管/
まっしょうけつ /末梢血/
まっしょうしんけい /末梢神経/
まっしょうじき /真正直/
まっしょうぶ /末梢部/
まっしょうめん /真正面/
まっしょうもうさいけっかん /末梢毛細血管/
まっしろ /真っ白/真白/
まっすぐ /真っ直/
まっせ /末世/
まっせき /末席/
まっせつ /末節/
まったく /全く/全/
まっただなか /真っ只中/真只中/
まったん /末端/
まったんかいいん /末端会員/
まったんくかん /末端区間/
まっち /マッチ/燐寸/
まっちゃ /抹茶/
まっちゃまち /松屋町/
まっちょう /末長/
まってい /末弟/
まっとう /松任/
まっとうし /松任市/
まっとうや /松任谷/
まっぴつ /末筆/
まっぴら /真平/
まっぴらごめん /真平御免/
まっぴるま /真っ昼間/真昼間/
まっぴんぐ /マッピング/
まっぽう /末法/
まつ /末/松/沫/抹/待つ/枩/秣/茉/靺/
まつい /松井/松居/松為/
まついし /松石/
まついだ /松井田/
まついち /松一/
まつうら /松浦/
まつうらてつどう /松浦鉄道/
まつえ /松江/
まつえい /末裔/未裔/
まつえだ /松枝/
まつえはん /松江藩/
まつえほうこう /松江方向/
まつえほうめん /松江方面/
まつお /松尾/松男/松夫/松雄/
まつおか /松岡/
まつおたいしゃ /松尾大社/
まつかざり /松飾り/
まつかぜ /松風/
まつかた /松方/
まつかつ /靺鞨/
まつかわ /松川/松河/
まつかわえきこうない /松川駅構内/
まつがおか /松が丘/
まつがさき /松ヶ崎/
まつがや /松ヶ谷/
まつき /松木/
まつきがわきょうりょう /松木川橋梁/
まつくら /松倉/
まつげ /睫/睫毛/
まつご /末期/
まつごろう /松五郎/松吾郎/
まつさか /松坂/松阪/
まつさかぎゅう /松坂牛/
まつさき /松崎/
まつさわ /松沢/
まつざか /松坂/松阪/
まつざかぎゅう /松坂牛/
まつざかしない /松阪市内/
まつざかにく /松坂肉/
まつざかや /松坂屋/
まつざき /松崎/松嵜/
まつざわ /松沢/松澤/
まつしげ /松重/松茂/
まつした /松下/
まつしたぎけん /松下技研/
まつしたじょうほう /松下情報/
まつしたせい /松下製/
まつしたせいけいじゅく /松下政経塾/
まつしたせいこう /松下精工/
まつしたちゅうけん /松下中研/
まつしたつうしん /松下通信/
まつしたつうしんこうぎょう /松下通信工業/
まつしたでんき /松下電器/
まつしたでんきさんぎょう /松下電器産業/
まつしたでんきじょうほう /松下電器情報/
まつしたでんこう /松下電工/
まつしたでんし /松下電子/
まつしたでんしこうぎょう /松下電子工業/
まつしたなごやけん /松下名古屋研/
まつしたはん /松下藩/
まつしたれいき /松下冷機/
まつしま /松島/松嶋/
まつしまちょう /松島町/
まつしろ /松代/
まつじつ /末日/
まつじつせいと /末日聖徒/
まつじめ /末締め/
まつた /松田/
まつたか /松高/
まつたけ /松茸/
まつたに /松谷/
まつたろう /松太郎/
まつだ /松田/
まつだい /末代/松代/
まつだいら /松平/
まつだいらただてる /松平忠輝/
まつだぐみ /松田組/
まつだせいこ /松田聖子/
まつだゆうさく /松田優作/
まつつか /松塚/
まつづき /松月/
まつとうや /松任谷/
まつとうやゆみ /松任谷由実/
まつとも /松友/
まつど /松戸/
まつどし /松戸市/
まつなえ /松苗/
まつなか /松中/
まつなが /松永/末永/松長/
まつなみ /松波/
まつぬま /松沼/
まつの /松野/松乃/
まつのうち /松の内/
まつのぶ /松延/
まつのべ /松延/
まつのやま /松之山/
まつはた /松畑/
まつば /松葉/
まつばせ /松橋/
まつばづえ /松葉杖/
まつばやし /松林/
まつばら /松原/
まつばらこ /松原湖/
まつひろ /松弘/
まつび /末尾/
まつびさいき /末尾再帰/
まつびさんしょう /末尾参照/
まつびし /松菱/
まつびばんごう /末尾番号/
まつふじ /松藤/
まつふる /松古/
まつぶさか /マツブサ科/Schisandraceae/
まつぶし /松伏/
まつぶん /末文/
まつぼうきき /松貿機器/
まつまい /末妹/
まつまえ /松前/
まつまえはん /松前藩/
まつまる /松丸/
まつみ /松見/
まつむら /松村/
まつむらしょてん /松村書店/
まつもか /マツモ科/Ceratopyllaceae/
まつもと /松本/松元/
まつもとくうこう /松本空港/
まつもとこうしろう /松本幸四郎/
まつもとし /松本市/
まつもとしない /松本市内/
まつもとせいちょう /松本清張/
まつもとたいかい /松本大会/
まつもとでんてつ /松本電鉄/
まつもとほうめん /松本方面/
まつもとれいじ /松本零士/
まつもり /松森/
まつや /松屋/
まつやに /松脂/
まつやま /松山/
まつやまかん /松山間/
まつやまし /松山市/
まつやましない /松山市内/
まつやましょう /松山商/
まつやまじょう /松山城/
まつやまだいがく /松山大学/
まつやまちはる /松山千春/
まつやまびん /松山便/
まつやまほうめん /松山方面/
まつやままち /松山町/
まつゆき /松雪/
まつよし /松吉/
まつり /祭/祭り/祀り/祀/
まつりごと /政/祭事/
まつろ /末路/
まつわこう /松輪港/
まづ /先づ/
まて /待て/蟶/
まてがい /蟶貝/
まてき /魔笛/
まてんろう /摩天楼/
まで /迄/
まと /的/魔都/
まとい /纏/纒/纒い/
まとうだい /的鯛/
まとはずれ /的外れ/
まとば /的場/
まとまり /纒まり/
まとりっくす /マトリックス/
まど /窓/窗/
まどう /魔導/魔道/
まどうし /魔道師/魔導士/魔導師/魔道士/
まどうしょ /魔導書/
まどか /円/
まどかんすう /窓関数/
まどがらす /窓ガラス/
まどがわ /窓側/
まどぎわ /窓際/
まどぎわせき /窓際席/
まどぐち /窓口/
まどぐちおく /窓口奥/
まどぐちぎょうむ /窓口業務/
まどぐちしょくいん /窓口職員/
まどぐちすう /窓口数/
まどぐちない /窓口内/
まどぐちまえ /窓口前/
まどぐちやく /窓口役/
まどぜんかい /窓全開/
まどぜんたい /窓全体/
まどちょう /窓長/
まどない /窓内/
まどはいち /窓配置/
まどべ /窓辺/
まどよう /窓用/
まどようだんねつざい /窓用断熱材/
まどり /間取り/
まどりーど /馬徳里/
まどりず /間取り図/
まどわく /窓枠/
まどわり /窓割/
まな /麻奈/愛/真奈/真名/茉奈/
まなー /マナー/
まないた /俎/俎板/
まなか /愛香/
まなこ /眼/
まなざし /眼差し/
まなじり /眥/眦/
まなつ /真夏/
まなつび /真夏日/
まなつる /真鶴/
まなつるこう /真鶴港/
まなづる /真鶴/
まなでし /愛弟子/
まなびや /学舎/
まなぶ /学/學/斈/
まなべ /真鍋/真部/
まなみ /真奈美/愛美/真名美/
まにあ /マニア/
まにあわせ /間に合わせ/
まにぴゅれーしょん /マニピュレーション/
まにぴゅれーた /マニピュレータ/
まにまに /随に/
まにゅある /マニュアル/
まにら /馬尼剌/
まにわ /真庭/
まにんげん /真人間/
まぬえど /真鵺道/Manued/Manuscript Editing/
まぬけ /間抜け/
まぬけづら /間抜面/
まね /真似/
まねーじゃ /マネージャ/
まねきねこ /招き猫/
まねきん /マネキン/
まねごと /真似事/
まねじめんと /マネジメント/
まねじゃー /マネジャー/
まねもの /真似物/
まの /真野/間野/
まのあたり /目の当たり/
まのび /間延び/間延/
まは /万葉/
まばし /馬橋/
まばしら /間柱/
まばたき /瞬き/
まばら /疎/
まばらぶんさんきおく /まばら分散記憶/
まひ /麻痺/痲痺/
まひかり /真光/
まひがし /真東/
まひじょうたい /麻痺状態/
まひと /真人/
まひる /真昼/
まび /魔美/
まびき /間引/
まふじえき /間藤駅/
まふね /真船/
まふゆ /真冬/
まふゆび /真冬日/
まぶか /目深/
まぶしさ /眩しさ/
まぶた /瞼/目蓋/
まぶち /馬渕/馬淵/
まほ /真帆/真秀/
まほう /魔法/
まほうがい /魔法街/
まほうぎじゅつ /魔法技術/
まほうけん /魔法剣/
まほうけんし /魔法剣士/
まほうしょ /魔法書/
まほうしょうじょ /魔法少女/
まほうじゅうし /魔法重視/
まほうじん /魔法陣/魔方陣/
まほうせき /魔法石/
まほうせん /魔法戦/
まほうせんもん /魔法専門/
まほうだいさくせん /魔法大作戦/
まほうつかい /魔法使い/
まほうてき /魔法的/
まほうびん /魔法瓶/
まほうりょく /魔法力/
まほか /真帆香/
まほりかん /馬堀間/
まぼろし /幻/
まま /侭/ママ/儘/圸/墹/壗/媽媽/随/
ままこ /継子/
ままちち /継父/
ままはは /継母/
まみ /真美/昌未/真実/麻美/磨美/麻実/麻弥/マミ/眞美/魔美/茉美/舞美/
まみこ /真美子/麻巳子/麻美子/
まみず /真水/
まみづか /馬見塚/
まみどりいろ /真緑色/
まみな /真美奈/
まみなみ /真南/
まみや /間宮/魔実也/
まむし /蝮/
まむろがわ /真室川/
まめ /豆/荳/
まめおか /豆岡/
まめか /豆科/マメ科/
まめきゅう /豆球/
まめせいひん /豆製品/
まめたん /豆炭/豆単/
まめだ /豆田/
まめちしき /豆知識/
まめつ /摩滅/磨滅/
まめつぶ /豆粒/
まめでんきゅう /豆電球/
まめほん /豆本/
まめまき /豆まき/
まめみそ /豆味噌/
まめもよう /豆模様/
まめや /豆屋/
まもう /摩耗/磨耗/
まもうぶぶん /摩耗部分/
まもうへんけい /摩耗変形/
まもなく /間も無く/
まもの /魔物/
まものたいじ /魔物退治/
まものたち /魔物達/
まもり /護/
まもる /衛/守/衞/
まや /麻弥/摩耶/魔夜/麻矢/麻那/
まやく /麻薬/
まやくきんしほうりつ /麻薬禁止法律/
まやくじょうしゅうしゃ /麻薬常習者/
まやくせい /麻薬性/
まやくせんしんこく /麻薬先進国/
まやくたんちけん /麻薬探知犬/
まやくちゅうどく /麻薬中毒/
まやくちゅうどくかんじゃ /麻薬中毒患者/
まやくてき /麻薬的/
まやくてきしゅうかんせい /麻薬的習慣性/
まやくろん /麻薬論/
まやこ /麻也子/
まやべ /真矢部/
まやま /間山/真山/
まゆ /繭/眉/麻由/真由/麻愉/
まゆげ /眉毛/
まゆこ /真由子/繭子/万由子/眉子/
まゆずみ /黛/
まゆつば /眉唾/
まゆみ /真由美/真弓/真祐美/麻由美/檀/万友美/誠由美/魔弓/
まゆむら /眉村/
まよ /真代/眞夜/真世/麻世/
まよい /迷い/
まよけ /魔除け/
まよこ /真横/
まよこほうこう /真横方向/
まよなか /真夜中/
まよなかいがい /真夜中以外/
まよねーず /マヨネーズ/
まら /摩羅/
まらそん /マラソン/
まらや /馬來/
まり /真理/麻里/真里/万里/茉莉/掬/鞠/満利/毬/茉利/麻理/マリ/
まりあ /マリア/真利亜/真里亜/万梨阿/
まりい /麻利衣/
まりえ /真理絵/真理恵/麻里絵/
まりお /真理雄/眞理雄/麻利夫/
まりこ /真理子/真里子/真璃子/真利子/真梨子/麻理子/麻里子/万里子/満利子/茉里子/まり子/鞠子/マリ子/
まりこうじ /鞠小路/
まりな /満里奈/
まりのす /横浜マリノス/
まりょく /魔力/
まりりん /マリリン/
まりん /まりン/
まる /○/丸/●/◎/円/。/◯/・/マル/．/圓/〇/゜/
まるあな /丸穴/
まるあらい /丸洗い/
まるあんき /丸暗記/
まるい /丸井/
まるいけ /丸池/
まるいす /丸椅子/
まるいち /丸一/
まるいちにち /丸一日/
まるうつし /丸写し/
まるえい /丸栄/
まるお /丸尾/丸生/円尾/
まるおか /丸岡/
まるか /満留賀/
まるかっこ /丸括弧/
まるかめかん /丸亀間/
まるかめがわ /丸亀側/
まるかわ /丸川/
まるかん /丸漢/
まるがお /丸顔/
まるがかえ /丸抱え/
まるがた /丸型/丸形/
まるがめ /丸亀/
まるがめこう /丸亀高/
まるがめこうこう /丸亀高校/
まるがめし /丸亀市/
まるきゅう /丸久/
まるきん /丸金/
まるく /マルク/
まるくに /丸国/
まるこ /丸子/
まるこう /丸興/
まるこし /丸腰/
まるこばし /丸子橋/
まるごし /丸腰/
まるさん /丸三/
まるしあ /マルシア/
まるしょう /丸正/
まるしょうしょくひん /丸正食品/
まるじるし /丸印/
まるす /マルス/
まるすうじ /丸数字/
まるせいゆ /馬耳塞/
まるせっぷ /丸瀬布/
まるぜん /丸善/丸全/
まるぜんせきゆ /丸善石油/
まるた /丸田/丸太/
まるたに /丸谷/
まるたまち /丸太町/
まるたまちせん /丸太町線/
まるだいしょくひん /丸大食品/
まるだし /丸出し/
まるち /マルチ/
まるちめでぃあ /マルチメディア/
まるつきすうじ /丸付数字/
まるてーぶる /丸テーブル/
まるてん /丸天/
まるとう /丸東/
まるどけい /丸時計/
まるなげ /丸投げ/
まるにし /丸西/
まるにねん /丸二年/
まるぬま /丸沼/
まるぬまこうげん /丸沼高原/
まるの /丸野/
まるのうち /丸の内/丸ノ内/
まるのうちせん /丸の内線/
まるのこ /丸鋸/
まるはい /丸灰/
まるはし /丸橋/
まるはだか /丸裸/
まるはち /丸八/
まるはんにち /丸半日/
まるばつ /○×/
まるばつしき /○×式/
まるばやし /丸林/
まるひじょうほう /丸秘情報/
まるひほうこく /丸秘報告/
まるふく /丸福/
まるぶつ /丸物/
まるぶん /丸文/
まるべに /丸紅/
まるぼうず /丸坊主/
まるまげ /丸髷/
まるまどでんしゃ /丸窓電車/
まるまる /○○/丸々/
まるみ /丸見/円美/
まるみえ /丸見え/
まるみつ /丸光/
まるめ /丸め/
まるめごさ /丸目誤差/丸め誤差/
まるもじ /丸文字/
まるもじけい /丸文字系/
まるもち /丸餅/
まるもと /丸元/丸本/
まるもり /丸森/
まるや /丸屋/丸谷/
まるやき /丸焼/
まるやね /丸屋根/
まるやま /丸山/円山/
まるやまおんがくどう /丸山音楽堂/
まるやまだい /丸山台/
まるやまちょう /丸山町/
まるゆう /マル優/
まるわ /丸和/
まれ /稀/希/
まれき /希樹/
まれすけ /希典/
まろ /麿/麻呂/
まわし /回し/廻/
まわしげり /廻し蹴り/
まわた /真綿/
まわたり /馬渡/
まわり /廻り/周り/回り/
まわりみち /回り道/
まわるまわる /(^o^)(o^ )(^  )(   )(  ^)( ^o)(^o^)/
まん /万/満/漫/慢/蔓/萬/饅/鰻/幡/曼/幔/悗/懣/滿/瞞/縵/謾/蹣/鬘/
まんいち /万一/
まんいん /満員/
まんいんおんれい /満員御礼/
まんいんじょうたい /満員状態/
まんいんでんしゃ /満員電車/
まんえつ /満悦/
まんえん /万円/蔓延/満塩/萬延/
まんえんさつ /万円札/
まんえんだい /万円代/
まんかい /満開/万回/
まんかん /満貫/
まんが /漫画/マンガ/萬画/
まんがいち /万が一/万一/
まんがおう /漫画王/
まんがか /漫画家/漫画化/
まんがかい /漫画界/
まんがきょうしつ /漫画教室/
まんがく /満額/
まんがくかいとう /満額回答/
まんがざっし /漫画雑誌/
まんがし /漫画誌/
まんがしゅう /漫画集/
まんがしょう /漫画賞/
まんがじたい /漫画自体/
まんがじょうほうざっし /漫画情報雑誌/
まんがたんこうぼん /漫画単行本/
まんがてき /漫画的/
まんがとくゆう /漫画特有/
まんがどうじんし /漫画同人誌/
まんがのもり /まんがの森/
まんがばん /漫画版/
まんがひょうろんか /漫画評論家/
まんがぶんか /漫画文化/
まんがぶんこばん /漫画文庫版/
まんがほん /漫画本/
まんがめいさくかん /漫画名作館/
まんがん /満貫/満願/
まんき /満期/
まんきじつ /満期日/
まんきつ /満喫/
まんぎょう /万行/
まんけん /漫研/
まんげきょう /万華鏡/
まんげつ /満月/
まんげつじ /満月時/
まんげつじょうたい /満月状態/
まんこ /万個/
まんこう /満腔/
まんごく /万石/
まんごじしょ /万語辞書/
まんさい /満載/
まんさく /万作/
まんさくもく /マンサク目/Hamamelidales/
まんさつ /万冊/
まんざ /万座/満座/
まんざい /漫才/
まんざいし /漫才師/
まんざいらく /萬歳楽/
まんざほうめん /万座方面/
まんざら /満更/
まんしつ /満室/
まんしゃ /満車/
まんしゅいん /曼殊院/
まんしゅう /満州/滿洲/
まんしゅうかいたくみん /満州開拓民/
まんしゅうけんこく /満州建国/
まんしゅうこく /満州国/滿洲國/
まんしゅうこくけんこく /満州国建国/
まんしゅうご /満州語/
まんしゅうじへん /満州事変/滿洲事變/
まんしゅうじん /満州人/
まんしゅうせんりょう /満州占領/
まんしゅうぞく /満州族/
まんしょく /万色/
まんしょくがぞう /万色画像/
まんしょん /マンション/
まんしん /万進/満身/慢心/
まんしんそうい /満身創痍/
まんしんほう /万進法/
まんじ /卍/
まんじがため /卍固/
まんじどもえ /卍巴/
まんじゅう /饅頭/
まんじゅしゃげ /曼珠沙華/
まんじょう /満場/
まんじょういっち /満場一致/
まんすい /満水/
まんず /萬子/
まんせい /慢性/
まんせいか /慢性化/
まんせいしん /慢性心/
まんせいじゅうたい /慢性渋滞/
まんせいてき /慢性的/
まんせいばし /万世橋/
まんせいびょう /慢性病/
まんせき /満席/
まんせきじ /満席時/
まんせきじょうたい /満席状態/
まんせん /満船/
まんぜん /漫然/
まんぞく /満足/
まんぞくかん /満足感/
まんぞくど /満足度/
まんた /万太/
まんたに /萬谷/
まんたん /満タン/
まんたんい /万単位/
まんだい /万代/万台/
まんだら /曼陀羅/
まんだん /漫談/
まんちゃく /瞞着/
まんちょう /満潮/
まんちょうぜんご /満潮前後/
まんちんろう /萬珍楼/
まんてつ /満鉄/滿鐵/
まんてつせんない /満鉄線内/
まんてん /満点/万点/満天/
まんとみ /万富/
まんどころ /政所/
まんなか /真中/真ん中/まん中/
まんにょうしゅう /万葉集/
まんにん /万人/
まんねん /万年/萬年/
まんねんひつ /万年筆/
まんねんびと /毎年人/
まんねんゆき /万年雪/
まんねんれき /万年暦/
まんのう /満濃/
まんば /万場/万馬/
まんばい /万倍/
まんばけん /万馬券/
まんぱ /万波/
まんぱい /満杯/満配/
まんぱん /満帆/
まんびき /万引/万引き/
まんびょう /万病/
まんぴょう /満票/
まんぶ /万部/
まんぷく /満腹/
まんぷくかん /満腹感/
まんぷくほーる /満腹ホール/
まんべん /万遍/万便/
まんぽ /漫歩/
まんぽけい /万歩計/
まんまい /万枚/
まんまえ /真ん前/
まんまく /幔幕/
まんまる /真円/
まんまん /満々/
まんめん /満面/
まんもう /滿蒙/
まんゆう /漫遊/
まんゆうき /漫遊記/
まんよう /万葉/
まんようかな /万葉仮名/
まんようしゅう /万葉集/
まんようせん /万葉線/
まんりき /万力/
まんりょう /満了/
まんりょうび /満了日/
まんるい /満塁/
まんるいさく /満塁策/
まんるいそうしゃいっそう /満塁走者一掃/
まんるいだん /満塁弾/
まんるいほんるいだ /満塁本塁打/
み /見/身/未/味/美/実/三/巳/箕/魅/己/御/稔/弥/靡/深/壬/實/彌/
み> /未/
み? /未/
みーてぃんぐ /ミーティング/
みあ /未亜/
みあい /見合い/見合/美合/
みあいあいて /見合相手/
みあいけっこん /見合結婚/
みあいれんあい /見合恋愛/
みあけ /三宅/
みあさ /美麻/
みあま /三甘/
みい /三井/魅衣/
みいけ /三池/
みいけこう /三池港/
みいけこうぎょう /三池工業/
みいでら /三井寺/
みいら /木乃伊/
みいらく /三井楽/
みいり /実入り/
みうけ /身請/
みうごき /身動き/
みうち /身内/
みうら /三浦/
みうらかいがん /三浦海岸/
みうらきた /美浦北/
みうらはんとう /三浦半島/
みうらわん /三浦湾/
みうり /身売/身売り/
みえ /三重/見栄/美枝/美江/見得/美瑛/水絵/美恵/
みえかくれ /見えかくれ/見え隠れ/
みえかた /見え方/
みえきんぺん /三重近辺/
みえぐん /三重郡/
みえけん /三重県/
みえけんかめやま /三重県亀山/
みえけんしゅっしん /三重県出身/
みえけんじん /三重県人/
みえけんすずかし /三重県鈴鹿市/
みえけんなばり /三重県名張/
みえこ /三枝子/三重子/美恵子/美枝子/実枝子/三恵子/
みえこうつう /三重交通/
みえせん /三江線/
みえだ /三枝/
みえだい /三重大/
みえだいがく /三重大学/
みえだいこう /三重大工/
みえっぱり /見栄張り/
みお /美織/未央/澪/三尾/美央/美尾/美緒/実音/未緒/水脈/
みおくり /見送り/
みおこ /美央子/
みおさめ /見納め/
みおつくし /澪標/
みおとし /見落とし/見落し/
みおとり /見劣り/
みおぼえ /見覚え/
みおも /身重/
みおり /美織/
みか /美香/美加/ミカ/実花/美伽/美佳/美歌/美華/三香/美夏/甕/実可/
みかい /未開/
みかいぎょうくかん /未開業区間/
みかいけつ /未解決/
みかいけつてん /未解決点/
みかいこんち /未開墾地/
みかいしゅう /未回収/
みかいじん /未開人/
みかいたく /未開拓/
みかいち /未開地/
みかいつう /未開通/
みかいつうぶぶん /未開通部分/
みかいとう /未回答/
みかいふう /未開封/
みかいめい /未解明/
みかえし /見返し/
みかえり /見返り/
みかく /味覚/
みかくてい /未確定/
みかくていせんきょく /未確定選挙区/
みかくていぶんせつ /未確定文節/
みかくていもじ /未確定文字/
みかくていもじれつ /未確定文字列/
みかくてき /味覚的/
みかくにん /未確認/
みかくにんじょうほう /未確認情報/見確認情報/
みかけ /見かけ/見掛け/
みかけじょう /見掛け上/
みかげ /御影/
みかげいし /御影石/
みかげえきしゅうへん /御影駅周辺/
みかげつ /三ケ月/
みかこ /美佳子/美加子/美香子/
みかさ /三笠/
みかさしょぼう /三笠書房/
みかた /味方/見方/三方/美方/
みかたがわ /味方側/
みかたきょうぎしゃ /味方競技者/
みかたせんしゅ /味方選手/
みかたはら /三方原/
みかだ /三ヶ田/
みかつき /三日月/
みかづき /三日月/
みかど /三門/御門/帝/
みかにゅう /未加入/
みかほ /美華保/
みかみ /三上/三神/見上/
みかみね /三神峯/
みかみひろし /三上博史/
みかめ /三瓶/
みかも /三加茂/美甘/
みかり /美加理/
みかわ /三河/美川/三川/実川/見川/三加和/
みかわあんじょう /三河安城/
みかわしま /三河島/
みかわせん /三河線/
みかわたはらえき /三河田原駅/
みかわちほう /三河地方/
みかわべん /三河弁/
みかわもの /三河者/
みかわわん /三河湾/
みかん /未完/未刊/蜜柑/
みかんか /ミカン科/
みかんけつ /未完結/
みかんさくひん /未完作品/
みかんせい /未完成/
みかんせいばん /未完成版/
みかんせいひん /未完成品/
みかんもく /ミカン目/Rutales/
みかんりょう /未完了/
みかんりょうかこ /未完了過去/
みがきこ /磨き粉/
みがきずな /磨き砂/
みがく /研/
みがくしゅう /未学習/
みがため /身固め/
みがって /身勝手/
みがまえ /身構え/
みがら /身柄/見柄/
みがらそうけん /身柄送検/
みがる /身軽/
みがわり /身代り/
みき /三木/美紀/美樹/幹/三紀/美喜/美希/未稀/美貴/美来/三基/三城/実紀/未木/御木/光希/三樹/美季/未希/未来/ミキ/三喜/
みきお /幹雄/幹夫/幹男/三起男/
みきき /見聞き/
みきこ /ミキコ/美希子/幹子/美紀子/美樹子/実希子/美貴子/
みきさいてん /未記載点/
みきたけお /三木武夫/
みきどう /未起動/
みきにゅう /未記入/
みきのり /幹典/
みきはら /美樹原/
みきひこ /三紀彦/幹彦/未来彦/
みきほ /美喜帆/
みきもと /美樹本/
みきや /御喜家/幹哉/
みきょうらん /美狂乱/
みきよ /幹代/
みきり /見切り/
みきりはっしゃ /見切り発車/
みきわめ /見極め/
みぎ /右/→/＞/）/】/』/」/
みぎあし /右足/右脚/
みぎいっぱい /右一杯/
みぎうえ /右上/
みぎうえすみ /右上隅/
みぎうしろ /右後/
みぎうで /右腕/
みぎえだ /右枝/
みぎおく /右奥/
みぎかいてん /右回転/
みぎかた /右肩/
みぎかっこ /右括弧/』/】/
みぎがわ /右側/
みぎがわつうこう /右側通行/
みぎきき /右利/右利き/
みぎぎし /右岸/
みぎけつごう /右結合/
みぎこ /右子/
みぎこし /右腰/
みぎした /右下/
みぎしたすみ /右下隅/
みぎしもて /右下手/
みぎしゃせん /右車線/
みぎしゃめん /右斜面/
みぎすみ /右隅/
みぎず /右図/
みぎぜんぽう /右前方/
みぎぜんりん /右前輪/
みぎそくめん /右側面/
みぎそろえ /右揃え/
みぎだしゃ /右打者/
みぎだせき /右打席/
みぎちゅうだん /右中段/
みぎづめ /右詰め/
みぎて /右手/
みぎておやゆび /右手親指/
みぎてがわ /右手側/
みぎてくび /右手首/
みぎてけい /右手系/
みぎてぜんぽう /右手前方/
みぎてなかゆび /右手中指/
みぎてまえ /右手前/
みぎてよう /右手用/
みぎてんかい /右転回/
みぎどなり /右隣/右隣り/
みぎのり /右乗/
みぎはし /右端/
みぎはんぶん /右半分/
みぎはんめん /右半面/
みぎひざ /右膝/
みぎひじ /右肘/
みぎひだり /右左/
みぎほうこう /右方向/
みぎまえ /右前/
みぎまえあし /右前脚/右前足/
みぎまがり /右曲り/
みぎまつ /右松/右末/
みぎまわり /右回り/
みぎみみ /右耳/
みぎむき /右向き/
みぎむね /右胸/
みぎめ /右目/
みぎめよう /右目用/
みぎや /→/⇒/
みぎやじるし /→/⇒/右矢印/
みぎようそ /右要素/
みぎよこ /右横/
みぎよせ /右寄/
みぎより /右寄/
みぎり /砌/
みぎわ /汀/頻/
みく /ミク/美久/未来/美来/
みくだりはん /三行半/三下半/
みくち /三口/
みくに /三國/三国/御國/皇國/
みくにちょう /三国町/
みくにとうげ /三国峠/
みくにやま /三国山/
みくにれんたろう /三國連太郎/
みくま /三隈/
みくも /三雲/
みくらしま /御蔵島/
みくりや /御厨/
みくるま /御車/
みくろ /ミクロ/
みくろん /μm/
みぐ /ミグ/
みけ /三毛/
みけいけん /未経験/
みけいけんしゃ /未経験者/
みけいさい /未掲載/
みけいさん /未計算/
みけいやく /未契約/
みけた /三桁/
みけっさい /未決済/
みけってい /未決定/
みけつ /未決/
みけねこ /三毛猫/
みけん /眉間/未見/
みけんしゅつ /未検出/
みけんせつ /未建設/
みけんとう /未検討/
みこ /美子/御子/巫女/巫/
みこう /未稿/
みこうかい /未公開/
みこうかいきょく /未公開曲/
みこうにゅう /未購入/
みこころ /御心/
みこし /御輿/
みこしば /御子柴/
みこと /美琴/尊/命/
みことのり /詔/勅/敕/
みことば /御言葉/
みこみ /見込み/見込/
みこみがく /見込額/
みこん /未婚/
みこんしゃ /未婚者/
みこんじょせい /未婚女性/
みごしらえ /身拵え/
みごたえ /見応え/
みごと /見事/
みごろ /見頃/
みさ /美佐/美砂/美沙/美紗/未沙/魅紗/
みさい /未済/
みさいぶん /未済分/
みさいる /ミサイル/
みさお /美沙緒/操/
みさか /御坂/三阪/
みさかい /見境/
みさき /岬/三崎/御前/美咲/美沙紀/三咲/
みさきぐち /三崎口/
みさきこう /三崎港/
みさきちょう /三崎町/
みさくせい /未作成/
みさくぼ /水窪/
みさこ /美佐子/美沙子/美砂子/美咲子/
みさご /鶚/
みささ /三笹/三篠/三朝/
みささぎ /御陵/陵/山陵/
みさと /美里/三郷/美郷/箕郷/
みさとし /三郷市/
みさとしはつ /三郷始発/
みさわ /三澤/三沢/
みさわえき /三沢駅/
みさわし /三沢市/
みさわやま /実沢山/
みしお /美潮/
みしきべつ /未識別/
みしこう /未施行/
みしな /三品/
みしま /三島/三嶋/
みしまえき /三島駅/
みしまし /三島市/
みしまたいしゃ /三嶋大社/
みしまたまち /三島田町/
みしまていしゃ /三島停車/
みしまはつ /三島発/
みしまひろこうじ /三島広小路/
みしまひろこうじえき /三島広小路駅/
みしまふつかまち /三島二日町/
みしまゆきお /三島由紀夫/
みしゅう /未収/
みしゅうきん /未収金/未集金/
みしゅうけいひょう /未集計票/
みしゅうせい /未修正/
みしゅうり /未修理/
みしゅうろく /未収録/
みしゅうろくきょく /未収録曲/
みしゅうろくさくひん /未収録作品/
みしゅうろくぶん /未収録分/
みしゅく /三宿/
みしゅっそう /未出走/
みしゅっそうば /未出走馬/
みしゅつげん /未出現/
みしゅとく /未取得/
みしょう /御荘/未詳/
みしょうか /未消化/
みしょうにん /未承認/
みしょうり /未勝利/
みしょうりせん /未勝利戦/
みしょうりば /未勝利馬/
みしょきか /未初期化/
みしょぶん /未処分/
みしょり /未処理/
みしよう /未使用/
みしようくかん /未使用区間/
みしようしんぴん /未使用新品/
みしようじ /未使用時/
みしようひん /未使用品/
みしようぶん /未使用分/
みしようへんすう /未使用変数/
みしようりょういき /未使用領域/
みしん /ミシン/
みしんせんか /未芯線化/
みじか /身近/
みじたく /身支度/身仕度/
みじっし /未実施/
みじっそう /未実装/
みじゅく /未熟/
みじゅくじ /未熟児/
みじゅくもの /未熟者/
みじゅこう /未受講/
みじゅつかんあんない /美術館案内/
みじん /微塵/
みじんこ /微塵子/
みす /ミス/三栖/簾/
みすい /未遂/
みすいざい /未遂罪/
みすえ /三末/御末/
みすか /美須賀/
みすがた /御姿/
みすぎ /美杉/
みすぎいそ /三杉磯/
みすぎさと /三杉里/
みすず /美鈴/三鈴/
みすぷり /ミスプリ/
みすみ /三角/三隅/
みず /水/瑞/
みずあか /水垢/
みずあげ /水揚げ/
みずあび /水浴び/
みずあめ /水飴/
みずあらい /水洗い/
みずい /水井/
みずいけ /水池/
みずいで /水出/
みずいらず /水入らず/
みずいろ /水色/
みずいろじだい /水色時代/
みずうみ /湖/
みずうみふきん /湖付近/
みずえ /水絵/瑞江/
みずお /瑞男/瑞生/
みずおけ /水桶/
みずおと /水音/
みずかき /蹼/水掻き/
みずかけろん /水掛論/
みずかげん /水加減/
みずかさ /水かさ/
みずかみ /水上/
みずから /自ら/
みずかわ /水川/
みずがかり /水掛/
みずがき /水柿/
みずがめ /水瓶/
みずがめざ /水瓶座/
みずき /水木/水樹/瑞季/美寿紀/未図紀/
みずきり /水切り/
みずぎ /水着/
みずぎすがた /水着姿/
みずぎたいかい /水着大会/
みずぎわ /水際/
みずくさ /水草/
みずくぼ /水窪/
みずくぼこ /水窪湖/
みずぐち /水口/
みずけ /水気/
みずけむり /水煙/
みずげい /水芸/
みずこ /水子/
みずこし /水越/
みずさき /水先/水崎/
みずさきにん /水先人/
みずさきにんじょうせん /水先人乗船/
みずさし /水差し/
みずさわ /水沢/水澤/
みずさわけいば /水沢競馬/
みずさわけいばじょう /水沢競馬場/
みずさわし /水沢市/
みずさわぼたる /水沢蛍/
みずし /瑞史/
みずしげん /水資源/
みずしぶき /水飛沫/
みずしま /水島/水嶋/水嶌/水縞/
みずしましんじ /水島新司/
みずしまや /水島屋/
みずしょうばい /水商売/
みずしらず /見ず知らず/
みずしろ /水城/
みずせ /水瀬/
みずせつやく /水節約/
みずせん /水栓/
みずぜき /水関/
みずた /水田/
みずたに /水谷/
みずたま /水玉/
みずたまもよう /水玉模様/
みずたまり /水溜/水溜まり/
みずだこ /水蛸/
みずち /蛟/
みずてきりょう /水適量/
みずてん /不見転/不見点/
みずでっぽう /水鉄砲/
みずとり /水鳥/
みずどけい /水時計/
みずなし /水無/水梨/
みずなみ /瑞浪/
みずに /水煮/
みずぬき /水抜/
みずぬま /水沼/
みずの /水野/
みずのあわ /水の泡/
みずのえ /壬/
みずのえいぬ /壬戌/
みずのえうま /壬午/
みずのえき /水野駅/
みずのえさる /壬申/
みずのえたつ /壬辰/
みずのえとら /壬寅/
みずのえね /壬子/
みずのきえき /水軒駅/
みずのけん /水野研/
みずのと /癸/
みずのとい /癸亥/
みずのとう /癸卯/
みずのとうし /癸丑/
みずのととり /癸酉/
みずのとひつじ /癸未/
みずのとみ /癸巳/
みずのみ /水飲み/
みずのもり /水の森/
みずはし /水橋/
みずはら /水原/
みずば /水場/
みずばしら /水柱/
みずひき /水引/
みずひと /瑞史/
みずひろ /瑞洋/
みずびたし /水浸し/
みずぶそく /水不足/
みずぶろ /水風呂/
みずぶんし /水分子/
みずべ /水辺/
みずほ /瑞穂/
みずほきゅうぎじょう /瑞穂球技場/
みずほきょうぎじょう /瑞穂競技場/
みずほせいさくしょ /瑞穂製作所/
みずぼうそう /水疱瘡/
みずま /三瀦/水間/
みずまき /水巻/水撒き/
みずまくら /水枕/
みずまし /水増し/水増/
みずまち /水町/
みずむし /水虫/
みずもと /水本/
みずもり /水杜/
みずやま /水山/
みずよ /瑞代/
みずら /髻/鬟/
みずわり /水割り/
みせ /店/壥/廛/三瀬/
みせいじゅく /未成熟/
みせいじゅくらん /未成熟卵/
みせいせい /未生成/
みせいねん /未成年/
みせいねんしゃ /未成年者/
みせいねんじだい /未成年時代/
みせいび /未整備/
みせいり /未整理/
みせかた /見せ方/
みせがね /見せ金/
みせがまえ /店構え/
みせがわ /店側/
みせこう /未施行/
みせさき /店先/
みせじたい /店自体/
みせじまい /店じまい/店仕舞/
みせす /ミセス/
みせってい /未設定/
みせつぞく /未接続/
みせば /見せ場/
みせばん /店番/
みせばんごう /店番号/
みせびらき /店開き/
みせもの /見せ物/見世物/
みせや /店屋/
みせんげん /未宣言/
みせんたく /未選択/
みぜに /身銭/
みぜん /未然/
みそ /味噌/ミソ/三十/晦/
みそあじ /味噌味/
みそう /未送/
みそか /晦日/晦/三十日/
みそかつ /味噌カツ/
みそぎ /禊/
みそくてい /未測定/
みそくばく /未束縛/
みそさざい /鷦鷯/
みそしょうゆ /味噌醤油/
みそしる /味噌汁/
みそじ /三十路/
みそっかす /味噌っ滓/
みそに /味噌煮/
みそにこみ /味噌煮込/
みその /美薗/御園/三園/
みそひともじ /三十一文字/
みそまめ /味噌豆/
みそら /美空/身空/
みそらひばり /美空ひばり/
みそんじ /見損じ/
みぞ /溝/渠/
みぞい /溝井/
みぞう /未曾有/
みぞうえ /溝上/
みぞうち /溝内/
みぞおち /鳩落ち/
みぞぐち /溝口/
みぞた /溝田/
みぞて /溝手/
みぞのくち /溝の口/
みぞはし /溝端/
みぞぶち /溝渕/溝淵/
みぞべ /溝辺/
みぞれ /霙/
みた /三田/美田/見田/
みたいおう /未対応/
みたいおうきじ /未対応記事/
みたいおうきのう /未対応機能/
みたいけん /未体験/
みたいけんしゃ /未体験者/
みたいしゅうか /未大衆化/
みたいしょ /未対処/
みたえき /三田駅/
みたか /三鷹/
みたかいとう /三鷹以東/
みたかえき /三鷹駅/
みたかかん /三鷹間/
みたかきんぺん /三鷹近辺/
みたかし /三鷹市/
みたかしおおさわ /三鷹市大沢/
みたかしざいじゅう /三鷹市在住/
みたかしやくしょまえ /三鷹市役所前/
みたかしょうぼうしょ /三鷹消防署/
みたかせん /三鷹線/
みたかはつ /三鷹発/
みたかん /三田間/
みたがわ /三田川/
みたけ /身丈/御嵩/三岳/三嶽/御岳/
みたこうぎょう /三田工業/
みたさいぜんやさい /三田祭前夜祭/
みたせん /三田線/
みたて /見立て/
みたに /三谷/見谷/
みたにほうしき /三谷方式/
みたび /三度/
みたま /三珠/
みたむら /三田村/
みため /見た目/
みたよしこ /三田佳子/
みたらい /御手洗/
みたんさく /未探索/
みだ /弥陀/
みだい /見台/
みだし /見出し/＊/◇/■/※/
みだしご /見出し語/
みだしなみ /身だしなみ/身嗜み/
みだら /婬/
みだれ /乱れ/
みだれがみ /乱れ髪/
みち /道/路/未知/通/美知/倫/蹊/謐/途/
みちあき /通晃/通明/道明/道朗/
みちあんない /道案内/
みちいと /道糸/
みちうえ /道上/
みちえ /道恵/美智恵/
みちお /道生/道夫/通夫/道男/道雄/三千夫/三千雄/道央/
みちおんせい /未知音声/
みちか /美智香/
みちがい /見違い/
みちがみ /道上/
みちがわ /道側/
みちくさ /道草/
みちこ /路子/美智子/道子/美千子/通子/光知子/倫子/満子/三智子/美知子/
みちご /未知語/
みちさと /満里/
みちしお /満ち潮/
みちしるべ /道標/
みちじゅん /道順/
みちすう /未知数/
みちすじ /道筋/
みちぞい /道沿/
みちた /道田/
みちたか /命孝/通隆/道隆/充隆/
みちたろう /道太郎/美知太郎/
みちつた /道蔦/
みちづれ /道連れ/
みちとし /通敏/
みちなり /道成/途也/道也/
みちにし /道西/
みちにゅうりょく /未知入力/
みちのく /陸奥/
みちのり /道のり/道程/
みちはば /道幅/
みちはら /道原/
みちはる /亨治/道春/
みちば /道場/
みちばた /道端/道傍/
みちばろくさぶろう /道場六三郎/
みちひこ /導彦/
みちひで /通秀/
みちひろ /道弘/通洋/道宏/倫洋/通博/道洋/倫広/道広/
みちへんすう /未知変数/
みちみち /道々/
みちむこ /道向/
みちむら /道村/
みちゃく /未着/
みちゃくしゅ /未着手/
みちゃくよう /未着用/
みちゃくようしゃ /未着用者/
みちゆき /道行/
みちょう /未聴/
みちょうか /未超過/
みちょうさ /未調査/
みちよ /美智代/路代/美千世/通代/美千代/道代/道世/三千代/満代/
みちよし /道由/
みちる /未散/未知瑠/
みちろう /道郎/
みちわしゃ /未知話者/
みぢか /身近/
みっか /三日/３日/3日/
みっかい /密会/
みっかいち /三日市/
みっかかん /三日間/
みっかてんか /三日天下/
みっかび /三ケ日/三ヶ日/
みっかびちょう /三ケ日町/
みっかぼうず /三日坊主/
みっかみばん /三日三晩/
みっかめ /三日目/
みっきょう /密教/
みっきょうきょうてん /密教経典/
みっきょうじてん /密教辞典/
みっきょうだいじてん /密教大辞典/
みっくす /ミックス/
みっこう /密航/
みっこうしゃ /密航者/
みっこく /密告/
みっし /密使/
みっしつ /密室/
みっしつけんてい /密室検定/
みっしつせい /密室性/
みっしつせいじてき /密室政治的/
みっしつぶつ /密室物/
みっしゅう /密集/
みっしゅうたい /密集体/
みっしょ /密書/
みっせい /密生/
みっせつ /密接/
みっせん /密栓/
みっそう /密葬/密送/
みっちゃく /密着/
みっちゃくけいしき /密着形式/
みっちゃくせい /密着性/
みっちゃくど /密着度/
みっちゃくれんけつき /密着連結器/
みっつ /３つ/三つ/3つ/
みっつう /密通/
みっつめ /三つめ/
みってい /密偵/
みっぷう /密封/
みっぷうほうそう /密封包装/
みっぷうようき /密封容器/
みっぺい /密閉/密蔽/
みっぺいがた /密閉型/
みっぺいけい /密閉型/
みっぺいしき /密閉式/
みっぺいじょうたい /密閉状態/
みっぺいせい /密閉性/
みっぺいど /密閉度/
みっぺいようき /密閉容器/
みつ /密/蜜/光/三/満/充/円/櫁/滿/謐/
みつあき /光昭/光明/光璋/充璋/充章/
みつい /三井/
みついぎんこう /三井銀行/
みついけんせつ /三井建設/
みついこうざん /三井鉱山/
みついし /三石/三ッ石/
みついじょうほうかいはつ /三井情報開発/
みついせいとう /三井製糖/
みついせきか /三井石化/
みついせきゆかがく /三井石油化学/
みついそうこ /三井倉庫/
みついぞうせん /三井造船/
みついとうあつかがく /三井東圧化学/
みついふとう /三井埠頭/
みついふどうさん /三井不動産/
みついぶっさん /三井物産/
みつうん /密雲/
みつえ /光枝/光江/御杖/光恵/
みつお /光雄/光男/光夫/三男/三夫/三雄/充雄/満夫/満雄/満男/光生/光穂/
みつかいどう /水海道/
みつかげ /光影/
みつかん /蜜柑/
みつがしわもく /Menyanthales/ミツガシワ目/
みつき /美月/観月/
みつぎ /三ッ木/調/密議/三ツ木/
みつぎもの /貢ぎ物/
みつぎょうれつ /密行列/
みつくち /兎唇/
みつぐ /貢/
みつぐみ /三つ組/三組/
みつけ /見付/見附/
みつけつごう /密結合/
みつけつごうがた /密結合型/
みつげつ /蜜月/
みつこ /美津子/三津子/美都子/光子/満子/充子/
みつこし /三越/
みつこしちか /三越地下/
みつこしべっかん /三越別館/
みつこしほんかん /三越本館/
みつこしほんてん /三越本店/
みつこしまえ /三越前/
みつこしまええき /三越前駅/
みつこしまえゆき /三越前行/
みつご /三子/
みつさと /満里/
みつざわ /光澤/
みつしま /美津島/満島;姓/
みつじ /光地/
みつせ /三瀬/光瀬/
みつせりゅう /光瀬龍/
みつせん /蜜腺/
みつぞう /密造/
みつた /光田/
みつたか /充隆/
みつたけ /光威/満武/
みつだ /光田/満田/
みつだん /密談/
みつつじ /光辻/
みつづか /三塚/
みつてる /光輝/充照/
みつてん /密天/
みつとし /光俊/光年/充敏/
みつとも /三友/
みつど /密度/
みつどかんすう /密度関数/
みつどせいそう /密度成層/
みつどぶんぷ /密度分布/
みつどもえ /三つ巴/
みつどやくそう /密度躍層/
みつなが /光永/満永/
みつなり /三成/実成/光成/
みつにゅうこく /密入国/
みつのぶ /光信/光伸/光延/
みつのり /光紀/充則/光徳/
みつはし /三橋/三ツ橋/
みつはる /光晴/充治/
みつば /三葉/
みつばい /密売/
みつばち /蜜蜂/
みつひこ /光彦/美比古/
みつひさ /充久/三久/
みつひで /光秀/
みつひろ /光博/円博/光弘/充宏/充博/満弘/光浩/光宏/光裕/充弘/充浩/満浩/充洋/
みつびし /三菱/
みつびしうらわ /三菱浦和/
みつびしえんぴつ /三菱鉛筆/
みつびしかがく /三菱化学/
みつびしかこうき /三菱化工機/
みつびしかせい /三菱化成/
みつびしきんぞく /三菱金属/
みつびしぎんこう /三菱銀行/
みつびしけい /三菱系/
みつびししょうじ /三菱商事/
みつびしじかわさき /三菱自川崎/
みつびしじこうきょうと /三菱自工京都/
みつびしじしょ /三菱地所/
みつびしじどうしゃ /三菱自動車/
みつびしじみずしま /三菱自水島/
みつびしじゅうこう /三菱重工/
みつびしじゅうこうぎょう /三菱重工業/
みつびしじゅし /三菱樹脂/
みつびしせい /三菱製/
みつびしせいこう /三菱製鋼/
みつびしせいし /三菱製紙/
みつびしせきゆ /三菱石油/
みつびしそうけん /三菱総研/
みつびしそうこ /三菱倉庫/
みつびしでんき /三菱電機/
みつびしでんきさんぎょう /三菱電機産業/
みつびしでんきさんけん /三菱電機産研/
みつびしはつ /三菱初/
みつびしゆか /三菱油化/
みつびしれいよん /三菱レイヨン/
みつぶつ /密勿/
みつぼし /三っ星/三星/三ッ星/
みつぼしべると /三ツ星ベルト/
みつまさ /光政/光正/光雅/
みつまた /三椏/
みつまたやり /三又槍/
みつまめ /蜜豆/
みつめ /三っ目/
みつめい /密命/
みつもと /光本/
みつもり /見積もり/見積り/見積/三森/
みつもりしょ /見積書/
みつや /三矢/三ッ矢/
みつやく /密約/
みつゆ /密輸/
みつゆき /光之/三幸/充之/
みつゆしゅつ /密輸出/
みつゆせん /密輸船/
みつゆにゅう /密輸入/
みつゆび /三ッ指/
みつよ /光代/
みつよし /光義/
みつりょう /密漁/密猟/
みつりょうしゃ /密猟者/密漁者/
みつりん /密林/
みつる /充/満/美弦/滿/
みつろう /光郎/蜜蝋/
みつわ /三輪/
みづ /美津/
みづき /観月/
みづきしょぼう /三月書房/
みづち /蛟/
みづの /美津濃/
みてい /未定/
みていぎ /未定義/
みていぎご /未定義語/
みていぎへんすう /未定義変数/
みていぎめいれい /未定義命令/
みていぎようご /未定義用語/
みていけいすう /未定係数/
みていけいすうほう /未定係数法/
みていしゅつ /未提出/
みていち /未定値/
みてくれ /見て呉れ/
みと /水戸/御津/三戸/美都/弥刀/
みといずみ /水戸泉/
みとう /未踏/美東/
みとうこう /未投稿/
みとうさい /未搭載/
みとうちゃく /未到着/
みとうりょういき /未踏領域/
みとうろく /未登録/
みとうろくしゃ /未登録者/
みとうわくせい /未踏惑星/
みとえき /水戸駅/
みとおし /見通し/
みとかいどう /水戸街道/
みとけ /水戸家/
みとげいじゅつかん /水戸芸術館/
みとこうもん /水戸黄門/
みところ /三所/
みところぜめ /三所攻め/
みとさんこう /水戸三高/
みとし /水戸市/
みとしょうけん /水戸証券/
みとせ /三年/
みとせいぶ /水戸西武/
みとせん /水戸線/
みとそう /未塗装/
みとどけやく /見届け役/
みとなっとう /水戸納豆/
みとにこう /水戸二高/
みとみ /三富/
みとめ /三留/
みとめいん /認め印/
みとや /三刀屋/
みとよ /三豊/
みとり /見取/
みとりず /見取図/見取り図/
みどう /御堂/
みどうかいかん /御堂会館/
みどうすじ /御堂筋/
みどうすじせん /御堂筋線/
みどうすじほんまち /御堂筋本町/
みどく /未読/
みどくきじ /未読記事/
みどくきじすう /未読記事数/
みどくにゅうりょく /未読入力/
みどくぶん /未読分/
みどころ /見どころ/見所/
みどし /巳年/
みどり /緑/美登里/ミドリ/翠/碧/美土里/
みどりいろ /緑色/
みどりかい /緑会/
みどりかわ /緑川/
みどりがおか /緑ケ丘/緑ヶ丘/緑が岡/緑が丘/
みどりく /緑区/
みどりご /嬰児/
みどりじゅうじ /ミドリ十字/
みどりちょう /緑町/
みどりでんし /緑電子/
みどりまち /緑町/
みどりまめ /緑豆/
みどりみ /緑味/
みどりや /緑屋/
みどりやま /緑山/
みどりやまこうこう /緑山高校/
みどろいけ /深泥池/
みどろがいけ /深泥池/
みな /皆/美奈/美那/美菜/
みない /南井/美内/
みないっしょ /皆一緒/
みなえ /美奈江/
みなおし /見直し/
みなかた /皆方/
みなかたくまぐす /南方熊楠/
みなかみ /水上/
みなかみおんせん /水上温泉/
みなかみしゅうへん /水上周辺/
みなかわ /皆川/
みながわ /皆川/
みなきょうだい /皆兄弟/
みなくち /水口/
みなぐち /皆口/源口/
みなげ /身投げ/
みなこ /美奈子/皆子/三奈子/美菜子/美名子/みな子/実奈子/
みなごろし /皆殺し/
みなさま /皆様/
みなさまがた /皆様方/
みなさん /皆さん/
みなつ /美夏/
みなつき /水無月/
みなづき /水月/水無月/
みなと /港/湊/
みなとおおはし /港大橋/
みなとがわ /湊川/
みなとがわこうえん /湊川公園/
みなときたく /港北区/
みなとく /港区/
みなとくあざぶだい /港区麻布台/
みなとくしろがねだい /港区白金台/
みなとくみた /港区三田/
みなとくみなみあおやま /港区南青山/
みなとくみなみあざぶ /港区南麻布/
みなとせいき /港製機/
みなとふじ /湊富士/
みなとまち /港町/湊町/港街/
みなとみなみぐち /港南口/
みなの /皆野/
みなびょうどう /皆平等/
みなべ /南部/
みなべがわ /南部川/
みなまた /水俣/
みなまたし /水俣市/
みなみ /南/南美/美波/皆実/美並/三波/
みなみあいづ /南会津/
みなみあおやま /南青山/
みなみあきた /南秋田/
みなみあざぶ /南麻布/
みなみあしがら /南足柄/
みなみあしがらし /南足柄市/
みなみあずみ /南安曇/
みなみあべかわばし /南安倍川橋/
みなみあまべ /南海部/
みなみありま /南有馬/
みなみいず /南伊豆/
みなみいばらき /南茨木/
みなみうおぬま /南魚沼/
みなみうらわ /南浦和/
みなみうわ /南宇和/
みなみおおさかせん /南大阪線/
みなみおおさわ /南大沢/
みなみおおさわえき /南大沢駅/
みなみおおつか /南大塚/
みなみおおつかこうえん /南大塚公園/
みなみおおゆうばりてつどう /南大夕張鉄道/
みなみおぎしま /南荻島/
みなみおぐに /南小国/
みなみおたり /南小谷/
みなみかぜ /南風/
みなみかた /南方/
みなみかやべ /南茅部/
みなみかるいざわ /南軽井沢/
みなみかわ /南河/
みなみかわち /南河内/
みなみかん /南舘/南館/
みなみかんとう /南関東/
みなみかんとうぜい /南関東勢/
みなみかんとうべん /南関東弁/
みなみかんとうほうげん /南関東方言/
みなみかんのんざん /南観音山/
みなみかんばら /南蒲原/
みなみがわ /南側/
みなみきゅうしゅう /南九州/
みなみく /南区/
みなみくしやま /南串山/
みなみくしやまちょう /南串山町/
みなみくまもとえきまえ /南熊本駅前/
みなみぐち /南口/
みなみぐちほうめん /南口方面/
みなみこいずみ /南小泉/
みなみこま /南巨摩/
みなみごたんばえき /南御殿場駅/
みなみさいたま /南埼玉/
みなみさおり /南沙織/
みなみさく /南佐久/
みなみしが /南志賀/
みなみしこく /南四国/
みなみしたら /南設楽/
みなみしなの /南信濃/
みなみしまばら /南島原/
みなみしゃめん /南斜面/
みなみじゅうじせい /南十字星/
みなみせん /南線/
みなみたいへいよう /南太平洋/
みなみたか /南高/
みなみたかき /南高来/
みなみたかぎ /南高来/
みなみたかさき /南高崎/
みなみたま /南多摩/
みなみたまえき /南多摩駅/
みなみたまち /南田町/
みなみたまほうめん /南多摩方面/
みなみだ /南田/
みなみだい /南台/
みなみだいとう /南大東/
みなみだいとうじま /南大東島/
みなみだか /南高/
みなみだて /南館/
みなみちいき /南地域/
みなみちく /南地区/
みなみちしま /南千島/
みなみちた /南知多/
みなみちとせ /南千歳/
みなみちょう /南町/
みなみちょうせん /南朝鮮/
みなみちょうせんご /南朝鮮語/
みなみつがる /南津軽/
みなみつる /南都留/
みなみで /南出/
みなみでわ /南出羽/
みなみとうきょう /南東京/
みなみとうほく /南東北/
みなみとうほくちほう /南東北地方/
みなみなか /南那珂/
みなみなさま /皆皆様/
みなみなす /南那須/
みなみの /南野/
みなみのかわち /南河内/
みなみはっこうだ /南八甲田/
みなみはるお /三波春夫/
みなみはんきゅう /南半球/
みなみはんきゅうぜい /南半球勢/
みなみはんぶん /南半分/
みなみひろしまし /南広島市/
みなみふくおか /南福岡/
みなみふなばし /南船橋/
みなみふなばしのりかえ /南船橋乗換/
みなみふらの /南富良野/
みなみべっぷ /南別府/
みなみほっかいどう /南北海道/
みなみほんしゅく /南本宿/
みなみほんじゅくでぐち /南本宿出口/
みなみほんちょう /南本町/
みなみぼうそう /南房総/
みなみまき /南牧/
みなみまち /南町/
みなみまちだ /南町田/
みなみまつうら /南松浦/
みなみまわり /南回り/
みなみまんしゅうてつどう /南満州鉄道/
みなみみのわ /南箕輪/
みなみみやざき /南宮崎/
みなみみやざきかん /南宮崎間/
みなみむき /南向き/
みなみむれ /南牟礼/
みなみむろ /南牟婁/
みなみもと /南本/
みなみもとまち /南元町/
みなみもりまち /南森町/
みなみもん /南門/
みなみやましろ /南山城/
みなみやまて /南山手/
みなみゆき /南行/
みなみゆふ /南由布/
みなみゆふえき /南由布駅/
みなみよの /南与野駅/
みなみりんかん /南林間/
みなみわっかない /南稚内/
みなも /水面/
みなもと /源/
みなもとけ /源家/
みなもとのよりとも /源頼朝/
みなもとよしつね /源義経/
みなもとよりよし /源頼義/
みなよ /美奈代/
みならい /見習/見習い/
みならいこう /見習工/
みなり /身なり/身形/
みなわ /水泡/
みに /ミニ/
みにこん /ミニコン/
みにまむ /ミニマム/
みにゅうしゅ /未入手/
みにゅうりょく /未入力/
みね /峯/峰/嶺/美禰/美祢/美根/岑/三根/三子/
みねい /嶺井/
みねうち /峰打ち/
みねお /岑生/岑夫/実音夫/峯夫/峰雄/
みねぎし /峰岸/峯岸/嶺岸/
みねこ /峰子/
みねごし /峰越/
みねざき /峯崎/
みねの /峯野/
みねのはら /峰の原/
みねはま /峰浜/
みねひさ /峰久/
みねまつ /峰松/
みねむら /峯村/峰村/
みねやま /峰山/
みねゆき /峰幸/
みねんしょう /未燃焼/
みの /美濃/蓑/箕/三野/簑/簔/
みのう /未納/箕面/美濃/
みのうえ /身の上/
みのうしゃ /未納者/
みのうにゅう /未納入/
みのうぶん /未納分/
みのうら /箕浦/
みのお /箕面/美濃/
みのおおた /美濃太田/
みのおせん /箕面線/
みのかも /美濃加茂/
みのけ /身の毛/
みのげ /蓑毛/
みのしま /箕島/
みのしょう /美濃庄/
みのしろきん /身代金/
みのだ /箕田/蓑田/簑田/
みのと /美濃戸/
みのとぐち /美濃戸口/
みのはた /蓑畑/
みのはら /箕原/蓑原/
みのぶ /美乃夫/身延/
みのぶさん /身延山/
みのぶせん /身延線/
みのぶせんけいゆ /身延線経由/
みのべ /美濃部/
みのほど /身の程/
みのほどしらず /身の程知らず/
みのまわり /身の回り/
みのむし /蓑虫/
みのり /稔/美野里/実り/御法/
みのる /稔/實/実/穣/
みのわ /箕輪/蓑輪/
みはい /未配/
みはかし /御刀/
みはし /三橋/
みはた /御旗/
みはっけん /未発見/
みはったつ /未発達/
みはっぴょう /未発表/
みはっぴょうきょく /未発表曲/
みはっぴょうさくひん /未発表作品/
みはっぴょうしゃしん /未発表写真/
みはつばい /未発売/
みはま /美浜/御浜/
みはまく /美浜区/
みはら /三原/美原/
みはらい /未払い/
みはらいきん /未払金/
みはらし /見晴らし/
みはらちょう /美原町/
みはり /見張り/
みはりばん /見張り番/
みはりやく /見張り役/
みはる /美春/美晴/三春/
みはるえき /三春駅/
みばえ /見栄え/見映え/
みばらい /未払/
みばん /三晩/
みひじゅん /未批准/
みひつ /未必/
みひつてき /未必的/
みひら /三平/
みひらき /見開き/
みびいき /身贔屓/
みふしとうげ /三伏峠/
みふじ /美富士/
みふね /三船/御船/
みふねとしろう /三船敏郎/
みぶ /壬生/
みぶり /身振り/身振/見ぶり/
みぶるい /身震い/
みぶん /身分/
みぶんか /未分化/
みぶんしょうごう /身分照合/
みぶんしょうめい /身分証明/
みぶんしょうめいしょ /身分証明書/
みぶんしょうめいしょう /身分証明証/
みぶんそうおう /身分相応/
みぶんふそうおう /身分不相応/
みへんかん /未変換/
みへんとう /未返答/
みほ /三保/美穂/美豊/美保/海蜂/実穂/美帆/美歩/美峰/美浦/
みほうえい /未放映/
みほうしゃ /未放射/
みほうそう /未放送/
みほこ /美保子/美穂子/三穂子/美帆子/
みほしょう /未保証/
みほぜき /美保関/
みほそう /未舗装/
みほそうくかん /未舗装区間/
みほそうどうろ /未舗装道路/
みほそうろ /未舗装路/
みほぞん /未保存/
みほた /三保田/
みほとけ /御仏/
みほろ /美浦/
みほん /見本/
みほんいち /見本市/
みほんいちかいじょう /見本市会場/
みほんし /見本誌/
みほんちょう /見本帳/
みほんひん /見本品/
みぼうじん /未亡人/
みま /美馬/三間/
みまい /見舞い/見舞/
みまいきん /見舞金/
みまき /御牧/
みまさか /美作/
みまた /三股/
みまちがい /見間違い/
みまっしょう /未抹消/
みまつ /三松/
みまね /見まね/見真似/
みまわし /見廻し/
みまわりひん /見回品/
みまん /未満/
みみ /耳/
みみあか /耳垢/
みみいがい /耳以外/
みみうち /耳打ち/耳打/
みみかざり /耳飾/
みみがくもん /耳学問/
みみがた /耳型/
みみしっかん /耳疾患/
みみず /蚯蚓/ミミズ/
みみずく /木莵/
みみせん /耳栓/耳詮/
みみせんよう /耳栓用/
みみたぶ /耳朶/
みみどしま /耳年増/
みみないぶ /耳内部/
みみなり /耳鳴り/耳鳴/
みみにゅうりょく /耳入力信号/
みみにゅうりょくしんごう /耳入力信号/
みみぬき /耳抜/
みみぶくろ /耳袋/
みみもちしだぞく /Acrostichum/ミミモチシダ属/
みみもと /耳許/耳元/
みみわ /耳輪/
みむ /美夢/
みむら /三村/
みむろ /三室/
みめ /美芽/見目/眉目/
みめい /未明/
みもち /身持/
みもと /身元/
みもとかくにん /身元確認/
みもとちょうさ /身元調査/
みもの /見物/
みもり /未森/深森/
みもりまる /美森丸/
みもん /未聞/
みゃく /脈/脉/
みゃくあつ /脈圧/
みゃくけい /脈系/
みゃくどう /脈動/
みゃくはく /脈拍/脈搏/
みゃくはくすう /脈拍数/
みゃくみゃく /脈脈/
みゃくらく /脈絡/
みゃくりゃく /脈略/
みゃくりゅう /脈流/
みや /宮/美弥/
みやい /宮井/
みやいだい /宮医大/
みやいり /宮入/
みやうち /宮内/
みやえき /宮駅/
みやお /宮尾/
みやおか /宮岡/
みやおそうか /ミヤオソウ科/Podophyllaceae/
みやおとみこ /宮尾登美子/
みやかわ /宮川/
みやがく /宮学/
みやがわ /宮川/
みやき /宮木/
みやきょう /宮教/
みやきょうだい /宮教大/宮城教育大学/
みやぎ /宮城/
みやぎがくいん /宮城学院/
みやぎがくいんだい /宮城学院大/
みやぎきょういくだい /宮城教育大/
みやぎけん /宮城県/
みやぎけんせんだいし /宮城県仙台市/
みやぎけんちく /宮城県地区/
みやぎけんみんかいかん /宮城県民会館/
みやぎこうせん /宮城高専/
みやぎざおう /宮城蔵王/
みやぎしま /宮城島/
みやぎだいいちじょし /宮城第一女子/
みやぎの /宮城野/
みやぎのかもつせん /宮城野貨物線/
みやぎのく /宮城野区/
みやくに /宮国/
みやくぼ /宮窪/
みやくら /宮倉/
みやぐち /宮口/
みやけ /三宅/
みやけいっせい /三宅一生/
みやけざか /三宅坂/
みやけじま /三宅島/
みやげ /土産/
みやげばなし /土産話/
みやげひん /土産品/
みやげもの /土産物/
みやげものてん /土産物店/
みやげものや /土産物屋/
みやげや /土産屋/
みやげよう /土産用/
みやこ /都/宮古/宮戸/宮子/美也子/美弥子/京都/
みやこう /宮交/
みやこおち /都落ち/
みやこけいゆ /宮古経由/
みやこじ /都路/
みやこじま /都島/宮古島/
みやこのじょう /都城/
みやこびと /都人/
みやこわん /宮古湾/
みやご /三八五/
みやごし /宮越/
みやさか /宮坂/
みやさと /宮里/
みやざき /宮崎/
みやざきおき /宮崎沖/
みやざきかん /宮崎間/
みやざきくうこう /宮崎空港/
みやざきくうこうえき /宮崎空港駅/
みやざきけん /宮崎県/宮崎研/
みやざきけんしゅっしん /宮崎県出身/
みやざきけんみん /宮崎県民/
みやざきしゅっしんしゃ /宮崎出身者/
みやざきじどうしゃどう /宮崎自動車道/
みやざきだい /宮崎大/宮崎台/
みやざきだいがく /宮崎大学/
みやざきちく /宮崎地区/
みやざきどう /宮崎道/
みやざきはやお /宮崎駿/
みやざきもの /宮崎物/
みやざと /宮里/
みやざわ /宮澤/宮沢/
みやざわきいち /宮沢喜一/
みやざわけんじ /宮沢賢治/
みやざわせいけん /宮沢政権/
みやざわないかく /宮沢内閣/
みやざわばし /宮沢橋/
みやした /宮下/
みやしたこうえん /宮下公園/
みやしの /宮篠/
みやしろ /宮代/
みやじ /宮地/宮路/
みやじま /宮嶋/宮島/
みやじまこうろ /宮島航路/
みやじません /宮島線/
みやじょう /宮絛/
みやずみ /宮住/
みやせ /宮瀬/
みやせん /美祢線/
みやぞえ /宮副/
みやぞの /宮苑/
みやた /宮田/
みやたけ /宮竹/宮武/
みやたに /宮谷/
みやだい /宮大/
みやだいく /宮大工/
みやち /宮地/
みやちよ /宮千代/
みやぢ /宮地/
みやぢてっこうしょ /宮地鐵工所/
みやづ /宮津/
みやづかえ /宮仕え/
みやづせん /宮津線/
みやと /宮戸/
みやなが /宮永/
みやなぎ /三柳/
みやの /宮野/
みやのうえ /宮之上/
みやのぎ /宮野木/
みやのさわ /宮の沢/
みやのじょう /宮之城/
みやのぼり /宮登/
みやはら /宮原/
みやび /雅/
みやふくせん /宮福線/
みやふくてつどう /宮福鉄道/
みやべ /宮部/
みやま /深山/三山/海山/美山/
みやまえ /宮前/
みやまえく /宮前区/
みやまち /宮町/
みやまちょう /美山町/
みやまる /宮丸/
みやみ /未也美/
みやむら /宮村/
みやもと /宮本/
みやもとけん /宮本研/
みやもとむさし /宮本武蔵/
みやもり /宮森/宮守/
みやら /宮良/
みやわき /宮脇/
みゅー /μ/
みゅーじしゃん /ミュージシャン/
みゅう /μ/
みゆう /美憂/
みゆき /美由紀/美由起/幸/美幸/美雪/深雪/美由希/御幸/美有紀/行幸/
みゆきけおり /御幸毛織/
みゆきせん /美幸線/
みゆにゅう /未輸入/
みょう /妙/名/明/命/冥/榠/螟/
みょうあん /妙案/
みょうおう /明王/
みょうおん /妙音/
みょうおんどおり /妙音通/
みょうが /茗加/茗荷/
みょうがだに /茗荷谷/
みょうぎ /妙技/妙義/
みょうぎさん /妙義山/
みょうけん /妙見/
みょうこう /妙高/
みょうこうあかくら /妙高赤倉/
みょうこうけいゆ /妙高経由/
みょうこうこうげん /妙高高原/
みょうこうざんいき /妙高山域/
みょうごにち /明後日/
みょうしゅ /妙手/
みょうしゅん /明春/
みょうじ /苗字/名字/
みょうじょう /明星/
みょうじょうしょくひん /明星食品/
みょうじん /明神/
みょうぜんじ /妙善寺/
みょうだい /名代/
みょうだに /名谷/
みょうちょう /明朝/
みょうな /妙な/
みょうにち /明日/
みょうねん /明年/
みょうばん /明晩/明礬/
みょうみ /妙味/
みょうやく /妙薬/
みょうり /冥利/名利/
みょうれい /妙齢/
みょうれん /明連/
みょうれんじ /妙蓮寺/
みょうれんじえき /妙蓮寺駅/
みょんどん /明洞/
みよ /美代/御代/
みよう /見様/
みようみまね /見よう見真似/見様見真似/
みよこ /美代子/
みよし /三好/三膳/三善/三吉/三芳/
みよた /御代田/
みよはら /みよ原/
みより /身寄り/
みらい /未来/味蕾/
みらいえいごう /未来永劫/
みらいがく /未来学/
みらいぎじゅつ /未来技術/
みらいけい /未来形/
みらいしこう /未来志向/
みらいしじょう /未来史上/
みらいしゃかい /未来社会/
みらいしょうねん /未来少年/
みらいじん /未来人/
みらいせいき /未来世紀/
みらいせかい /未来世界/
みらいぞう /未来像/
みらいてき /未来的/
みらいとし /未来都市/
みらいにほん /未来日本/
みらいは /未来派/
みらいへん /未来編/
みらいよそうず /未来予想図/
みらいよち /未来予知/
みらくるがーるず /ミラクル☆ガールズ/
みらさか /三良坂/
みらの /未蘭/
みり /ミリ/粍/
みりおんしゅっぱん /ミリオン出版/
みりぐらむ /瓱/
みりめーとる /粍/
みりょう /未了/魅了/
みりょく /魅力/
みりょくてき /魅力的/
みりりっとる /竓/
みりん /味醂/未林/
みりんあじ /味醂味/
みりんかい /未臨界/
みりんかいど /未臨界度/
みる /覩/
みるく /ミルク/
みるめ /見る目/
みれい /美麗/
みれん /未練/
みれんらく /未連絡/
みろく /弥勒/彌勒/
みわ /美和/三輪/三和/巳波/
みわく /魅惑/
みわくてき /魅惑的/
みわけ /見分/
みわこ /美和子/
みわた /三輪田/
みわだ /三輪田/
みわだがくえん /三輪田学園/
みわやま /三輪山/
みん /民/眠/明/ミン/閔/罠/
みんい /民意/
みんいけいせい /民意形成/
みんえい /民営/
みんえいか /民営化/
みんえいかご /民営化後/
みんえいかとうじ /民営化当時/
みんおん /民音/
みんおんかいかん /民音会館/
みんか /民家/
みんかへい /民家塀/
みんかん /民間/明槓/
みんかんかつりょく /民間活力/
みんかんかんきん /民間換金/
みんかんかんきんごや /民間換金小屋/
みんかんかんきんじょう /民間換金場/
みんかんかんきんばしょ /民間換金場所/
みんかんがいしゃ /民間会社/
みんかんきぎょう /民間企業/
みんかんけんこうほけん /民間健康保険/
みんかんこうじょう /民間工場/
みんかんしせつ /民間施設/
みんかんしゅどう /民間主導/
みんかんじん /民間人/
みんかんだんたい /民間団体/
みんかんちりょう /民間治療/
みんかんでんしょう /民間伝承/
みんかんとばく /民間賭博/
みんかんびょういん /民間病院/
みんかんほりょ /民間捕虜/
みんかんりょうほう /民間療法/
みんぎょう /民業/
みんけん /民権/
みんげい /民芸/
みんげいひん /民芸品/
みんげいひんじょうほう /民芸品情報/
みんこう /民航/
みんこく /民国/民國/
みんしゃ /民社/
みんしゃとう /民社党/
みんしゃとういがい /民社党以外/
みんしゅ /民主/
みんしゅう /民衆/
みんしゅか /民主化/
みんしゅかせいさく /民主化政策/
みんしゅかようきゅう /民主化要求/
みんしゅく /民宿/
みんしゅこく /民主国/
みんしゅこっか /民主国家/
みんしゅしゅうちゅうせい /民主集中性/
みんしゅしゅぎ /民主主義/
みんしゅしゅぎかん /民主主義観/
みんしゅしゅぎけんぽう /民主主義憲法/
みんしゅしゅぎこく /民主主義国/
みんしゅしゅぎこっか /民主主義国家/
みんしゅしゅぎしゃ /民主主義者/
みんしゅしゅぎしゃかい /民主主義社会/
みんしゅしゅぎじたい /民主主義自体/
みんしゅしゅぎせいりつ /民主主義成立/
みんしゅしゅぎてき /民主主義的/
みんしゅせい /民主性/
みんしゅせいど /民主制度/
みんしゅてき /民主的/
みんしゅてきい /民主的/
みんしゅてききじゅん /民主的基準/
みんしゅてきじち /民主的自治/
みんしゅてきとうひょう /民主的投票/
みんしゅてきほうほう /民主的方法/
みんしゅとう /民主党/
みんしん /民心/
みんじ /民事/
みんじさいせいほう /民事再生法/
みんじさいばん /民事裁判/
みんじそしょう /民事訴訟/
みんじそしょうほう /民事訴訟法/
みんじてき /民事的/
みんじばいしょう /民事賠償/
みんじふかいにゅう /民事不介入/
みんじゅ /民需/
みんせい /民生/民青/民政/
みんせいき /民生機/
みんせいしじょう /民生市場/
みんせいどうめい /民青同盟/
みんせいひん /民生品/民製品/
みんせいぶ /民生部/
みんせいよう /民生用/
みんせいようき /民生用機/
みんせいようきき /民生用機器/
みんぞく /民族/民俗/
みんぞくいしょう /民族衣装/
みんぞくいどう /民族移動/
みんぞくおんがく /民族音楽/
みんぞくおんがくかんけい /民族音楽関係/
みんぞくおんがくかんしょう /民族音楽鑑賞/
みんぞくかん /民族間/
みんぞくがく /民俗学/民族学/
みんぞくがっき /民族楽器/
みんぞくがみ /民族神/
みんぞくきょういく /民族教育/
みんぞくこっか /民族国家/
みんぞくこんこう /民族混交/
みんぞくご /民族語/
みんぞくごひょうき /民族語表記/
みんぞくしゅぎ /民族主義/
みんぞくしゅっしん /民族出身/
みんぞくじけつ /民族自決/
みんぞくじけつけん /民族自決権/
みんぞくせい /民族性/
みんぞくぜんたい /民族全体/
みんぞくちょう /民族調/
みんぞくてき /民族的/
みんぞくむら /民族村/
みんぞくめい /民族名/
みんたろう /民太郎/
みんたんしゅう /民譚集/
みんだ /民田/
みんち /ミンチ/
みんちょう /明朝/
みんちょうたい /明朝体/
みんちょうたいかつじ /明朝体活字/
みんてつ /民鉄/
みんてつかくしゃ /民鉄各社/
みんてつせん /民鉄線/
みんと /ミント/
みんど /民度/
みんな /皆/皆な/
みんはく /民博/
みんぱく /民博/
みんぶ /民部/
みんぶんか /明文化/
みんぺい /民平/民兵/
みんぽう /民放/民法/
みんぽうかいせい /民法改正/
みんぽうじょう /民法上/
みんぽうだい /民法第/
みんまら /三厩/
みんめいしょぼう /民明書房/
みんゆう /民有/
みんゆうりん /民有林/
みんよう /民謡/
みんようしゅう /民謡集/
みんようふう /民謡風/
みんりょく /民力/
みんわ /民話/
みんわしゅう /民話集/
む /無/霧/夢/務/矛/鵡/牟/六/武/謀/梦/无/毋/
む> /無/
む? /無/
むーど /ムード/
むーみん /夢民/
むあっしゅく /無圧縮/
むあつしき /無圧式/
むあんだ /無安打/
むい /無為/無意/
むいか /６日/六日/6日/
むいかいち /六日市/
むいかまち /六日町/
むいしき /無意識/
むいしきか /無意識下/
むいしきてき /無意識的/
むいしきてきりょういき /無意識的領域/
むいそん /無医村/
むいちもん /無一文/
むいはん /無違反/
むいみ /無意味/
むいみご /無意味語/
むえき /無益/
むえん /無縁/無煙/無鉛/無塩/無援/
むえんか /無煙化/
むえんたばこ /無煙煙草/
むえんたん /無煙炭/
むおう /夢奥/
むおうとう /無応答/
むおん /無音/
むおんくかん /無音区間/
むおんせい /無音声/
むかい /向井/迎/向/向かい/
むかいかぜ /向い風/
むかいがおか /向ケ丘/
むかいがわ /向川/
むかいがわら /向河原/
むかいさつ /無改札/
むかいしま /向島/
むかいぞう /無改造/
むかいたに /向谷/
むかいとう /無回答/
むかいなだ /向洋/
むかいの /向野/
むかいはら /向原/
むかいへん /無改変/
むかいや /向谷/
むかいやま /向山/
むかえ /迎/
むかか /無花果/
むかきゅう /無過給/
むかし /昔/
むかしつ /無過失/
むかしつせきにん /無過失責任/
むかしにほん /昔日本/
むかしばなし /昔話/
むかしふう /昔風/
むかしむかし /昔々/昔昔/
むかじゅう /無荷重/無果汁/
むかち /無価値/
むかっぷかん /占冠間/
むかで /蜈蚣/百足/
むかひ /無花被/
むかべん /無花弁/
むかべんるい /無花弁類/Apetalae/
むかわ /武川/鵡川/
むかん /無冠/無感/
むかんかく /無感覚/
むかんけい /無関係/
むかんさ /無鑑査/
むかんしょう /無干渉/
むかんしん /無関心/
むかんじょう /無感情/
むが /無我/
むがい /無害/無蓋/
むがく /無学/
むがくしゃ /無学者/
むがむちゅう /無我夢中/
むき /向き/無機/無期/無記/牟岐/
むきえ /向江/
むきえん /無機塩/
むきえんき /無期延期/
むきおく /無記憶/
むきおん /無気音/
むきかがく /無機化学/
むきかごうぶつ /無機化合物/
むきかた /剥き方/
むきけい /無機系/
むきげん /無期限/
むきげんきんしん /無期限謹慎/
むきげんゆうこう /無期限有効/
むきざいりょう /無機材料/
むきしつ /無機質/
むきしつてき /無機質的/
むきじょうでんしゃ /無軌条電車/
むきず /無傷/
むきちょうえき /無期懲役/
むきてき /無機的/
むきどう /無軌道/
むきにゅう /無記入/
むきはい /無気肺/
むきはつばいえんき /無期発売延期/
むきぶつ /無機物/
むきめい /無記名/
むきめいとうひょう /無記名投票/
むきゅう /無休/無給/無級/無窮/
むきゅうゆ /無給油/
むきょう /無響/
むきょうしつ /無響室/
むきょうじょうたい /無響状態/
むきょうよう /無教養/
むきょか /無許可/
むきょくせい /無極性/
むきょくせいぶんし /無極性分子/
むきょだく /無許諾/
むきりょく /無気力/
むきん /無菌/
むきんせいずいまくえん /無菌性髄膜炎/
むぎ /麦/牟岐/麥/
むぎくさとうげ /麦草峠/
むぎたに /麦谷/麥谷/
むぎちゃ /麦茶/
むぎばたけ /麦畑/
むぎひと /麦人/
むぎめし /麦飯/
むぎや /麦谷/
むぎゆ /麦湯/
むぎわら /麦藁/麦ワラ/麦わら/
むぎわらぼうし /麦稈帽子/
むく /椋/無垢/向/
むくい /報/
むくげ /槿/毳/葮/
むくだ /椋田/
むくだい /椋代/
むくち /無口/
むくどり /椋鳥/
むくな /椋名/
むくのき /椋木/
むくろ /骸/躯/
むくろじもく /ムクロジ目/Sapindales/
むけ /向/
むけい /無形/無茎/
むけいかく /無計画/
むけいこていしさん /無形固定資産/
むけいぶつ /無形物/
むけってい /無決定/
むけつ /無欠/無血/
むけん /無券/無間/
むけんしき /無見識/
むげ /無碍/無下/
むげい /無芸/
むげいたしゅみ /無芸多趣味/
むげがわ /武芸川/
むげん /無限/∞/夢幻/無幻/
むげんあつ /無限厚/
むげんあつせんすい /無減圧潜水/
むげんえん /無限遠/
むげんえんてん /無限円点/無限遠点/
むげんえんぽう /無限遠方/
むげんかい /無限回/
むげんかいほうけい /無限解放系/
むげんきしゃく /無限希釈/
むげんきどう /無限軌道/
むげんきゅうすう /無限級数/
むげんぎ /無限木/
むげんけい /無限系/
むげんこ /無限個/
むげんこうり /無限公理/
むげんしゅうごう /無限集合/
むげんしょう /無限小/
むげんしょうか /無限小化/
むげんしょうけいさん /無限小計算/
むげんしょうすう /無限小数/
むげんしんし /夢幻紳士/
むげんしんでん /夢幻神殿/
むげんじげん /無限次元/
むげんすうれつ /無限数列/
むげんせい /無限性/
むげんそく /無原則/
むげんぞうしょく /無限増殖/
むげんぞうばいりつ /k$_{inf}$/無限増倍率/
むげんだい /∞/無限大/
むげんちょう /無限長/
むげんてい /無限定/
むげんとうひきゅうすう /無限等比級数/
むげんりすと /無限リスト/
むげんれつ /無限列/
むげんれんさ /無限連鎖/
むげんれんさこう /無限連鎖講/
むげんれんさはんばい /無限連鎖販売/
むこ /婿/無辜/壻/聟/
むこう /無効/向こう/無向/向う/
むこういん /無効印/
むこうか /無効化/
むこうかくにんとうひょう /無効確認投票/
むこうかようきゅう /無効化要求/
むこうかん /無交換/
むこうかんさくせん /無交換作戦/
むこうがい /無公害/
むこうがおか /向ヶ丘/向ケ丘/
むこうがおかゆうえん /向ヶ丘遊園/
むこうじま /向島/
むこうじまえき /向島駅/
むこうじょうめん /向正面/
むこうずね /向こう脛/
むこうせい /無効性/
むこうちょう /向日町/
むこうでんりょく /無効電力/
むこうでんりょくぶん /無効電力分/
むこうとうひょう /無効投票/
むこうひょう /無効票/
むこうまち /向日町/
むこうめいれい /無効命令/
むこうりょう /無香料/
むこがわ /武庫川/婿側/
むこがわうがん /武庫川右岸/
むこがわえき /武庫川駅/
むこがわせん /武庫川線/
むこがわだんち /武庫川団地/
むこくいん /無刻印/
むこくせき /無国籍/
むこくせきじょうたい /無国籍状態/
むこくせきてき /無国籍的/
むこのそう /武庫之荘/
むこようし /婿養子/
むこん /無根/
むこんきょ /無根拠/
むごん /無言/
むごんのぎょう /無言の行/
むさいしょく /無彩色/
むさいしょくこう /無採色光/
むさく /無策/
むさくい /無作為/
むさくいちゅうしゅつ /無作為抽出/
むさし /武蔵/
むさしいつかいち /武蔵五日市/
むさしいつかいちいき /武蔵五日市行/
むさしいつかいちゆき /武蔵五日市行/
むさしうらわ /武蔵浦和/
むさしこうぎょうだいがく /武蔵工業大学/
むさしこうだい /武蔵工大/武蔵工業大学/
むさしこがねい /武蔵小金井/
むさしこがねいかん /武蔵小金井間/
むさしこすぎ /武蔵小杉/
むさしこやま /武蔵小山/
むさしさかい /武蔵境/
むさししんじょう /武蔵新城/
むさしせき /武蔵関/
むさしだい /武蔵大/武蔵台/
むさしだいがく /武蔵大学/
むさしだいがくほうめん /武蔵大学方面/
むさしなかはら /武蔵中原/
むさしなかはらえき /武蔵中原駅/
むさしの /武蔵野/
むさしのえいぎょうしょ /武蔵野営業所/
むさしのおんだい /武蔵野音大/
むさしのかいそく /武蔵野快速/
むさしのかん /武蔵野館/
むさしのぎんこう /武蔵野銀行/
むさしのこうこう /武蔵野高校/
むさしのし /武蔵野市/
むさしのしなかまち /武蔵野市中町/
むさしのしみどりちょう /武蔵野市緑町/
むさしのしやくしょ /武蔵野市役所/
むさしのじょがくいん /武蔵野女学院/
むさしのじょしがくいん /武蔵野女子学院/
むさしのせん /武蔵野線/
むさしのせんくかん /武蔵野線区間/
むさしのせんでんしゃ /武蔵野線電車/
むさしのせんほうめん /武蔵野線方面/
むさしのてつどう /武蔵野鉄道/
むさしのなんせん /武蔵野南線/
むさしぼうべんけい /武蔵坊弁慶/
むさしまる /武蔵丸/
むさしむらやま /武蔵村山/
むさべつ /無差別/
むさべつきゅう /無差別級/
むさべつこうげき /無差別攻撃/
むさべつばくげき /無差別爆撃/
むさべつばくげきか /無差別爆撃下/
むさん /無産/
むさんそじょうたい /無酸素状態/
むざい /無罪/
むざいほうめん /無罪放免/
むざせきか /無座席化/
むざん /無惨/無残/
むし /無視/蟲/虫/無死/無私/毟/
むしあき /虫明/
むしかえし /蒸し返し/
むしかく /無資格/
むしかくしゃ /無資格者/
むしがた /虫型/
むしき /無支奇/蒸し器/
むしきゅうかんぷう /無四球完封/
むしけら /虫螻/
むしこうせい /無指向性/
むししゃ /無視者/
むしず /虫酸/虫唾/
むしってん /無失点/
むしつかい /蟲使い/
むしつりょう /無質量/
むしてい /無指定/
むしていじ /無指定時/
むしとり /虫取り/
むしば /虫歯/
むしぼし /虫干し/
むしまんるい /無死満塁/
むしめがね /虫眼鏡/
むしもの /蒸し物/
むしゃ /武者/
むしゃけん /無車検/
むしゃしゅぎょう /武者修行/武者修業/
むしゃのこうじ /武者小路/
むしゃのこうじさねあつ /武者小路実篤/
むしゅう /無臭/
むしゅうきょう /無宗教/
むしゅうさ /無収差/
むしゅうせい /無修正/
むしゅうにゅう /無収入/
むしゅうはいきょく /無集配局/
むしゅく /無宿/
むしょう /無償/無性/霧消/
むしょうこうかい /無償公開/
むしょうこうかん /無償交換/
むしょうざんぎょう /無償残業/
むしょうしゅうり /無償修理/
むしょうたいよ /無償貸与/
むしょうていきょう /無償提供/
むしょうはいふ /無償配布/
むしょうほしょうきかん /無償保証期間/
むしょうろうどうしゃ /無償労働者/
むしょく /無職/夢色/無色/
むしょくしゃ /無職者/
むしょくとうめい /無色透明/
むしょぞく /無所属/
むしょり /無処理/
むしよけ /虫除け/
むしろ /筵/蓆/莚/寧ろ/
むしん /無心/
むしんけい /無神経/
むしんこう /無信仰/
むしんこく /無申告/
むしんさつしんりょう /無診察診療/
むしんろん /無神論/
むしんろんしゃ /無神論者/
むじ /無地/無事/
むじかく /無自覚/
むじかくてき /無自覚的/
むじげん /無次元/
むじこ /無事故/
むじこむいはん /無事故無違反/
むじつ /無実/
むじな /豸/
むじひ /無慈悲/
むじまく /無字幕/
むじゃき /無邪気/
むじゅうりょう /無重量/
むじゅうりょうじょうたい /無重量状態/
むじゅうりょく /無重力/
むじゅうりょくけい /無重力系/
むじゅうりょくじょうたい /無重力状態/
むじゅうりょくたいけん /無重力体験/
むじゅん /矛盾/⊥/
むじゅんじょうほう /矛盾情報/
むじゅんせい /矛盾性/
むじゅんてん /矛盾点/
むじゅんめいだい /矛盾命題/
むじゅんろんり /矛盾論理/
むじょう /無常/無情/無上/
むじょうけん /無条件/
むじょうけんかいきん /無条件解禁/
むじょうけんこうふく /無条件降伏/
むじょうけんさんせいは /無条件賛成派/
むじょうけんひじゅん /無条件批准/
むじょうけんひてい /無条件否定/
むじょうけんぶんき /無条件分岐/
むじょそうざい /無除草剤/
むじるし /無印/
むじるしりょうひん /無印良品/
むじん /無人/無尽/
むじんえいぎょう /無人営業/
むじんえき /無人駅/
むじんか /無人化/
むじんかいさつ /無人改札/
むじんき /無人機/
むじんせん /無人船/
むじんぞう /無尽蔵/
むじんとう /無人島/
むじんとうひょうりゅうき /無人島漂流記/
むすい /無水/
むすいありゅうさん /無水亜硫酸/
むすいちょうり /無水調理/
むすいちょうりよう /無水調理用/
むすいなべ /無水鍋/
むすいなべしよう /無水鍋使用/
むすう /無数/
むすこ /息子/
むすこたち /息子達/
むすび /結び/
むすびつき /結び付き/
むすめ /娘/
むすめじだい /娘時代/
むすめむこ /娘婿/
むすめやく /娘役/
むずかしさ /難しさ/
むせい /夢精/無声/
むせいおん /無声音/
むせいか /無声化/
むせいげん /無制限/
むせいげんはいふ /無制限配布/
むせいしいん /無声子音/
むせいしおん /無声子音/
むせいししょう /無精子症/
むせいふ /無政府/
むせいふしゅぎ /無政府主義/
むせいふしゅぎてき /無政府主義的/
むせいふじょうたい /無政府状態/
むせいぶつ /無生物/
むせきにん /無責任/
むせきにんおとこ /無責任男/
むせきにんか /無責任化/
むせきにんとうこうしゃ /無責任投稿者/
むせきにんどくほん /無責任読本/
むせきにんやろう /無責任野郎/
むせきにんりょこう /無責任旅行/
むせっしょく /無接触/
むせっそう /無節操/
むせってい /無設定/
むせってん /無接点/
むせってんか /無接点化/
むせん /無線/無銭/
むせんいがい /無線以外/
むせんうんよう /無線運用/
むせんか /無線家/
むせんかい /無線界/
むせんかいぜんたい /無線界全体/
むせんかんけい /無線関係/
むせんき /無線機/
むせんきき /無線機器/
むせんきや /無線機屋/
むせんきょく /無線局/
むせんきょくけんさ /無線局検査/
むせんきるい /無線機類/
むせんぎし /無線技師/
むせんぎじゅつ /無線技術/
むせんぎょうむにっし /無線業務日誌/
むせんけん /無線研/
むせんこうがく /無線工学/
むせんざっし /無線雑誌/
むせんしかく /無線資格/
むせんしゅうはすう /無線周波数/
むせんしんこうきょうかい /無線振興協会/
むせんじゅうじしゃ /無線従事者/
むせんせつび /無線設備/
むせんだんたい /無線団体/
むせんつうしん /無線通信/
むせんつうしんぎじゅつ /無線通信技術/
むせんでんしん /無線電信/
むせんでんぱ /無線電波/
むせんでんぱほう /無線電波法/
むせんでんわ /無線電話/
むせんでんわつうしん /無線電話通信/
むせんめんきょ /無線免許/
むせんや /無線屋/
むせんゆうどう /無線誘導/
むせんよう /無線用/
むせんようご /無線用語/
むせんりょこう /無銭旅行/
むぜい /無税/
むぜんてい /無前提/
むそう /夢想/無双/
むそうか /夢想家/
むそうかん /無相関/
むそうやま /武双山/
むそんしつ /無損失/
むぞうさ /無造作/無雑作/
むた /牟田/無佗/
むたい /無体/
むたいざいさん /無体財産/
むたいざいさんけん /無体財産権/
むたいざいさんけんほう /無体財産権法/
むたぐち /牟田口/
むたんぽ /無担保/
むだ /無駄/ムダ/徒/
むだあし /無駄足/
むだい /無題/
むだがね /無駄金/
むだじかん /無駄時間/
むだじに /無駄死に/
むだづかい /無駄使い/
むだにく /無駄肉/
むだばなし /無駄話/
むだぼね /無駄骨/
むだん /無断/
むだんいんよう /無断引用/
むだんかい /無段階/
むだんかいちょうせい /無段階調整/
むだんかいへんそく /無段階変速/
むだんがいしゅつ /無断外出/
むだんけっせき /無断欠席/
むだんしよう /無断使用/
むだんしようしゃ /無断使用者/
むだんちゅうしゃ /無断駐車/
むだんてんさい /無断転載/
むだんはいしゃく /無断拝借/
むだんへんそく /無段変速/
むだんへんそくき /無段変速機/
むち /無知/鞭/笞/
むちうち /鞭打/
むちつじょ /無秩序/
むちつじょか /無秩序化/
むちつじょじょうたい /無秩序状態/
むちつじょせい /無秩序性/
むちゃ /無茶/
むちゃくちゃ /無茶苦茶/
むちゅう /夢中/霧中/
むちゅうせん /無抽選/
むちょうせい /無調整/
むちん /無賃/
むちんあつかい /無賃扱い/
むちんじょうしゃ /無賃乗車/
むっつ /六つ/
むつ /睦/陸奥/六/
むつあい /六会/
むつあき /睦明/
むつう /無痛/
むつうしん /無通信/
むつうせい /無痛性/
むつうぶんべん /無痛分娩/
むつうら /六浦/
むつお /睦夫/
むつき /睦紀/睦月/
むつこ /睦子/
むつごと /睦言/
むつざわ /睦沢/
むつしげ /睦茂/
むつのり /睦典/
むつひろ /睦裕/
むつみ /睦美/睦/睦都美/睦つ美/六実/
むつゆき /睦之/
むつよ /睦予/
むつわん /陸奥湾/
むていぎ /無定義/
むていぎがいねん /無定義概念/
むていこう /無抵抗/
むていし /無停止/
むていしゃ /無停車/
むていでん /無停電/
むていでんでんげん /無停電電源/
むていりょう /無定量/
むてき /無敵/霧笛/
むてきがったい /無敵合体/
むてきしょうぐん /無敵将軍/
むてきひっさつわざ /無敵必殺技/
むてきぶぶん /無敵部分/
むてじゅん /無手順/
むてっぽう /無鉄砲/
むてんか /無添加/
むてんとう /無転倒/
むでん /無電/
むでんくかん /無電区間/
むとう /武藤/無答/無糖/無頭/
むとうか /無灯火/無燈火/
むとうかしゃ /無燈火車/
むとうせい /無統制/
むとうひょう /無投票/
むとうろく /無登録/
むとくてん /無得点/
むとそう /無塗装/
むとどけ /無届け/
むとんちゃく /無頓着/
むどう /武堂/
むどく /無毒/
むどくか /無毒化/
むな /胸/棟/宗/
むないよう /無内容/
むなかた /宗方/宗像/棟方/宗形/
むなぐら /胸倉/
むなげ /胸毛/
むなさき /胸先/
むなさわぎ /胸騒ぎ/
むなざんよう /胸算用/
むなせ /皆瀬/
むなもと /胸元/
むに /無二/
むにえる /ムニエル/
むにねん /無二念/
むにんか /無認可/
むね /旨/胸/宗/棟/刀背/
むねあき /宗昭/宗明/
むねあげ /棟上げ/
むねあげしき /棟上式/
むねうち /刀背打ち/
むねお /宗男/宗雄/宗夫/
むねかた /宗片/
むねくに /宗国/
むねざわ /宗澤/
むねしげ /宗重/
むねた /崇田/
むねたか /宗高/
むねたけ /宗武/
むねだ /宗田/
むねとし /宗俊/宗敏/
むねとも /宗朋/
むねにく /胸肉/
むねのり /宗典/
むねはる /宗治/
むねひさ /宗久/
むねひろ /宗裕/
むねふじ /宗藤/
むねもと /胸元/
むねゆき /宗幸/
むねよし /宗良/宗吉/
むねん /無念/
むねんむそう /無念無想/
むのう /無能/
むのうしゃ /無能者/
むのうしゃいん /無能社員/
むのうやく /無農薬/
むのうやくやさい /無農薬野菜/
むのうりょくか /無能力化/
むのうりょくしゃ /無能力者/
むはい /無敗/無配/
むはいりょ /無配慮/
むはんしゃ /無反射/
むはんしゃたん /無反射端/
むはんせい /無反省/
むはんのう /無反応/
むばつ /無罰/
むばんそう /無伴奏/
むばんち /無番地/
むひ /無比/
むひきすう /無引数/
むひはん /無批判/
むひょう /霧氷/無標/
むひょうじ /無表示/
むひょうじょう /無表情/
むびゅう /無謬/
むびゅうせい /無謬性/
むびょう /無病/
むびよくき /無尾翼機/
むふう /無風/
むふか /無負荷/
むふかかいてんすう /無負荷回転数/
むふかじょうたい /無負荷状態/
むふかでんりゅう /無負荷電流/
むふんべつ /無分別/
むへん /無辺/
むへんか /無変化/
むへんかん /無変換/
むへんかんにゅうりょく /無変換入力/
むへんけい /無変形/
むへんこう /無変更/
むへんちょう /無変調/
むべんか /無弁花/
むべんべつ /無弁別/
むほう /無法/
むほうしきしゅぎ /無方式主義/
むほうしゃ /無法者/
むほうじょうたい /無法状態/
むほうちたい /無法地帯/
むほうもの /無法物/
むほきゅう /無補給/
むほけん /無保険/
むほけんしゃ /無保険車/
むほけんしんりょう /無保険診療/
むほしゅ /無保守/
むほしょう /無保証/
むほせい /無補正/
むほん /謀反/謀叛/
むぼう /無謀/
むぼうび /無防備/
むぼうびじょうたい /無防備状態/
むぼうふざい /無防腐剤/
むま /夢魔/
むみ /無味/
むみかんそう /無味乾燥/
むみむしゅう /無味無臭/
むみょう /無明/
むむじゅん /無矛盾/
むむじゅんせい /無矛盾性/
むむじゅんせいしょうめい /無矛盾性証明/
むめい /無名/無銘/
むめいしょてん /無名書店/
むめいじゅく /無名塾/
むめいへんすう /無名変数/
むめんきょ /無免許/
むめんきょうんてん /無免許運転/
むめんきょしゃ /無免許者/
むもくてき /無目的/
むやみ /無闇/
むゆうびょう /夢遊病/
むよう /無用/
むようちょうぶつ /無用長物/
むよく /無欲/無慾/
むら /村/邑/群/屯/邨/叢/斑/
むらい /村井/
むらいし /村石/
むらいせんせい /村井線製/
むらうち /村内/
むらお /村尾/村生/
むらおか /村岡/
むらおこし /村起こし/
むらかた /村方/
むらかみ /村上/
むらかみはるき /村上春樹/
むらかみりゅう /村上龍/
むらき /村木/
むらくし /村櫛/
むらくも /叢雲/
むらこし /村越/
むらさき /紫/村さ来/
むらさきいろ /紫色/
むらさきしきぶ /紫式部/
むらさきすいしょう /紫水晶/
むらさきもく /Biorraginales/ムラサキ目/
むらさめ /叢雨/村雨/
むらさわ /村沢/村澤/
むらした /村下/
むらじ /村地/
むらせ /村瀬/
むらた /村田/邑田/
むらたきかい /村田機械/
むらたじょし /村田女子/
むらたじょししょうぎょう /村田女子商業/
むらたせいさくしょ /村田製作所/
むらたせいさくじょ /村田製作所/
むらたに /村谷/
むらち /村地/
むらなか /村中/
むらにし /村西/
むらの /村野/
むらはちぶ /村八分/
むらびと /村人/
むらびとたち /村人達/
むらまさ /村正/
むらまつ /村松/
むらまつり /村祭り/
むらむすめ /村娘/
むらむら /村々/
むらもと /村本/
むらやま /村山/
むらやましゅしょう /村山首相/
むらやまそうり /村山総理/
むらやまないかく /村山内閣/
むらわき /村脇/
むり /無理/
むりかい /無理解/
むりし /無利子/
むりしんじゅう /無理心中/
むりじい /無理強い/
むりすう /無理数/
むりぜめ /無理攻め/
むりそく /無利息/
むりなんだい /無理難題/
むりやり /無理矢理/無理槍/
むりょ /無慮/
むりょう /無料/無量/無聊/
むりょうおうふくけん /無料往復券/
むりょうか /無料化/
むりょうきゅうけいじょ /無料休憩所/
むりょうけん /無料券/
むりょうこうえん /無料公演/
むりょうこうかん /無料交換/
むりょうこうくうけん /無料航空券/
むりょうごしょうたい /無料御招待/
むりょうしじょうかい /無料試乗会/
むりょうしゅうり /無料修理/
むりょうしゅくはく /無料宿泊/
むりょうしんだん /無料診断/
むりょうしんりょう /無料診療/
むりょうじゅ /無量寿/
むりょうそうげい /無料送迎/
むりょうそうだん /無料相談/
むりょうたいすう /無量大数/
むりょうだいすう /無量大数/
むりょうちゅうしゃ /無料駐車/
むりょうちゅうしゃじょう /無料駐車場/
むりょうでんわ /無料電話/
むりょうはいそう /無料配送/
むりょうはいふ /無料配布/
むりょうふもん /無料不問/
むりょうりよう /無料利用/
むりょく /無力/
むりょくかん /無力感/
むるい /無類/
むれ /群/羣/牟礼/
むれい /牟礼/
むれんそうへんかん /無連想変換/
むろ /室/牟婁/榁/室町/
むろい /室井/
むろう /室生/
むろおか /室岡/
むろか /無濾過/
むろかわ /室川/
むろが /室賀/
むろた /室田/
むろたけん /室田研/
むろたに /室谷/
むろと /室戸/
むろとし /室戸市/
むろとみさき /室戸岬/
むろどう /室堂/
むろね /室根/
むろはし /室橋/
むろふし /室伏/
むろまち /室町/
むろまちじだい /室町時代/
むろまちばくふ /室町幕府/
むろみ /室見/
むろや /室谷/室屋/室哉/
むろやま /室山/
むろらん /室蘭/
むろらんし /室蘭市/
むろん /無論/
め /目/女/眼/芽/瑪/睨/碼/雌/
めーか /メーカ/
めーかー /メーカー/
めーくあっぷ /メークアップ/
めーた /メータ/
めーでー /メーデー/
めーとる /メートル/
めーる /メール/
めあかん /雌阿寒/
めあて /目当て/貭/
めい /名/明/命/迷/銘/鳴/盟/姪/冥/瞑/酩/謎/暝/榠/溟/茗/
めい< /名/
めい> /名/
めいあらし /明嵐/
めいあん /名案/明暗/
めいい /名医/
めいうせん /名羽線/
めいうん /命運/
めいえん /名演/
めいえんぎ /名演技/
めいえんしゅう /名演集/
めいえんそう /名演奏/
めいえんそうか /名演奏家/
めいおう /冥王/
めいおうせい /冥王星/
めいおうせいきどう /冥王星軌道/
めいか /名家/銘菓/名歌/
めいかい /明解/明快/冥界/
めいかく /明確/
めいかくか /明確化/
めいかん /名鑑/
めいかんとく /名監督/
めいかんぶ /名幹部/
めいが /名画/
めいがく /明学/
めいがくだい /明学大/
めいがざ /名画座/
めいがら /銘柄/
めいがらごと /銘柄毎/
めいき /明記/名器/銘器/銘記/名機/銘機/
めいきゅう /迷宮/
めいきゅういり /迷宮入り/
めいきゅうぶっけん /迷宮物件/
めいきゅうものがたり /迷宮物語/
めいきょう /明鏡/
めいきょく /名曲/名局/
めいきょくしゅう /名曲集/
めいきょくだいぜんしゅう /名曲大全集/
めいきょくどう /名曲堂/
めいきんせん /名金線/
めいぎ /名義/
めいぎじょう /名義上/
めいぎにん /名義人/
めいぎへんこう /名義変更/
めいく /メイク/名句/
めいくん /明訓/名君/
めいけ /女池/名家/
めいけいどう /茗渓堂/
めいけつ /名血/
めいけん /迷犬/名犬/
めいげかい /名外科医/
めいげき /名劇/
めいげつ /明月/名月/
めいげついん /明月院/
めいげん /名言/明言/迷言/
めいげんしゅう /名言集/
めいこ /茗子/
めいこう /名工/名港/
めいこうだい /名工大/
めいこうだいちのう /名工大知能/
めいこうだいてっけん /名工大鉄研/
めいご /迷語/明午/
めいさい /明細/迷彩/明細書/
めいさいしょ /明細書/
めいさいしょく /迷彩色/
めいさいずしゅう /明細図集/
めいさいとそう /迷彩塗装/
めいさいひょう /明細表/
めいさいふく /迷彩服/
めいさく /名作/迷作/
めいさくげきじょう /名作劇場/
めいさくしゅう /名作集/
めいさつ /名刹/明察/
めいさま /名様/
めいさん /名産/
めいさんち /名産地/
めいさんひん /名産品/
めいさんぼう /名参謀/
めいし /名刺/名詞/名士/名氏/
めいしか /名詞化/
めいしかんり /名刺管理/
めいしく /名詞句/
めいしけい /名詞形/
めいしこうかん /名刺交換/
めいしてき /名詞的/
めいしゃ /目医者/名車/眼医者/
めいしゅ /名手/盟主/銘酒/名酒/
めいしょ /名所/名処/
めいしょう /名称/名勝/名将/
めいしょうあん /名称案/
めいしょうけってい /名称決定/
めいしょうこうほ /名称候補/
めいしょうせん /名松線/
めいしょうふめい /名称不明/
めいしょうぶ /名勝負/
めいしょうへんこう /名称変更/
めいしん /迷信/名神/
めいじ /明示/明治/名辞/
めいじ#ねん /明治#0年/明治#1年/明治#2年/明治#3年/(skk-gengo-to-ad "" "年")/(skk-gengo-to-ad "西暦" "年")/
めいじいこう /明治以降/
めいじいご /明治以後/
めいじいしん /明治維新/
めいじいしんいぜん /明治維新以前/
めいじいぜん /明治以前/
めいじいらい /明治以来/
めいじか /明示化/
めいじがくいんだい /明治学院大/
めいじき /明治期/
めいじきいこう /明治期以降/
めいじきねんかん /明治記念館/
めいじしょき /明治初期/
めいじしんせいふ /明治新政府/
めいじじだい /明治時代/
めいじじょうほう /明治情報/
めいじじんぐう /明治神宮/
めいじせいか /明治製菓/
めいじせいとう /明治製糖/
めいじせん /明治戦/
めいじたいしょうしょうわ /明治大正昭和/
めいじだい /明治大/
めいじだいがく /明治大学/
めいじだいがくいくた /明治大学生田/
めいじっきょう /名実況/
めいじつ /名実/名實/
めいじつとも /名実共/
めいじてき /明示的/
めいじてんのう /明治天皇/
めいじてんもん /明治天文/
めいじどおり /明治通り/
めいじにゅうぎょう /明治乳業/
めいじばし /明治橋/
めいじばんねん /明治晩年/
めいじむら /明治村/
めいじゃく /名弱/
めいじや /明治屋/
めいじょう /名城/名状/
めいじょうせん /名城線/
めいじょうだいがく /名城大学/
めいじん /名人/明神/
めいじんい /名人位/
めいじんけいけんしゃ /名人経験者/
めいじんげい /名人芸/
めいじんせん /名人戦/
めいじんだっしゅ /名人奪取/
めいすい /名水/
めいすいり /名推理/
めいすう /命数/
めいすうひょう /命数表/
めいすうほう /命数法/
めいせい /名声/明星/名聲/
めいせいこうこう /明星高校/
めいせいだいがく /明星大学/
めいせき /明晰/
めいせんしゅ /名選手/
めいぜりふ /名台詞/
めいぜんりょう /明善寮/
めいそう /冥想/瞑想/迷走/名僧/面相/
めいそうしんけい /迷走神経/
めいそうてき /瞑想的/
めいそうほう /瞑想法/
めいたん /名短/
めいたんてい /名探偵/
めいだ /銘打/
めいだい /命題/名大/明大/名古屋大学/
めいだいかんすう /命題関数/
めいだいがくりがくぶ /名大学理学部/
めいだいけいさん /命題計算/
めいだいこう /名大工/
めいだいこうがく /名大工学/
めいだいこうがくぶ /名大工学部/
めいだいじょうほう /名大情報/明大情報/
めいだいすいろん /命題推論/
めいだいせいけい /明大政経/
めいだいていすう /命題定数/
めいだいでんき /名大電気/
めいだいとうけつ /命題凍結/
めいだいどうてきろんり /命題動的論理/
めいだいない /名大内/
めいだいなかの /明大中野/
めいだいなかのはちおうじ /明大中野八王子/
めいだいなかのはちおうじこうこう /明大中野八王子高校/
めいだいにんげんじょうほう /名大人間情報/
めいだいぶぶん /命題部分/
めいだいへんすう /命題変数/
めいだいまえ /明大前/名大前/
めいだいりこう /明大理工/
めいだいろんり /命題論理/
めいだいろんりしき /命題論理式/
めいち /命知/
めいちゅう /命中/
めいちゅうすう /命中数/
めいちゅうせいど /命中精度/
めいちゅうりつ /命中率/
めいちょ /名著/
めいちょう /明徴/
めいちんばめん /名珍場面/
めいっぱい /目一杯/
めいてい /酩酊/名艇/
めいてつ /名鉄/
めいてつせとせん /名鉄瀬戸線/
めいてつせんない /名鉄線内/
めいてつとこなめせん /名鉄常滑線/
めいてつとっきゅう /名鉄特急/
めいてつひろみせん /名鉄広見線/
めいてん /名店/
めいてんかい /名展開/
めいてんがい /名店街/
めいでんこう /名電高/
めいでんしゃ /明電舎/
めいでんしゃぬまづ /明電舎沼津/
めいとう /名答/名東/名刀/明答/
めいとうさんぎょう /明糖産業/
めいとく /明徳/
めいど /明度/冥土/冥途/
めいどう /鳴動/
めいにち /命日/
めいはく /明白/
めいはん /名阪/
めいはんけいゆ /名阪経由/
めいはんこくどう /名阪国道/
めいはんとっきゅう /名阪特急/
めいば /名馬/
めいばめん /名場面/迷場面/
めいばめんしゃしんしゅう /名場面写真集/
めいばめんしゅう /名場面集/
めいばん /名盤/
めいひょう /名票/
めいひん /名品/名牝/
めいび /明媚/名媚/
めいふ /冥府/
めいふく /冥福/
めいふまどう /冥府魔道/
めいぶつ /名物/
めいぶつおとこ /名物男/
めいぶつし /名物紙/
めいぶつりょうり /名物料理/
めいぶん /名分/名文/明文/銘文/
めいぶんか /明文化/
めいへんこう /名変更/
めいへんしゅうちょう /名編集長/
めいほう /明芳/名豊/盟邦/
めいほかんきのう /名補完機能/
めいぼ /名簿/
めいぼう /明眸/
めいぼさくせい /名簿作成/
めいぼじゅんい /名簿順位/
めいみ /芽美/
めいみゃく /命脈/
めいめい /命名/銘々/
めいめいしき /命名式/
めいめいしゃ /命名者/
めいめいほう /命名法/
めいめつ /明滅/
めいもう /迷妄/
めいもく /名目/瞑目/
めいもくじょう /名目上/
めいもん /名門/
めいもんく /名文句/
めいやく /名訳/盟約/
めいゆう /盟友/名優/
めいよ /名誉/
めいよう /没有/
めいよおうざ /名誉王座/
めいよかいいん /名誉会員/
めいよかいちょう /名誉会長/
めいよかいふく /名誉回復/
めいよきそん /名誉棄損/名誉毀損/
めいよきそんざい /名誉毀損罪/
めいよきょうじゅ /名誉教授/
めいよこづな /名横綱/
めいよごせい /名誉碁聖/
めいよしょく /名誉職/
めいよそうさい /名誉総裁/
めいよだんい /名誉段位/
めいよばんかい /名誉挽回/
めいよめいじん /名誉名人/
めいりょう /明瞭/明良/
めいりょうせい /明瞭性/
めいりょうてい /名料亭/
めいりょうど /明瞭度/
めいりょうどしけん /明瞭度試験/
めいりょうどしんけん /明瞭度試験/
めいりょどしけんけっか /明瞭度試験結果/
めいりん /明林/
めいりんかん /明倫館/
めいりんどう /明林堂/
めいりんどうしょてん /明倫堂書店/
めいる /メイル/滅入る/
めいれい /命令/
めいれいがた /命令型/
めいれいくちょう /命令口調/
めいれいぐん /命令群/
めいれいけい /命令形/
めいれいご /命令語/
めいれいごじゅん /命令語順/
めいれいしょ /命令書/
めいれいじっこう /命令実行/
めいれいじっこうかのう /命令実行可能/
めいれいすう /命令数/
めいれいちょう /命令調/命令長/
めいれいついか /命令追加/
めいれいでんたつ /命令伝達/
めいれいはっこう /命令発行/
めいれいひょう /命令表/
めいれいほう /命令法/
めいれいもと /命令元/
めいれいれつ /命令列/
めいろ /迷路/
めいろう /明朗/
めいろない /迷路内/
めいわ /明和/
めいわきやく /名脇役/
めいわく /迷惑/
めいわくいがい /迷惑以外/
めいわくこうい /迷惑行為/
めいわくせんまん /迷惑千万/
めいわくちゅうしゃ /迷惑駐車/
めいわくでんわ /迷惑電話/
めいわくど /迷惑度/
めいわくもの /迷惑者/
めいわくやろう /迷惑野郎/
めいわくりょう /迷惑料/
めいん /メイン/
めうえ /目上/
めうし /雌牛/
めうつり /目移り/
めうまげんていしば /牝馬限定芝/
めおし /目押し/
めおと /夫婦/娚/
めか /メカ/
めかくし /目隠/目隠し/
めかけ /妾/
めかた /目方/
めかにずむ /メカニズム/
めかま /目蒲/
めかません /目蒲線/
めかませんでんしゃ /目蒲線電車/
めかませんぬまべえき /目蒲線沼部駅/
めが /女鹿/
めがしら /目頭/
めがね /眼鏡/メガネ/
めがねてん /眼鏡店/
めがねや /眼鏡屋/
めがみ /女神/
めがみさま /女神様/
めがみぞう /女神像/
めがみてんせい /女神転生/
めがわ /女川/
めきしこ /墨西哥/
めぎか /メギ科/Berberidaceae/
めぎつね /女狐/
めくじら /目鯨/
めくばせ /眼配せ/目配せ/
めくら /盲/
めくらばん /盲判/
めくるめく /目眩く/
めぐすり /目薬/
めぐみ /恵/恵美/めぐ美/惠/愛美/慈/
めぐむ /恵/萠/
めぐりあい /巡り合い/
めぐろ /目黒/
めぐろえいぎょうしょ /目黒営業所/
めぐろえき /目黒駅/
めぐろえきけいゆ /目黒駅経由/
めぐろえきけいゆう /目黒駅経由/
めぐろがくえん /目黒学園/
めぐろがわ /目黒川/
めぐろきねん /目黒記念/
めぐろく /目黒区/
めぐろくおおおかやま /目黒区大岡山/
めぐろくこまば /目黒区駒場/
めぐろくしもめぐろ /目黒区下目黒/
めぐろくみん /目黒区民/
めぐろけいさつしょ /目黒警察署/
めぐろけいとう /目黒系統/
めぐろけいゆ /目黒経由/
めぐろげしゃ /目黒下車/
めぐろせいびがくえん /目黒星美学園/
めぐろとうきゅう /目黒東急/
めぐろほうめん /目黒方面/
めさき /目先/目崎/
めざし /目刺し/
めざす /目指す/
めざまし /目覚し/
めざめ /目覚め/
めし /飯/
めしあい /飯合/
めした /目下/
めしつかい /召使い/召使/
めしつぶ /飯粒/
めしびつ /飯櫃/
めしべ /雌蘂/雌蕊/
めしや /飯屋/
めじ /目時/
めじか /女鹿/
めじゃー /メジャー/
めじり /目尻/
めじるし /目印/
めじろ /目白/
めじろおし /目白押/
めじろかん /目白間/
めじろがくえん /目白学園/
めす /牝/♀/雌/メス/
めすいぬ /牝犬/
めすうま /牝馬/雌馬/
めすうまげんてい /牝馬限定/
めすかぶ /雌株/
めすねこ /雌猫/
めず /馬頭/
めせん /目線/
めそっど /メソッド/
めぞねっと /メゾネット/
めぞん /メゾン/
めた /メタ/
めたもるふぉーぜ /メタモルフォーゼ/
めたる /メタル/
めたん /メタン/
めだち /目立/
めだつ /目立つ/
めだま /目玉/眼球/
めだまきかく /目玉企画/
めだましょうひん /目玉商品/
めだまじいん /目玉寺院/
めだませいひん /目玉製品/
めだまぜんぶ /目玉全部/
めだまふうせん /目玉風船/
めだまやき /目玉焼/
めだる /メダル/
めちゃ /目茶/
めちゃくちゃ /滅茶苦茶/目茶苦茶/
めちゃめちゃ /滅茶滅茶/
めっき /鍍金/
めっきゃく /滅却/
めっきん /滅菌/
めっきんご /滅菌後/
めっきんずみ /滅菌済み/
めっきんまえ /滅菌前/
めっさう /滅相/
めっしつ /滅失/
めっしほうこう /滅私奉公/滅私奉行/
めっしゅ /メッシュ/
めっせーじ /メッセージ/
めっそう /滅相/
めった /滅多/
めったに /滅多に/
めったやたら /滅多矢鱈/
めっぽう /滅法/
めつ /滅/
めつき /目つき/眼付/眼つき/
めつけ /目付/
めつぼう /滅亡/
めて /右手/
めでぃあ /メディア/
めでとう /目出当/
めでゅさんどらもく /メデュサンドラ目/Medusandrales/
めとき /目時/
めど /目途/目処/メド/
めどぎ /蓍/
めにゅー /メニュー/
めぬき /目抜き/
めぬま /妻沼/
めのう /瑪瑙/
めのまえ /目の前/
めはな /目鼻/
めばえ /芽生え/
めばな /雌花/
めばり /目貼り/
めびき /目引/
めぶんりょう /目分量/
めべり /目減り/
めぼし /目星/
めまい /眩暈/暈/目眩い/
めまひ /目眩ひ/眩暈/目眩い/
めまんべつ /女満別/
めまんべつくうこう /女満別空港/
めむろ /芽室/
めめしい /女々しい/
めも /メモ/
めもちょう /メモ帳/
めもと /目元/
めもとくちもと /目元口元/
めもめも /(..)φ/
めもり /メモリ/目盛/目盛り/
めやす /目安/
めやすていど /目安程度/
めやすひょう /目安表/
めら /目良/
めりか /芽里香/
めりっと /メリット/
めりはり /減り張り/乙張/減張/
めろでぃー /メロディー/
めろめろ /メロメロ/
めん /面/麺/緬/綿/免/棉/緜/麪/眄/
めんあつ /面圧/
めんあつぶんぷ /面厚分布/
めんいつ /面一/
めんえき /免疫/免役/
めんえきかんけい /免疫関係/
めんえききこう /免疫機構/
めんえきけい /免疫系/
めんえきせい /免疫性/
めんえきていかじょうたい /免疫低下状態/
めんえきふぜん /免疫不全/
めんえきりょく /免疫力/
めんおりもの /綿織物/
めんか /綿花/綿価/
めんかい /面会/
めんかいしつ /面会室/
めんかいじかん /面会時間/
めんかやく /綿火薬/
めんかん /免官/
めんが /面画/
めんきつ /面詰/
めんきょ /免許/
めんきょかいせい /免許改正/
めんきょかいでん /免許皆伝/
めんきょぎょうせい /免許行政/
めんきょこうしん /免許更新/
めんきょこうしんじ /免許更新時/
めんきょこうふ /免許交付/
めんきょこうふじ /免許交付時/
めんきょしかく /免許資格/
めんきょしっこう /免許失効/
めんきょしゅとく /免許取得/
めんきょしゅとくしゃ /免許取得者/
めんきょしょ /免許書/
めんきょしょう /免許証/
めんきょしんせい /免許申請/
めんきょしんせいふよう /免許申請不要/
めんきょじょう /免許状/
めんきょじょうそうふよう /免許状送付用/
めんきょせい /免許制/
めんきょせいど /免許制度/
めんきょとりけし /免許取消/
めんきょにん /免許人/
めんきょばんごう /免許番号/
めんきょふしょじ /免許不所持/
めんきょふよう /免許不要/
めんきょほじしゃ /免許保持者/
めんぎょ /面魚/
めんくい /面食い/面食/
めんけつごう /面結合/
めんこうげん /面光源/
めんざい /免罪/
めんざいふ /免罪符/
めんし /綿糸/
めんしき /面識/
めんしゅうごう /面集合/
めんしょく /免職/
めんじゅうふくはい /面従腹背/
めんじょ /免除/
めんじょう /免状/面上/面状/
めんじょうりょう /免状料/
めんじょしんせい /免除申請/
めんじょせいど /免除制度/
めんすう /面数/
めんせい /面性/
めんせき /面積/免責/
めんせきあたり /面積当たり/
めんせきがく /免責額/
めんせきじこう /免責事項/
めんせきず /面積図/
めんせきぶん /面積分/
めんせつ /面接/
めんせつかん /面接官/
めんせつしけん /面接試験/
めんせつしつ /面接室/
めんせつび /面接日/
めんぜい /免税/
めんぜいさく /免税策/
めんぜいてん /免税店/
めんぜいひん /免税品/
めんぜいひんてん /免税品店/
めんぜん /面前/
めんぜんちん /門前清/
めんそ /免租/免訴/面素/
めんそう /面相/
めんたい /面体/面対/
めんたいこ /明太子/
めんだ /免田/
めんだん /面談/
めんちょう /面疔/
めんつ /面子/
めんて /メンテナンス/
めんてい /免停/
めんとう /面頭/
めんど /面倒/
めんどう /面倒/面堂/
めんどうみ /面倒見/
めんどり /雌鳥/
めんない /面内/
めんば /メンバ/面罵/
めんばー /メンバー/
めんばかんすう /メンバ関数/
めんばへんすう /メンバ変数/
めんぷ /綿布/
めんぼう /綿棒/麺棒/
めんぼく /面目/
めんぼくやくじょ /面目躍如/
めんぽう /面皰/
めんみつ /綿密/
めんみつど /面密度/
めんめん /面々/綿々/面面/
めんもう /綿毛/
めんもく /面目/
めんよう /綿羊/面妖/緬羊/
めんようそ /面要素/
めんるい /麺類/
めんれんけつ /面連結/
も /茂/模/母/摸/藻/喪/裳/望/貰/邑/姆/楙/糢/
もーせのじっかい /モーセの十戒/モーセの十誡/
もーた /モータ/
もーたー /モーター/
もーど /モード/
もーどぎょう /モード行/
もーどめい /モード名/
もう /網/耗/盲/猛/蒙/毛/妄/孟/魍/申/望/亡/曚/朦/檬/濛/矇/网/罔/耄/艨/莽/芒/
もうあい /妄愛/
もうい /猛威/
もういちど /もう一度/
もううん /妄雲/
もうか /猛火/真岡/
もうかてつどう /真岡鉄道/
もうかんじゅうそう /盲管銃創/
もうがっこう /盲学校/
もうきん /猛禽/
もうぎゅう /猛牛/
もうけ /儲/
もうけやく /儲役/
もうけん /猛犬/
もうげん /妄言/
もうこ /蒙古/猛虎/
もうこう /猛攻/
もうことう /猛虎党/
もうことういん /猛虎党員/
もうこは /猛虎派/
もうこれき /猛虎暦/
もうこん /毛根/
もうさい /毛細/
もうさいかんげんしょう /毛細管現象/
もうさいけっかん /毛細血管/網細血管/
もうし /孟子/
もうしあわせ /申し合せ/申し合わせ/
もうしいれ /申し入れ/
もうしこみ /申込/申し込み/
もうしこみうけつけじゅん /申込受付順/
もうしこみきかん /申込期間/
もうしこみきげん /申込期限/
もうしこみご /申込後/
もうしこみさき /申込先/申し込み先/
もうしこみしめきり /申込締切/
もうしこみしゃ /申込者/
もうしこみしゃしめい /申込者氏名/
もうしこみしゃたすう /申込者多数/
もうしこみしょ /申込書/
もうしこみしょにち /申込初日/
もうしこみじ /申込時/
もうしこみじょう /申込状/
もうしこみせい /申し込み制/
もうしこみたすう /申込多数/
もうしこみたんとうしゃ /申込担当者/
もうしこみちゅう /申込中/
もうしこみにん /申込人/
もうしこみひょう /申込票/
もうしこみび /申込日/
もうしこみほうほう /申込方法/
もうしこみようし /申込用紙/
もうしたて /申立/申立て/
もうしたてしょ /申立書/
もうしたてにん /申立人/
もうしで /申し出/
もうしぶん /申し分/
もうしもく /網翅目/
もうしゅう /妄執/
もうしょ /猛暑/
もうしわけ /申し訳/申し訳け/申訳/
もうしわけない /申し訳ない/
もうしん /盲信/猛進/盲進/
もうじゃ /亡者/盲者/
もうじゅう /猛獣/盲従/
もうじゅうおうこく /猛獣王国/
もうじゅうつかい /猛獣使い/
もうじょう /毛状/網状/
もうじょうせんこう /網状穿孔/網状せん孔/
もうじょうたい /網状態/毛状体/
もうじょうみゃく /網状脈/
もうじん /盲人/
もうじんかしゅ /盲人歌手/
もうじんしょかん /盲人書簡/
もうすこし /もう少し/
もうせい /猛省/
もうせん /毛氈/
もうぜん /猛然/
もうそう /妄想/網総/
もうそうか /妄想家/
もうそうがっこう /妄想学校/
もうたい /毛帯/
もうたいかく /毛帯核/
もうたくとう /毛沢東/
もうだ /猛打/
もうだしょう /猛打賞/
もうだん /妄断/
もうちょう /盲腸/
もうちょうせん /盲腸線/
もうつい /猛追/
もうてん /盲点/
もうで /詣/詣で/
もうとう /毛頭/
もうとく /孟徳;曹操の字(あざな)/
もうどう /盲導/艨艟/妄動/
もうどうけん /盲導犬/
もうどく /猛毒/
もうない /網内/
もうねん /妄念/
もうはつ /毛髪/
もうはつよう /毛髪用/
もうはんげき /猛反撃/
もうはんたい /猛反対/
もうばく /猛爆/
もうひつ /毛筆/
もうひつしょたい /毛筆書体/
もうひつたい /毛筆体/
もうひょう /猛豹/
もうふ /毛布/
もうふぶき /猛吹雪/
もうまい /蒙昧/曚昧/濛昧/矇昧/
もうまく /網膜/
もうまくしょう /網膜症/
もうまくじょう /網膜上/
もうまくとうえい /網膜投影/
もうまくはくり /網膜剥離/
もうまくふしゅ /網膜浮腫/
もうもう /濛々/濛濛/
もうもく /盲目/
もうもくてき /盲目的/
もうもん /網紋/
もうもんせんこう /網紋穿孔/
もうよう /網様/
もうようたい /毛様体/
もうら /網羅/
もうらせい /網羅性/
もうらてき /網羅的/
もうらりつ /網羅率/
もうり /毛利/
もうりょう /魍魎/
もうれつ /猛烈/
もうれつきょじん /猛烈巨人/
もうれつふきょう /猛烈不況/
もうれんしゅう /猛練習/
もうれんちゃん /猛連荘/
もうろう /朦朧/
もうろく /耄碌/
もえ /燃/萌/萠/
もえぎいろ /萌木色/
もえこ /萌子/
もおか /真岡/
もおかし /真岡市/
もおかてつどう /真岡鉄道/
もがみ /最上/
もがみがわ /最上川/
もがみよしみつ /最上義光/
もぎ /模擬/摸擬/茂木/
もぎおんじょう /模擬音場/
もぎかのう /模擬可能/
もぎけい /模擬系/
もぎさいばん /模擬裁判/
もぎしけん /模擬試験/
もぎしゅほう /模擬手法/
もぎせいど /模擬精度/
もぎせん /模擬戦/
もぎてきせかい /模擬的世界/
もぎてん /模擬店/
もぎどう /没義道/
もぎりょういき /模擬領域/
もく /木/目/黙/杢/沐/默/
もくあみ /木阿弥/黙阿弥/
もくきん /木金/
もくきんど /木金土/
もくぎょ /木魚/
もくぐん /目群/
もくげき /目撃/
もくげきしゃ /目撃者/
もくげきだん /目撃談/
もくげきほうこく /目撃報告/
もくこうぞう /木構造/
もくさつ /黙殺/
もくさん /目算/
もくざい /木材/
もくざいこう /木材港/
もくざいしげん /木材資源/
もくし /目指/目視/黙視/
もくしけんさ /目視検査/
もくしつ /木質/
もくしろく /黙示録/
もくじ /目次/黙示/
もくじあん /目次案/
もくじさくせいきのう /目次作成機能/
もくじろく /黙示録/
もくず /藻屑/
もくせい /木星/木製/Jupiter/木犀/
もくせいか /モクセイ科/
もくせいかんそく /木星観測/
もくせいきどうじょう /木星軌道上/
もくせいめん /木星面/
もくせいもく /モクセイ目/Oleales/
もくぜん /目前/黙然/
もくそう /黙想/
もくそく /目測/
もくぞう /木造/
もくぞうかおく /木造家屋/
もくぞうけんちくぶつ /木造建築物/
もくたん /木炭/
もくだく /黙諾/
もくづ /藻屑/
もくてき /目的/
もくてきいがい /目的以外/
もくてきいしき /目的意識/
もくてきえき /目的駅/
もくてきおん /目的音/
もくてきかく /目的格/
もくてきかんすう /目的関数/
もくてきがい /目的外/
もくてきがいしよう /目的外使用/
もくてきがわ /目的側/
もくてきげんご /目的言語/
もくてきご /目的語/
もくてきごと /目的毎/
もくてきしょく /目的食/
もくてきしんごう /目的信号/
もくてきじたい /目的自体/
もくてきじょうせいとう /目的上正当/
もくてきじょうひつよう /目的上必要/
もくてきすいこう /目的遂行/
もくてきせってい /目的設定/
もくてきせんよう /目的専用/
もくてきぜい /目的税/
もくてきち /目的地/
もくてきちふきん /目的地付近/
もくてきちほうこう /目的地方向/
もくてきふめい /目的不明/
もくてきぶつ /目的物/
もくてきべつ /目的別/
もくとう /黙祷/
もくどく /黙読/
もくにん /黙認/
もくねん /黙念/
もくの /杢野/
もくば /木馬/
もくひ /黙秘/
もくひょう /目標/
もくひょうかん /目標艦/
もくひょうき /目標機/
もくひょうち /目標値/
もくひょうぶつ /目標物/
もくひょうほうこう /目標方向/
もくひょうまいすう /目標枚数/
もくぶ /木部/
もくぶうんぱんさいぼう /木部運搬細胞/
もくへん /木片/
もくほん /木本/
もくまおうもく /モクマオウ目/Casuarinales/
もくまおうもくあぐん /モクマオウ目亜群/
もくめ /木目/
もくめもよう /木目模様/
もくもく /黙々/
もくよう /木曜/
もくようび /木曜日/
もくよく /沐浴/
もくれい /黙礼/目礼/
もくれん /モクレン/木蓮/
もくれんか /モクレン科/Magnoliaceae/
もくれんもく /モクレン目/Magnoliales/
もくろく /目録/黙録/
もくろみ /目論見/
もくろん /目論/
もぐら /土龍/土竜/
もけい /模型/
もけいか /模型化/
もけいかい /模型界/
もけいぎょうかい /模型業界/
もけいぐん /模型群/
もけいこうさく /模型工作/
もけいざっし /模型雑誌/
もけいず /模型図/
もけいせいさく /模型製作/
もけいせんもんし /模型専門誌/
もけいてき /模型的/
もけいてん /模型店/
もけいひこうき /模型飛行機/
もけいや /模型屋/
もけいよう /模型用/
もこ /模糊/糢糊/
もこく /摸刻/
もこと /藻琴/
もさ /猛者/
もさく /模索/模作/摸索/
もさくじょうたい /模索状態/
もさくちゅう /模索中/
もさくてき /模索的/
もし /模試/若し/
もしか /若しか/
もしき /模式/摸式/
もしきか /模式化/
もしきず /模式図/
もしきてき /模式的/
もしくは /若しくは/
もしゃ /模写/摸写/摸冩/
もしゅ /喪主/
もしょう /喪章/
もじ /文字/門司/綟/選択/
もじいか /文字以下/
もじいがい /文字以外/
もじいじょう /文字以上/
もじいち /文字位置/
もじえき /門司駅/
もじえきがわ /門司駅側/
もじおち /文字落/
もじか /文字化/
もじかくてい /文字確定/
もじかん /文字間/
もじかんかく /文字間隔/
もじがた /文字型/
もじきごう /文字記号/
もじきょうかい /文字境界/
もじくばり /文字配り/
もじぐん /文字群/
もじこーど /文字コード/
もじこう /門司港/
もじこうほ /文字侯補/
もじこぶんしょ /文字古文書/
もじごと /文字毎/
もじさくじょ /文字削除/
もじざひょうけい /文字座標系/
もじしき /文字式/
もじした /文字下/
もじしてん /門司支店/
もじしゅ /文字種/
もじしゅうごう /文字集合/
もじしゅうしょく /文字修飾/
もじしゅうとく /文字修得/
もじしゅつりょく /文字出力/
もじしゅるい /文字種類/
もじしょうきょ /文字消去/
もじしょり /文字処理/
もじじしょ /文字辞書/
もじじたい /文字自体/
もじじょうほう /文字情報/
もじすう /文字数/
もじすうせいげん /文字数制限/
もじぜんぶ /文字全部/
もじたいおう /文字対応/
もじたいけい /文字体系/
もじたいだん /文字対談/
もじたじゅうほうそう /文字多重放送/
もじたんい /文字単位/
もじたんまつ /文字端末/
もじたんまつじょう /文字端末上/
もじちょう /文字長/
もじつうか /門司通過/
もじつうしん /文字通信/
もじづら /文字面/
もじていすう /文字定数/
もじとくてん /文字得点/
もじどおり /文字通り/
もじにゅうりょく /文字入力/
もじにゅうりょくじ /文字入力時/
もじにゅうりょくちゅう /文字入力中/
もじにんしき /文字認識/
もじにんしきぎじゅつ /文字認識技術/
もじにんしきしょうがい /文字認識障害/
もじにんしきや /文字認識屋/
もじはいれつ /文字配列/
もじはば /文字幅/
もじばけ /文字化け/
もじばん /文字盤/文字版/
もじひょうき /文字表記/
もじひょうじ /文字表示/
もじぶん /文字分/
もじへんこう /文字変更/
もじへんすう /文字変数/
もじほうそう /文字放送/
もじめ /文字目/
もじめいじがた /文字明示型/
もじゅーる /モジュール/
もじゆらい /文字由来/
もじよう /文字用/
もじり /捩/
もじれつ /文字列/
もじれつか /文字列化/
もじれつがた /文字列型/
もじれつがたへんすう /文字列型変数/
もじれつこうほ /文字列候補/
もじれつこうもく /文字列項目/
もじれつしょうごう /文字列照合/
もじれつしょり /文字列処理/
もじれつそうさ /文字列操作/
もじれつたんさく /文字列探索/
もじれつちゅう /文字列中/
もじれつちょう /文字列長/
もじれつていすう /文字列定数/
もじれつにゅうりょく /文字列入力/
もじれつへんしゅう /文字列編集/
もじわく /文字枠/
もすくわ /莫斯科/
もず /百舌/百舌鳥/鵙/鴃/
もずみ /茂住/
もずめ /物集女/物集/
もせうし /妹背牛/
もそう /模奏/
もぞう /模造/摸造/
もぞうし /模造紙/
もぞうひん /模造品/
もた /持た/
もだえ /悶え/
もち /餅/持/勿/餠/持ち/望/
もちーふ /モチーフ/
もちあじ /持ち味/
もちあわせ /持ち合せ/
もちいえ /持ち家/
もちうた /持ち歌/
もちお /持尾/
もちかた /持ち方/
もちかぶ /持ち株/
もちかぶかい /持株会/
もちがせ /用瀬/
もちがね /持ち金/
もちこし /持越/
もちこみ /持ち込み/
もちこみうま /持込馬/
もちごま /持駒/
もちごめ /餅米/糯/糯米/
もちじかん /持ち時間/
もちだ /持田/
もちだせいやく /持田製薬/
もちづき /望月/餅月/
もちづきでんき /望月電気/
もちてん /持ち点/
もちぬし /持ち主/持主/
もちはこび /持ち運び/
もちば /持ち場/
もちひろ /望洋/
もちぶん /持分/
もちまえ /持ち前/貭/
もちむね /用宗/
もちもの /持ち物/持物/
もちや /餅屋/
もちゅう /喪中/
もちろん /勿論/
もちろんれいがい /勿論例外/
もっか /目下/
もっかどこんすい /木火土金水/
もっかん /木管/
もっかんがっき /木管楽器/
もっかんがっきいっぱん /木管楽器一般/
もっかんがっきよう /木管楽器用/
もっかんぐん /木管群/
もっかんごじゅうそう /木管五重奏/
もっきつ /勿吉/
もっけ /勿怪/
もっこう /木工/黙考/
もっこうじゅつ /木工術/
もっこうよう /木工用/
もったい /勿体/
もったいない /勿体ない/勿体無い/
もって /以て/
もっとー /モットー/
もっとも /最も/尤も/
もっともやく /尤役/
もっぱら /専ら/
もつ /物/勿/
もつやく /没薬/
もてぎ /茂木/
もでる /モデル/
もでるか /モデル化/
もと /元/本/基/下/許/素/幹/礎/望都/
もと> /元/
もとあいぼう /元相棒/
もとあき /元昭/元明/
もとあざぶ /元麻布/
もとあり /本有/
もとい /基/
もといあんふ /元慰安婦/
もといけ /本池/
もといし /本石/元石/
もといせ /元伊勢/
もとうけ /元請け/
もとうた /元歌/
もとうり /元売り/
もとえ /元絵/
もとえい /基栄/
もとお /元夫/元男/元朗/基夫/誠生/
もとおか /元岡/
もとおり /本居/
もとかしゅ /元歌手/
もとかず /元一/
もとかど /本門/
もとかわ /本川/
もとかわさきしみん /元川崎市民/
もとかんじ /元幹事/
もとかんじちょう /元幹事長/
もとき /本木/基紀/元木/元基/基樹/元紀/
もときじ /元記事/
もときじちゅう /元記事中/
もときじとうこうしゃ /元記事投稿者/
もときゅう /本久/
もときん /元金/
もとぎぼ /元義母/
もとぐんじん /元軍人/
もとけいきゅう /元京急/
もとこ /素子/基子/茂登子/
もとこうこうきょうし /元高校教師/
もとこくさい /元国際/
もとこくたいせんしゅ /元国体選手/
もとこくてつ /元国鉄/
もとこくむちょうかん /元国務長官/
もとこむすび /元小結/
もとごうかく /元合格/
もとさぎし /元詐欺師/
もとさと /理元/
もとざわ /本澤/
もとし /元司/元志/基志/基史/
もとしずおかけんみん /元静岡県民/
もとしゃいん /元社員/
もとしゅしょう /元首相/
もとしゅふ /元主婦/
もとしりょう /元資料/
もとしんじゃ /元信者/
もとしんぱん /元審判/
もとじ /元司/
もとじめ /元締め/元締/
もとじゅうぐんいあんふ /元従軍慰安婦/
もとじゅく /本宿/
もとじょうし /元上司/
もとじろう /基次郎/
もとす /本巣/本栖/
もとすこ /本栖湖/
もとすみよし /元住吉/
もとすみよしでんしゃく /元住吉電車区/
もとせきわけ /元関脇/
もとせん /元栓/
もとせんしゅ /元選手/
もとたいいん /元隊員/
もとたか /元孝/基隆/
もとたからずかしみん /元宝塚市民/
もとただ /元正/
もとたなか /元田中/
もとだ /元田/
もとだいじん /元大臣/
もとだいとうりょう /元大統領/
もとだいにしょうたい /元第二小隊/
もとちゅうにち /元中日/
もとちょう /元帳/
もとていとでんてつ /元帝都電鉄/
もとで /元手/
もとでら /元寺/
もとでんきや /元電気屋/
もととうきゅう /元東急/
もととうしゅ /元投手/
もととうだい /元東大/
もとどうりょう /元同僚/
もとどおり /元通り/
もとどくしゃ /元読者/
もとどれいしょうにん /元奴隷商人/
もとなが /源久/
もとなり /元就/元成/
もとに /元に/基に/
もとにほんぐんじん /元日本軍人/
もとにほんこうくう /元日本航空/
もとにほんへい /元日本兵/
もとね /元値/
もとねた /元ネタ/
もとの /元野/基乃/本埜/
もとのり /素典/一徳/元紀/
もとはこね /元箱根/
もとはし /本橋/
もとはま /元浜/
もとはら /本原/
もとはる /元春/
もとはんきゅう /元阪急/
もとはんしん /元阪神/
もとばこ /元箱/
もとばこづき /元箱付/
もとばやし /本林/
もとばらい /元払/
もとひこ /元彦/
もとひさ /幹久/元久/基久/
もとひしょ /元秘書/
もとひで /元秀/元英/
もとひろ /元洋/基史/礎弘/基博/
もとひろしま /元広島/
もとび /元火/
もとふみ /元文/
もとぶ /本部/
もとへんしゅうちょう /元編集長/
もとほうしょう /元法相/
もとまくうち /元幕内/
もとまくうちりきし /元幕内力士/
もとまち /元町/
もとまちえき /元町駅/
もとみや /本宮/
もとむら /本村/
もとめ /求め/
もとめいこうだい /元名工大/
もとめかた /求め方/
もともと /元々/基々/
もとや /元也/
もとやま /本山/元山/
もとやまえきこうない /本山駅構内/
もとやまかん /本山間/
もとやまきたまち /本山北町/
もとやわた /本八幡/
もとゆい /元結/
もとゆき /基之/幹之/
もとよこづな /元横綱/
もとよし /元吉/本吉/基吉/基良/元慶/
もとりじちょう /元理事長/
もとりようしゃ /元利用者/
もとる /乖/
もどしこうはい /戻し交配/
もどりさき /戻り先/
もどりち /戻り値/戻値/
もなか /最中/邑中/
もにた /モニタ/
もにみあか /モニミア科/Monimiaceae/
もにわ /茂庭/
もぬけ /蛻/
もぬし /喪主/
もの /物/者/モノ/
ものいい /物言い/
ものいっぱん /物一般/
ものいみ /物忌み/
ものうい /物憂い/懶い/
ものうげ /物憂げ/
ものお /桃生/
ものおき /物置/
ものおじ /物怖/
ものおぢ /物怖/
ものおと /物音/
ものおぼえ /物覚え/
ものかき /物書き/
ものかげ /物陰/
ものがたり /物語/
ものがたりじょう /物語上/
ものがたりせい /物語性/
ものがたりせかい /物語世界/
ものがたりちゅう /物語中/
ものがたりてき /物語的/
ものがたりぶんしょう /物語文章/
ものくろ /モノクロ/
ものぐさ /懶/
ものごい /物乞/
ものごころ /物心/
ものごし /物腰/
ものごと /物事/
ものさし /物差し/物指し/物指/
ものしり /物知り/
ものじたい /物自体/
ものずき /物好き/
ものたち /者達/
ものたりない /物足りない/
ものども /者共/
もののけ /物の怪/物怪/
もののふ /武士/
もののべ /物部/
もののべし /物部氏/
もののほん /物の本/
ものぶそく /物不足/
ものべ /物部/
ものほし /物干し/物干/
ものまね /物真似/
ものまねし /物真似師/
ものみ /物見/
ものみゆさん /物見遊山/
ものもち /物持ち/
ものわかれ /物別れ/
ものわすれ /物忘れ/
もはや /最早/
もはら /茂原/
もはん /模範/
もはんえんぎ /模範演技/
もはんえんそう /模範演奏/
もはんかいとう /模範解答/模範回答/
もはんこうい /模範行為/
もはんしゅう /模範囚/
もはんじあい /模範試合/
もはんてき /模範的/
もはんてきえんそう /模範的演奏/
もばら /茂原/
もばらえき /茂原駅/
もふく /喪服/
もほう /模倣/
もほうせい /模倣性/
もみ /籾/樅/
もみあい /揉み合い/
もみあげ /揉み上げ/
もみあらい /揉み洗い/
もみい /籾井/
もみじ /紅葉/楓/椛/
もみじのが /紅葉賀/
もみじばふう /紅葉葉楓/モミジ葉楓/
もみぞく /Abies/モミ属/
もみて /揉み手/
もめごと /揉め事/揉事/
もめん /木綿/
もめんばり /木綿針/
もも /桃/百/腿/
ももい /桃井/
ももいし /百石/
ももいろ /桃色/
ももいろぞうさん /粉紅色仔象/
ももうち /桃内/
ももえ /百恵/
ももかわ /百川/桃川/
ももくりさんねん /桃栗三年/
ももこ /桃子/
ももさき /桃崎/
ももざき /百崎/
ももじりむすめ /桃尻娘/
ももせ /百瀬/
ももぞの /桃園/
ももた /百田/
ももたろう /桃太郎/
ももたろうかつげき /桃太郎活劇/
ももたろうざむらい /桃太郎侍/
ももたろうでんせつ /桃太郎伝説/
ももたろうでんてつ /桃太郎電鉄/
ももだに /桃谷/
ももとみみ /桃と耳/
もものき /桃の木/
ももひめ /桃姫/
ももみみ /桃耳/
ももむら /百村/
ももや /桃屋/
ももやま /桃山/
ももよ /百代/
ももんが /モモンガ/
もや /母屋/靄/
もよう /模様/
もようがえ /模様替/
もよおし /催し/
もよおしじょう /催場/
もよおしもの /催し物/催物/
もより /最寄り/最寄/
もよりえき /最寄駅/
もらいて /もらい手/
もらる /モラル/
もり /森/守/盛/杜/護/銛/
もりーゆ /モリーユ/
もりあい /盛合/
もりあがり /盛り上がり/
もりあき /守章/
もりあげ /盛り上げ/
もりあげかた /盛りあげ方/
もりあわせ /盛り合せ/
もりい /森井/
もりいで /森出/
もりいゆ /モリーユ/
もりうち /森内/
もりえだ /森枝/
もりお /森尾/守男/盛雄/守夫/森男/森生/杜夫/盛夫/
もりおうがい /森鴎外/
もりおか /盛岡/森岡/守岡/森丘/
もりおかいき /盛岡行/
もりおかきんこう /盛岡近郊/
もりおかけいばじょう /盛岡競馬場/
もりおかし /盛岡市/
もりおかだいいちこう /盛岡第一高/
もりおかだいさんこう /盛岡第三高/
もりおかちさい /盛岡地裁/
もりおかはつ /盛岡発/
もりかげ /森景/
もりかず /盛和/
もりかわ /森川/守川/森河/
もりがき /森垣/
もりきた /森北/
もりきたしゅっぱん /森北出版/
もりくち /森口/
もりくら /森蔵/
もりぐち /守口/森口/
もりぐちきんこう /守口近郊/
もりぐちし /守口市/
もりぐちしかん /守口市間/
もりぐちしていしゃ /守口市停車/
もりけい /森景/
もりさがり /盛り下がり/
もりさき /森崎/
もりさだ /森定/
もりさと /森里/
もりさわ /森沢/
もりしげ /護重/森重/
もりした /森下/
もりしま /森島/森嶋/
もりしんいち /森進一/
もりじり /森尻/
もりすえ /森末/
もりすみ /森住/
もりせ /森瀬/
もりそば /盛蕎麦/
もりぞう /森蔵/
もりぞの /森園/
もりた /森田/守田/盛田/
もりたか /森高/
もりたかちさと /森高千里/
もりたに /守谷/森谷/
もりだくさん /盛沢山/盛り沢山/
もりちょう /森町/
もりつ /森津/
もりつぐ /森嗣/
もりつち /盛り土/
もりつちしき /盛土式/
もりてん /森店/
もりと /森戸/
もりとう /森藤/
もりとお /盛遠/
もりとかいがん /森戸海岸/
もりとし /守利/
もりとも /守友/
もりなが /森永/
もりながじけん /森永事件/
もりながせいか /森永製菓/
もりの /森野/
もりのさと /森の里/
もりのぶ /森信/
もりのみや /森の宮/
もりばな /盛り花/
もりひこ /守彦/
もりひろ /守弘/護煕/
もりびと /守人/
もりべ /森部/
もりまつ /森松/
もりみち /守倫/
もりみつ /森光/
もりむら /森村/
もりむらせいいち /森村誠一/
もりもち /守通/
もりもと /守本/森本/盛本/
もりや /守屋/守谷/森谷/森屋/
もりやく /守役/
もりやす /森保/森安/守安/
もりやま /森山/守山/
もりやまく /守山区/
もりゆき /森雪/
もりよし /森吉/守克/
もりわか /森若/
もりわき /森脇/
もりわけ /守分/
もるもっと /モルモット/
もれ /洩れ/漏れ/
もろ /諸/師/
もろえ /諸江/
もろえや /諸江屋/
もろお /師尾/
もろおか /諸岡/師岡/師丘/
もろこし /蜀黍/
もろさと /諸里/
もろずみ /双墨/諸角/両角/
もろた /諸田/
もろつか /諸塚/
もろて /諸手/双手/
もろどみ /諸富/
もろは /両刃/
もろはし /諸橋/師橋/
もろば /両刃/
もろほし /諸星/
もろぼし /諸星/
もろみ /醪/
もろもろ /諸々/諸/
もろやま /毛呂山/
もん /門/問/文/紋/悶/聞/捫/
もんえい /門衛/
もんか /門下/
もんかせい /門下生/
もんがい /門外/
もんがいかん /門外漢/
もんがいふしゅつ /門外不出/
もんきり /紋切/紋切り/
もんく /文句/
もんくなし /文句無/文句無し/
もんげん /門限/
もんこ /門戸/
もんこく /旺角/
もんごん /文言/
もんし /悶死/門歯/
もんしょう /紋章/
もんしょうがく /紋章学/
もんしろちょう /紋白蝶/
もんしん /問診/
もんしんひょう /問診票/
もんじ /文字/
もんじゅ /文珠/
もんじょ /文書/
もんすたー /モンスター/
もんせき /問責/
もんせん /門扇/
もんぜき /門跡/
もんぜつ /悶絶/
もんぜん /門前/
もんぜんなかちょう /門前仲町/
もんぜんなかまち /門前仲町/
もんぜんまち /門前町/
もんだい /問題/
もんだいあり /問題有/
もんだいいがい /問題以外/
もんだいいしき /問題意識/
もんだいいぜん /問題以前/
もんだいいっぱん /問題一般/
もんだいか /問題化/
もんだいかいけつ /問題解決/
もんだいかいけつこうりつ /問題解決効率/
もんだいかいけつほう /問題解決法/
もんだいかいけつりょく /問題解決力/
もんだいがい /問題外/
もんだいきじ /問題記事/
もんだいきじゅつ /問題記述/
もんだいくうかん /問題空間/
もんだいけいしき /問題形式/
もんだいさく /問題作/
もんだいし /問題視/
もんだいしゅう /問題集/
もんだいじ /問題児/
もんだいじこう /問題事項/
もんだいじたい /問題自体/
もんだいすう /問題数/
もんだいず /問題図/
もんだいせい /問題性/
もんだいせってい /問題設定/
もんだいたいしょう /問題対象/
もんだいていき /問題提起/
もんだいていきしゃ /問題提起者/
もんだいてん /問題点/
もんだいてんほうこくしょ /問題点報告書/
もんだいとうこう /問題投稿/
もんだいなし /問題無/
もんだいはっけん /問題発見/
もんだいはっせい /問題発生/
もんだいはつげん /問題発言/
もんだいひょうげん /問題表現/
もんだいぶん /問題文/
もんだいぶんせき /問題分析/
もんだいようし /問題用紙/
もんだいようやく /問題要約/
もんだいりょういき /問題領域/
もんだいれい /問題例/
もんだんてん /問題点/
もんち /門地/
もんちゃく /悶着/
もんちゅう /問中/門柱/
もんちゅうじょ /問注所/
もんつき /紋付/
もんつきはかま /紋付袴/
もんてい /門弟/
もんてかるろ /モンテカルロ/
もんてかるろほう /モンテカルロ法/
もんてつかんない /門鉄管内/
もんでん /門田/
もんど /主水/門戸/
もんどう /問答/
もんどうけいしき /問答形式/
もんどうしゅう /問答集/
もんどうへん /問答篇/
もんどうむよう /問答無用/
もんどころ /紋所/
もんな /門奈/
もんの /門野/
もんばつ /門閥/
もんばやし /門林/
もんばん /門番/
もんぴ /門扉/
もんぴょう /門標/
もんぶ /文部/
もんぶかがくしょう /文部科学省;文部省と科学技術庁が2001年1月の中央省庁再編で再編されたもの/
もんぶかんりょう /文部官僚/
もんぶきょうかん /文部教官/
もんぶしょう /文部省;2001年1月の中央省庁再編で文部科学省に再編された/
もんぶしょうかんかつ /文部省管轄/
もんぶしょうけんてい /文部省検定/
もんぶだいじん /文部大臣/
もんべつ /紋別/門別/
もんべつえき /紋別駅/
もんま /門馬/門真/
もんみゃく /門脈/
もんめ /匁/問目/
もんもう /文盲/
もんもうしゃ /文盲者/
もんもん /悶々/
もんよう /文様/紋様/
や /屋/矢/野/夜/家/谷/也/↓/→/←/弥/↑/哉/冶/爺/耶/八/彌/⇒/ゃ/揶/椰/笶/埜/
やー /Я/
やいた /矢板/
やいづ /焼津/
やいづえきまえ /焼津駅前/
やいづちゅうおう /焼津中央/
やいば /刃/
やいん /夜陰/
やうち /矢内/
やえ /八重/
やえい /野営/
やえいじょう /野営場/
やえいずみ /八重泉/
やえがき /八重垣/
やえがし /八重樫/
やえこ /八重子/彌生子/
やえざくら /八重桜/
やえす /八重州/八重洲/
やえすがわ /八重洲側/
やえすぐち /八重洲口/
やえすしゅっぱん /八重洲出版/
やえすちかがい /八重洲地下街/
やえすみなみぐち /八重洲南口/
やえすむせん /八重洲無線/
やえば /八重歯/
やえやま /八重山/
やえん /野猿/
やお /八尾/八百/矢尾/
やおい /矢追/
やおいた /矢尾板/
やおき /八起/
やおくうこう /八尾空港/
やおくめ /八百粂/
やおし /八尾市/
やおちょう /八百長/
やおつ /八百津/
やおとめ /八乙女/
やおはら /八百原/
やおはん /八百半/
やおもて /矢面/
やおや /八百屋/
やおよろず /八百万/
やおん /野音/
やおんほうめん /野音方面/
やかい /夜会/
やかいふく /夜会服/
やかけちょう /矢掛町/
やかげ /矢掛/
やかた /館/屋形/舘/
やかたぶね /屋形船/屋形舟/
やから /輩/
やかん /夜間/薬罐/
やかんきゅうきゅう /夜間救急/
やかんざせきしよう /夜間座席使用/
やかんすいじょうせん /夜間水上戦/
やかんそうこうご /夜間走行後/
やかんだいがくいん /夜間大学院/
やかんちゅうきじょう /夜間駐機場/
やかんでんりょく /夜間電力/
やかんとうせき /夜間透析/
やかんぶ /夜間部/
やが /屋我/
やがい /野外/屋外/
やがいかつどう /野外活動/
やがいがた /屋外型/
やがいせっち /屋外設置/
やがいよう /野外用/
やがいりょうり /野外料理/
やがく /夜学/
やがけ /矢掛/
やがて /軅/軈/軈て/
やがみ /八神/矢上/
やがみだいこうしゃ /矢上台校舎/
やがも /矢鴨/
やがわ /矢川/
やがわら /谷川原/
やき /焼/夜気/燒/
やきいも /焼芋/
やきいん /焼き印/
やきがし /焼き菓子/
やきぎょうざ /焼餃子/
やきぐり /燒栗/
やきざかな /焼き魚/焼魚/
やきそば /焼きそば/
やきつけ /焼付け/焼付/
やきとり /焼き鳥/焼鳥/
やきとりや /焼き鳥屋/
やきどうふ /焼き豆腐/
やきなおし /焼直し/
やきにく /焼肉/焼き肉/
やきにくていしょく /焼肉定食/
やきにくや /焼肉屋/
やきにくよう /焼肉用/
やきはたのうぎょう /焼畑農業/
やきはまぐり /焼蛤/
やきびたい /焼額/
やきびたいやま /焼額山/
やきふ /焼麩/
やきぶた /焼豚/
やきまし /焼き増し/焼増/
やきめし /焼き飯/
やきもの /焼物/
やきゅう /野球/
やきゅうおうこく /野球王国/
やきゅうかい /野球界/
やきゅうかいまくちょくぜん /野球開幕直前/
やきゅうかん /野球観/
やきゅうかんけいしゃ /野球関係者/
やきゅうかんせん /野球観戦/
やきゅうかんれん /野球関連/
やきゅうきこう /野球機構/
やきゅうきゅうだん /野球球団/
やきゅうきょう /野球狂/
やきゅうきょうやく /野球協約/
やきゅうこぞう /野球小僧/
やきゅうしあい /野球試合/
やきゅうしょうねん /野球少年/
やきゅうしんぶん /野球新聞/
やきゅうじっきょう /野球実況/
やきゅうじょう /野球場/
やきゅうじん /野球人/
やきゅうずき /野球好き/
やきゅうせんしゅ /野球選手/
やきゅうたいかい /野球大会/
やきゅうだん /野球団/
やきゅうちゅうけい /野球中継/
やきゅうちゅうけいえんちょう /野球中継延長/
やきゅうつう /野球通/
やきゅうぶ /野球部/
やきゅうぶいん /野球部員/
やきゅうほんらい /野球本来/
やきゅうまんが /野球漫画/
やきゅうようご /野球用語/
やきゅうようひん /野球用品/
やきょく /夜曲/
やきりんご /焼林檎/
やきん /夜勤/冶金/
やきんこうぎょう /冶金工業/
やぎ /八木/柳/山羊/
やぎがわ /山羊革/
やぎざ /山羊座/
やぎた /八木田/
やぎぬま /八木沼/
やぎはし /八木橋/
やぎやま /八木山/
やぎゅう /柳生/
やぎゅういちぞく /柳生一族/
やぎゅうさんだい /柳生三代/
やぎゅうばし /柳生橋/
やぎょう /夜業/ヤ行/
やく /約/役/訳/薬/躍/繹/厄/夜久/龠/屋久/扼/檪/籥/葯/藥/譯/鑰/焼/蜴/≒/
やく#ねんまえ /約#3年前/
やく> /約/
やく? /約/
やくあり /訳有/
やくいちにち /約一日/
やくいちめい /約一名/
やくいん /役員/役印/薬院/約因/
やくいんかい /役員会/
やくいんしつ /役員室/
やくいんしょうよ /役員賞与/
やくいんだん /役員団/
やくえき /薬液/
やくおとし /厄落とし/
やくおん /約音/
やくがい /薬害/
やくがいきょういく /薬害教育/
やくがく /薬学/
やくがくぶ /薬学部/
やくがら /役柄/
やくぎょうじほうしゃ /薬業時報社/
やくご /訳語/
やくごめん /役御免/
やくさい /厄災/薬菜/
やくさつ /薬殺/扼殺/
やくざい /薬剤/
やくざいし /薬剤師/
やくざいしめんきょ /薬剤師免許/
やくし /訳詞/訳詩/薬師/
やくしじ /薬師寺/
やくしだけ /薬師岳/
やくしどう /薬師堂/
やくしま /屋久島/
やくしまる /薬師丸/
やくしまるひろこ /薬師丸ひろ子/
やくしゃ /訳者/役者/
やくしゃたち /役者達/
やくしゃちゅう /訳者注/
やくしゃばか /役者馬鹿/
やくしゅつ /訳出/
やくしょ /役所/訳書/
やくしょかん /役所間/
やくしょく /役職/
やくしょくめい /役職名/
やくしょしごと /役所仕事/
やくしん /躍進/薬疹/
やくじ /薬事/
やくじほう /薬事法/
やくじほういはん /薬事法違反/
やくじょ /躍如/
やくじょう /約定/
やくじょうしょ /約定書/
やくじょうりそく /約定利息/
やくじん /厄神/
やくすう /約数/
やくすぎ /屋久杉/
やくずもう /役相撲/
やくせき /薬石/
やくぜん /薬膳/
やくぜんりょうり /薬膳料理/
やくそう /薬草/躍層/
やくそうがく /薬草学/
やくそく /約束/
やくそくごと /約束事/
やくそくてがた /約束手形/
やくたい /益体/
やくだつ /役立つ/
やくちゅう /訳注/訳註/薬中/
やくづき /役付き/
やくて /約手/
やくてい /約定/
やくとく /役得/
やくどう /躍動/
やくどうかん /躍動感/
やくどく /役得/
やくどし /厄年/
やくなし /訳無/
やくなんこ /約何個/
やくにん /役人/
やくにんさま /役人様/
やくにんたち /役人達/
やくの /夜久野/
やくはんすう /約半数/
やくはんとし /約半年/
やくはんとしまえ /約半年前/
やくはんね /約半値/
やくはんぶん /約半額/約半分/
やくば /役場/
やくばらい /厄払い/
やくひん /薬品/
やくひんしゅう /薬品臭/
やくひんじょうほう /薬品情報/
やくび /厄日/
やくびょうがみ /厄病神/
やくぶそく /役不足/
やくぶつ /薬物/
やくぶついぞんしょう /薬物依存症/
やくぶつしょじ /薬物所持/
やくぶつちゅうどく /薬物中毒/
やくぶつてきしゅうかんせい /薬物的習慣性/
やくぶつはんのう /薬物反応/
やくぶん /約分/訳文/
やくほう /薬包/
やくほん /訳本/
やくぼ /矢久保/
やくまる /薬丸/
やくまわり /役回り/
やくまん /役満/
やくまんれき /役満歴/
やくみ /薬味/
やくみけい /薬味系/
やくめ /役目/
やくめい /役名/
やくも /八雲/
やくもがくえん /八雲学園/
やくもの /役物/
やくゆ /薬湯/
やくよう /薬用/
やくよけ /厄除/
やくり /薬理/
やくりがく /薬理学/
やくりきし /役力士/
やくりさよう /薬理作用/
やくると /ヤクルト/
やくるとほんしゃ /ヤクルト本社/
やくろう /薬籠/
やくわり /役割/
やくわりいっぱん /役割一般/
やくわりぶんたん /役割分担/
やぐ /夜具/
やぐち /矢口/谷口/
やぐら /櫓/矢倉/
やぐらなげ /櫓投げ/
やけ /自棄/
やけあと /焼け跡/焼跡/
やけい /夜景/夜警/野鶏/
やけいし /焼け石/
やけこげ /焼け焦げ/
やけだけ /焼岳/
やけど /火傷/
やけどじょうたい /火傷状態/
やけのはら /焼野原/焼け野原/
やけひばし /焼け火箸/
やけびたい /焼額/
やけびたいさん /焼額山/
やけぼっくい /焼け棒杭/
やけん /野犬/
やこう /夜行/矢向/夜光/八高/夜香/
やこうかいそく /夜行快速/
やこうきゅうこう /夜行急行/
やこうこうそく /夜行高速/
やこうしんだい /夜行寝台/
やこうしんだいれっしゃ /夜行寝台列車/
やこうせい /夜行性/夜光性/
やこうちゅう /夜行虫/夜光虫/
やこうちょうきょり /夜行長距離/
やこうとっきゅう /夜行特急/
やこうばす /夜行バス/
やこうびん /夜行便/
やこうれっしゃ /夜行列車/
やこぜん /野狐禅/
やこびぎょうれつ /ヤコビ行列/
やごう /屋号/
やごし /矢越/
やごと /八事/
やさい /野菜/
やさいいため /野菜炒め/
やさいいちば /野菜市場/
やさいうりば /野菜売場/
やさいしつ /野菜室/
やさいぞえ /野菜添え/
やさいほぞんよう /野菜保存用/
やさいるい /野菜類/
やさか /八坂/八尺/弥栄/
やさかじんじゃ /八坂神社/
やさき /矢先/
やさく /矢作/
やさと /八郷/
やざき /矢崎/
やざわ /矢沢/矢澤/谷沢/
やし /椰子/香具師/椰/
やしお /八潮/八入/
やしき /屋敷/屋輔/矢輔/邸/壥/廛/
やしち /弥七/
やしのみ /椰子の実/
やしま /屋島/矢島/
やしもく /ヤシ目/Aracales/Palmales/Principes/
やしもくぐん /ヤシ目群/
やしゃ /夜叉/
やしゃご /玄孫/
やしゅ /野趣/野手/
やしゅう /夜襲/
やしゅじん /野手陣/
やしょく /夜食/
やしろ /社/八代/安城/
やしわご /玄孫/
やしん /野心/
やしんてき /野心的/
やじ /野次/
やじうま /野次馬/弥次馬/
やじうまてききょうみ /野次馬的興味/
やじま /谷島/矢島/矢嶋/八島/
やじまや /谷島屋/
やじゅう /野獣/
やじゅうは /野獸派/
やじり /鏃/
やじるし /矢印/↓/→/↑/←/⇒/⇔/
やじるしきー /矢印キー/
やじるししんごう /矢印信号/
やじるしほうこう /矢印方向/
やじろべい /弥次郎兵衛/
やす /安/康/泰/靖/野洲/恭/保/裕/夜須/
やすあき /康明/恭章/泰昭/保昭/
やすい /安井/靖/保井/
やすいけ /安池/
やすいちろう /靖一郎/
やすうら /安浦/
やすうり /安売/安売り/
やすえ /康恵;名/安江;姓/安恵;名/保江;名/
やすお /康夫/康生/泰生/泰男/靖雄/康雄/安男/安雄/康男/泰夫/泰雄/保男/保夫/保雄/靖夫/八洲男/裕雄/恭朗/寿男/保生/弥寿夫/
やすおか /安岡/泰阜/
やすかが /安加賀/
やすかず /保和/保一/康一/
やすかわ /安川/
やすかわでんき /安川電機/
やすき /康己/泰樹/安樹/靖己/
やすきよ /安挙/
やすぎ /安来/八杉/
やすくに /靖国/
やすくにじんじゃ /靖国神社/
やすくにじんじゃさんぱい /靖国神社参拝/
やすくにどおり /靖国通り/
やすげっきゅう /安月給/
やすこ /靖子/康子/恭子/泰子/妥子/安子/
やすさ /安さ/
やすさだ /保貞/
やすさと /安里/
やすざか /安坂/
やすざけ /安酒/
やすし /靖/康/泰/康史/泰司/也寸志/尉/保司/靖史/泰士/保/廉史/安/靖志/寧/
やすしば /安柴/
やすじ /康司/康次/康二/康嗣/
やすじろう /安二郎/
やすたか /康隆/泰隆/泰宇/泰孝/泰臣/
やすたけ /康剛/安武/
やすたに /保谷/
やすたみ /康民/
やすだ /安田/保田/
やすだかさい /安田火災/
やすだきねん /安田記念/
やすだきねんば /安田記念馬/
やすだこうどう /安田講堂/
やすだなるみ /安田成美/
やすっぽい /安っぽい/
やすづか /安塚/
やすて /野ステ/
やすてつ /康哲/
やすと /靖人/保人/
やすとし /康俊/康敏/泰稔/
やすとみ /安富/
やすとめ /安留/
やすとも /康友/
やすなお /康尚/
やすなが /安永/康永/保永/
やすなり /康成/康也/
やすね /安値/
やすの /安野/
やすのう /安納/
やすのぶ /恭伸/保信/泰信/
やすのり /保則/保法/康則/安則/泰憲/康徳/靖則/保徳/安紀/泰則/泰典/保憲/靖教/保典/
やすは /泰葉/
やすはら /安原/保原/
やすはる /泰晴/康治/泰治/康晴/
やすひこ /康彦/靖彦/泰彦/安彦/
やすひさ /恭久/靖久/
やすひで /保秀/
やすひと /保人/康仁/
やすひろ /泰宏/恭弘/康博/康弘/康裕/泰広/保浩/保博/安弘/靖宏/安浩/康浩/泰寛/泰弘/靖浩/靖太/康宏/康広/靖弘/恭裕/保広/
やすふみ /泰史/康文/康史/
やすぶしん /安普請/
やすぶみ /康文/
やすまさ /康正/泰正/康雅/
やすまつ /安松/
やすみ /休み/保美/休/
やすみあけ /休み明け/
やすみじかん /休み時間/
やすみち /易道/
やすみちゅう /休み中/
やすみつ /康光/康満/
やすむら /安村/
やすもと /安本/
やすもの /安物/
やすや /恭也/
やすやす /易々/
やすやど /安宿/
やすゆき /靖幸/康之/保之/泰之/靖之/康行/育志/恭之/康幸/泰幸/
やすよ /靖代/安代/康代/康世/
やすよし /康善/康良/康義/靖佳/
やすら /安良/
やすり /鑢/
やすろう /恭郎/康朗/
やず /谷津/
やずぎ /八杉/
やせ /八瀬/
やせい /野生/野性/
やせいか /野性化/
やせいしゅ /野性種/
やせいじ /野生児/野性児/
やせいじだい /野生時代/野性時代/
やせいどうぶつ /野生動物/
やせいみ /野生味/
やせがた /やせ型/
やせがまん /痩せ我慢/
やせん /夜戦/野戦/
やせんぐん /野戦軍/
やせんこうじょう /野戦攻城/
やそ /八十/耶蘇/
やそう /夜走/野草/
やそうえん /野草園/
やそうきょく /夜想曲/
やそかわ /八十川/
やそすけ /八十助/
やそよろず /八十万/
やた /矢田/八咫/
やたい /屋台/
やたいぼね /屋台骨/
やたいむら /屋台村/
やたがい /矢田貝/
やたがらす /八咫鴉/
やたでら /矢田寺/
やたのかがみ /八咫鏡/
やたべ /谷田部/
やたま /矢玉/
やたやま /矢田山/
やたら /矢鱈/
やたろう /弥太郎/
やだ /矢田/煎田/
やち /谷地/萢/
やちた /谷地田/
やちだ /谷内田/
やちほ /八千穂/
やちまた /八街/
やちまたし /八街市/
やちゅう /夜中/
やちょう /野鳥/野帳/
やちよ /八千代/
やちよかん /八千代間/
やちよし /八千代市/
やちよだい /八千代台/
やちよばし /八千代橋/
やちん /家賃/屋賃/
やちんしゅうにゅう /家賃収入/
やちんほじょ /家賃補助/
やちんほじょがく /家賃補助額/
やっか /薬科/薬価/
やっかい /厄介/
やっかいごと /厄介事/
やっかきじゅん /薬価基準/
やっかさえき /薬価差益/
やっかだいがく /薬科大学/
やっかん /約款/
やっき /躍起/
やっきょう /薬夾/薬莢/
やっきょく /薬局/
やっこ /奴/
やっこうはつげん /薬効発現/
やっこそうか /ヤッコソウ科/Rafflesiaceae/
やっこそうもく /ヤッコソウ目/Rafflesiales/
やっつ /八つ/
やっとこ /鋏/
やっぱり /矢つ張り/
やつ /奴/谷津/八/谷/
やつお /八尾/
やつか /八束/
やつがたけ /八ヶ岳/
やつがだけ /八岳/八ヶ岳/
やつぎ /矢継/
やつぎばや /矢継ぎ早/矢次ぎ早/
やつざき /八つ裂き/
やつしろ /八代/
やつだ /谷津田/
やつだま /八玉/
やつはし /八つ橋/
やつめうなぎ /鱧/
やつもり /八ッ森/
やつゆうえん /谷津遊園/
やつら /奴等/
やと /野兎/
やとい /雇/
やといにん /雇人/
やといぬし /雇主/雇い主/
やとう /野党/
やとみ /弥富/
やど /宿/
やどかり /寄居虫/寄居蟲/
やどじょうほう /宿情報/
やどだい /宿代/
やどちょう /宿帳/
やどちん /宿賃/
やどぬし /宿主/
やどや /宿屋/
やどりき /宿木/
やどりぎ /宿り木/
やどろく /宿六/
やな /梁/簗/
やない /柳井/矢内/屋内/
やないづ /柳津/
やなお /柳尾/
やなか /谷中/
やながわ /柳川/梁川/
やながわしない /柳川市内/
やなぎ /柳/
やなぎごし /柳腰/
やなぎさわ /柳沢/柳澤/
やなぎさわえき /柳沢駅/
やなぎしま /柳島/
やなぎたに /柳谷/
やなぎだ /柳田/
やなぎちょう /柳町/
やなぎはら /柳原/
やなぎば /柳葉/
やなぎばとしろう /柳葉敏郎/
やなぎぼり /柳堀/
やなぎまち /柳町/
やなぎもく /ヤナギ目/Salicales/
やなぎもくあぐん /ヤナギ目亜群/
やなぎもと /柳本/
やなぎや /柳家/柳谷/
やなざき /柳崎/
やなせ /柳瀬/
やなだに /柳谷/
やなつ /柳津/
やなとり /梁取/
やなはら /柵原/
やなば /簗塲/
やなみ /家並み/
やなる /矢鳴/
やに /脂/
やぬし /家主/
やね /屋根/
やねあと /屋敷跡/
やねいた /屋根板/
やねうま /屋根馬/
やねうら /屋根裏/
やねうらべや /屋根裏部屋/
やねがた /屋根型/
やねこうばい /屋根勾配/
やねごし /屋根越し/
やねざい /屋根材/
やねした /屋根下/
やねじょう /屋根上/
やねづけ /屋根付/
やねゆき /屋根雪/
やの /矢野/
やのあきこ /矢野顕子/
やのくら /矢野倉/
やのぐち /矢野口/
やのけん /矢野研/
やのはら /矢箆原/
やはぎ /矢作/矢矧/八萩/
やはた /八幡/
やはたし /八幡市/
やはたしえき /八幡市駅/
やはたしかん /八幡市間/
やはたしょてん /八幡書店/
やはたていしゃ /八幡停車/
やはたにし /八幡西/
やはたの /八幡野/
やはたひがし /八幡東/
やはたやま /八幡山/
やはば /矢巾/
やはり /矢張り/
やはん /夜半/
やはんまえ /夜半前/
やばけい /耶馬渓/
やばとん /矢場とん/
やばん /野蛮/
やばんじん /野蛮人/
やひ /野卑/
やひこ /弥彦/
やひこせん /弥彦線/
やひろ /八尋/
やぶ /薮/藪/
やぶうち /薮内/
やぶか /薮蚊/
やぶがみ /薮上/
やぶき /矢吹/
やぶさか /吝か/
やぶさめ /流鏑馬;流鏑馬;騎射(きしゃ)の一種/薮雨;シオサザイ、カワリウグイス/薮鮫;シオサザイ、カワリウグイス/
やぶさわ /薮沢/
やぶそば /薮蕎麦/
やぶた /藪田/
やぶにらみ /藪睨み/
やぶはら /薮原/
やぶへび /薮蛇/
やぶみ /矢文/
やぶもと /薮本/藪本/
やぶん /夜分/
やべ /矢部/
やべせん /矢部線/
やほ /屋舗/谷保/
やほう /野砲/
やほうず /野放図/
やほこ /八穂子/
やほり /矢堀/
やぼ /野暮/ヤボ/
やぼう /野望/
やぼよう /野暮用/
やま /山/耶麻/夜魔/岾/
やまあい /山合/
やまあし /山足/
やまあらし /山嵐/
やまあるき /山歩き/
やまい /病/山井/
やまいこうこう /病膏肓/
やまいち /山一證券/
やまいちしょうけん /山一證券/
やまいぬ /山犬/犲/豺/
やまいも /山芋/
やまいもあめ /山芋飴/
やまうずら /鷓鴣/
やまうち /山内/
やまうら /山浦/
やまえ /山江/
やまお /山尾/
やまおか /山岡/
やまおき /山沖/
やまおく /山奥/
やまおとこ /山男/
やまおり /山折り/
やまかげ /山影/山陰/
やまかさ /山笠/
やまかみ /山上/
やまかわ /山川/
やまかわしゅっぱんしゃ /山川出版社/
やまかん /山勘/
やまが /山鹿/山賀/山香/
やまがさ /山笠/
やまがた /山形/山縣/山県/山型/山方/
やまがたいえん /山形以遠/
やまがたえき /山形駅/
やまがたかん /山形間/
やまがたがわ /山形側/
やまがたきた /山形北/
やまがたぎんこう /山形銀行/
やまがたけいゆう /山形経由/
やまがたけん /山形県/
やまがたけんない /山形県内/
やまがたざおう /山形蔵王/
やまがたし /山形市/
やまがたしはつ /山形始発/
やまがたしんかんせん /山形新幹線/
やまがたじどうしゃどう /山形自動車道/
やまがただい /山形大/
やまがただいがく /山形大学/
やまがただいこう /山形大工/
やまがたばん /山形版/
やまがたひがし /山形東/
やまがたふう /山形風/
やまがたほうそう /山形放送/
やまがたほうめん /山形方面/
やまがみ /山上/
やまがわ /山側/山川/
やまき /山木/八巻/八槇/八槙/
やまきた /山北/
やまぎし /山岸/
やまぎわ /山際/
やまぎん /山吟/
やまくずれ /山崩れ/
やまくに /山国/
やまくら /山倉/
やまぐち /山口/
やまぐちけん /山口県/
やまぐちけんしゅっしん /山口県出身/
やまぐちけんない /山口県内/
やまぐちさよこ /山口小夜子/
やまぐちし /山口市/
やまぐちしゅっしん /山口出身/
やまぐちせん /山口線/
やまぐちせんけいゆ /山口線経由/
やまぐちせんけいゆう /山口線経由/
やまぐちだい /山口大/
やまぐちだいがく /山口大学/
やまぐちほうそう /山口放送/
やまぐちももえ /山口百恵/
やまぐに /山国/
やまぐるまか /ヤマグルマ科/Trochodendraceae/
やまけい /山渓/
やまこう /山交/
やまこし /山越/山腰/山古志/
やまごや /山小屋/
やまさ /山佐/
やまさか /山坂/
やまさき /山崎/
やまざき /山崎/山咲/
やまざきせいぱん /山崎製パン/
やまざきひろこ /山崎浩子/
やまざくら /山桜/
やまざと /山里/
やまし /山師/
やました /山下/
やましたけん /山下研/
やましたこうえん /山下公園/
やましたしょてん /山下書店/
やましたたつろう /山下達郎/
やましたふとう /山下埠頭/
やましな /山科/
やましなえき /山科駅/
やましなく /山科区/
やましなじゅうみん /山科住民/
やましななんぶ /山科南部/
やましなふきん /山科付近/
やましなほうめん /山科方面/
やましろ /山城/
やましろこうこう /山城高校/
やましろや /山代屋/
やまじ /山路/山地/
やますそ /山裾/
やまずい /山瑞/
やまずみ /山積/
やませ /山瀬/
やまぜん /山善/
やまそだち /山育ち/
やまそと /山外/
やまぞい /山沿い/
やまぞえ /山添/
やまたい /耶馬台/
やまたいこく /邪馬台国/邪馬壹国/邪馬臺国/
やまたかぼう /山高帽/
やまたけ /山武/
やまたけはねうぇる /山武ハネウェル/
やまたに /山谷/
やまたねさんぎょう /山種産業/
やまたねしょうけん /山種証券/
やまたのおろち /八俣の大蛇/八俣之大蛇/八岐大蛇/八岐の大蛇/
やまだ /山田/
やまだい /山大/
やまだいこう /山大工/
やまだいすず /山田五十鈴/
やまだおんせん /山田温泉/
やまだがわ /山田川/
やまだしょいん /山田書院/
やまだせん /山田線/
やまだにしき /山田錦/
やまだようじ /山田洋次/
やまちく /山蓄/
やまっけ /山っ気/
やまつか /山塚/
やまつり /矢祭/
やまづみ /山積み/
やまて /山手/
やまてかもつせん /山手貨物線/
やまてせん /山手線/
やまてせんけいゆ /山手線経由/
やまてせんない /山手線内/
やまてら /山寺/
やまでら /山寺/
やまでらかん /山寺間/
やまでん /山電/
やまと /大和/山門/
やまとうんゆ /ヤマト運輸/
やまとえいぎょうしょ /大和営業所/
やまとえき /大和駅/
やまとおうちょう /大和王朝/
やまときち /大和基地/
やまとぐさもく /ヤマトグサ目/Theligonales/
やまとけいゆ /大和経由/
やまとこうぎょう /大和工業/
やまとこおりやま /大和郡山/
やまとことば /大和言葉/
やまとご /大和語/
やまとし /大和市/
やまとしみん /大和市民/
やまとじ /大和路/
やまとじむしょ /大和事業所/
やまとそうけん /大和総研/
やまとたかだ /大和高田/
やまとたける /日本武尊/
やまとちょうてい /大和朝廷/
やまとなでしこ /大和撫子/
やまとに /大和煮/
やまとみ /山富/
やまとみんぞく /大和民族/
やまな /山名/
やまなか /山中/
やまなかこ /山中湖/
やまなかこしゅうへん /山中湖周辺/
やまなかごえ /山中越/
やまなし /山梨/
やまなしがわ /山梨側/
やまなしけん /山梨県/
やまなしけんおおつき /山梨県大月/
やまなしけんおぶちざわ /山梨県小淵沢/
やまなしけんがわ /山梨県側/
やまなしけんしゅっしん /山梨県出身/
やまなしけんじん /山梨県人/
やまなしけんない /山梨県内/
やまなしこうじょう /山梨工場/
やまなしざいじゅう /山梨在住/
やまなしし /山梨市/
やまなししゅっしん /山梨出身/
やまなしだい /山梨大/
やまなしだいがく /山梨大学/
やまなしとくゆう /山梨特有/
やまなしながのけんざかい /山梨長野県境/
やまなしほうそう /山梨放送/
やまなみ /山並み/山並/
やまなり /山形/
やまにし /山西/
やまね /山根/
やまねこ /山猫/
やまの /山野/
やまのうえ /山上/
やまのうち /山之内/山ノ内/
やまのうちけん /山之内研/
やまのうちせいやく /山之内製薬/
やまのかみ /山之上/
やまのがっき /山野楽器/
やまのくち /山之口/
やまのて /山の手/山手/
やまのてせん /山手線/
やまのてせんない /山手線内/
やまのぼり /山登り/
やまのぼりほう /山登り法/
やまは /ヤマハ/山葉/
やまはい /山廃/
やまはいぎんじょう /山廃吟醸/
やまはいじこみ /山廃仕込み/
やまはた /山畑/
やまはだ /山肌/
やまははつどうき /ヤマハ発動機/
やまはら /山原/
やまば /山場/
やまばい /山廃/
やまび /山日/
やまびこ /山彦/谺/
やまびらき /山開き/
やまふじ /山藤/
やまふだ /山札/
やまぶき /山吹/
やまぶきいろ /山吹色/
やまぶきちょう /山吹町/
やまぶし /山伏/
やまぶち /山淵/
やまべ /山部/山辺/
やまほこじゅんこう /山鉾巡行/
やまほど /山程/
やまぼこ /山鉾/
やままつ /山松/
やままん /山万/
やまみち /山道/
やまむら /山村/
やまむらがらす /山村硝子/
やまめ /山女/
やまもがしもく /ヤマモガシ目/Proteales/
やまもがしもくぐん /ヤマモガシ目群/
やまもと /山本/山元/
やまもとかんさい /山本寛斎/
やまもとけん /山本研/
やまもとこうじ /山本浩二/
やまもとしゅうごろう /山本周五郎/
やまもとちょう /山本丁/
やまもとひろし /山本弘/
やまもとや /山本屋/
やまもとやま /山本山/
やまもももく /ヤマモモ目/Myricales/
やまもり /山森/山盛り/山守/
やまや /山矢/山屋/山家/
やまやしき /山屋敷/
やまやま /山々/
やまゆき /山行/
やまよう /山用/
やまようひん /山用品/
やまわき /山脇/
やまわきがくえん /山脇学園/
やまわけ /山分け/
やまんば /山姥/
やみ /闇/
やみいち /闇市/
やみうち /闇討/
やみきょういく /闇教育/
やみくも /闇雲/
やみごめ /闇米/
やみしょうばい /闇商売/
やみつき /病み付き/
やみなべ /闇鍋/
やみね /闇値/
やみもり /闇森/
やみよ /闇夜/
やみりょうがえ /闇両替/
やむ /已む/
やむちゃ /飲茶/茶飲/
やむをえず /止むを得ず/
やもお /鰥/
やもと /矢本/
やもめ /寡/鰥夫/
やもり /夜森/
やや /漸/稍/
ややおも /稍重/
やゆ /揶揄/
やゆてき /揶揄的/
やよい /弥生/
やよいき /弥生期/
やよいご /弥生語/
やよいしょう /弥生賞/
やよいじだい /弥生時代/
やよいじだいごろ /弥生時代頃/
やよいじん /弥生人/
やよいちく /弥生地区/
やよいちょう /弥生町/
やよいぶんか /弥生文化/
やよいもん /弥生門/
やら /屋良/
やらい /矢来/
やらいちょう /矢来町/
やり /鑓/矢理/槍/
やりかた /やり方/
やりがたけ /槍ヶ岳/
やりがだけ /槍岳/
やりきへい /槍騎兵/
やりくち /遣口/
やりしき /やり式/
やりた /鎗田/
やりだま /やり玉/槍玉/
やりて /やり手/
やりとり /やり取り/遣り取り/
やりみず /鑓水/
やりよう /やり様/
やるせない /遣る瀬ない/
やろう /野郎/
やろうどうし /野郎同士/
やわ /夜話/
やわた /八幡/
やわたはま /八幡浜/
やわはだ /柔肌/
やわら /柔/谷和原/
やん /楊/梁/
やんぐ /ヤング/
やんべ /山家/
ゆ /油/諭/輸/由/湯/癒/愉/愈/喩/揃/遊/兪/揄/渝/瑜/瘉/腴/臾/蝓/覦/諛/踰/逾/斎/柚/楡/
ゆーざ /ユーザ/
ゆーざーず /ユーザーズ/
ゆーてぃりてぃ /ユーティリティ/
ゆーみん /松任谷由実/ユーミン/
ゆあえるむ /ユアエルム/
ゆあさ /湯浅/湯淺/
ゆあさでんち /湯浅電池/
ゆあつ /油圧/
ゆあつけい /油圧系/油圧計/
ゆあつけんしゅつき /油圧検出器/
ゆあつしき /油圧式/
ゆい /唯/由/結/由以/悠衣/遺/油井/湯井/由衣/由比/由井/
ゆいいつ /唯一/惟一/
ゆいいつせい /唯一性/
ゆいいつぜったい /唯一絶対/
ゆいいつち /唯一知/
ゆいいつむに /唯一無二/
ゆいえき /由比駅/
ゆいか /結花/
ゆいが /唯我/
ゆいがどくそん /唯我独尊/唯我獨尊/
ゆいごん /遺言/
ゆいごんしょ /遺言書/
ゆいごんじょう /遺言状/
ゆいごんにん /遺言人/
ゆいしょ /由緒/
ゆいしょうせつ /由比小説/
ゆいしん /唯心/
ゆいしんろん /唯神論/
ゆいのう /結納/
ゆいのうきん /結納金/
ゆいのうしき /結納式/
ゆいのうひん /結納品/
ゆいのうや /結納屋/
ゆいのうろん /唯脳論/
ゆいぶつ /唯物/
ゆいぶつろん /唯物論/
ゆいぶつろんてき /唯物論的/
ゆいぶつろんべんしょうほう /唯物論弁証法/
ゆいめいろん /唯名論/
ゆう /有/夕/優/雄/由/裕/融/遊/祐/郵/誘/友/猶/勇/湧/邑/憂/猷/涌/右/揖/柚/幽/悠/宥/尤/佑/酉/熊/侑/囿/尢/悒/攸/游/犹/疣/肬/莠/蕕/蚰/蝣/釉/黝/木綿/俑/由宇/
ゆう> /優/
ゆうあい /友愛/
ゆうい /優位/有為/有意/
ゆういぎ /有意義/
ゆういさ /有意差/
ゆういさけんてい /有意差検定/
ゆういしゃ /優位者/
ゆういせい /優位性/有意性/
ゆういせいけんてい /優位性検定/有意性検定/
ゆういち /雄一/裕一/祐一/勇一/友一/有一/優一/
ゆういちろう /祐一郎/勇一郎/雄一郎/裕一郎/有一郎/
ゆういてん /優位点/
ゆういみ /有意味/
ゆういん /誘因/誘引/
ゆううつ /憂鬱/
ゆうえい /遊泳/游泳/
ゆうえき /有益/
ゆうえきせい /有益性/
ゆうえきせいついきゅう /有益性追求/
ゆうえつ /優越/勇悦/
ゆうえつかん /優越感/
ゆうえつこう /優越項/
ゆうえん /結縁/有鉛/遊園/幽艶/優艶/
ゆうえんち /遊園地/
ゆうえんちけん /遊園地券/
ゆうおう /勇徃/
ゆうおうまいしん /勇徃邁進/
ゆうおんくかん /有音区間/
ゆうか /有価/
ゆうかい /誘拐/有界/融解/幽界/
ゆうかいくかん /有界区間/
ゆうかいじけん /誘拐事件/
ゆうかいだん /優階段/
ゆうかいはん /誘拐犯/
ゆうかいはんにん /誘拐犯人/
ゆうかいへんどう /有界変動/
ゆうかいほうどう /誘拐報道/
ゆうかいもの /誘拐物/
ゆうかいようぎ /誘拐容疑/
ゆうかく /遊廓/
ゆうかしょうけん /有価証券/
ゆうかだん /憂歌団/
ゆうかぶつ /有価物/
ゆうかん /夕刊/勇敢/有閑/有感/
ゆうかんじしん /有感地震/
ゆうかんぶぶん /有感部分/
ゆうが /優雅/勇牙/
ゆうがい /有害/
ゆうがいしがいせん /有害紫外線/
ゆうがいしてい /有害指定/
ゆうがいとしょ /有害図書/
ゆうがいぶっしつ /有害物質/
ゆうがいむえき /有害無益/
ゆうがお /夕顔/
ゆうがく /遊学/
ゆうがた /夕方/
ゆうがたいこう /夕方以降/
ゆうがたごろ /夕方頃/
ゆうがたしゅっぱつ /夕方出発/
ゆうがたはつ /夕方発/
ゆうがたびん /夕方便/
ゆうがびみょう /優雅微妙/
ゆうき /勇気/有機/結城/夕貴/優希/裕木/夕希/雄希/友樹/雄基/雄規/幽鬼/有希/勇喜/悠紀/有紀/有規/裕樹/夕樹/有基/祐己/憂木/優起/祐希/誘起/又木/優樹/
ゆうきおん /有気音/
ゆうきかがく /有機化学/
ゆうきかごうぶつ /有機化合物/
ゆうきごうせい /有機合成/
ゆうきざい /有機材/
ゆうきしつ /有機質/
ゆうきすいそこうせき /有機水素鉱石/
ゆうきせいおんがく /誘起性音楽/
ゆうきたい /有機体/
ゆうきち /勇吉/有吉/祐吉/
ゆうきてき /有機的/有基的/
ゆうきてきかんれん /有機的関連/
ゆうきのうほう /有機農法/
ゆうきひりょう /有機肥料/
ゆうきぶつ /有機物/
ゆうきゃく /遊脚/
ゆうきや /有機屋/
ゆうきゅう /有休/遊休/悠久/有給/
ゆうきゅうきゅうか /有給休暇/
ゆうきゅうしさん /遊休資産/
ゆうきゅうすう /優級数/
ゆうきゅうち /遊休地/
ゆうきょう /遊興/
ゆうきょうでん /遊侠伝/
ゆうきようざい /有機溶剤/
ゆうきようばい /有機溶媒/
ゆうぎ /遊戯/遊技/友誼/
ゆうぎき /遊技機/遊戯機/
ゆうぎきんし /遊技禁止/
ゆうぎしゃ /遊戯者/
ゆうぎしゃすう /遊戯者数/
ゆうぎじょう /遊戯場/遊技場/
ゆうぎだい /遊技台/
ゆうぎちゅう /遊技中/
ゆうぎほう /遊技法/
ゆうぎょ /勇魚/游魚/
ゆうぎり /夕霧/
ゆうぎりょうきん /遊技料金/
ゆうぐう /優遇/
ゆうぐうぜいせい /優遇税制/
ゆうぐうそち /優遇措置/
ゆうぐれ /夕暮れ/夕暮/
ゆうぐん /友軍/遊軍/
ゆうぐんき /友軍機/
ゆうけい /有形/
ゆうけいこていしさん /有形固定資産/
ゆうけいりょく /有形力/
ゆうけっていけい /優決定系/
ゆうけん /有権/
ゆうけんしゃ /有権者/
ゆうけんしゃすう /有権者数/
ゆうけんしゃぞう /有権者像/
ゆうげ /夕餉/
ゆうげき /遊撃/
ゆうげきしゅ /遊撃手/
ゆうげん /有限/祐源/幽玄/有言/幽幻/
ゆうげんいっぱん /有限一般/
ゆうげんおんど /有限温度/
ゆうげんかい /有限回/
ゆうげんがいしゃ /有限会社/
ゆうげんぐん /有限群/
ゆうげんぐんろん /有限群論/
ゆうげんけいれつ /有限系列/
ゆうげんこ /有限個/
ゆうげんしげん /有限資源/
ゆうげんしつりょう /有限質量/
ゆうげんしゅうごう /有限集合/
ゆうげんじっこう /有言実行/
ゆうげんじっこうがた /有言実行型/
ゆうげんじょうたい /有限状態/
ゆうげんせい /有限性/
ゆうげんだいすう /有限代数/
ゆうげんち /有限値/
ゆうげんちょう /有限長/
ゆうげんてき /有限的/
ゆうげんようそほう /有限要素法/
ゆうげんれつ /有限列/
ゆうこ /裕子/祐子/友子/優子/裕有子/ゆう子/由子/夕子/悠子/木綿子/有子/由布子/侑子/
ゆうこう /有効/有向/友好/遊興/有孔/裕弘/
ゆうこういんじりょういき /有効印字領域/
ゆうこうえだ /有向枝/
ゆうこうか /有効化/
ゆうこうかいとうすう /有効回答数/
ゆうこうかつよう /有効活用/
ゆうこうかんけい /友好関係/
ゆうこうがそ /有効画素/
ゆうこうがそすう /有効画素数/
ゆうこうきかん /有効期間/
ゆうこうきかんちゅう /有効期間中/
ゆうこうきかんない /有効期間内/
ゆうこうきげん /有効期限/有効期間/
ゆうこうきげんない /有効期限内/
ゆうこうきょり /有効距離/
ゆうこうぎ /有向木/
ゆうこうくかんない /有効区間内/
ゆうこうけた /有効桁/
ゆうこうけたすう /有効桁数/
ゆうこうけたすうひょうじ /有効桁数表示/
ゆうこうこうけい /有効口径/
ゆうこうこく /友好国/
ゆうこうこくどうし /友好国同士/
ゆうこうしつりょう /有効質量/
ゆうこうしゅうごう /有向集合/
ゆうこうじかんたい /有効時間帯/
ゆうこうじょうやく /友好条約/
ゆうこうすう /有効数/
ゆうこうすうじ /有効数字/
ゆうこうせい /有効性/
ゆうこうせいぶん /有効成分/
ゆうこうせんぶん /有向線分/
ゆうこうそくど /有効速度/
ゆうこうだ /有効打/
ゆうこうだすう /有効打数/
ゆうこうちゅう /有孔虫/
ゆうこうちょう /有効長/
ゆうこうてき /友好的/有効的/
ゆうこうてんれつ /有向点列/
ゆうこうとうひょうしゃ /有効投票者/
ゆうこうとうひょうすう /有効投票数/
ゆうこうとうひょうちゅう /有効投票中/
ゆうこうとうひょうりつ /有効投票率/
ゆうこうとくてん /有効得点/
ゆうこうど /友好度/
ゆうこうはんい /有効範囲/
ゆうこうひょう /有効票/
ゆうこうひょうじめんせき /有効表示面積/
ゆうこうび /有効日/
ゆうこうびっと /有効ビット/
ゆうこうぶ /有効部/
ゆうこうへん /有向辺/
ゆうこうまいすう /有効枚数/
ゆうこうりょう /有効量/
ゆうこうりよう /有効利用/
ゆうこうりようほう /有効利用法/
ゆうこく /憂国/夕刻/幽谷/
ゆうごう /融合/
ゆうごうがた /融合型/
ゆうごうがたげんご /融合型言語/
ゆうごうがったい /融合合体/
ゆうごうけい /融合型/
ゆうごうけん /融合研/
ゆうごうてき /融合的/
ゆうごうぶんや /融合分野/
ゆうごうろ /融合炉/
ゆうごはん /夕御飯/
ゆうさい /幽斎/
ゆうさく /優作/祐策/裕作/勇作/雄作/雄策/
ゆうざい /有罪/
ゆうざいはんけつ /有罪判決/
ゆうざん /雄山/
ゆうざんかく /雄山閣/
ゆうし /融資/有志/勇史/勇士/勇姿/雄姿/有史/遊資/
ゆうしかく /有資格/
ゆうしかくしゃ /有資格者/
ゆうしき /有識/
ゆうしきしゃ /有識者/
ゆうししゃ /有志者/
ゆうしじょうけん /融資条件/
ゆうしてっせん /有刺鉄線/
ゆうしゃ /勇者/
ゆうしゃたち /勇者達/
ゆうしゅう /優秀/憂愁/有終/
ゆうしゅうきょくしょう /優秀曲賞/
ゆうしゅうしゃ /優秀者/
ゆうしゅうしょう /優秀賞/
ゆうしゅうせい /優秀性/
ゆうしゅうせんしゅしょう /優秀選手賞/
ゆうしゅうだい /優秀台/
ゆうしゅうはっぴょう /優秀発表/
ゆうしゅうろくおん /優秀録音/
ゆうしゅつ /湧出/
ゆうしゅん /優駿/
ゆうしゅんひんば /優駿牝馬/
ゆうしょう /優勝/有償/湧昇/
ゆうしょういがい /優勝以外/
ゆうしょうかいすう /優勝回数/
ゆうしょうかくりつ /優勝確率/
ゆうしょうきねん /優勝記念/優勝祈念/
ゆうしょうきねんごう /優勝記念号/
ゆうしょうきねんひん /優勝記念品/
ゆうしょうきょく /優勝曲/
ゆうしょうけいけん /優勝経験/
ゆうしょうけってい /優勝決定/
ゆうしょうけっていせん /優勝決定戦/
ゆうしょうこう /優勝校/
ゆうしょうこうほ /優勝候補/
ゆうしょうご /優勝後/
ゆうしょうしゃ /優勝者/優勝車/
ゆうしょうしゃよそう /優勝者予想/
ゆうしょうしゅうり /有償修理/
ゆうしょうしゅくがかい /優勝祝賀会/
ゆうしょうしょうきん /優勝賞金/
ゆうしょうしょうひん /優勝商品/優勝賞品/
ゆうしょうせん /優勝戦/
ゆうしょうせんせん /優勝戦線/
ゆうしょうとうしゅ /優勝投手/
ゆうしょうはい /優勝杯/
ゆうしょうば /優勝馬/
ゆうしょうふかのう /優勝不可能/
ゆうしょうよそう /優勝予想/
ゆうしょく /夕食/憂色/有色/
ゆうしょくかい /夕食会/
ゆうしょくざつおん /有色雑音/
ゆうしょくしゃ /有職者/
ゆうしょくだい /夕食代/
ゆうしょくどき /夕食時/
ゆうしょくよう /夕食用/
ゆうしん /有信/有心/
ゆうじ /裕司/雄二/祐二/勇次/勇治/勇二/祐司/裕治/裕二/雄士/雄志/右二/雄司/友二/有事/祐治/祐地/裕志/雄次/雄爾/祐史/祐次/裕慈/裕史/祐之/
ゆうじゃ /雄者/
ゆうじゅう /優柔/
ゆうじゅうふだん /優柔不断/
ゆうじょ /遊女/
ゆうじょう /友情/
ゆうじょうかんけい /友情関係/
ゆうじょうしゅつえん /友情出演/
ゆうじろう /雄二郎/裕次郎/悠二郎/
ゆうじん /友人/有人/遊人/
ゆうじんいちどう /友人一同/
ゆうじんえき /有人駅/
ゆうじんかいさつ /有人改札/
ゆうじんかいさつぐち /有人改札口/
ゆうじんかん /友人間/
ゆうじんかんけい /友人関係/
ゆうじんしょゆう /友人所有/
ゆうじんたく /友人宅/
ゆうじんたち /友人達/
ゆうじんちじん /友人知人/
ゆうじんちゅう /友人中/
ゆうじんつうろ /有人通路/
ゆうじんとう /有人島/
ゆうじんどうし /友人同士/
ゆうじんぶん /友人分/
ゆうじんまどぐち /有人窓口/
ゆうじんれんちゅう /友人連中/
ゆうすい /有水/
ゆうすいち /遊水地/
ゆうすう /有数/
ゆうすけ /祐介/勇介/有祐/裕介/幽助/祐輔/佳祐/雄介/雄輔/勇輔/
ゆうずい /雄蕊/
ゆうずう /融通/
ゆうずうむげ /融通無碍/
ゆうせい /郵政/優勢/優性/有声/有生/優生/有性/遊星/雄性/
ゆうせいいでん /優勢遺伝/
ゆうせいおん /有声音/
ゆうせいかいしじこく /有声開始時刻/
ゆうせいかんさつきょく /郵政監察局/
ゆうせいがく /優生学/
ゆうせいがち /優勢勝ち/
ゆうせいしいん /有声子音/
ゆうせいしゃ /遊星社/
ゆうせいしょう /郵政省;2001年1月の中央省庁再編で総務省に再編された/
ゆうせいしょうすいしょう /郵政省推奨/
ゆうせいしょうれい /郵政省令/
ゆうせいせいしょく /有性生殖/
ゆうせいだいじん /郵政大臣/
ゆうせいほごほう /優生保護法/
ゆうせきせい /有責性/
ゆうせつ /融雪/
ゆうせつざい /融雪剤/
ゆうせつすいたいさく /融雪水対策/
ゆうせん /優先/有線/郵船/
ゆうせんかいけつ /優先解決/
ゆうせんかいせん /有線回線/
ゆうせんがわ /優先側/
ゆうせんきじゅん /優先基準/
ゆうせんけん /優先権/
ゆうせんこうにゅう /優先購入/
ゆうせんしき /有線式/
ゆうせんしゅっそうけん /優先出走権/
ゆうせんしんごう /優先信号/
ゆうせんじこう /優先事項/
ゆうせんじゅん /優先順/
ゆうせんじゅんい /優先順位/
ゆうせんじゅんいつき /優先順位付/
ゆうせんじゅんじょ /優先順序/
ゆうせんじょうけん /優先条件/
ゆうせんせき /優先席/
ゆうせんそうしん /有線送信/
ゆうせんたんさく /優先探索/
ゆうせんつうしん /有線通信/
ゆうせんてき /優先的/
ゆうせんてきけんり /優先的権利/
ゆうせんでんわき /有線電話機/
ゆうせんでんわよやく /優先電話予約/
ゆうせんど /優先度/
ゆうせんどう /優先道/
ゆうせんどうろ /優先道路/
ゆうせんはんばい /優先販売/
ゆうせんほうそう /有線放送/
ゆうせんよやく /優先予約/
ゆうせんろしゅつ /優先露出/
ゆうせんわく /優先枠/
ゆうぜい /有税/遊説/游説/
ゆうぜん /友禅/悠然/
ゆうそう /郵送/勇壮/
ゆうそうか /郵送可/
ゆうそうきぼう /郵送希望/
ゆうそうさいぼう /遊走細胞/
ゆうそうさき /郵送先/
ゆうそうだい /郵送代/
ゆうそうてすうりょう /郵送手数料/
ゆうそうひ /郵送費/
ゆうそうぶつ /郵送物/
ゆうそうりょう /郵送料/
ゆうそく /有職/
ゆうぞう /雄三/裕三/勇三/勇蔵/祐三/
ゆうた /由宇太/祐太/
ゆうたい /優待/勇退/融体/幽体/郵袋/
ゆうたいかかく /優待価格/
ゆうたいけん /優待券/
ゆうたいしゅくはくけん /優待宿泊券/
ゆうたいりょうきん /優待料金/
ゆうたいるい /有袋類/
ゆうたいわりびきけん /優待割引券/
ゆうたろう /裕太郎/
ゆうたんぽしゃさい /有担保社債/
ゆうだい /雄大/
ゆうだち /夕立/夕立ち/
ゆうだん /勇断/
ゆうだんしゃ /有段者/
ゆうち /誘致/
ゆうちうんどう /誘致運動/
ゆうちゃく /融着/
ゆうちょ /郵貯/
ゆうちょう /悠長/
ゆうづう /融通/
ゆうづうせい /融通性/
ゆうづき /有月/夕月/
ゆうづる /夕鶴/
ゆうてい /夕定/
ゆうてん /融点/
ゆうてんじ /祐天寺/
ゆうでん /誘電/
ゆうでんかねつ /誘電加熱/
ゆうでんそんしつ /誘電損失/
ゆうでんたい /誘電体/
ゆうでんぶんきょく /誘電分極/
ゆうでんりつ /誘電率/
ゆうと /勇人/
ゆうとう /雄踏/優等/遊蕩/
ゆうとうぐん /雄踏郡/
ゆうとうしゃ /優等車/
ゆうとうせい /優等生/
ゆうとうせいてき /優等生的/
ゆうとうれっしゃ /優等列車/
ゆうとうれっしゃうんよう /優等列車運用/
ゆうとうれっしゃせんよう /優等列車専用/
ゆうとく /祐徳/
ゆうど /尤度/裕度/
ゆうどう /誘導/有働/
ゆうどうがかり /誘導係/
ゆうどうがた /誘導型/
ゆうどうざつおん /誘導雑音/
ゆうどうじんもん /誘導尋問/
ゆうどうたい /誘導体/
ゆうどうだん /誘導弾/
ゆうどうでんどうき /誘導電動機/
ゆうどうほうしゃのう /誘導放射能/
ゆうどかんすう /尤度関数/
ゆうどく /有毒/
ゆうどくせい /有毒性/
ゆうどくせいぶん /有毒成分/
ゆうどくぶっしつ /有毒物質/
ゆうどくぶつ /有毒物/
ゆうなぎ /夕凪/
ゆうねつき /有熱期/
ゆうのう /有能/
ゆうはい /有配/
ゆうはつ /誘発/
ゆうはつざい /誘発剤/
ゆうはつでんい /誘発電位/
ゆうはもん /幽波紋/
ゆうはん /夕飯/
ゆうばえ /夕暎え/
ゆうばく /誘爆/
ゆうばくじこ /誘爆事故/
ゆうばり /夕張/
ゆうぱっく /ゆうパック/
ゆうひ /夕日/夕陽/雄飛/
ゆうひかく /有斐閣/
ゆうひょう /有標/融氷/
ゆうひょうか /優評価/
ゆうひょうき /融氷期/
ゆうび /優美/
ゆうびん /郵便/〒/
ゆうびんうけ /郵便受け/
ゆうびんかわせ /郵便為替/
ゆうびんきょく /郵便局/
ゆうびんきょくいん /郵便局員/
ゆうびんきょくけいゆう /郵便局経由/
ゆうびんきょくどめ /郵便局止め/
ゆうびんきょくまえ /郵便局前/
ゆうびんこがわせ /郵便小為替/
ゆうびんこづつみ /郵便小包/
ゆうびんしゃ /郵便車/
ゆうびんしょかん /郵便書簡/
ゆうびんじこ /郵便事故/
ゆうびんせいど /郵便制度/
ゆうびんそくたつ /郵便速達/
ゆうびんだい /郵便代/
ゆうびんちょきん /郵便貯金/
ゆうびんでんしゃ /郵便電車/
ゆうびんはいたつ /郵便配達/
ゆうびんばこ /郵便箱/
ゆうびんばんごう /〒/郵便番号/
ゆうびんばんごうじしょ /郵便番号辞書/
ゆうびんばんごうぼ /郵便番号簿/
ゆうびんふりかえ /郵便振替/
ゆうびんふりかえこうざ /郵便振替口座/
ゆうびんふりかえようし /郵便振替用紙/
ゆうびんふりこみ /郵便振込/
ゆうびんふりこみようし /郵便振込用紙/
ゆうびんぶつ /郵便物/
ゆうびんや /郵便屋/
ゆうびんりょう /郵便料/
ゆうびんりょうきん /郵便料金/
ゆうふく /裕福/
ゆうふつ /勇払/
ゆうふつぐん /勇払郡/
ゆうへい /幽閉/雄平/裕平/
ゆうべ /昨夜/夕べ/夕/
ゆうべつ /湧別/
ゆうべつえき /湧別駅/
ゆうべん /雄弁/
ゆうべんか /雄弁家/
ゆうほう /友邦/
ゆうほうどうしょてん /友朋堂書店/
ゆうほどう /遊歩道/
ゆうぼう /有望/
ゆうぼうかぶ /有望株/
ゆうぼうし /有望視/
ゆうぼく /遊牧/
ゆうぼくみん /遊牧民/
ゆうぼくみんぞく /遊牧民族/
ゆうま /遊馬/
ゆうまぐれ /夕間暮れ/
ゆうみ /裕美/
ゆうみん /遊民/
ゆうみんしゃ /遊民社/遊眠社/
ゆうむ /有無/
ゆうめい /有名/
ゆうめいかしゅ /有名歌手/
ゆうめいかんこうち /有名観光地/
ゆうめいこう /有名校/
ゆうめいこく /有名国/
ゆうめいこしょてん /有名古書店/
ゆうめいしょ /有名所/
ゆうめいしんがっこう /有名進学校/
ゆうめいじいん /有名寺院/
ゆうめいじん /有名人/
ゆうめいせんしゅ /有名選手/
ゆうめいてん /有名店/
ゆうめいてんじょうほう /有名店情報/
ゆうめいはいゆう /有名俳優/
ゆうめいば /有名馬/
ゆうめいむじつ /有名無実/
ゆうめいむじつか /有名無実化/
ゆうめいりきし /有名力士/
ゆうめし /夕飯/
ゆうもう /有毛/勇猛/
ゆうもうせん /湧網線/
ゆうもや /夕靄/
ゆうもん /幽門/
ゆうや /裕也/裕弥/雄也/裕哉/
ゆうやく /勇躍/釉薬/
ゆうやけ /夕焼け/夕焼/
ゆうやみ /夕闇/
ゆうゆう /悠悠/悠々/
ゆうゆうじてき /悠々自適/
ゆうよ /猶予/
ゆうよう /有用/融溶/
ゆうようせい /有用性/
ゆうようてき /有用的/
ゆうよきかん /猶予期間/
ゆうよく /遊弋/
ゆうらく /有楽/
ゆうらくがい /有楽街/
ゆうらくちょう /有楽町/
ゆうらくちょうえきまえ /有楽町駅前/
ゆうらくちょうせいぶ /有楽町西武/
ゆうらくちょうせん /有楽町線/
ゆうらくてん /有楽店/
ゆうらん /遊覧/
ゆうらんせん /遊覧船/
ゆうらんひこう /遊覧飛行/
ゆうり /有利/友里/悠里/有理/遊離/悠理/遊里/
ゆうりかく /遊離核/
ゆうりかんすう /有理関数/
ゆうりかんすうぞく /有理関数族/
ゆうりきょうかい /有理境界/
ゆうりすう /有理数/
ゆうりすうじょう /有理数上/
ゆうりすうたい /有理数体/
ゆうりてき /有理的/
ゆうりふり /有利不利/
ゆうりゃくてんのう /雄略天皇/
ゆうりょ /憂慮/
ゆうりょう /有料/優良/
ゆうりょううんてんしゃ /優良運転者/
ゆうりょううんてんしゅ /優良運転手/
ゆうりょうか /有料化/優良可/
ゆうりょうかいしゅうほうしき /有料回収方式/
ゆうりょうきぎょう /優良企業/
ゆうりょうきゅうこう /有料急行/
ゆうりょうせい /優良性/
ゆうりょうぜい /遊漁税;法定外目的税/
ゆうりょうちゅうしゃじょう /有料駐車場/
ゆうりょうてん /優良店/
ゆうりょうとっきゅう /有料特急/
ゆうりょうとっきゅうりつ /有料特急率/
ゆうりょうどうろ /有料道路/
ゆうりょうどうろいりぐち /有料道路入口/
ゆうりょうどうろけいゆう /有料道路経由/
ゆうりょうにゅうじょうしゃすう /有料入場者数/
ゆうりょうひん /優良品/
ゆうりょうもんだい /有料問題/
ゆうりょく /有力/
ゆうりょくかぶ /有力株/
ゆうりょくこう /有力校/
ゆうりょくこうほ /有力候補/
ゆうりょくし /有力視/
ゆうりょくしゃ /有力者/
ゆうりょくせいじか /有力政治家/
ゆうりょくせんしゅ /有力選手/
ゆうりょくだいぎし /有力代議士/
ゆうりょくば /有力馬/
ゆうりょくばじょうほう /有力馬情報/
ゆうりん /友隣/
ゆうりんしゃ /友隣社/
ゆうりんどう /有隣堂/
ゆうれい /幽霊/
ゆうれいせん /幽霊船/
ゆうれいたいじ /幽霊退治/
ゆうれいにんぎょう /幽霊人形/
ゆうれいやく /幽霊役/
ゆうれいれっしゃ /幽霊列車/
ゆうれつ /優劣/
ゆうわ /融和/優和/友輪/雄和/宥和/
ゆうわぎじゅつ /融和技術/
ゆうわく /誘惑/
ゆうわくしゃ /誘惑者/
ゆうわくせい /誘惑性/
ゆうわさく /融和策/
ゆうわせいさく /融和政策/
ゆえ /故/優恵/湯江/
ゆえき /輸液/
ゆえつ /愉悦/諛悦/
ゆえに /∴/
ゆえん /所以/結縁/由縁/油煙/
ゆおん /油温/湯温/
ゆおんけい /油温計/
ゆか /床/結花/ユカ/友香/夕香/由香/由佳/由加/油化/弓佳/友華/友賀/裕香/夕佳/夕夏/由架/
ゆかい /愉快/
ゆかいた /床板/
ゆかいはん /愉快犯/
ゆかうえ /床上/
ゆかうんどう /床運動/
ゆかぐみ /床組/
ゆかげん /湯加減/
ゆかこ /優香子/友華子/有香子/由香子/裕香子/
ゆかした /床下/
ゆかしたきき /床下機器/
ゆかしたよう /床下用/
ゆかた /浴衣/
ゆかたすがた /浴衣姿/
ゆかだんぼう /床暖房/
ゆかの /由佳乃/
ゆかめん /床面/
ゆかめんせき /床面積/
ゆかり /由香里/由加里/由香利/紫/由加利/由架梨/友佳梨/由佳利/由佳里/
ゆかわ /湯河/湯川/
ゆかわおんせん /湯川温泉/
ゆかわひでき /湯川秀樹/
ゆが /憂花/瑜伽/
ゆがしま /湯が島/湯ヶ島/湯ケ島/
ゆがしゅう /瑜伽宗/
ゆがま /湯釜/
ゆがわ /湯川/
ゆがわら /湯河原/
ゆき /雪/之/由貴/由樹/幸/由記/行/有紀/夕貴/由妃/友紀/由希/夕紀/由紀/倖/恭/志/征/油機/由喜/礼暁/裄/ユキ/行き/有希/由季/湯来/油木/由岐/由姫/裕紀/
ゆきあか /雪垢/
ゆきいり /雪入/
ゆきえ /好恵/雪絵/由喜枝/由起絵/幸恵/幸栄/幸枝/由紀江/
ゆきお /由起夫/幸男/幸夫/幸雄/行夫/行雄/雪夫/行生/由希夫/幸生/由紀夫/由記雄/悠紀雄/幸應/悠紀夫/
ゆきおとこ /雪男/
ゆきおんな /雪女/
ゆきか /幸香/
ゆきかた /行き方/
ゆきかべ /雪壁/
ゆきがっせん /雪合戦/
ゆきき /行き来/
ゆきくら /雪倉/
ゆきぐに /雪国/
ゆきぐにいがい /雪国以外/
ゆきけむり /雪煙/
ゆきげしき /雪景色/
ゆきげしょう /雪化粧/
ゆきこ /由紀子/有希子/友紀子/由貴子/由起子/夕紀子/由希子/幸子/雪子/由季子/有紀子/有己子/
ゆきさき /行き先/行先/
ゆきしつ /雪質/
ゆきじるし /雪印/
ゆきすずめ /雪雀/
ゆきぞう /行三/
ゆきた /幸田/
ゆきたか /幸貴/
ゆきたけ /雪竹/
ゆきたに /雪谷/
ゆきだおれ /行き倒れ/
ゆきだま /雪玉/
ゆきち /諭吉/
ゆきとし /幸敏/礼暁/幸俊/
ゆきとみ /幸富/
ゆきとり /雪取/
ゆきどけ /雪解け/
ゆきどころ /行き所/
ゆきなり /幸成/志勢/
ゆきの /雪乃/雪野/
ゆきのじょう /雪之丞/
ゆきのすけ /雪ノ助/
ゆきのぶ /之宣/
ゆきのり /行則/幸紀/幸則/行徳/幸範/幸記/幸徳/幸典/
ゆきはる /幸春/
ゆきば /行き場/
ゆきひこ /行彦/由紀彦/由記彦/幸彦/
ゆきひで /幸秀/
ゆきひと /幸仁/
ゆきひらなべ /雪平鍋/
ゆきひろ /幸弘/幸宏/幸広/幸博/幸拾/幸展/行宏/行弘/
ゆきふみ /幸史/
ゆきぶそく /雪不足/
ゆきほ /行穂/
ゆきまさ /幸政/幸正/幸真/
ゆきまつ /行松/
ゆきみ /雪見/
ゆきみち /雪道/雪路/幸道/
ゆきみちよう /雪道用/
ゆきみつ /幸光/
ゆきむし /雪虫/
ゆきむら /幸村/
ゆきもと /雪本/
ゆきや /幸也/
ゆきやま /雪山/
ゆきよ /幸代/雪代/
ゆきよし /幸義/幸喜/
ゆきれっしゃ /雪列車/
ゆぎ /由木/柚木/
ゆぎょう /遊行/
ゆぎん /輸銀/
ゆくえ /行方/行く方/
ゆくえふめい /行方不明/
ゆくえふめいしゃ /行方不明者/
ゆくさき /行く先/行先/
ゆくすえ /行く末/
ゆくはし /行橋/
ゆくへ /行方/
ゆけつ /輸血/
ゆけむり /湯煙/
ゆけん /油研/
ゆけんこうぎょう /油研工業/
ゆげ /湯気/弓削/
ゆげい /靫負/
ゆげた /弓削田/
ゆこく /諭告/
ゆごう /癒合/
ゆさ /遊佐/
ゆさい /油彩/
ゆさてき /遊佐的/
ゆさぼう /遊佐坊/
ゆざめ /湯ざめ/
ゆざわ /湯沢/湯澤/
ゆし /油脂/諭旨/
ゆしま /湯島/油島/
ゆしまてんじん /湯島天神/
ゆしゅつ /輸出/
ゆしゅつきせい /輸出規制/
ゆしゅつきょうそうりょく /輸出競争力/
ゆしゅつさき /輸出先/
ゆしゅつしゃ /輸出車/
ゆしゅつしよう /輸出仕様/
ゆしゅつぜい /輸出税/
ゆしゅつぜんたい /輸出全体/
ゆしゅつにゅう /輸出入/
ゆしゅつひん /輸出品/
ゆしゅつよう /輸出用/
ゆしゅつようじゅんせい /輸出用純正/
ゆすはら /梼原/
ゆすら /桜桃/
ゆず /柚/柚子/梼/
ゆずがま /柚釜/
ゆずき /柚月/柚木/
ゆずこ /柚子/
ゆずとうがらし /柚唐辛子/
ゆずりうけにん /譲受人/
ゆずりわたしにん /譲渡人/
ゆずる /譲/穣/穰/讓/
ゆせ /湯瀬/
ゆせい /油性/油井/
ゆせいかん /輸精管/
ゆせん /湯煎/
ゆそう /輸送/湯槽/
ゆそうかん /輸送管/輸送艦/
ゆそうき /輸送機/
ゆそうきかん /輸送機関/
ゆそうきど /輸送輝度/
ゆそうきょり /輸送距離/
ゆそうぎょうしゃ /輸送業者/
ゆそうけいかく /輸送計画/
ゆそうけいさん /輸送計算/
ゆそうしゃ /輸送車/
ゆそうしゅだん /輸送手段/
ゆそうじ /輸送時/
ゆそうじっせき /輸送実績/
ゆそうじゅよう /輸送需要/
ゆそうじょう /輸送上/
ゆそうじんいん /輸送人員/
ゆそうせん /輸送船/
ゆそうたい /輸送隊/
ゆそうちゅう /輸送中/
ゆそうのうりょく /輸送能力/
ゆそうひ /輸送費/
ゆそうひよう /輸送費用/
ゆそうぶんたんりつ /輸送分担率/
ゆそうほうていしき /輸送方程式/
ゆそうほうほう /輸送方法/
ゆそうほごよう /輸送保護用/
ゆそうよう /輸送用/
ゆそうようてつどう /輸送用鉄道/
ゆそうりょう /輸送量/輸送料/
ゆそうりょく /輸送力/
ゆそうりょくじょうきょう /輸送力状況/
ゆそうりょくぞうきょう /輸送力増強/
ゆそうりょくたんい /輸送力単位/
ゆそうりょくぶそく /輸送力不足/
ゆそうろ /輸送路/
ゆそつ /輸卒/
ゆたか /裕/豊/豊か/泰/優/豐/穰/
ゆたかさ /豊かさ/豊さ/
ゆたかしょうゆ /豊醤油/
ゆたに /由谷/湯谷/
ゆたんぽ /湯湯婆/
ゆだ /湯田/
ゆだなか /湯田中/
ゆだなかえき /湯田中駅/
ゆだや /猶太/
ゆだん /油断/
ゆちゃく /癒着/
ゆつか /弓束/
ゆづかみ /湯津上/
ゆづき /由月/弓月/
ゆてき /油滴/
ゆてん /油点/
ゆでたまご /茹で卵/
ゆでん /油田/
ゆとう /湯桶/
ゆとうよみ /湯桶読み/
ゆどうふ /湯豆腐/
ゆに /由仁/
ゆにっと /ユニット/
ゆにばーさる /ユニバーサル/
ゆにばーさるきばん /ユニバーサル基板/
ゆにばーす /ユニバース/
ゆにふぉーむ /ユニフォーム/
ゆにもーる /ユニモール/
ゆにゅう /輸入/
ゆにゅうきかんしゃ /輸入機関車/
ゆにゅうきんし /輸入禁止/
ゆにゅうぎょうしゃ /輸入業者/
ゆにゅうざい /輸入材/
ゆにゅうしゃ /輸入車/輸入者/
ゆにゅうしゅぼば /輸入種牡馬/
ゆにゅうしょ /輸入書/
ゆにゅうじ /輸入時/
ゆにゅうじゆうか /輸入自由化/
ゆにゅうせんもん /輸入専門/
ゆにゅうぜい /輸入税/
ゆにゅうだいこう /輸入代行/
ゆにゅうだいりてん /輸入代理店/
ゆにゅうはんばい /輸入販売/
ゆにゅうば /輸入馬/
ゆにゅうばん /輸入版/輸入盤/
ゆにゅうばんせんもんてん /輸入盤専門店/
ゆにゅうばんてん /輸入盤店/
ゆにゅうばんめあて /輸入盤目当/
ゆにゅうばんや /輸入盤屋/
ゆにゅうひよう /輸入費用/
ゆにゅうひん /輸入品/
ゆにゅうぶつ /輸入物/
ゆにゅうまい /輸入米/
ゆにゅうもと /輸入元/
ゆにゅうりょう /輸入量/
ゆのかわ /湯野川/
ゆのき /柚木/
ゆのたに /湯之谷/
ゆのつ /温泉津/
ゆのはま /湯野浜/
ゆのはまおんせん /湯野浜温泉/
ゆのまえ /湯前/
ゆのみ /湯飲み/
ゆはら /湯原/
ゆば /湯葉/弓場/
ゆばら /湯原/
ゆび /指/趾/
ゆびいっぽん /指一本/
ゆびいっぽんぶん /指一本分/
ゆびおり /指折り/
ゆびさき /指先/
ゆびさしかくにん /指差確認/
ゆびづかい /指使い/
ゆびばん /指板/
ゆびもじ /指文字/
ゆびわ /指輪/指環/
ゆびわものがたり /指輪物語/
ゆふ /由府/
ゆふいん /湯布院/由布院/
ゆふこうげん /由布高原/
ゆふね /湯舟/
ゆふばえ /夕暎え/
ゆぶね /湯ぶね/湯船/湯舟/
ゆま /由真/
ゆまく /油膜/
ゆまくいじょう /油膜以上/
ゆまくけいせいりょく /油膜形成力/
ゆみ /弓/由美/友美/有美/祐未/由実/優美/宙美/裕美/祐美/有望/
ゆみえ /弓技/由美恵/
ゆみおか /弓岡/
ゆみか /由美香/
ゆみがはま /弓ヶ浜/
ゆみこ /弓子/由美子/裕美子/佑三子/優美子/有美子/祐三子/祐美子/
ゆみず /湯水/
ゆみた /弓田/
ゆみなか /弓仲/
ゆみなが /弓長/
ゆみの /弓野/
ゆみへい /弓兵/
ゆみや /弓矢/
ゆむら /湯村/
ゆむらおんせん /湯村温泉/
ゆめ /夢/梦/結女/
ゆめいろ /夢色/
ゆめかかく /夢価格/
ゆめきこう /夢紀行/
ゆめきぶん /夢気分/
ゆめこ /夢子/
ゆめこうぼう /夢工房/
ゆめごこち /夢心地/
ゆめさき /夢前/
ゆめじ /夢二/夢路/
ゆめぞの /夢園/
ゆめでんせつ /夢伝説/
ゆめと /夢人/
ゆめどの /夢殿/
ゆめの /夢野/
ゆめのうきはし /夢浮橋/
ゆめのきゅうさく /夢野久作/
ゆめのしま /夢の島/
ゆめはんだん /夢判断/
ゆめぼうけん /夢冒険/
ゆめまくら /夢枕/
ゆめみ /夢見/
ゆめものがたり /夢物語/
ゆめよ /夢代/
ゆもと /湯本/湯元/
ゆや /油谷/
ゆやま /湯山/
ゆゆ /結由/
ゆゆしき /由々しき/
ゆら /由良/
ゆらい /由来/
ゆらおんせん /由良温泉/
ゆらがわてっきょう /由良川鉄橋/
ゆらのすけ /由良之助/
ゆり /由梨/百合/ユリ/由里/由利/岼/閖/友利/友梨/友理/有里/祐里/憂里/由理/祐理/
ゆりあげ /閖上/
ゆりあげこう /閖上港/
ゆりあにあもく /ユリアニア目/Julianiales/
ゆりえ /友里恵/百合枝/由梨絵/
ゆりか /ユリ科/Liliaceae/優里香/
ゆりこ /百合子/由里子/ゆり子/由利子/祐理子/
ゆりこう /ユリ綱/Liliopsida/
ゆりのちょう /百合野町/
ゆりみ /有里巳/
ゆりもく /ユリ目/Liliales/
ゆりもくあぐん /ユリ目亜群/
ゆりもくぐん /ユリ目群/
ゆりょう /湯量/
ゆりょうほうふ /湯量豊富/
ゆる /閖/
ゆるすまじ /許すまじ/
ゆれ /揺れ/
ゆわかし /湯沸し/
ゆわかしき /湯沸かし機/湯沸かし器/湯沸器/
ゆわり /湯割り/
ゆゑ /故/
ゆゑん /所以/
ゆん /潤/
ゆんで /左手/
ゆんも /潤模/
よ /世/予/与/夜/代/余/預/誉/輿/四/豫/弥/丗/歟/畭/舁/與/蕷/譽/飫/餘/
よーぐると /ヨーグルト/
よーろっぱ /ヨーロッパ/欧羅巴/歐羅巴/
よあけ /夜明け/
よあけまえ /夜明け前/
よあつ /予圧/
よい /良い/宵/酔い/酔/
よいき /余域/
よいごし /宵越し/
よいた /与板/
よいち /余市/四一/
よいっぱり /宵っ張り/
よいど /余緯度/
よいまち /宵待/
よいまちぐさ /宵待草/
よいむ /酔夢/
よいやま /宵山/
よいやみ /宵闇/
よいん /余韻/余音/餘音/餘韻/
よいんし /余因子/
よいんしぎょうれつ /余因子行列/
よう /用/要/陽/様/洋/葉/養/曜/謡/蓉/遥/溶/容/踊/揚/楊/耀/羊/擁/庸/窯/熔/雍/幼/揺/妖/傭/甬/瘍/佯/俑/壅/夭/姚/孕/幺/廱/徭/恙/慂/慵/拗/搖/杳/昜/暘/曄/榕/樣/殀/漾/瀁/煬/燿/瑶/瓔/珱/痒/癢/癰/穃/窈/窰/膺/蛹/謠/踴/邀/鎔/遙/瑤/陶/泱/怏/厭/腰/鷹/八/
よう> /要/
ようあん /溶暗/
ようい /用意/容易/
よういく /養育/
よういくがっきゅう /養育学級/
よういくひ /養育費/
よういしゅうとう /用意周到/
よういせい /容易性/
よういち /陽一/洋一/暢一/要一/
よういちろう /陽一郎/洋一郎/
よういん /要因/要員/
よういんりろん /要因理論/
ようえき /溶液/葉腋/
ようえきちゅう /溶液中/
ようえきるい /溶液類/
ようえん /陽炎/妖艶/葉縁/揺炎/
ようおん /拗音/
ようか /八日/８日/蛹化/八鹿/
ようかい /妖怪/溶解/容喙/鎔解/
ようかいえき /溶解液/
ようかいち /八日市/
ようかいちば /八日市場/
ようかいへんげ /妖怪変化/
ようかかん /8日間/八日間/
ようかくにん /要確認/
ようかん /洋館/羊羹/羊羮/ヨウカン/
ようかんすう /陽関数/
ようが /用賀/洋画/幼芽/
ようがい /要害/
ようがく /洋楽/洋学/
ようがけい /洋画系/
ようがげきじょう /洋画劇場/
ようがさ /洋傘/
ようがし /洋菓子/
ようがふきん /用賀付近/
ようがん /溶岩/熔岩/
ようき /容器/陽気/妖気/妖鬼/
ようきちゅう /容器中/
ようきひ /楊貴妃;唐の玄宗に愛された美女/
ようきほあんきそく /容器保安規則/
ようきゅう /要求/
ようきゅうがく /要求額/
ようきゅうがわ /要求側/
ようきゅうきのう /要求機能/
ようきゅうくどう /要求駆動/
ようきゅうこうもく /要求項目/
ようきゅうしつ /要求室/
ようきゅうしゃ /要求者/
ようきゅうしょ /要求書/
ようきゅうしょり /要求処理/
ようきゅうしよう /要求仕様/
ようきゅうしようしょ /要求仕様書/
ようきゅうじこう /要求事項/
ようきゅうじょうけん /要求条件/
ようきゅうせいのう /要求性能/
ようきゅうちゅう /要求中/
ようきゅうていぎ /要求定義/
ようきゅうどおり /要求通り/
ようきゅうないよう /要求内容/
ようきゅうなど /要求等/
ようきゅうひん /要求品/
ようきゅうぶつ /要求物/
ようきゅうぶん /要求文/
ようきゅうぶんせき /要求分析/
ようきゅうまち /要求待ち/
ようきゅうめいれい /要求命令/
ようきょうか /要強化/
ようきょく /陽極/謡曲/
ようきょくがわ /陽極側/
ようきん /溶菌/
ようぎ /容疑/八尾木/
ようぎしゃ /容疑者/
ようぎょ /養魚/幼魚/
ようぎょう /窯業/
ようぎょじょう /養魚場/
ようぐ /用具/
ようけい /養鶏/幼形/
ようけつ /溶血/
ようけん /用件/要件/
ようけんじじつ /要件事実/
ようけんとう /要検討/
ようけんとうざいりょう /要検討材料/
ようけんどう /養賢堂/
ようげき /邀撃/
ようげん /用言/揚言/
ようげんか /溶原化/
ようげんしゅうしけい /用言終止形/
ようこ /陽子/葉子/洋子/容子/よう子/庸子/楊子/耀子/暢子/瑤子/揚子/妖子/
ようこう /要項/洋行/陽光/要綱/用高/
ようこうかん /要交換/
ようこうぐてん /洋工具店/
ようこうしゅう /要項集/
ようこうだい /洋光台/
ようこうだいちゃく /洋光台着/
ようこうろ /溶鉱炉/鎔鉱爐/鎔鉱炉/
ようこん /幼根/
ようご /用語/擁護/養護/
ようごかくてい /用語確定/
ようごがっこう /養護学校/
ようごきほう /用語記法/
ようごきょうゆ /養護教諭/
ようごこうほ /用語侯補/
ようごしゅう /用語集/
ようごじしょ /用語辞書/
ようごじてん /用語辞典/
ようごせつめい /用語説明/
ようごだんたい /養護団体/
ようごは /擁護派/用語派/
ようごへん /用語編/
ようごほう /用語法/
ようごろん /擁護論/
ようさい /要塞/洋裁/洋才/
ようさいあと /要塞跡/
ようさいか /要塞化/
ようさいこうげき /要塞攻撃/
ようさいとっこう /要塞特攻/
ようさいない /要塞内/
ようざい /溶剤/用材/
ようざっし /洋雑誌/
ようざら /洋皿/
ようざん /腰斬/要斬/
ようし /用紙/容姿/要旨/養子/陽子/洋紙/
ようしえんぐみ /養子縁組/
ようしかくにん /容姿確認/
ようしき /様式/洋式/
ようしきけしょうしつ /洋式化粧室/
ようしきじょう /様式上/
ようしきび /様式美/
ようしきふう /洋式風/
ようしきべんき /洋式便器/
ようししてい /用紙指定/
ようししゅう /要旨集/
ようしせってい /用紙設定/
ようしたんれい /容姿端麗/
ようしつ /洋室/
ようしつき /用紙付き/
ようしはば /用紙幅/
ようしば /洋芝/
ようしほうしゅつ /陽子放出/
ようしゃ /容赦/
ようしゅ /洋酒/
ようしゅうり /要修理/
ようしゅうりひん /要修理品/
ようしゅん /陽春/
ようしょ /洋書/要所/
ようしょう /幼少/要衝/葉鞘/
ようしょうき /幼少期/
ようしょうじ /幼少時/
ようしょうりば /洋書売場/
ようしょく /養殖/洋食/要職/容色/
ようしょくうお /養殖魚/
ようしょくぎょ /養殖魚/
ようしょくじょう /養殖場/
ようしょくもの /養殖物/
ようしょくよう /養殖用/
ようしょせんもんてん /洋書専門店/
ようしょてんかかく /洋書店価格/
ようしょや /洋書屋/
ようしょようしょ /要所要所/
ようしろう /陽志郎/
ようしん /葉身/
ようじ /用事/幼児/洋司/洋二/康次/幼時/庸次/洋次/陽次/楊枝/庸治/曜示/洋治/用字/陽二/耀司/陽治/陽司/
ようじあいて /幼児相手/
ようじき /幼児期/
ようじきょういく /幼児教育/
ようじご /幼児語/
ようじたいけい /幼児体型/
ようじたいけん /幼児体験/
ようじばんぐみ /幼児番組/
ようじゃく /幼若/
ようじゅう /妖獣/
ようじゅつ /妖術/
ようじょ /幼女/養女/妖女/葉序/
ようじょう /養生/洋上/
ようじよう /幼児用/
ようじようご /用字用語/
ようじろう /陽治郎/洋次郎/
ようじん /用心/要人/
ようじんぼう /用心棒/
ようす /様子/
ようすい /陽水/羊水/用水/揚水/
ようすけ /洋介/洋輔/洋祐/洋助/庸介/陽介/葉介/
ようすこう /揚子江/
ようすみ /様子見/
ようせい /要請/妖精/養成/陽性/夭逝/幼生/葉性/
ようせいかい /妖精界/
ようせいきかん /養成機関/
ようせいしせつ /養成施設/
ようせいしょ /要請書/
ようせいじょ /養成所/
ようせいぞく /妖精族/
ようせいたち /妖精達/
ようせいちゅう /養成中/
ようせいぶん /要請文/
ようせいまきひげ /葉性巻きひげ/葉性巻鬚/
ようせき /容積/
ようせきりつ /容積率/
ようせつ /溶接/夭折/熔接/殀折/
ようせつぶ /溶接部/
ようせん /用箋/用船/
ようぜん /陶然/
ようそ /要素/
ようそう /様相/洋装/
ようそうろんり /様相論理/
ようそうろんりたいけい /様相論理体系/
ようそかん /要素間/
ようそぎじゅつ /要素技術/
ようそぎじゅつかいはつ /要素技術開発/
ようそぐん /要素群/
ようそしきべつ /要素識別/
ようそしゅぎ /要素主義/
ようそすう /要素数/
ようそちょう /要素長/
ようそばんごう /要素番号/
ようそぶんかつ /要素分割/
ようそわ /要素和/
ようぞう /洋三/容三/陽三/
ようぞん /溶存/
ようた /洋太/
ようたい /容体/様態/容態/
ようたつ /用達/
ようたろう /洋太郎/
ようだい /容体/容態/煬帝;隋王朝の第二代皇帝/
ようだん /用談/要談/
ようち /幼稚/用地/夜討/要地/
ようちえん /幼稚園/
ようちえんきょうゆ /幼稚園教諭/
ようちえんじ /幼稚園児/
ようちえんじだい /幼稚園時代/
ようちえんせい /幼稚園生/
ようちばいしゅう /用地買収/
ようちゅう /幼虫/鎔鑄/
ようちゅうい /要注意/
ようちゅういかしょ /要注意箇所/
ようちゅうじだい /幼虫時代/
ようちょう /膺懲/
ようつい /腰椎/
ようつう /腰痛/
ようてい /要諦/羊蹄/
ようていざん /羊帝山/羊蹄山/
ようてん /要点/陽転/
ようでんし /陽電子/
ようでんしずのう /陽電子頭脳/
ようと /用途/
ようとう /洋燈/
ようとうくにく /羊頭狗肉/
ようとへんこう /用途変更/
ようとべつ /用途別/
ようとべつてきせい /用途別適性/
ようとん /養豚/
ようど /用度/
ようどう /揺動/陽動/
ようどがかり /用度掛/
ようなし /洋梨/
ように /陽に/様に/用に/
ようにく /葉肉/
ようにん /容認/
ようねん /幼年/
ようねんき /幼年期/
ようねんし /幼年誌/
ようねんへい /幼年兵/
ようのすけ /陽之助/洋之介/
ようはい /遥拝/
ようはん /洋販/
ようばい /溶媒/
ようばん /洋盤/
ようひ /要否/
ようひん /用品/洋品/
ようひんてん /用品店/洋品店/
ようひんや /用品屋/
ようび /曜日/
ようびごと /曜日毎/
ようびしていうんてん /曜日指定運転/
ようびべつ /曜日別/
ようびめい /曜日名/
ようびよやく /曜日予約/
ようふ /養父/
ようふう /洋風/
ようふく /洋服/
ようふくだい /洋服代/
ようふくや /洋服屋/
ようふくよう /洋服用/
ようふぼ /養父母/
ようふよう /要不要/
ようぶ /洋舞/
ようぶん /幼文/養分/
ようへい /洋平/用兵/傭兵/葉柄/
ようへん /窯変/
ようへんこう /要変更/
ようほう /用法/
ようぼう /要望/容貌/
ようぼうあん /要望案/
ようぼうかいい /容貌魁偉/
ようぼうしょ /要望書/
ようぼうしょていしゅつ /要望書提出/
ようぼうじこう /要望事項/
ようぼうないよう /要望内容/
ようぼうようし /容貌容姿/
ようぼく /幼木/
ようま /洋間/妖魔/
ようまく /羊膜/
ようませんし /妖魔戦士/
ようまたんちき /妖魔探知機/
ようまつ /洋松/
ようみゃく /葉脈/
ようみゃくけい /葉脈系/
ようみょう /幼名/
ようむ /用務/遥夢/妖霧/要務/
ようむいん /用務員/
ようむいんしつ /用務員室/
ようむき /用向き/
ようむさき /用務先/
ようめい /養命/用命/
ようめいしゅ /養命酒/
ようめいしゅせいぞう /養命酒製造/
ようめん /容面/
ようもう /羊毛/
ようもく /要目/
ようもの /洋物/
ようやく /要約/
ようやくきのう /要約機能/
ようやくひっき /要約筆記/
ようゆう /溶融/熔融/
ようよう /様々/要用/妖々/幼葉/揚々/
ようようたい /幼葉態/
ようらん /要覧/揺籃/
ようりく /揚陸/
ようりくかん /揚陸艦/
ようりつ /擁立/
ようりゃく /要略/
ようりょう /容量/要領/用量/
ようりょういっぱい /容量一杯/
ようりょうかくほ /容量確保/
ようりょうかへんけい /容量可変型/
ようりょうかんり /容量管理/
ようりょうけいかく /容量計画/
ようりょうげんかい /容量限界/
ようりょうせいげん /容量制限/
ようりょうせってい /容量設定/
ようりょうせっていしだい /容量設定次第/
ようりょうぞうか /容量増加/
ようりょうてき /容量的/
ようりょうどおり /容量通り/
ようりょうひょうじ /容量表示/
ようりょうぶそく /容量不足/
ようりょく /妖力/揚力/
ようりょくけいすう /揚力係数/
ようりょくそ /葉緑素/
ようりょくたい /葉緑体/
ようれい /用例/
ようれいしゅう /用例集/
ようれき /陽暦/
ようれつ /庸劣/
ようれつぐどん /庸劣愚鈍/
ようろう /養老/
ようろうのたき /養老の滝/
ようろく /要録/
ようろん /要論/
よえつ /与悦/
よか /余暇/予科/予価/餘暇/
よかかつどう /余暇活動/
よかく /余核/与格/
よかじかん /余暇時間/
よかれ /善かれ/
よかれん /予科練/
よかわ /吉川/
よかん /予感/余寒/豫感/
よき /予期/豫期/
よきょう /余興/餘興/
よきょくいり /余曲入/
よきん /預金/
よきんがく /預金額/
よきんこうざ /預金口座/
よきんざんだか /預金残高/
よきんしゃ /預金者/
よきんしゅもく /預金種目/
よきんつうちょう /預金通帳/
よきんとうけつ /預金凍結/
よぎ /余儀/余技/
よぎしゃ /夜汽車/
よぎた /与北/
よぎり /夜霧/
よく /翼/翌/欲/浴/抑/沃/慾/良く/峪/弋/杙/緘/翊/
よく> /翌/
よくあさ /翌朝/
よくあつ /抑圧/
よくあつしゃ /抑圧者/
よくあつしゅほう /抑圧手法/
よくあつてき /抑圧的/
よくあつほう /抑圧法/
よくうかん /余空間/
よくか /翼果/
よくがた /翼型/
よくき /翌期/
よくけい /翼形/
よくげつ /翌月/
よくげつごう /翌月号/
よくげつばらい /翌月払い/
よくげつぶん /翌月分/
よくし /抑止/
よくしこうか /抑止効果/
よくしつ /浴室/
よくしつかんそうき /浴室乾燥機/
よくしゅう /翌週/翌秋/
よくしゅうはっこうぶん /翌週発行分/
よくしゅん /翌春/
よくしん /慾心/
よくじつ /翌日/
よくじつぶん /翌日分/
よくじつゆうがた /翌日夕方/
よくじょう /浴場/欲情/翼状/慾情/
よくせい /抑制/
よくせいがた /抑制型/
よくせいこうか /抑制効果/
よくせいさいぼう /抑制細胞/
よくせいさく /抑制策/
よくせいしゅほう /抑制手法/
よくせいせい /抑制性/
よくせいせいそし /抑制性素子/
よくせいちゅうかんしんけいさいぼう /抑制中間神経細胞/
よくせいてき /抑制的/
よくせいぶっし /抑制物質/
よくそう /浴槽/
よくそくじ /抑速時/
よくたん /翼端/
よくちょう /翌朝/翼長/
よくとく /欲得/
よくとし /翌年/
よくとしいっぱい /翌年一杯/
よくねん /翌年/
よくばり /欲張り/欲張/
よくぼう /欲望/慾望/
よくめ /欲目/
よくめん /翼面/
よくめんせき /翼面積/
よくや /沃野/
よくよう /抑揚/浴用/
よくよく /翌々/
よくよくじつ /翌々日/
よくりゅう /抑留/翼龍/翼竜/
よくりゅうけいけんしゃ /抑留経験者/
よくりゅうしゃ /抑留者/
よくれつ /翼列/
よぐち /与口/
よけい /余計/餘計/
よけん /予見/与件/豫見/
よげつ /余月/
よげん /予言/余弦/預言/豫言/
よげんしゃ /予言者/
よげんしょ /予言書/
よげんは /余弦波/
よげんふのう /予言不能/
よこ /横/─/━/
よこあな /横穴/
よこい /横井/
よこいた /横板/
よこいち /横位置/
よこいちれつ /横一列/
よこいっせん /横一線/
よこいっちょくせん /横一直線/
よこいと /横糸/
よこいどう /横移動/
よこう /予行/予稿/
よこうえんしゅう /予行演習/
よこうげんこう /予稿原稿/
よこうしゅう /予稿集/
よこうしゅうだい /予稿集代/
よこうち /横内/
よこうれんしゅう /予行練習/
よこお /横尾/
よこおき /横置/
よこおけん /横尾研/
よこかいてん /横回転/
よこかいてんほうしき /横回転方式/
よこかぜ /横風/
よこかぜちゃくりく /横風着陸/
よこかべ /横壁/
よこかわ /横河/横川/
よこかわえき /横川駅/
よこかわでんき /横河電気/
よこがお /横顔/
よこがき /横書/横書き/
よこがた /横型/
よこがめん /横画面/
よこがわ /横河/横川/
よこがわでんき /横河電機/
よこぎ /横木/
よこく /予告/豫告/
よこくかんばん /予告看板/
よこくとう /予告灯/
よこくひょうしき /予告標識/
よこくへん /予告編/予告篇/
よこくよう /予告用/
よこくら /横倉/
よこぐみ /横組/
よこぐるま /横車/
よこけい /横罫/
よこげり /横蹴り/
よここうず /横構図/
よここくだい /横国大/
よこごし /横越/
よこさと /横里/
よこざひょう /横座標/
よこざま /横方/横樣/
よこざわ /横沢/
よこしば /横芝/
よこしま /横島/邪/辟/奸/邪ま/
よこじく /横軸/
よこじくざひょうち /横軸座標値/
よこじくじょう /横軸上/
よこじま /横縞/
よこすか /横須賀/
よこすかえき /横須賀駅/
よこすかきち /横須賀基地/
よこすかし /横須賀市/
よこすかしざいじゅう /横須賀市在住/
よこすかしたけ /横須賀市武/
よこすかせん /横須賀線/
よこすかつうけん /横須賀通研/
よこすかどうろ /横須賀道路/
よこすじ /横筋/
よこせ /横瀬/
よこせん /横線/─/
よこた /横田/
よこたきち /横田基地/
よこたに /横谷/
よこだおし /横倒し/
よこちょう /横丁/横町/
よこっつら /横っ面/
よこつか /横塚/
よこづけ /横付け/
よこづな /横綱/
よこづなきゅう /横綱級/
よこづなしょうしん /横綱昇進/
よこづなすいせん /横綱推薦/
よこづなずもう /横綱相撲/
よこづみ /横積/
よこて /横手/
よこてくかん /横手区間/
よこてさん /横手山/
よこてやま /横手山/
よこどり /横取り/
よこなが /横長/
よこなががめん /横長画面/
よこながし /横流し/
よこながばん /横長版/
よこなみ /横並/横波/
よこの /横野/
よこはね /横羽/
よこはば /横幅/横巾/
よこはま /横浜/横濱/
よこはまありーな /横浜アリーナ/
よこはまいえん /横浜以遠/
よこはまいちりつだい /横浜市立大/
よこはまえき /横浜駅/
よこはまえきにしぐち /横浜駅西口/
よこはまえきはつ /横浜駅発/
よこはまかん /横浜間/
よこはまがた /横浜方/
よこはまがわ /横浜側/
よこはまきゅうじょう /横浜球場/
よこはまきんこう /横浜近郊/
よこはまきんぺん /横浜近辺/
よこはまぎんこう /横浜銀行/
よこはまけいむしょ /横浜刑務所/
よこはまけんきゅうじょ /横浜研究所/
よこはまこう /横浜高/横浜港/
よこはまこうえん /横浜公演/
よこはまこうじょう /横浜工場/
よこはまこうほく /横浜港北/
よこはまこくだい /横浜国大/
よこはまこくりつだいがく /横浜国立大学/
よこはまごむ /横浜ゴム/
よこはまざいじゅう /横浜在住/
よこはまし /横浜市/
よこはましあさひく /横浜市旭区/
よこはましいそごく /横浜市磯子区/
よこはましえい /横浜市営/
よこはましかなざわく /横浜市金沢区/
よこはましきんこう /横浜市近郊/
よこはましさかえく /横浜市栄区/
よこはましざいじゅう /横浜市在住/
よこはましせやく /横浜市瀬谷区/
よこはましつるみく /横浜市鶴見区/
よこはましてん /横浜支店/
よこはましとつかく /横浜市戸塚区/
よこはましない /横浜市内/
よこはましないえき /横浜市内駅/
よこはましないざいじゅう /横浜市内在住/
よこはましにしく /横浜市西区/
よこはましぶ /横浜支部/
よこはましみどりく /横浜市緑区/
よこはましみなときたく /横浜市港北区/
よこはましみん /横浜市民/
よこはましゅうへん /横浜周辺/
よこはましゅっしん /横浜出身/
よこはましりつだい /横浜市立大/
よこはましんどう /横浜新道/
よこはまじん /横浜人/
よこはませいさくしょ /横浜製作所/
よこはません /横浜線/横浜戦/
よこはませんおおぐちえき /横浜線大口駅/
よこはませんかいそく /横浜線快速/
よこはませんけいゆ /横浜線経由/
よこはませんじょうげ /横浜線上下/
よこはませんはしもとえき /横浜線橋本駅/
よこはまたいかい /横浜大会/
よこはまたいよう /横浜大洋/
よこはまたいようきゅうだん /横浜大洋球団/
よこはまたいようせん /横浜大洋戦/
よこはまたかしまや /横浜高島屋/
よこはまちく /横浜地区/
よこはまてん /横浜店/
よこはまとうきゅう /横浜東急/
よこはまにしぐち /横浜西口/
よこはまにしぐちこう /横浜西口校/
よこはまはく /横浜博/
よこはまばん /横浜版/
よこはまふきん /横浜付近/
よこはまほうめん /横浜方面/
よこはままつざかや /横浜松坂屋/
よこはまみつこし /横浜三越/
よこはまもとまち /横浜元町/
よこはまや /横浜屋/横濱屋/
よこばい /横ばい/横這い/
よこばいかく /横倍角/
よこばいかくしゅうしょく /横倍角修飾/
よこばしり /横走り/
よこばら /横腹/
よこひょうじ /横表示/
よこひら /横平/
よこぶえ /横笛/
よこぶんれつ /横分裂/
よこほうこう /横方向/
よこほり /横堀/
よこぼう /横棒/
よこぼり /横堀/
よこまつ /横松/
よこまる /横丸/
よこみぞ /横溝/
よこみち /横道/
よこみねでら /横峰寺/
よこむき /横向/
よこめ /横目/
よこもじ /横文字/
よこもじすう /横文字数/
よこもり /横森/
よこや /横谷/横矢/
よこやま /横山/
よこやり /横槍/横やり/
よこよこ /横横/
よこよこどう /横横道/
よこれんぼ /横恋慕/
よこわけ /横分/
よこわり /横割り/
よご /予後/豫後/余呉/
よごと /夜毎/
よごふりょう /予後不良/
よごれ /汚れ/
よごれやく /汚役/
よさ /与謝/
よさく /与作/
よさぶろう /与三郎/
よさむ /夜寒/
よさん /予算/予讃/豫算/
よさんあん /予算案/
よさんかくだい /予算拡大/
よさんかんけい /予算関係/
よさんさくげん /予算削減/
よさんじょう /予算上/
よさんせん /予讃線/
よさんそしき /予算組織/
よさんてき /予算的/
よさんとうにゅう /予算投入/
よさんはいぶん /予算配分/
よさんはん /予算班/
よさんぶそく /予算不足/
よさんわく /予算枠/
よざい /余罪/餘罪/
よざくら /夜桜/
よざくらこうえん /夜桜公園/
よし /吉/由/義/嘉/良/芳/好/膳/善/葦/佳/喜/圭/慶/美/克/宜/淑/純/祥/禎/譱/葭/禧/ヨシ/
よしあき /喜明/嘉章/義章/義昭/義明/吉明/美明/芳明/良昭/良明/義亮/由明/嘉明/良晃/吉昭/嘉昭/宜明/義晃/吉晃/善章/義朗/善昭/良秋/克明/嘉晃/
よしあし /善し悪し/善悪/
よしい /吉井/芳井/
よしいけ /吉池/
よしいち /義一/
よしうみ /吉海/
よしうら /吉浦/
よしえ /好恵/芳恵/好江/ヨシエ/吉江/良枝/佳恵/
よしお /良雄/嘉男/義男/義夫/義雄/吉男/吉夫/吉雄/好男/好夫/好雄/善雄/芳男/芳夫/芳雄/由夫/良男/良夫/佳雄/嘉雄/好生/善夫/誉志雄/佳郎/嘉夫/吉生/宗生/淑生/新生/善男/美夫/温雄/好央/昌男/禧雄/佳男/
よしおか /吉岡/
よしおかしょてん /吉岡書店/
よしおみ /佳臣/善臣/
よしか /佳香/
よしかず /喜一/善一/義和/義一/由和/良和/好一/佳和/佳一/善和/美一/芳一/慶一/能収/英一/
よしかつ /義勝/好克/隆克/良勝/
よしかわ /吉川/好川/
よしがみ /吉上/
よしき /佳樹/吉城/吉敷/与式/芳樹/義樹/吉喜/芳希/慶樹/吉輝/善樹/由樹/良樹/嘉樹/喜紀/好輝/芳季/美樹/吉起/
よしきゅう /与死球/
よしきよ /義清/
よしくに /喜国/吉国/美邦/
よしこ /佳子/良子/由子/好子/美子/賀子/芳子/淑子/よし子/ヨシ子/嘉子/
よしこし /吉越/
よしさだ /悦貞/義貞/
よしさと /義聡/
よしざき /吉崎/
よしざわ /吉沢/吉澤/義澤/
よしじ /良治/良至/良司/
よしじま /吉島/
よしすけ /義介/
よしずみ /吉住/
よしぞう /芳三/
よしたか /佳孝/義孝/義隆/嘉隆/芳孝/吉高/善孝/善隆/良隆/孝高/禎孝/
よしたけ /吉竹/美武/義竹/吉武/義丈/尚武/
よしたに /吉谷/
よしたろう /芳太郎/由太郎/
よしだ /吉田/慶田/
よしだこうぎょう /吉田工業/
よしだしげる /吉田茂/
よしだせんしゃ /吉田戦車/
よしだちょう /吉田町/
よしだみわ /吉田美和/
よしだや /吉田屋/
よしつ /好津/
よしつぐ /善嗣/佳次/善次/
よしつね /義経/
よしつねごう /義経号/
よしつねせんぼんざくら /義経千本桜/
よしつねぞう /義経像/
よしづか /吉塚/
よしづかえき /吉塚駅/
よしてる /喜照/芳輝/
よしと /義人/芳人/圭人/
よしとお /義遠/
よしとし /吉年/義敏/
よしとせん /吉都線/
よしとみ /吉富/善富/
よしとも /良知/義恭/佳友/義智/義朋/
よしどめ /吉留/
よしなお /喜直/義直/
よしなか /義仲/吉仲/
よしなが /吉永/
よしながさゆり /吉永小百合/
よしなり /祐生/芳成/吉成/義也/能成/義成/良成/善成/悌也/
よしの /吉野/美乃/淑乃/吉乃/芳野/
よしのがわ /吉野川/
よしのせん /吉野線/
よしのだに /吉野谷/
よしのぶ /義信/慶喜/芳信/嘉伸/栄伸/良伸/
よしのや /吉野屋/吉野家/
よしのり /良則/良紀/嘉則/義則/義典/善範/芳則/義徳/美則/美徳/彬伯/吉徳/芳範/良典/由典/吉則/善則/佳典/嘉典/好則/善典/善徳/義昇/義範/芳規/良教/良法/佳則/吉典/良憲/嘉哲/由規/佳紀/良規/
よしは /吉葉/
よしはま /吉浜/
よしはら /吉原/
よしはらせいゆ /吉原製油/
よしはらちゅうおうえき /吉原中央駅/
よしはる /善治/義治/義晴/義春/芳晴/吉春/喜晴/佳春/喜治/
よしば /吉場/吉羽/
よしひこ /義彦/吉彦/芳彦/良彦/喜彦/義比古/慶彦/善彦/嘉彦/
よしひさ /義久/由久/慶久/純央/善久/良久/嘉久/芳久/
よしひで /慶英/善英/
よしひと /圭仁/芳人/善一/由人/芳仁/
よしひろ /喜博/吉宏/義浩/義弘/美博/吉弘/善弘/嘉弘/良浩/義博/佳浩/佳寛/佳泰/嘉宏/嘉伯/吉広/好広/良広/良祐/嘉浩/義宏/義広/義裕/吉廣/善博/喜弘/由泰/至寛/良博/良宏/
よしふみ /善文/良文/義文/仁史/佳文/祥史/好文/
よしほ /美穂/
よしま /吉間/
よしまさ /義雅/喜昌/好正/良昌/義正/
よしまつ /由松/吉松/
よしみ /吉見/昌美/好美/芳美/義美/良美/善美/嘉美/義巳/誼/由光/ヨシミ/由美/
よしみず /吉水/
よしみち /由道/
よしみつ /義光/嘉光/善光/喜光/芳充/
よしむね /義統/吉宗/
よしむら /吉村/義村/
よしもと /吉本/芳本/
よしもとこうぎょう /吉本興業/
よしもとこうぎょうせいさく /吉本興業制作/
よしもとしんきげき /吉本新喜劇/
よしもり /吉森/
よしや /義哉/吉屋/善哉/嘉也/
よしやす /嘉康/好康/
よしやま /吉山/
よしゅ /余種/
よしゅう /予習/豫習/
よしゅうよう /予習用/
よしゆき /芳行/誉志幸/良幸/義行/義之/良之/義幸/好幸/善幸/佳之/嘉志/嘉雪/嘉之/佳行/吉行/由行/善之/
よしゆきじゅんのすけ /吉行淳之介/
よしろう /義郎/芳郎/与四郎/喜朗/嘉朗/善郎/
よしわ /吉和/
よしわら /吉原/
よしん /余震/餘震/
よじ /四次/四時/
よじげん /四次元/
よじげんくうかん /四次元空間/
よじたこうしき /四次多項式/
よじみゃく /四次脈/
よじょう /余剰/余情/餘情/餘剩/
よじょうきざい /余剰器材/
よじょうぎみ /余剰気味/
よじょうしゃ /余剰車/
よじょうせい /余剰性/
よじょうでんりょく /余剰電力/
よじょうはん /四畳半/
よじょうぶぶん /余剰部分/
よじん /余燼/餘人/余人/
よすて /世捨/
よすみ /四隅/
よずめ /余詰/
よせ /寄せ/寄席/
よせい /余生/余勢/餘勢/餘生/
よせえんげい /寄席演芸/
よせがき /寄書き/
よせき /余積/
よせつ /余接/
よせつくうかん /余接空間/
よせなべ /寄せ鍋/
よせもと /寄元/
よせん /予戦/予選/予餞/豫選/
よせんいっかいせん /予選一回戦/
よせんおち /予選落/
よせんかいじょう /予選会場/
よせんけっか /予選結果/
よせんけん /予選券/
よせんごと /予選毎/
よせんさいかい /予選最下位/
よせんじゅんい /予選順位/
よせんぜんじつ /予選前日/
よせんだいいっせん /予選第一戦/
よせんちゅう /予選中/
よせんつうか /予選通過/
よせんつうかしゃ /予選通過者/
よせんとっぱ /予選突破/
よせんふつかめ /予戦二日目/
よせんめんじょ /予選免除/
よせんめんじょしかく /予選免除資格/
よぜみ /代ゼミ/
よそ /他所/余所/餘所/
よそう /予想/豫想/
よそういじょう /予想以上/
よそうかい /予想会/
よそうかくりつ /予想確率/
よそうかそくど /予想加速度/
よそうかのう /予想可能/
よそうかんせいじき /予想完成時期/
よそうがい /予想外/
よそうきじ /予想記事/
よそうけいしき /予想形式/
よそうごさ /予想誤差/
よそうしゃ /予想者/
よそうしゃめい /予想者名/
よそうじゅんい /予想順位/
よそうず /予想図/
よそうせんりょうとうりょう /予想線量等量/
よそうち /予想値/
よそうどおり /予想通り/
よそうにんずう /予想人数/
よそうひょう /予想表/
よそうほう /予想法/
よそうほうほう /予想方法/
よそうもんだい /予想問題/
よそうもんだいしゅう /予想問題集/
よそうや /予想屋/予想家/
よそうりゆう /予想理由/
よそおい /装/装い/
よそく /予測/豫測/
よそくかいてんすう /予測回転数/
よそくがい /予測外/
よそくがた /予測型/
よそくき /予測器/
よそくきそく /予測規則/
よそくごさ /予測誤差/
よそくせい /予測性/
よそくち /予測値/
よそくてき /予測的/
よそくどおり /予測通り/
よそくのうりょく /予測能力/
よそくふかのう /予測不可能/
よそくふのう /予測不能/
よそくほう /予測法/
よそくりつ /予測率/
よそみ /よそ見/
よそもの /他所者/
よぞら /夜空/
よた /与太/世太/
よたい /預貸/
よたいりつ /預貸率/
よたか /夜鷹/
よたく /預託/
よたくきん /預託金/
よたばなし /与太話/
よたろう /四太郎/与太郎/
よだ /依田/余田/与田/誉田/
よだいすう /余代数/
よだつ /与奪/予奪/
よだれ /涎/
よだん /余談/予断/四段/餘談/豫斷/
よち /余地/予知/余値/豫知/予地/
よちかん /予知観/
よちかんそくしつ /予知観測室/
よちのうりょく /予知能力/
よちむ /予知夢/
よちょう /予兆/余丁/
よちょうまち /余丁町/
よちょきん /預貯金/
よちれん /予知連/
よっか /４日/四日/4日/
よっかいち /四日市/
よっかいちいき /四日市行/
よっかいちえき /四日市駅/
よっかいちほうめん /四日市方面/
よっかいちゆき /四日市行/
よっかめ /四日目/
よっきゅう /欲求/
よっきゅうじつげん /欲求実現/
よっきゅうふまん /欲求不満/
よっつ /四つ/4つ/
よって /∴/依って/
よっと /ヨット/
よっぱらい /酔っぱらい/
よつ /四/
よつあし /四足/
よついけ /四ツ池/
よつかいどう /四街道/
よつかど /四つ角/
よつぎ /世継/世嗣/世嗣ぎ/
よつぎり /四切/
よつくら /四倉/
よつば /四葉/
よつばし /四つ橋/
よつや /四谷/四ツ谷/
よつやえき /四谷駅/
よつやかいだん /四谷怪談/
よつやさんちょうめ /四谷三丁目/
よつやしょうぼうしょ /四谷消防署/
よつやなぎ /四柳/
よつやほうこう /四谷方向/
よつやほうめん /四谷方面/
よつやま /四つ山/
よつゆ /夜露/
よづめ /余詰/
よづり /夜釣り/
よてい /予定/豫定/
よていあん /予定案/
よていかかく /予定価格/
よていがい /予定外/
よていこう /予定稿/
よていしゃ /予定者/
よていしゃめい /予定者名/
よていじかん /予定時間/
よていじこく /予定時刻/
よていすう /予定数/
よていせん /予定線/
よていち /予定地/
よていちょうわ /予定調和/
よていちょうわてき /予定調和的/
よていないよう /予定内容/
よていにんずう /予定人数/
よていはつばいまいすう /予定発売枚数/
よていひょう /予定表/
よていひん /予定品/
よていび /予定日/
よていへんこう /予定変更/
よてき /余滴/
よとう /与党/
よとぎ /夜伽/
よとく /余得/
よとだ /豊田/
よど /淀/
よどえ /淀江/
よどおし /夜通し/
よどがわ /淀川/
よどがわかこう /淀川河口/
よどがわかせんこうえん /淀川河川公園/
よどがわかせんじき /淀川河川敷/
よどしゃこ /淀車庫/
よどせん /予土線/
よどはつじゅんきゅう /淀発準急/
よどばやし /淀屋橋/
よどみ /澱/
よどみばし /澱橋/
よどやばし /淀屋橋/
よない /米内/
よないやま /米内山/
よなか /夜中/
よなかじゅう /夜中中/
よなが /夜長/
よなき /夜泣き/
よなくに /与那国/
よなくにとう /与那国島/
よなぐすく /与那城/
よなぐに /与那国/
よなぐにじま /与那国島/
よなご /米子/
よなごくうこう /米子空港/
よなごじどうしゃどう /米子自動車道/
よなごゆき /米子行/
よなばる /与那原/
よにげ /夜逃げ/
よにゅう /預入/
よにん /四人/
よにんしゅう /四人衆/
よにんしょうぎ /四人将棋/
よにんめ /四人目/
よね /米/
よねい /米井/
よねいちまる /米一丸/
よねお /米雄/
よねきち /米吉/
よねくら /米倉/
よねぐち /米口/
よねこ /米子/
よねさかせん /米坂線/
よねざき /米崎/
よねざわ /米澤/米沢/
よねざわけいゆ /米沢経由/
よねざわし /米沢市/
よねしま /米嶋/
よねしろがわ /米代川/
よねじま /米嶋/
よねだ /米田/
よねだけん /米田研/
よねつ /余熱/予熱/
よねづ /米津/
よねなが /米長/
よねはら /米原/
よねはらはつ /米原発/
よねはる /米春/
よねばやし /米林/
よねみつ /米光/
よねむら /米村/
よねもと /米本/
よねもり /米森/
よねやま /米山/
よねやまけん /米山研/
よねん /四年/４年/余念/餘念/
よねんせい /四年生/
よねんめ /四年目/
よの /与野/
よのう /予納/
よのうづ /米水津/
よのじ /よノ字/
よのてん /与野店/
よのなか /世の中/
よは /余波/餘波/
よはく /余白/餘白/
よばい /夜這い/
よばんちょう /四番丁/
よび /予備/呼び/豫備/餘/
よびえき /予備役/
よびかいぎ /予備会議/
よびかいせき /予備解析/
よびかけ /呼掛け/呼掛/
よびかた /呼び方/
よびがわ /呼び側/
よびき /予備機/
よびぎろん /予備議論/
よびぐん /予備軍/予備群/
よびけい /呼び径/
よびけん /予備検/
よびこう /予備校/
よびこうか /予備校化/
よびこうさつ /予備考察/
よびこうしゅうかい /予備講習会/
よびこうせい /予備校生/
よびこせん /呼子線/
よびこみ /呼び込み/
よびごえ /呼び声/
よびしあい /予備試合/
よびしゃ /予備車/
よびしゃけんじょう /予備車検場/
よびしん /予備審/
よびしんさ /予備審査/
よびしんさかい /予備審査会/
よびしんぱん /予備審判/
よびじあい /予備試合/
よびじっけん /予備実験/
よびじょうほう /予備情報/
よびすいせん /予備水洗/
よびすて /呼びすて/
よびせっけい /予備設計/
よびせん /予備選/
よびせんりょく /予備戦力/
よびだし /呼び出し/呼出/呼出し/
よびだしがわ /呼出側/
よびだしふごう /呼出符号/呼出符合/
よびちしき /予備知識/
よびちょうさ /予備調査/
よびてき /予備的/
よびでんち /予備電池/
よびとうひょう /予備投票/
よびな /呼名/呼び名/
よびね /呼び値/
よびひ /予備費/
よびび /予備日/
よびへんせい /予備編成/
よびみず /呼び水/
よびめんきょ /予備免許/
よびもどし /呼び戻し/
よびもの /呼び物/
よびや /呼び屋/
よびよせん /予備予選/
よびよびしん /予備予備審/
よびりん /呼び鈴/
よふかし /夜更し/夜更かし/
よふけ /夜更け/夜更/
よぶん /余分/余聞/餘分/
よへい /与平/
よほう /予報/余方/豫報/
よほうく /予報区/
よほうし /予報士/
よほうじかん /予報時間/
よほど /余程/
よぼう /予防/與望/豫防/
よぼういがく /予防医学/
よぼういりょう /予防医療/
よぼうきん /予防菌/
よぼうさく /予防策/
よぼうせん /予防線/
よぼうせんそう /予防戦争/
よぼうそち /予防措置/
よぼうちゅうしゃ /予防注射/
よぼうどうさ /予防動作/
よぼうほう /予防法/
よぼうほうほう /予防方法/
よみ /読み/黄泉/
よみあげ /読み上げ/
よみあわせ /読み合わせ/
よみうり /読売/讀売/
よみうりがわ /読売側/
よみうりきょじん /読売巨人/
よみうりきょじんぐん /読売巨人軍/
よみうりけい /読売系/
よみうりけいれつ /読売系列/
よみうりしんぶん /読売新聞/
よみうりしんぶんしゃ /読売新聞社/
よみうりしんぶんゆうかん /読売新聞夕刊/
よみうりせん /読売戦/
よみうりちょうかん /読売朝刊/
よみうりにほん /読売日本/
よみうりびいき /読売贔屓/
よみうりらんど /読売ランド/
よみかき /読み書き/
よみかた /読み方/
よみがな /読み仮名/
よみきり /読切り/
よみこみ /読み込み/読込/
よみこみじ /読み込み時/
よみじ /黄泉路/
よみせ /夜店/
よみたに /読谷/
よみだし /読み出し/
よみち /夜道/
よみて /読み手/
よみとり /読み取り/
よみとりき /読み取り機/
よみのくに /黄泉国/黄泉の国/
よみびとしらず /詠人不知/
よみもの /読物/読み物/
よみょう /余命/
よむ /読む/
よめ /嫁/夜目/読め/
よめい /余命/餘命/
よめいり /嫁入り/嫁入/
よめえらび /嫁選び/
よめさん /嫁さん/
よめしゅうとめ /嫁姑/
よめとり /嫁取り/
よも /四方/
よもぎ /蓬/蒿/艾/
よもぎう /蓬生/
よもぎた /蓬田/
よもぎだ /蓬田/蓮田/
よもすがら /終夜/
よもつしこめ /黄泉津醜女/
よもやま /四方山/
よもやまばなし /四方山話/
よやく /予約/豫約/
よやくうけつけ /予約受付/
よやくうけつけちゅう /予約受付中/
よやくか /予約課/
よやくかいし /予約開始/
よやくかいしび /予約開始日/
よやくかのう /予約可能/
よやくかんけい /予約関係/
よやくがかり /予約係/
よやくきげん /予約期限/
よやくきのう /予約機能/
よやくきゃく /予約客/
よやくきろく /予約記録/
よやくきん /予約金/
よやくけん /予約券/
よやくこうどく /予約講読/予約購読/
よやくこうにゅう /予約購入/
よやくご /予約語/
よやくしゃ /予約者/
よやくしゅっぱん /予約出版/
よやくしょうめいしょ /予約証明書/
よやくじ /予約時/
よやくじじょう /予約事情/
よやくじゅん /予約順/
よやくじょうきょう /予約状況/
よやくせい /予約制/予約性/
よやくせき /予約席/
よやくせってい /予約設定/
よやくそうち /予約装置/
よやくちゅう /予約中/
よやくてはい /予約手配/
よやくでんわばんごう /予約電話番号/
よやくとういつきかく /予約統一規格/
よやくとくてん /予約特典/
よやくないよう /予約内容/
よやくはんばい /予約販売/
よやくばんごう /予約番号/
よやくひ /予約費/
よやくひょう /予約表/
よやくびんめい /予約便名/
よやくぶん /予約分/
よやくへんこう /予約変更/
よやくほうしき /予約方式/
よやくまどぐち /予約窓口/
よやくめい /予約名/
よやくよう /予約要/
よやくようし /予約用紙/
よやくらん /予約欄/
よやくりょういき /予約領域/
よやくろくが /予約録画/
よやくろくがきのう /予約録画機能/
よやす /世安/
よやとう /与野党/
よゆう /余裕/餘裕/
よゆうじかん /余裕時間/
よゆうばりき /余裕馬力/
よよぎ /代々木/
よよぎうえはら /代々木上原/
よよぎきょうぎじょう /代々木競技場/
よよぎこうえん /代々木公園/
より /和/依里/寄/頼/縒/依/
よりあい /寄り合い/
よりあき /頼芸/頼晶/頼明/
よりい /寄居/
よりいかん /寄居間/
よりいと /縒り糸/
よりお /頼男/
よりきり /寄り切り/
よりこ /頼子/依子/夜梨子/
よりしま /寄島/
よりしろ /依代/憑代/
よりたおし /寄り倒し/
よりちか /頼近/
よりとも /頼朝/
よりどころ /拠所/拠り所/より所/據/拠/
よりのぶ /頼信/
よりまし /憑巫/
よりみち /寄り道/
よりょく /余力/餘力/
よる /夜/憑る/依/倚/
よるがた /夜型/
よるごはん /夜御飯/
よるちゃく /夜着/
よるよう /夜用/
よれい /予鈴/余齢/
よろい /鎧/
よろいざわ /鎧沢/
よろいせんし /鎧戦士/
よろいむしゃ /鎧武者/
よろく /余録/余禄/
よろこび /喜び/悦び/慶び/憙/
よろしく /宜しく/
よろず /万/萬/
よろずちょうほう /万朝報/
よろずやきんのすけ /萬屋錦之介/
よろん /世論/與論/餘論/余論/与論/
よろんちょうさ /世論調査/
よろんゆうどう /世論誘導/
よわい /弱い/齢/齡/
よわき /弱気/
よわごし /弱腰/
よわたり /世渡り/
よわね /弱音/
よわび /弱火/
よわふくみ /弱含み/
よわみ /弱味/
よわむし /弱虫/
よわめ /弱目/
よわよわ /弱々/
よわよわしい /弱々しい/
よん /四/４/
よんい /四位/
よんいいじょうかくてい /四位以上確定/
よんかい /四階/
よんかいせい /四回生/
よんかいめ /四回目/
よんかんおう /四冠王/
よんがっか /四学科/
よんき /四紀/
よんきゅう /四球/四級/
よんきょうか /四教科/
よんぎょう /四行/
よんく /四駆/
よんけたほう /四桁法/
よんけん /４研/四研/
よんげんすう /四元数/
よんげんそせつ /四元素説/
よんこう /4項/
よんこうかんけい /4項関係/
よんごう /四合/
よんごうびん /四合瓶/
よんさいば /四歳馬/
よんしまい /四姉妹/
よんしゃ /4者/
よんしゃたくいつ /四者択一/
よんしゅうかん /四週間/
よんしゅるい /4種類/四種類/
よんしょう /四章/四商/
よんしょうめ /四勝目/
よんしょく /四色/
よんじゅう /四重/四十/
よんじゅうじんかく /四重人格/
よんじゅうそうばん /四重奏番/
よんじゅうだいぜんはん /四十代前半/
よんせい /四声/
よんせんねん /四千年/
よんだい /四台/四大/
よんだいしゅうきょう /四大宗教/
よんちゃく /四着/
よんとう /四島/
よんとうこく /四等国/
よんとうごらく /四当五落/
よんど /四度/
よんどかく /四度核/
よんなん /四男/
よんねん /四年/
よんばんめ /4番目/四番目/
よんぱく /四白/
よんひき /四匹/
よんぶ /四部/
よんぶん /四分/
よんぶんかつ /四分割/
よんほん /四本/
よんまい /四枚/
よんめい /４名/
よんめん /四面/
よんもく /四目/
よんりん /四輪/
よんりんくどうしゃ /四輪駆動車/
よんりんしゃ /四輪車/
よんりんどう /四輪道/
よんろくばん /四六版/
ら /裸/羅/等/螺/良/鑼/們/蘿/邏/騾/
らーめん /ラーメン/拉麺/
らい /来/雷/頼/莱/礼/蕾/莢/來/儡/徠/擂/櫑/癩/磊/籟/罍/耒/賚/醴/
らい> /来/
らいいん /来院/
らいう /雷雨/
らいうん /雷雲/
らいえん /来演/
らいおん /ライオン/
らいか /来夏/
らいかい /来会/
らいかん /来館/雷管/
らいが /来駕/雷牙/
らいがく /来学/
らいがくねん /来学年/
らいがっき /来学期/
らいき /来期/来季/
らいきぎょうむもくひょう /来期業務目標/
らいきゃく /来客/
らいきゃくかいかん /来客会館/
らいきゃくちゅう /来客中/
らいきよそうかい /来期予想会/
らいぎょ /雷魚/
らいげき /雷撃/
らいげつ /来月/
らいげつごう /来月号/
らいげつさいしょ /来月最初/
らいげつちゅう /来月中/
らいげつど /来月度/
らいげつぶん /来月分/
らいげつぼうじつ /来月某日/
らいげん /来源/
らいこう /来航/来校/来光/来冦/雷光/
らいさん /礼賛/礼讃/
らいしつ /来室/
らいしゃ /来社/
らいしゅう /来週/来秋/来襲/
らいしゅうあたま /来週頭/
らいしゅうかよう /来週火曜/
らいしゅうげつよう /来週月曜/
らいしゅうちゅう /来週中/
らいしゅうぶん /来週分/
らいしゅうほうえい /来週放映/
らいしゅうまつ /来週末/
らいしゅうよこく /来週予告/
らいしゅん /来春/
らいしゅんかいまく /来春開幕/
らいしゅんしゅうしょく /来春就職/
らいしょ /来所/
らいしん /来信/来診/
らいじゅ /頼樹/
らいじょう /来場/来状/
らいじょうしゃ /来場者/
らいじん /雷神/
らいじんおう /雷神王/
らいす /ライス/
らいせ /来世/
らいせいき /来世紀/
らいせん /来仙/
らいせんす /ライセンス/
らいぞう /頼三/
らいた /ライタ/雷太/
らいたー /ライター/
らいたく /来宅/
らいだん /来談/
らいちょう /来聴/雷鳥/
らいちょうさわ /雷鳥沢/
らいちょうざわしゅうへん /雷鳥沢周辺/
らいちょうざわほうめん /雷鳥沢方面/
らいてい /雷帝/
らいてん /来店/
らいでん /雷電/来電/
らいでんためえもん /雷電為衛門/
らいと /ライト/
らいどう /雷同/
らいなつ /来夏/
らいにち /来日/
らいにちけってい /来日決定/
らいにちこうえん /来日公演/
らいにちこくち /来日告知/
らいにちじ /来日時/
らいにちちゅう /来日中/
らいにちちゅうし /来日中止/
らいにちまえ /来日前/
らいねん /来年/
らいねんあき /来年秋/
らいねんいこう /来年以降/
らいねんいっぱい /来年一杯/
らいねんかいさい /来年開催/
らいねんごろ /来年頃/
らいねんじょばん /来年序盤/
らいねんそつぎょう /来年卒業/
らいねんど /来年度/
らいねんどちゅう /来年度中/
らいねんどまつ /来年度末/
らいねんなつ /来年夏/
らいねんはる /来年春/
らいねんまつ /来年末/
らいはい /礼拝/
らいばしょ /来場所/來場所/
らいばる /ライバル/
らいひん /来賓/
らいひんせき /来賓席/
らいびょう /癩病/
らいふ /ライフ/
らいぶ /ライブ/
らいぶらり /ライブラリ/
らいぶらりかんすう /ライブラリ関数/
らいほう /来訪/
らいほうしゃ /来訪者/
らいむ /来夢/
らいめい /雷鳴/
らいらい /来々/
らいらいねん /来々年/
らいらく /磊落/
らいりん /来臨/
らいれき /来歴/
らいん /ライン/莱因/
らいんすう /ライン数/
らうす /羅臼/
らうどねす /ラウドネス/
らうんど /ラウンド/
らおん /ラ音/
らかん /羅漢/
らがん /裸眼/
らがんりったいし /裸眼立体視/
らぎょう /ラ行/
らく /楽/落/酪/絡/洛/樂/烙/犖/珞/駱/ラク/
らくいん /烙印/落胤/
らくえん /楽園/
らくかん /楽観/
らくかんてき /楽観的/
らくがい /洛外/
らくがき /落書/落書き/
らくがきちょう /らく書き帳/落書帳/
らくがん /落雁/
らくご /落語/落後/落伍/
らくごか /落語家/
らくごしゃ /落後者/
らくごばんぐみ /落語番組/
らくさ /落差/
らくさつ /落札/
らくさつかかく /落札価格/
らくしゃ /落車/
らくしゅ /落手/
らくしょ /落書/
らくしょう /楽勝/落掌/酪漿/
らくじつ /落日/
らくじょう /落城/
らくせい /落成/
らくせいけんさ /落成検査/
らくせいしき /落成式/
らくせき /落石/
らくせん /落選/
らくせんしゃ /落選者/
らくたん /落胆/
らくだ /駱駝/
らくだい /落第/
らくだいせいど /落第制度/
らくちゃく /落着/
らくちゃわん /楽茶碗/
らくちゅう /洛中/
らくちょう /落丁/
らくちん /楽珍/
らくてつ /落鉄/
らくてん /楽天/
らくてんか /楽天家/
らくてんし /楽天使/
らくてんてき /楽天的/
らくとうこうじょうりゅう /洛東江上流/
らくとうこうりゅういき /洛東江流域/
らくど /楽土/
らくなんしんとしん /洛南新都心/
らくのう /酪農/
らくば /落馬/
らくばん /落磐/落盤/
らくび /楽日/
らくほく /洛北/
らくほくこうこう /洛北高校/
らくほくこうこうまえ /洛北高校前/
らくめい /落命/
らくよう /落葉/洛陽/落陽/
らくようこうようじゅ /落葉広葉樹/
らくようじゅ /落葉樹/
らくようじゅりん /落葉樹林/
らくらい /落雷/
らくらく /楽々/
らくるい /落涙/
らぐびー /ラグビー/
らぐらんじゅ /ラグランジュ/
らけっと /ラケット/
らし /螺子/裸子/
らししょくぶつ /裸子植物/
らししょくぶつあもん /裸子植物亜門/Gymnospermae/
らしゅつ /裸出/
らしょうもん /羅生門/
らしん /裸身/
らしんばん /羅針盤/
らじ /裸耳/
らじお /ラジオ/
らじこん /ラジコン/
らすた /ラスタ/
らすと /ラスト/
らせつ /羅切/羅刹/
らせん /螺旋/ら旋/
らせんかいだん /螺旋階段/
らせんじょう /螺旋状/
らそく /裸足/
らたい /裸体/
らち /埒/埓/拉致/
らちがい /埒外/
らっか /落下/落花/
らっかうんどう /落下運動/
らっかかんせい /落下慣性/
らっかさん /落下傘/
らっかせい /落花生/
らっかちてん /落下地点/
らっかちゅう /落下中/
らっかてん /落下点/
らっかぶったい /落下物体/
らっかぶつ /落下物/
らっかん /楽観/
らっかんしゅぎしゃ /楽観主義者/
らっかんてき /楽観的/
らっきゅう /落球/
らっこ /ラッコ/
らっしゅ /ラッシュ/
らっと /ラット/
らっぱ /ラッパ/喇叭/
らつ /辣/剌/喇/拉/溂/
らつわん /辣腕/
らでん /螺鈿/
らば /騾馬/
らびおり /ラビオリ/
らびりんす /ラビリンス/
らふ /裸婦/
らぶ /ラブ/
らべる /ラベル/
らぼ /ラボ/
らむだ /Λ/ラムダ/λ/
らむにく /ラム肉/
らりー /ラリー/
られつ /羅列/
らん /欄/覧/乱/嵐/卵/蘭/藍/濫/欒/亂/儖/婪/嬾/巒/懶/攬/檻/欖/瀾/爛/籃/繿/纜/臠/襤/襴/覽/闌/鸞/
らんおう /卵黄/
らんおうのう /卵黄嚢/
らんおうまく /卵黄膜/
らんかく /乱獲/濫獲/
らんかつ /卵割/
らんかん /欄干/藍関/卵管/
らんかんさい /卵管采/
らんがい /欄外/
らんがく /乱学/蘭学/
らんきゅう /卵丘/
らんきりゅう /乱気流/
らんぎょく /藍玉/
らんく /ランク/
らんこ /蘭子/
らんこう /乱行/乱交/
らんこし /蘭越/
らんさいぼう /卵細胞/
らんざつ /乱雑/
らんざん /嵐山/
らんし /卵子/乱視/
らんしま /蘭島/
らんしゃ /乱射/
らんしゅう /蘭州/
らんしょう /濫觴/
らんしん /乱心/乱臣/
らんしんぞくし /乱臣賊子/
らんじゅ /藍綬/
らんじゅく /爛熟/
らんすう /乱数/
らんすうか /乱数化/
らんすうけいれつ /乱数系列/
らんすうせいせい /乱数生成/
らんすうせいせいけい /乱数生成系/
らんすうち /乱数値/
らんすうはっせい /乱数発生/
らんすうはっせいき /乱数発生器/
らんすうひょう /乱数表/
らんすうれつ /乱数列/
らんせい /乱世/
らんせん /乱戦/
らんぜん /爛然/
らんそ /濫訴/
らんそう /卵巣/藍藻/乱奏/
らんぞう /乱造/濫造/
らんたろう /乱太郎/
らんだ /乱打/
らんだせん /乱打戦/
らんだむ /ランダム/
らんちき /乱痴気/
らんちょう /乱丁/乱調/鸞鳥/
らんちょん /ランチョン/
らんでぃ /蘭泥/
らんでい /蘭泥/
らんでん /藍田/
らんとう /乱闘/
らんとうじけん /乱闘事件/
らんとうちゅう /乱闘中/
らんどく /乱読/濫読/濫讀/
らんどり /乱取り/
らんなー /ランナー/
らんにゅう /乱入/闌入/
らんにゅうしゃ /乱入者/
らんにゅうたいせん /乱入対戦/
らんはんしゃ /乱反射/
らんばい /乱売/
らんばつ /乱伐/濫伐/
らんぱく /卵白/
らんぱつ /乱発/
らんぴ /乱費/濫費/
らんぴつ /乱筆/
らんぴつらんぶん /乱筆乱文/
らんぶ /乱舞/
らんぶん /乱文/
らんぶんかつ /卵分割/
らんぷ /ランプ/
らんぼう /乱暴/
らんぼうもの /乱暴者/
らんぽ /乱歩/
らんぽう /蘭方/卵胞/
らんぽうい /蘭方医/
らんぽしょう /乱歩賞/
らんぽん /藍本/
らんま /乱馬/乱麻/
らんまる /蘭丸/
らんまん /爛漫/爛縵/
らんみゃく /乱脈/
らんもく /ラン目/Gynandrae/Microspermae/Orchidales/
らんよう /乱用/濫用/
らんらん /爛々/爛爛/
らんりつ /乱立/
らんりつじょうたい /乱立状態/
らんりゅう /乱流/
らんりゅうきそけんきゅう /乱流基礎研究/
らんりゅうろん /乱流論/
らんる /襤褸/藍縷/
り /理/利/里/裏/離/痢/履/裡/璃/梨/李/莉/吏/俚/俐/悧/罹/漓/籬/莅/詈/釐/驪/浬/哩/
りー /李/
りーぐ /リーグ/
りーじょん /リージョン/
りーす /リース/
りーだ /リーダ/
りーち /立直/
りーど /リード/
りーる /リール/
りあ /里亜/
りあげ /利上げ/
りありずむ /リアリズム/
りいち /理１/利一;名/理一;名/
りいちろう /理一郎;名/
りえ /理絵;名/里絵;名/リエ;名/利栄;名/利恵;名/利枝;名/理恵;名/里恵;名/里枝;名/理央;名/莉英;名/
りえき /利益/
りえきかんかく /利益感覚;計数感覚/
りえきかんげん /利益還元/
りえきかんげんほうしき /利益還元方式/
りえきしゃふたん /利益者負担/
りえきじゅんびきん /利益準備金;法定準備金の一種。資本金の4分の1に達するまで配当の10分の1以上を積み立てる商法上の制度/
りえきぞう /利益増/
りえきついきゅう /利益追求/
りえきはいぶん /利益配分/
りえきふりえき /利益不利益/
りえきぶんぱい /利益分配/
りえきゆうせん /利益優先/
りえきゆうどう /利益誘導/
りえきりつ /利益率/
りえこ /理恵子/利江子/
りえん /離縁/
りお /理音/
りおち /利落ち/
りおな /里緒菜/
りか /理科/利香/里歌/リカ/理香/里香/利佳/李下/梨香/梨果/理化/理加/里佳/梨加/
りかい /理解/
りかいかてい /理解過程/
りかいしゃ /理解者/
りかいじょうたい /理解状態/
りかいど /理解度/
りかいのうりょく /理解能力/
りかいふかのう /理解不可能/
りかいふのう /理解不能/
りかいぶそく /理解不足/
りかいりょく /理解力/
りかいりょくぶそく /理解力不足/
りかがく /理化学/
りかがくけんきゅうしょ /理化学研究所/
りかがくけんきゅうじょ /理化学研究所/
りかがくじてん /理科学辞典/
りかききや /理科機器屋/
りかく /離角/
りかけい /理科系/
りかけいしゅっしんしゃ /理科系出身者/
りかけいにんげん /理科系人間/
りかこ /りか子/理香子/里佳子/
りかじょしだい /梨花女子大/
りかだい /理科大/
りかだいがく /理科大学/
りかてき /理科的/
りかにるい /理科二類/
りかねんぴょう /理科年表/理化年表/
りかばー /リカバー/
りかん /罹患/
りかんりつ /罹患率/
りがい /利害/
りがいかんけい /利害関係/
りがいかんけいしゃ /利害関係者/
りがいとくしつ /利害得失/
りがく /理学/
りがくけい /理学系/
りがくけいけんきゅうか /理学系研究科/
りがくけんきゅうか /理学研究科/
りがくしゅうし /理学修士/
りがくてき /理学的/
りがくはかせ /理学博士/
りがくはくし /理学博士/
りがくぶ /理学部/
りがくぶ#ごうかん /理学部#0号館/
りがくぶかがくけい /理学部化学系/
りがくぶかがっか /理学部化学科/
りがくぶけいとう /理学部系統/
りがくぶしゅっしん /理学部出身/
りがくぶすうがっか /理学部数学科/
りがくぶちょう /理学部長/
りがくぶぶつり /理学部物理/
りがくぶぶつりがっか /理学部物理学科/
りがっか /理学科/
りがん /離岸/
りき /力/利器/理器/篥/
りきいし /力石/
りきえい /力泳/
りきえん /力演/
りきお /理紀夫/力男/力雄/
りきかく /力覚/
りきかん /力感/
りきがく /力学/
りきがくえねるぎ /力学エネルギ/
りきがくかんけい /力学関係/
りきがくけい /力学系/
りきがくけいりろん /力学系理論/
りきがくけんきゅうしつ /力学研究室/
りきがくせんもんしょ /力学専門書/
りきがくてき /力学的/
りきがくてきせかいかん /力学的世界観/
りきがくてきせつめい /力学的説明/
りきさく /力作/
りきし /力士/
りきせつ /力説/
りきせん /力戦/力線/
りきそう /力走/
りきぞう /力蔵/
りきたけ /力武/
りきち /利吉/
りきてん /力点/
りきとう /力闘/
りきどうかん /力動感/
りきどうざん /力道山/
りきどうざんいっこう /力道山一行/
りきどうざんじだい /力道山時代/
りきば /力馬/力場/
りきや /力也/力哉/
りきゅう /離宮/利休/
りきりょう /力量/
りきりょうてき /力量的/
りく /陸/勠/戮/淕/
りくあげ /陸揚げ/陸揚/
りくう /陸羽/
りくうさいせん /陸羽西線/
りくうとうせん /陸羽東線/
りくうん /陸運/
りくうんきょく /陸運局/
りくうんぎょう /陸運業/
りくうんさんじょかい /陸運賛助会/
りくうんしきょく /陸運支局/
りくうんじむきょく /陸運事務局/
りくうんじむしょ /陸運事務所/
りくえすと /リクエスト/
りくお /陸男/
りくかい /陸海/
りくかいくう /陸海空/
りくかいくうぐん /陸海空軍/
りくかいぐん /陸海軍/
りくかいりょうぐん /陸海両軍/
りくかぜ /陸風/
りくかわ /陸川/
りくがわ /陸側/
りくがん /陸岸/
りくきょう /陸橋/
りくくういったい /陸空一体/
りくぐん /陸軍/
りくぐんぐんいぶ /陸軍軍医部/
りくぐんしき /陸軍式/
りくぐんしょう /陸軍省/
りくぐんだいじん /陸軍大臣/
りくぐんちゅうおうぶ /陸軍中央部/
りくし /陸士/
りくしき /陸式/
りくしょう /戮笑/
りくじ /陸自/
りくじょう /陸上/
りくじょうかんけい /陸上関係/
りくじょうき /陸上機/
りくじょうきょうぎ /陸上競技/
りくじょうきょうぎじょう /陸上競技場/
りくじょうこうつう /陸上交通/
りくじょうこうつうもう /陸上交通網/
りくじょうたはつ /陸上多発/
りくじょうたんぱつ /陸上単発/
りくじょうぶ /陸上部/
りくじょうぶたい /陸上部隊/
りくじょうゆそういがい /陸上輸送以外/
りくじょく /戮辱/
りくせい /陸生/
りくせん /陸戦/
りくせんきそく /陸戦規則/
りくせんたい /陸戦隊/
りくぜん /陸前/
りくぜんさんのう /陸前山王/
りくぜんたかた /陸前高田/
りくそう /陸送/
りくたん /陸単/
りくだな /陸棚/
りくち /陸地/
りくちゅう /陸中/
りくちゅうおおはし /陸中大橋/
りくつ /理屈/
りくとう /陸稲/
りくとく /六徳;人が守るべき六つの徳。「ろくとく」とも/
りくどう /六道/
りくの /陸野/
りくべつ /陸別/
りくぼつ /戮没/
りくやね /陸屋根/
りくよう /陸用/
りくりょく /戮力/
りくるーと /リクルート/
りくれん /陸連/
りくれんとうろくせんしゅ /陸連登録選手/
りくろ /陸路/
りぐい /利食い/
りけい /理経/理系/
りけいがくせい /理系学生/
りけいしゅっしん /理系出身/
りけいしんがく /理系進学/
りけいてき /理系的/
りけいにんげん /理系人間/
りけん /理研/利権/
りけんがらみ /利権絡み/
りけんこうぞう /利権構造/
りげん /理元/
りこ /利己/
りこー /リコー/
りこう /理工/利口/履行/利巧/利光/
りこうか /理工科/
りこうがく /理工学/
りこうがくけん /理工学研/
りこうがくけんきゅうか /理工学研究科/
りこうがくしょせんもん /理工学書専門/
りこうがくせんこう /理工学専攻/
りこうがくせんこうか /理工学専攻科/
りこうがくぶ /理工学部/
りこうがくよう /理工学用/
りこうけい /理工系/
りこしゅぎ /利己主義/
りこしゅぎしゃ /利己主義者/
りこせい /利己性/
りこてき /利己的/
りこてきいでんし /利己的遺伝子/
りこん /離婚/
りこんけいけん /離婚経験/
りこんりつ /離婚率/
りこんれき /離婚歴/
りご /俚語/
りごう /離合/
りさ /理沙/理佐/リサ/梨沙/里沙/里紗/
りさーち /リサーチ/
りさい /罹災/り災/
りさいしょうめい /り災証明/
りさげ /利下げ/
りさこ /りさ子/
りさぶろう /利三郎/
りさん /離散/理III/
りさんいそう /離散位相/
りさんか /離散化/
りさんかごさ /離散化誤差/
りさんきんじ /離散近似/
りさんけい /離散系/
りさんじかん /離散時間/
りさんじしょう /離散事象/
りさんすうがく /離散数学/
りさんせい /離散性/
りさんち /離散値/
りさんてき /離散的/
りざーぶ /リザーブ/
りざや /利鞘/
りし /利子/
りしそうとうがく /利子相当額/
りしゅう /履修/
りしゅうしゃ /履修者/
りしゅうちゅう /履修中/
りしゅたい /利主体/
りしょく /離職/利殖/
りしり /利尻/
りしりとう /利尻島/
りしん /離心/
りじ /理事/
りじぇくと /リジェクト/
りじかい /理事会/
りじかいしつ /理事会室/
りじこく /理事国/
りじちょう /理事長/
りじつ /離日/
りじゅん /利潤/
りじゅんついきゅう /利潤追求/
りじゅんもくてき /利潤目的/
りじょう /鯉城/
りじょく /詈辱/
りす /リス/栗鼠/
りすい /理水/
りすう /理数/
りすうか /理数科/
りすうけい /理数系/
りすく /リスク/
りすけ /理介/
りすと /リスト/
りすとあっぷ /リストアップ/
りずむ /リズム/
りせい /理性/離生/
りせいしんぴ /離生心皮/
りせいてき /理性的/
りせいてきそんざいしゃ /理性的存在者/
りせき /離席/
りせん /離仙/
りそーす /リソース/
りそう /理想/
りそうか /理想化/
りそうきたい /理想気体/
りそうきゅうめん /理想球面/
りそうきょう /理想郷/理想境/
りそうぎゃくふぃるた /理想逆フィルタ/
りそうけい /理想形/理想系/
りそうげんご /理想言語/
りそうしゃかい /理想社会/
りそうしゅぎ /理想主義/
りそうしゅぎしゃ /理想主義者/
りそうしゅぎてき /理想主義的/
りそうじょう /理想上/
りそうじょうたい /理想状態/
りそうせかい /理想世界/
りそうぞう /理想像/
りそうち /理想値/
りそうてき /理想的/
りそうてきかんきょう /理想的環境/
りそうてきじょうたい /理想的状態/
りそうてきじょせいぞう /理想的女性像/
りそうてきだんせいぞう /理想的男性像/
りそうは /理想派/
りそうろん /理想論/
りそく /利息/利足/
りそくそうとう /利息相当/
りそくぶん /利息分/
りそん /離村/
りぞっと /リゾット/
りた /利他/
りたーん /リターン/
りたい /履帯/
りたいあ /リタイア/
りたこうどう /利他行動/
りだつ /離脱/
りだつれいこん /離脱霊魂/
りだん /離断/
りち /理知/律/篥/
りちうむ /リチウム/
りちぎ /律義/律儀/
りちてき /理知的/
りちゃくりく /離着陸/
りちゃくりくじ /離着陸時/
りちょう /李朝/
りっか /立夏/
りっきゃく /立脚/立客/
りっきゃくしき /立脚式/
りっきゃくてん /立脚点/
りっきょう /立教/陸橋/
りっきょうせん /立教戦/
りっきょうだい /立教大/
りっきょうだいがく /立教大学/
りっけん /立件/立憲/
りっけんくんしゅ /立憲君主/
りっこうほ /立候補/
りっこうほしゃ /立候補者/
りっこうほしゃすう /立候補者数/
りっこく /立国/
りっし /立志/
りっしゃくじ /立石寺/
りっしゅう /立秋/
りっしゅん /立春/
りっしょう /立証/立正/
りっしょうこうせいかい /立正佼正会/
りっしょうせきにん /立証責任/
りっしょうちゅう /立証中/
りっしょく /立食/
りっしん /立身/
りっしんべん /愡/慄/
りっすい /立錐/立推/
りっすいのち /立錐の地/立錐之地/
りっせき /立席/
りっそく /律速/
りっそくだんかい /律速段階/
りったい /立体/
りったいうちゅう /立体宇宙/
りったいえいぞう /立体映像/
りったいか /立体化/
りったいかく /立体角/
りったいかん /立体感/
りったいがぞう /立体画像/
りったいきじゅつげんご /立体記述言語/
りったいけいじょう /立体形状/
りったいこうさ /立体交差/
りったいこうぞう /立体構造/
りったいし /立体視/
りったいしがぞう /立体視画像/
りったいしたんし /立体視端子/
りったいしちゅう /立体視中/
りったいしちゅうどく /立体視中毒/
りったいしゃしん /立体写真/
りったいぞう /立体像/
りったいちゅうしゃじょう /立体駐車場/
りったいてき /立体的/
りったいばん /立体版/
りったいぶつ /立体物/
りっち /立地/
りっちじょうけん /立地条件/
りっとう /立冬/栗東/立東/
りっとうしゃ /立東社/
りっとうちょう /栗東町/
りっとく /六徳;単位。10^-19/
りっとる /リットル/
りっぱ /立派/
りっぷく /立腹/
りっぽう /立方/立法/
りっぽういん /立法院/
りっぽうがそ /立方画素/
りっぽうきかん /立法機関/
りっぽうけん /立法権/
りっぽうこうし /立方格子/
りっぽうこん /立方根/
りっぽうたい /立方体/
りっぽうたいばいせき /立方体倍積/
りっぽうふ /立法府/
りつ /率/立/律/葎/栗/慄/
りつあん /立案/
りつい /立位/
りつき /利付き/
りつきょう /立教/
りつけいさん /率計算/
りつこ /律子/りつ子/里葎子/利津子/理津子/
りつぜん /慄然/
りつぞう /立像/
りつだい /立大/
りつどう /律動/
りつめい /立命/
りつめいかん /立命館/
りつめいかんだい /立命館大/
りつめいかんだいがく /立命館大学/
りつめいかんだいがくいん /立命館大学院/
りつめいがわ /立命側/
りつめいしゅっしん /立命出身/
りつめいじじん /立命自陣/
りつめいせん /立命戦/
りつめいだい /立命大/
りつめんず /立面図/
りつりつ /慄慄/栗栗/
りつりょう /律令/
りつりん /栗林/
りつれつ /慄冽/
りつろん /立論/
りづめ /理詰/理詰め/
りてい /里程/
りてき /理的/
りてきそくめん /理的側面/
りてん /利点/
りとう /離島/
りとく /利得/
りな /ＲＩＮＡ/リナ/利奈/里菜/里奈/梨菜/理奈/梨奈/梨名/莉菜/
りに /理２/
りにあ /リニア/
りにち /離日/
りにゅう /離乳/
りにゅうしょく /離乳食/
りにゅうしょくさくせい /離乳食作成/
りにょう /利尿/
りにん /離任/
りにんち /離任地/
りねん /理念/
りねんそんざい /理念存在/
りねんてきそんざい /理念的存在/
りの /梨乃/
りのう /離農/
りはく /理博/李白/
りはっちゃく /離発着/
りはっちゃくかいすう /離発着回数/
りはっちゃくほんすう /離発着本数/
りはつ /理髪/利発/
りはつし /理髪師/
りはつてん /理髪店/
りはつりく /離発陸/
りはば /利幅/
りはびり /リハビリ/
りはん /離反/離叛/
りばけ /理化/
りばらい /利払い/
りびょう /罹病/
りふ /利府/
りふじん /理不尽/
りふと /リフト/
りふとけん /リフト券/
りぶつ /理物/
りぷらい /リプライ/
りぷれーす /リプレース/
りへい /利平/
りべい /離米/
りべつ /離別/
りべん /利便/離弁/
りべんか /離弁花/
りべんかるい /離弁花類/Apopetalae/Choripetalae/
りべんせい /利便性/履便性/
りほ /里穂/理保/理穂/
りほう /李鵬/理法/
りほこ /理保子/
りぼん /リボン/
りぽーたー /リポーター/
りぽーと /リポート/
りまわり /利回り/
りみ /梨美/
りめん /裏面/裡面/
りもーと /リモート/
りゃく /略/掠/擽/畧/(中略)/
りゃくかい /略解/
りゃくき /略記/
りゃくきほう /略記法/
りゃくぎ /略儀/
りゃくこう /略光/
りゃくご /略語/
りゃくごう /略号/
りゃくごしゅう /略語集/
りゃくしき /略式/
りゃくしきさいばん /略式裁判/
りゃくしょう /略称/
りゃくしょうしょぞく /略称所属/
りゃくしょうひょう /略称表/
りゃくじ /略字/
りゃくじゅつ /略述/
りゃくず /略図/
りゃくせつ /略説/
りゃくそう /略装/
りゃくだつ /略奪/掠奪/
りゃくひつ /略筆/
りゃくふく /略服/
りゃくめい /略名/
りゃくれき /略歴/
りゃくれきしょ /略歴書/
りゃっき /略記/
りゃっきほう /略記法/
りゃんそう /二索/
りゃんはんしばり /二翻縛/
りやく /利益/理薬/
りゅう /流/留/龍/隆/竜/立/粒/劉/琉/硫/溜/榴/笠/柳/瑠/嚠/嶐/旒/澑/瀏/畄/瘤/窿/苙/鉚/鏐/霤/餾/
りゅうあん /硫安/
りゅうい /留意/
りゅういいそう /緑一色/
りゅういき /流域/
りゅういち /龍一/隆一/竜一/
りゅういちろう /竜一郎/隆一郎/
りゅういてん /留意点/
りゅういん /溜飲/
りゅうおう /竜王/龍王/龍玉/
りゅうおうせん /竜王戦/
りゅうおん /流音/
りゅうか /硫化/
りゅうかい /流会/
りゅうかかごうぶつ /硫化化合物/
りゅうかん /流感/
りゅうがく /留学/
りゅうがくせい /留学生/
りゅうがくせいか /留学生課/
りゅうがくせいかつ /留学生活/
りゅうがくせいぜんいん /留学生全員/
りゅうがくせいたち /留学生達/
りゅうがくせいもんだい /留学生問題/
りゅうがくちゅう /留学中/
りゅうがさき /竜崎/龍崎/竜ケ崎/竜ヶ崎/
りゅうがだけ /竜ヶ岳/
りゅうがん /竜顔/竜眼/龍眼/
りゅうき /隆起/劉貴/
りゅうきし /竜騎士/
りゅうきへい /竜騎兵/
りゅうきゅう /琉球/
りゅうきゅうおうちょう /琉球王朝/
りゅうきゅうおうちょうふ /琉球王朝府/
りゅうきゅうおんかい /琉球音階/
りゅうきゅうぎんこう /琉球銀行/
りゅうきゅうご /琉球語/
りゅうきゅうじん /琉球人/
りゅうきゅうだい /琉球大/
りゅうきゅうだいがく /琉球大学/
りゅうきゅうだいがくじょうほう /琉球大学情報/
りゅうきゅうほうげん /琉球方言/
りゅうきゅうほうそう /琉球放送/
りゅうきょく /流局/
りゅうぎ /流儀/
りゅうぐう /龍宮/竜宮/
りゅうぐうじょう /龍宮城/
りゅうけつ /流血/
りゅうけん /竜権/
りゅうげん /流言/
りゅうげんひご /流言飛語/流言蜚語/
りゅうこ /竜子/龍虎/隆子/
りゅうこう /流行/龍宏/
りゅうこうおんがく /流行音楽/
りゅうこうか /流行歌/
りゅうこうかようきょく /流行歌謡曲/
りゅうこうご /流行語/
りゅうこうじょうほう /流行情報/
りゅうこうせい /流行性/
りゅうこく /竜谷/龍谷/
りゅうこくだい /龍谷大/
りゅうこくだいがく /龍谷大学/
りゅうこくだいがくせた /龍谷大学瀬田/
りゅうこくだいがくせん /龍谷大学線/
りゅうこくだいりこう /龍谷大理工/
りゅうご /隆吾/龍五/
りゅうさ /流砂/
りゅうさん /硫酸/
りゅうざき /竜崎/
りゅうざん /流産/竜山/
りゅうし /粒子/
りゅうしけいそく /粒子計測/
りゅうしすう /粒子数/
りゅうしせい /粒子性/
りゅうしせん /粒子線/
りゅうしそく /粒子束/
りゅうしそくど /粒子速度/
りゅうしつ /流失/
りゅうしゅつ /流出/
りゅうしゅつすい /流出水/
りゅうしょう /隆昌/
りゅうじ /隆二/竜二/龍二/隆治/隆司/隆史/
りゅうじゅ /龍樹/
りゅうじょう /粒状/
りゅうじょうかっせいたん /粒状活性炭/
りゅうじょうせい /粒状性/
りゅうじん /龍神/
りゅうすい /流水/
りゅうすう /留数/
りゅうすけ /龍介/隆介/竜介/龍輔/竜助/
りゅうず /竜頭/
りゅうせい /流星/隆盛/
りゅうせいう /流星雨/
りゅうせいかんそく /流星観測/
りゅうせいぐん /流星群/
りゅうせいじん /流星塵/
りゅうせん /流線/隆線/
りゅうせんかく /竜泉閣/
りゅうせんかんすう /流線関数/
りゅうせんけい /流線形/流線型/
りゅうせんけいじょうき /流線形蒸機/
りゅうせんけいぶぶん /流線形部分/
りゅうぜつらん /龍舌蘭/
りゅうそうざん /流早産/
りゅうそく /流速/流束/
りゅうぞう /隆三/龍蔵/竜三/
りゅうぞうじ /龍造寺/
りゅうた /竜太/隆太/
りゅうたい /流体/
りゅうたいかいせき /流体解析/
りゅうたいかがくけんきゅうじょ /流体科学研究所/
りゅうたいけん /流体研/流体科学研究所/
りゅうたいせいぎょがく /流体制御学/
りゅうたいぶつり /流体物理/
りゅうたいりきがく /流体力学/
りゅうたく /流謫/
りゅうたろう /龍太郎/竜太郎/
りゅうだい /琉大/龍大/
りゅうだん /榴弾/榴彈/
りゅうち /留置/
りゅうちしゅう /笠智衆/
りゅうちじょう /留置場/
りゅうちせん /留置線/
りゅうちばり /留置針/
りゅうちょう /流暢/
りゅうちよう /留置用/
りゅうつう /流通/
りゅうつうかかく /流通価格/
りゅうつうかがくだいがく /流通科学大学/
りゅうつうかてい /流通過程/
りゅうつうきこう /流通機構/
りゅうつうぎょう /流通業/
りゅうつうぎょうしゃ /流通業者/
りゅうつうけいひ /流通経費/
りゅうつうけいろ /流通経路/
りゅうつうしじょう /流通市場/
りゅうつうしゅだん /流通手段/
りゅうつうしゅっか /流通出荷/
りゅうつうじじょう /流通事情/
りゅうつうじょう /流通上/
りゅうつうじょうきょう /流通状況/
りゅうつうせい /流通性/
りゅうつうせいじょうか /流通正常化/
りゅうつうだんかい /流通段階/
りゅうつうまい /流通米/
りゅうつうりょう /流通量/
りゅうつうりょうちょうさ /流通量調査/
りゅうでん /流電/
りゅうとう /竜党/
りゅうど /粒度/
りゅうどう /流動/竜童/竜堂/
りゅうどうか /流動化/
りゅうどうけんきゅういん /流動研究員/
りゅうどうしさん /流動資産;当座資産、棚卸資産、その他の流動資産(前払費用、未収入金、短期貸付金など)の3つ/
りゅうどうしょく /流動食/
りゅうどうせい /流動性/
りゅうどうせいはいれつほう /流動性配列法;貸借対照表などで換金性の高い項目から順に配列するルール/
りゅうどうてき /流動的/
りゅうどうひりつ /流動比率/
りゅうどうふさい /流動負債/
りゅうにち /留日/
りゅうにゅう /流入/
りゅうにん /留任/
りゅうねん /留年/
りゅうねんせい /留年生/
りゅうのすけ /龍之介/竜之介/
りゅうは /流派/
りゅうひょう /流氷/
りゅうび /劉備;三国時代・蜀漢の初代皇帝/
りゅうへい /龍平/
りゅうほ /留保/
りゅうほう /龍鳳/隆法/
りゅうほく /竜北/
りゅうぼく /流木/立木/
りゅうま /竜馬/
りゅうよう /流用/竜洋/
りゅうようか /流用化/
りゅうようひん /流用品/
りゅうようほう /流用法/
りゅうりゅう /隆々/
りゅうりょう /流量/
りゅうりょうちょうせつ /流量調節/
りゅうれい /流麗/
りゅうろ /流路/
りゆう /理由/
りゆうしょ /理由書/
りゆうせつめい /理由説明/
りゆうづけ /理由付け/理由付/
りょ /慮/旅/虜/侶/呂/梠/絽/膂/踉/閭/
りょう /量/寮/両/良/料/領/諒/糧/涼/陵/猟/療/遼/瞭/僚/了/亮/稜/凌/梁/魎/綾/菱/漁/兩/霊/倆/凉/喨/寥/崚/廖/撩/暸/楞/燎/獵/粱/粮/繆/繚/聊/蓼/輛/輌/鐐/鬣/鷯/靈/椋/令/嶺/怜/裲/
りょう> /両/
りょうあし /両足/両脚/
りょうあしかじゅう /両足荷重/
りょうあて /寮宛/
りょうあん /両案/良案/
りょうあんじ /竜安寺/
りょうい /良為/霊異/
りょういき /領域/
りょういきか /領域化/
りょういきかいほう /領域解放/
りょういきかくほ /領域確保/
りょういきがい /領域外/
りょういききぼ /領域規模/
りょういきしてい /領域指定/
りょういきしていよう /領域指定用/
りょういきせきぶん /領域積分/
りょういきない /領域内/
りょういきぶんかつ /領域分割/
りょういきぶんかつほう /領域分割法/
りょういきほうていしき /領域方程式/
りょういきりろん /領域理論/
りょういきろん /領域論/
りょういち /亮一/良一/凌一/領一/遼一/竜一/龍一/
りょういちろう /良一朗/良一郎/
りょういん /両院/
りょううで /両腕/
りょううわて /両上手/
りょううんしゃ /両運車/
りょううんてんだい /両運転台/
りょうえき /両駅/
りょうえきかん /両駅間/
りょうえん /良縁/遼遠/
りょうえんこ /両円弧/
りょうおやゆび /両親指/
りょうおんせい /両音声/
りょうか /量化/良化/良貨/良過/良家/
りょうかい /了解/領海/諒解/
りょうかいじこう /了解事項/
りょうかいずみ /了解済み/
りょうかいせい /了解性/
りょうかいせん /領海線/
りょうかいど /了解度/
りょうかいどしけん /了解度試験/
りょうかいない /領海内/
りょうかいほう /領海法/
りょうかがた /良化型/
りょうかきごう /量化記号/
りょうかし /量化子/
りょうかた /両肩/両方/
りょうかみ /両神/
りょうかん /量感/僚艦/両艦/寮監/良寛/寮管/
りょうが /凌駕/
りょうがいじん /両外人/
りょうがえ /両替/
りょうがえき /両替機/
りょうがえしょう /両替商/
りょうがえじょ /両替所/
りょうがえてすうりょう /両替手数料/
りょうがえや /両替屋/
りょうがわ /両側/
りょうがわぶんかい /両側分解/
りょうがん /両眼/両岸/
りょうがんし /両眼視/
りょうがんしさ /両眼視差/
りょうがんしほう /両眼視法/
りょうがんりったいし /両眼立体視/
りょうき /漁期/猟奇/猟期/僚機/両機/
りょうきおう /猟奇王/
りょうきごう /量記号/
りょうきち /良吉/
りょうきてき /猟奇的/
りょうきょく /両極/
りょうきょくしゅう /両曲集/
りょうきょくたん /両極端/
りょうきん /料金/
りょうきんあんない /料金案内/
りょうきんか /料金課/
りょうきんかいしゅうき /料金回収機/
りょうきんかいしゅうりつ /料金回収率/
りょうきんかいてい /料金改定/
りょうきんかくさ /料金格差/
りょうきんけいさん /料金計算/
りょうきんけん /料金券/
りょうきんさ /料金差/
りょうきんしはらいけいたい /料金支払形態/
りょうきんしょ /料金所/
りょうきんしょじゅうたい /料金所渋滞/
りょうきんじょ /料金所/
りょうきんじょじゅうたい /料金所渋滞/
りょうきんじょへいさ /料金所閉鎖/
りょうきんせいきゅう /料金請求/
りょうきんせってい /料金設定/
りょうきんたいけい /料金体系/
りょうきんちゃくばらい /料金着払/
りょうきんちょうしゅう /料金徴収/
りょうきんてき /料金的/
りょうきんねさげ /料金値下/料金値下げ/
りょうきんばこ /料金箱/
りょうきんひょう /料金表/
りょうきんふたん /料金負担/
りょうきんふよう /料金不要/
りょうぎいん /両議院/
りょうぎし /両岸/
りょうくう /領空/
りょうくうかん /両空間/
りょうくん /両君/
りょうぐん /両軍/両群/
りょうぐんせんしゅ /両軍選手/
りょうけ /両家/良家/
りょうけい /良形/量刑/両系/
りょうけいとう /両系統/
りょうけつ /良血/
りょうけつば /良血馬/
りょうけん /了見/猟犬/両県/良兼/了簡/料簡/
りょうげん /燎原/両舷/
りょうげんご /両言語/
りょうこ /量子/良子/涼子/亮子/了子/領子/遼子/僚子/寮子/凌子/
りょうこう /良好/両校/良港/
りょうこうほ /両候補/
りょうこうり /両公理/
りょうこく /両国/
りょうこくかん /両国間/
りょうごく /両国/
りょうごくけっせん /両国決戦/
りょうごくこくぎかん /両国国技館/
りょうごくたいかい /両国大会/
りょうごくはなにしきとうし /両国花錦闘士/
りょうごくほうめん /両国方面/
りょうごくよびこう /両国予備校/
りょうさい /寮祭/良妻/
りょうさいけんぼ /良妻賢母/
りょうさく /良策/
りょうさくひん /両作品/
りょうさん /量産/
りょうさんおんがく /量産音楽/
りょうさんか /量産化/
りょうさんがた /量産型/
りょうさんき /量産機/
りょうさんけい /量産形/
りょうさんこうか /量産効果/
りょうさんしゃ /量産車/
りょうさんちゅう /量産中/
りょうざぶろう /量三朗/
りょうざんぱく /梁山泊/
りょうし /両氏/量子/漁師/猟師/両市/両誌/良之/
りょうしあい /両試合/
りょうしうちゅう /量子宇宙/
りょうしか /量子化/
りょうしかがく /量子化学/
りょうしかがくけいさん /量子化学計算/
りょうしかがくてき /量子化学的/
りょうしかせいど /量子化精度/
りょうしき /良識/両式/
りょうしきか /良識家/
りょうしきじん /良識人/
りょうしきてき /良識的/
りょうしこうか /量子効果/
りょうしこうがく /量子光学/量子工学/
りょうしこうがくせんこう /量子工学専攻/
りょうしこうぞう /量子構造/
りょうしこうりつ /量子効率/
りょうしざつおん /量子雑音/
りょうしつ /良質/
りょうしつきつえんしゃ /良質喫煙者/
りょうしてき /量子的/
りょうしでんし /量子電子/
りょうしでんじきがく /量子電磁気学/
りょうしとうけい /量子統計/
りょうしば /量子場/
りょうしぶつり /量子物理/
りょうしぶつりがく /量子物理学/
りょうしゃ /両者/両社/
りょうしゃかん /両者間/
りょうしゃきょうつう /両者共通/
りょうしゃきょうどうかいはつ /両社共同開発/
りょうしゃはんそく /両者反則/
りょうしゅ /領主/領取/料酒/
りょうしゅう /領収/領袖/
りょうしゅういん /領収印/
りょうしゅうがく /領収額/
りょうしゅうしょ /領収書/
りょうしゅうしょう /領収証/
りょうしゅうずみ /領収済/
りょうしゅだい /両主題/
りょうしゅほう /両手法/
りょうしょ /両書/良書/
りょうしょう /了承/諒承/
りょうしょく /寮食/
りょうしょくどう /寮食堂/
りょうしりきがく /量子力学/
りょうしりきがくてき /量子力学的/
りょうしりきがくや /量子力学屋/
りょうしろん /量子論/
りょうしん /両親/良心/両身/
りょうしんせい /両新製/
りょうしんてき /良心的/
りょうしんとも /両親共/
りょうじ /良治/療治/良二/両耳/領事/良司/亮二/亮治/良知/良至/
りょうじいち /両耳位置/
りょうじおんあつ /両耳音圧/
りょうじかん /領事館/両時間/両耳間/
りょうじかんさ /両耳間差/
りょうじかんそうかん /両耳間相関/
りょうじく /両軸/
りょうじこうか /両耳効果/
りょうじさ /両耳差/
りょうじそうよう /両耳装用/
りょうじちかい /寮自治会/
りょうじちょう /両耳聴/
りょうじつ /両日/
りょうじつさんか /両日参加/
りょうじゅう /猟銃/
りょうじゆうごう /両耳融合/
りょうじょく /凌辱/
りょうじん /猟人/梁塵/
りょうじんえい /両陣営/
りょうすいき /量水器/
りょうすう /両数/輛数/
りょうすけ /良祐/良助/良介/領介/了介/遼右/亮介/
りょうず /両図/
りょうせい /寮生/良性/両性/両生/両棲/
りょうせいか /両性花/
りょうせいかつ /寮生活/
りょうせいしゅうかい /寮生集会/
りょうせいしょく /寮生食/
りょうせいたいかい /寮生大会/
りょうせいびょうどう /両性平等/
りょうせいるい /両生類/両棲類/
りょうせん /稜線/両川/両線/両船/僚船/
りょうせんしゅ /両選手/
りょうせんじょう /稜線上/
りょうせんせい /両先生/
りょうせんぱつとうしゅ /両先発投手/
りょうせんれつ /稜線列/
りょうぜん /瞭然/霊山/
りょうそく /寮則/両側/
りょうそくめん /両側面/
りょうそしき /両組織/
りょうそで /両袖/
りょうぞう /良三/
りょうぞく /良俗/
りょうぞくせい /両属性/
りょうた /良太/亮太/
りょうたいすう /両対数/
りょうたろう /遼太郎/亮太郎/
りょうたん /両端/
りょうたんてん /両端点/
りょうだいがく /両大学/
りょうだて /両建て/
りょうだん /両断/
りょうだんたい /両団体/
りょうち /領地/
りょうちく /両地区/
りょうちょう /寮長/
りょうつ /両津/
りょうて /両手/
りょうてい /料亭/
りょうてき /量的/
りょうてきもんだい /量的問題/
りょうてなべ /両手鍋/
りょうてりょうあし /両手両足/
りょうてんさい /両天才/
りょうてんびん /両天秤/
りょうでん /菱電/
りょうでんしゃく /両電車区/
りょうとう /両党/両刀/両頭/
りょうとく /両得/
りょうとし /両都市/
りょうど /領土/
りょうどう /両道/糧道/
りょうどうたい /良導体/
りょうどかくだい /領土拡大/
りょうどない /領土内/
りょうどなり /両隣/
りょうどほぜん /領土保全/
りょうない /領内/寮内/
りょうなん /綾南/
りょうにん /両人/
りょうねん /両年/
りょうの /稜野/
りょうのう /両脳/
りょうは /両派/
りょうはい /両肺/
りょうはし /両端/
りょうはじ /両端/
りょうはんきゅう /両半球/
りょうはんてん /量販店/
りょうば /両馬/
りょうばば /良馬場/
りょうばばしこう /良馬場志向/
りょうひ /寮費/良否/
りょうひざ /両膝/
りょうひん /良品/
りょうび /綾美/両備/
りょうびげっぽう /綾美月報/
りょうぶもん /両部門/
りょうぶん /両分/領分/領文/
りょうぶんや /両分野/
りょうへい /良平/
りょうへき /両壁/
りょうへん /両辺/
りょうほう /両方/療法/
りょうほういっしょ /両方一緒/
りょうほうかくにん /両方確認/
りょうほうこう /両方向/
りょうほうさいよう /両方採用/
りょうほうしき /両方式/
りょうほうそうび /両方装備/
りょうほうたいおう /両方対応/
りょうほうとも /両方共/
りょうほうどうじ /両方同時/
りょうほうほう /両方法/
りょうほぞん /量保存/
りょうほんごく /両本国/
りょうぼ /寮母/
りょうま /竜馬/龍馬/遼麻/
りょうまつ /糧秣/
りょうみ /涼味/
りょうみみ /両耳/
りょうみみかん /両耳間/
りょうみん /領民/
りょうむ /寮務/
りょうむいいん /寮務委員/
りょうめ /両目/
りょうめい /両名/
りょうめじり /両目尻/
りょうめん /両面/
りょうめんいんさつ /両面印刷/
りょうめんきばん /両面基板/
りょうめんさいせい /両面再生/
りょうもう /両毛/
りょうもうせん /両毛線/
りょうもうせんない /両毛線内/
りょうもん /良問/
りょうや /⇔/
りょうやく /良薬/
りょうゆう /僚友/領有/両雄/
りょうゆうけん /領有権/
りょうゆうともにはたたず /両雄不倶立/両雄倶には立たず/
りょうゆうならびたたず /両雄並び立たず/
りょうよう /療養/両様/両用/
りょうよういん /療養院/
りょうようき /両用機/
りょうようじょ /療養所/
りょうようせいかつ /療養生活/
りょうようちゅう /療養中/
りょうようてき /療養的/
りょうようひ /療養費/
りょうよく /両翼/
りょうらん /撩乱/繚乱/
りょうり /料理/
りょうりいぜん /料理以前/
りょうりかい /料理会/料理界/
りょうりがく /料理学/
りょうりがっこう /料理学校/
りょうりきょうしつ /料理教室/
りょうりけんきゅうか /料理研究家/
りょうりごうかばん /料理豪華版/
りょうりざっし /料理雑誌/
りょうりしゅ /料理酒/
りょうりじょうず /料理上手/
りょうりちょう /料理長/
りょうりつ /両立/料率/
りょうりてじゅん /料理手順/
りょうりてん /料理店/
りょうりどうぐ /料理道具/
りょうりにん /料理人/
りょうりばん /料理番/
りょうりほう /料理法/
りょうりほうほう /料理方法/
りょうりめい /料理名/
りょうりめいじん /料理名人/
りょうりや /料理屋/
りょうりょう /了了/両両/喨喨/稜稜/寥寥/
りょうりょういき /両領域/
りょうりよう /料理用/
りょうりん /両輪/
りょうれん /寮連/
りょうろん /両論/
りょうわき /両脇/
りょうわん /両腕/
りょかく /旅客/
りょかくき /旅客機/
りょかっき /旅客機/
りょかん /旅館/
りょかんがい /旅館街/
りょかんなみ /旅館並み/
りょがい /慮外/
りょきゃく /旅客/
りょきゃくあつかい /旅客扱い/
りょきゃくあんない /旅客案内/
りょきゃくうんちん /旅客運賃/
りょきゃくえいぎょう /旅客営業/
りょきゃくえいぎょうきせい /旅客営業規制/
りょきゃくえいぎょうきそく /旅客営業規則/
りょきゃくえき /旅客駅/
りょきゃくか /旅客化/
りょきゃくかんり /旅客管理/
りょきゃくき /旅客機/
りょきゃくしゃ /旅客車/
りょきゃくせん /旅客線/
りょきゃくせんがわ /旅客線側/
りょきゃくとりあつかいきてい /旅客取扱規程/
りょきゃくにん /旅客人/
りょきゃくひこうき /旅客飛行機/
りょきゃくゆそう /旅客輸送/
りょきゃくよう /旅客用/
りょきゃくりゅうどう /旅客流動/
りょきゃくれっしゃ /旅客列車/
りょきゃくれっしゃよう /旅客列車用/
りょきゃっき /旅客機/
りょく /力/緑/仂/
りょくいん /緑陰/
りょくえんとし /緑園都市/
りょくおうしょくやさい /緑黄色野菜/
りょくおうやさい /緑黄野菜/
りょくか /緑化/
りょくかききん /緑化基金/
りょくしきもう /緑色盲/
りょくしょく /緑色/
りょくすい /緑水/
りょくすいてい /緑水亭/
りょくせいしきもう /緑青色盲/
りょくち /緑地/
りょくちたい /緑地帯/
りょくちゃ /緑茶/
りょくでんか /緑電化/
りょくないしょう /緑内障/
りょくのうきん /緑膿菌/
りょけん /旅券/
りょけんか /旅券課/
りょけんじむしょ /旅券事務所/
りょけんばんごう /旅券番号/
りょこう /旅行/
りょこうあんないしょ /旅行案内所/旅行案内書/
りょこうあんないじょ /旅行案内所/
りょこううかがい /旅行伺/
りょこうかい /旅行会/
りょこうかかく /旅行価格/
りょこうかばん /旅行鞄/
りょこうかんきょう /旅行環境/
りょこうかんけい /旅行関係/
りょこうかんりょう /旅行完了/
りょこうがいしゃ /旅行会社/
りょこうき /旅行記/旅行紀/
りょこうきぶん /旅行気分/
りょこうぎょうしゃ /旅行業者/
りょこうぎょうほう /旅行業法/
りょこうけいかく /旅行計画/
りょこうけん /旅行券/
りょこうけんきゅうかい /旅行研究会/
りょこうさき /旅行先/
りょこうさくせん /旅行作戦/
りょこうざっし /旅行雑誌/
りょこうしゃ /旅行者/旅行社/
りょこうしゃあん /旅行社案/
りょこうしゃかかく /旅行者価格/
りょこうしゅうりょうえき /旅行終了駅/
りょこうじ /旅行時/
りょこうじゅつ /旅行術/
りょこうじょうほう /旅行情報/
りょこうずき /旅行好き/
りょこうせんもんがっこう /旅行専門学校/
りょこうだい /旅行代/
りょこうだいりてん /旅行代理店/
りょこうだん /旅行団/
りょこうちゅう /旅行中/
りょこうちゅうし /旅行中止/
りょこうちょきん /旅行貯金/
りょこうにってい /旅行日程/
りょこうにっていがいよう /旅行日程概要/
りょこうひよう /旅行費用/
りょこうほけん /旅行保険/
りょこうぼう /旅行帽/
りょこうまえ /旅行前/
りょこうもくてき /旅行目的/
りょこうよてい /旅行予定/
りょしゅう /慮囚/旅愁/
りょじゅん /旅順/
りょじょう /旅情/
りょそう /旅装/
りょだん /旅団/
りょっか /緑化/
りょてい /旅程/
りょていひょう /旅程表/
りょてつ /旅鉄/
りょひ /旅費/
りょひしゅくはくひ /旅費宿泊費/
りょふ /呂布;後漢末期の群雄/
りょりつ /呂律/
りょりょく /膂力/
りよう /利用/理容/
りようあんない /利用案内/
りよういがい /利用以外/
りようえき /利用駅/
りようか /利用可/
りようかく /利用角/
りようかくだい /利用拡大/
りようかち /利用価値/
りようかのう /利用可能/
りようかのうせい /利用可能性/
りようかんきょう /利用環境/
りようがかり /利用掛/
りようがく /利用額/利用学/
りようきかい /利用機会/
りようきかん /利用期間/
りようきげん /利用期限/
りようきてい /利用規程/
りようきぼう /利用希望/
りようきゃく /利用客/
りようきょり /利用距離/
りようきんがく /利用金額/
りようぎじゅつ /利用技術/
りようくかん /利用区間/
りようけいかく /利用計画/
りようけいけん /利用経験/
りようけいたい /利用形態/
りようけいやくしゃ /利用契約者/
りようけん /利用研/利用券/利用権/
りようけんきゅうかい /利用研究会/
りようけんげん /利用権限/
りようげんど /利用限度/
りようげんどがく /利用限度額/
りようこうりつ /利用効率/
りようし /理容師/
りようしかく /利用資格/
りようしゃ /利用者/
りようしゃいがい /利用者以外/
りようしゃかくい /利用者各位/
りようしゃかんり /利用者管理/
りようしゃがわ /利用者側/
りようしゃげんてい /利用者限定/
りようしゃこうしゅうかい /利用者講習会/
りようしゃごと /利用者毎/
りようしゃじしょ /利用者辞書/
りようしゃじゅえき /利用者受益/
りようしゃすう /利用者数/
りようしゃぜんたい /利用者全体/
りようしゃそう /利用者層/
りようしゃとうろく /利用者登録/
りようしゃとくてん /利用者特典/
りようしゃばんごう /利用者番号/
りようしゃめい /利用者名/
りようしゃれんらくかい /利用者連絡会/
りようしゅうはすう /利用周波数/
りようしゅだん /利用手段/
りようしょう /利用証/
りようしんせい /利用申請/
りようしんせいしょ /利用申請書/
りようじ /利用時/
りようじかん /利用時間/
りようじっせき /利用実績/
りようじょう /利用上/
りようじょうきょう /利用状況/
りようじょうけん /利用条件/
りようじょうほう /利用情報/
りようせいげん /利用制限/
りようぜんぱん /利用全般/
りようちゅう /利用中/
りようてん /理容店/
りようとうけい /利用統計/
りようど /利用度/
りようはんい /利用範囲/
りようひんど /利用頻度/
りようび /利用日/
りようふか /利用不可/
りようふかのう /利用不可能/
りようふたんきん /利用負担金/
りようぶんや /利用分野/
りようほう /利用法/
りようほうほう /利用方法/
りようめいさい /利用明細/
りようもくてき /利用目的/
りようゆうしかくしゃ /利用有資格者/
りようようにん /利用容認/
りようよそく /利用予測/
りようよてい /利用予定/
りようりつ /利用率/
りようりょう /利用料/
りようりょうきん /利用料金/
りようれい /利用例/
りようれき /利用歴/
りよく /利欲/
りよこ /理代子/
りよん /里昴/
りりーす /リリース/
りりく /離陸/
りりくご /離陸後/
りりくじ /離陸時/
りりくじかん /離陸時間/
りりくそくど /離陸速度/
りりくちゅうし /離陸中止/
りりくふのう /離陸不能/
りりくまえ /離陸前/
りりこ /梨々子/
りりつ /利率/
りりょく /理力/
りるい /離塁/
りれー /リレー/
りれき /履歴/
りれきしょ /履歴書/
りれきちかん /履歴置換/
りろ /理路/
りろせいぜん /理路整然/
りろん /理論/
りろんか /理論家/
りろんかい /理論解/
りろんかいせき /理論解析/
りろんかがく /理論化学/
りろんきょくせん /理論曲線/
りろんけいさん /理論計算/
りろんけいさんきかがく /理論計算機科学/
りろんけいざいがく /理論経済学/
りろんけん /理論研/
りろんげんかい /理論限界/
りろんこうせい /理論構成/
りろんこうちく /理論構築/
りろんし /理論誌/
りろんしき /理論式/
りろんしゅぎ /理論主義/
りろんしょ /理論書/
りろんじく /理論軸/
りろんじょう /理論上/
りろんじょうかのう /理論上可能/
りろんすうがく /理論数学/
りろんせいぶつがく /理論生物学/
りろんせんせん /理論戦線/
りろんたいけい /理論体系/
りろんち /理論値/
りろんてき /理論的/
りろんてきかいしゃく /理論的解釈/
りろんてきかのうせい /理論的可能性/
りろんてきぎろん /理論的議論/
りろんてきげんかい /理論的限界/
りろんてきこんきょ /理論的根拠/
りろんてきしょうめい /理論的証明/
りろんてきすうがく /理論的数学/
りろんてきせいごうせい /理論的整合性/
りろんてきせいしつ /理論的性質/
りろんてきそくめん /理論的側面/
りろんてきてんぼう /理論的展望/
りろんてきはしら /理論的柱/
りろんてきぶんるい /理論的分類/
りろんてんかい /理論展開/
りろんは /理論派/
りろんぶ /理論部/
りろんぶそう /理論武装/
りろんぶつり /理論物理/
りろんぶつりがく /理論物理学/
りろんめいだい /理論命題/
りろんや /理論屋/
りろんりがく /理論理学/
りん /輪/隣/臨/林/倫/麟/鱗/琳/燐/淋/鈴/厘/稟/凛/吝/廩/悋/懍/棆/淪/痳/禀/綸/菻/藺/躙/躪/鄰/醂/霖/凜/
りんいち /倫一/
りんいちろう /倫一郎/
りんう /霖雨/
りんか /隣家/輪禍/リンカ/
りんかい /臨海/臨界/
りんかいあんぜん /臨界安全/
りんかいかく /臨界角/
りんかいきょうぎじょう /臨海競技場/
りんかいげんしょう /臨界現象/
りんかいじょうたい /臨界状態/
りんかいたいいき /臨界帯域/
りんかいたいいきしょり /臨界帯域処理/
りんかいたいいきはば /臨界帯域幅/
りんかいち /臨界値/
りんかいてん /臨界点/
りんかいふくとしん /臨海副都心/
りんかいぶ /臨海部/
りんかく /隣隔/輪郭/
りんかくせん /輪郭線/
りんかくとくちょうてん /輪郭特徴点/
りんかん /林間/
りんがく /林学/
りんがっか /林学科/
りんがっかい /林学会/
りんき /臨機/
りんきおうへん /臨機応変/
りんきょうしん /臨教審/
りんぎ /禀議/稟議/
りんぎしょ /禀議書/稟議書/
りんぎょう /林業/
りんぎょうか /林業家/
りんぎょうよう /林業用/
りんく /リンク/
りんくう /臨空/
りんぐ /リング/
りんけい /鱗茎/
りんけいきょう /林経協/
りんけん /臨検/
りんげつ /臨月/
りんこ /凛乎/
りんこう /輪講/林光/燐光/臨港/輪行/
りんこうかい /輪講会/
りんこうぐん /燐光群/
りんこうしつ /輪講室/
りんこうしゃ /輪行車/
りんこうじゅん /輪講順/
りんこうせん /臨港線/
りんご /林檎/
りんごく /隣国/
りんごばたけ /林檎畑/
りんさいぼう /林災防/
りんさく /輪作/
りんさん /リン酸/林産/燐酸/
りんさんかごうぶつ /リン酸化合物/
りんさんぶつ /林産物/
りんざい /林材/
りんし /臨死/
りんししつ /燐脂質/
りんしつ /隣室/
りんしもく /鱗翅目/
りんしゃ /倫社/
りんしゃん /嶺上/
りんしゃんかいほう /嶺上開花/
りんしゅう /凛秋/
りんしゅつ /臨出/
りんしょう /臨床/臨牀/輪唱/
りんしょうい /臨床医/
りんしょういがく /臨床医学/
りんしょういがくけい /臨床医学系/
りんしょうか /臨床家/
りんしょうけん /臨床研/
りんしょうけんさ /臨床検査/
りんしょうしけん /臨床試験/
りんしょうしょうじょう /臨床症状/
りんしょうしんり /臨床心理/
りんしょうしんりがく /臨床心理学/
りんしょうしんりし /臨床心理士/
りんしょうじっけん /臨床実験/
りんしょうせいりがく /臨床生理学/
りんしょうちけん /臨床治験/
りんしょうてき /臨床的/
りんしょうれい /臨床例/
りんしょく /吝嗇/
りんしん /稟申/禀申/凛森/
りんじ /臨時/
りんじいん /臨時員/
りんじえき /臨時駅/
りんじかいいん /臨時会員/
りんじかいさつぐち /臨時改札口/
りんじかいそく /臨時快速/
りんじかいそくれっしゃ /臨時快速列車/
りんじきゅうこう /臨時休講/臨時急行/
りんじけんさ /臨時検査/
りんじそうかい /臨時総会/
りんじぞうかん /臨時増刊/
りんじぞうかんごう /臨時増刊号/
りんじていしゃ /臨時停車/
りんじてき /臨時的/
りんじでんしゃ /臨時電車/
りんじとっきゅう /臨時特急/
りんじはつばい /臨時発売/
りんじばんぐみ /臨時番組/
りんじばんごう /臨時番号/
りんじびん /臨時便/
りんじふぁいる /臨時ファイル/
りんじぶもん /臨時部門/
りんじへんせい /臨時編成/
りんじゅう /臨終/
りんじょう /臨場/輪状/
りんじょうかん /臨場感/
りんじょうかんつうしん /臨場感通信/
りんじれっしゃ /臨時列車/
りんじん /隣人/
りんじんたち /隣人達/
りんず /綸子/綾子/
りんせい /林政/輪生/
りんせいじょう /輪生状/
りんせいもく /輪生目/Verticillatae/
りんせき /臨席/隣席/
りんせつ /隣接/
りんせつえき /隣接駅/
りんせつかんけい /隣接関係/
りんせつぎょうれつ /隣接行列/
りんせつせき /隣接席/
りんせつち /隣接地/
りんせつちょさくけん /隣接著作権/
りんせんじ /林泉寺/
りんぜん /凛然/
りんたい /輪帯/
りんたいさく /倫対策/
りんだ /リンダ/
りんち /隣地/林地/
りんちょう /臨調/
りんてん /輪転/
りんてんき /輪転機/
りんどう /林道/竜胆/
りんどうか /リンドウ科/
りんどうぐん /林道群/
りんどうしゅうてん /林道終点/
りんどうじたい /林道自体/
りんどうめい /林道名/
りんどうもく /リンドウ目/Gentianales/
りんどく /輪読/
りんない /林内/
りんね /輪廻/
りんねてんしょう /輪廻転生/
りんねてんせい /輪廻転生/
りんば /臨場/
りんばかん /臨場感/
りんばん /輪番/
りんばんせい /輪番制/
りんぱ /リンパ/
りんぱせつ /リンパ節/
りんびょう /淋病/
りんぴょうとうしゃかいちんれつざいぜん /臨兵鬪者皆陳列在前/
りんぶ /輪舞/
りんぶん /林分/
りんぷん /鱗粉/
りんぽう /隣邦/
りんむ /林務/
りんや /林野/
りんやちょう /林野庁/
りんらく /淪落/
りんり /倫理/淋漓/
りんりかん /倫理観/倫理感/
りんりがく /倫理学/
りんりがくせんこう /倫理学専攻/
りんりきせい /倫理規制/
りんりきてい /倫理規定/
りんりしゃかい /倫理社会/
りんりじょう /倫理上/
りんりじょうもんだい /倫理上問題/
りんりつ /林立/
りんりてき /倫理的/
りんりてきもんだい /倫理的問題/
りんりどうとく /倫理道徳/
りんりどうとくかん /倫理道徳観/
りんりめん /倫理面/
りんりん /凛々/凛凛/
りんれつ /凛冽/
りんわ /輪話室/
りんわしつ /輪話室/
る /瑠/流/留/屡/琉/婁/璢/畄/縷/褸/鏤/陋/
るーじゅ /ルージュ/
るーちん /ルーチン/
るーと /ルート/√/
るーぶる /ルーブル/
るーぷ /ループ/
るーまにあ /羅馬尼/
るーむ /ルーム/
るーる /ルール/
るい /類/涙/累/塁/留衣/壘/泪/瘰/縲/羸/誄/瑠偉/瑠維/ルイ/
るいえふしょうまぞく /Actaea/ルイエフショウマ属/
るいか /ルイ華/累加/
るいぎ /類義/
るいぎご /類義語/
るいぎごじてん /類義語辞典/
るいけい /類型/累計/類形/
るいけいか /類型化/類形化/
るいけいてき /類型的/
るいけいろん /類型論/
るいけいろんてき /類型論的/
るいこ /ルイ子/
るいご /類語/
るいごじてん /類語辞典/
るいごめい /類語名/
るいさん /累算/
るいざん /累算/
るいざんき /累算器/
るいしょ /類書/
るいしょう /類焼/類症/
るいしん /累進/塁審/
るいしんかぜい /累進課税/
るいしんせい /累進性/
るいしんぜい /累進税/
るいしんぜいりつ /累進税率/
るいしんてきしょとくぜい /累進的所得税/
るいしんりつ /累進率/
るいじ /類似/類字/
るいじかもく /類似科目/
るいじきかん /類似機関/
るいじご /類似語/
るいじせい /類似性/
るいじてん /類似点/
るいじど /類似度/
るいじひん /類似品/
るいじぶつ /類似物/
るいじぶぶん /類似部分/
るいじほう /類似法/
るいじめい /類似名/
るいじょう /累乗/塁上/
るいじょうこん /累乗根/
るいじれい /類似例/
るいじんえん /類人猿/
るいすい /類推/
るいすいかのう /類推可能/
るいすいしゅほう /類推手法/
るいせき /累積/
るいせききつえんりょう /累積喫煙量/
るいせききのうほう /累積帰納法/
るいせききよりつ /累積寄与率/
るいせきせんりょう /累積線量/
るいせきぶんぷ /累積分布/
るいせん /涙線/
るいたいろん /類体論/
るいだすう /塁打数/
るいひ /類比/
るいべつ /類別/
るいるい /累々/累累/
るいれい /類例/
るいわ /累和/
るえん /流涎/
るか /流花/
るくす /ルクス/
るけい /流刑/
るけいせつ /流刑説/
るざい /流罪/
るす /留守/
るすたく /留守宅/
るすちゅう /留守中/
るすつ /留寿都/
るすでん /留守電/
るすばん /留守番/
るすばんそうち /留守番装置/
るすばんでんわ /留守番電話/
るすばんでんわき /留守番電話機/留守番電話器/
るすばんろくが /留守番録画/
るすろく /留守録/
るすろくが /留守録画/
るすろくきのう /留守録機能/
るそん /呂宋/
るたく /流謫/
るっくす /ルックス/
るつこ /路津子/
るつぼ /坩堝/
るてん /流転/
るにん /流人/
るび /ルビ/
るふ /流布/
るべしべ /留辺蕊/
るべつ /留別/
るぽるたーじゅ /ルポルタージュ/
るみ /流美/留美/瑠美/留実/ルミ/
るみこ /留美子/るみ子/
るもい /留萌/
るり /瑠璃/
るりこ /瑠璃子/ルリ子/るり子/留理子/
るる /縷々/縷縷/
るろう /流浪/
るろうのたみ /流浪の民/
るん /♪/
れーざー /レーザー/
れーざこう /レーザ光/
れーす /レース/
れーだ /レーダ/
れーと /レート/
れーべる /レーベル/
れーる /レール/
れい /例/冷/礼/麗/霊/齢/玲/鈴/令/励/隷/零/苓/嶺/怜/伶/戻/レイ/祈/儷/勵/唳/囹/櫺/澪/犂/犁/癘/禮/糲/綟/羚/聆/茘/蛉/蠡/醴/隸/靈/驪/鴒/黎/齡/蛎/砺/〇/
れいあうと /レイアウト/
れいあんしつ /霊安室/
れいあんじょ /冷暗所/
れいいち /鈴一/
れいえん /霊園/
れいおんたい /冷温帯/
れいおんていし /冷温停止/
れいか /冷夏/零下/玲花/隷下/麗香/麗華/
れいかい /例会/例解/霊界/
れいかいご /例会後/
れいかん /霊感/冷汗/
れいかんしょうほう /霊感商法/
れいがい /例外/冷害/
れいがいきこう /例外機構/
れいがいきじゅつ /例外記述/
れいがいきそく /例外規則/
れいがいきてい /例外規定/
れいがいしょり /例外処理/
れいがいしょりきのう /例外処理機能/
れいがいじこう /例外事項/
れいがいちゅう /例外中/
れいがいてき /例外的/
れいがいてん /例外点/
れいき /冷気/励起/冷機/
れいきじょうたい /励起状態/
れいきはちょう /励起波長/
れいきゃく /冷却/
れいきゃくいき /冷却域/
れいきゃくえき /冷却液/
れいきゃくおんど /冷却温度/
れいきゃくきかん /冷却期間/
れいきゃくぎじゅつ /冷却技術/
れいきゃくけいぜんたい /冷却系全体/
れいきゃくこうか /冷却効果/
れいきゃくざい /冷却材/
れいきゃくしゅだん /冷却手段/
れいきゃくすい /冷却水/
れいきゃくすいぶそく /冷却水不足/
れいきゃくせいのう /冷却性能/
れいきゃくたいさく /冷却対策/
れいきゃくのうりょく /冷却能力/
れいきゃくのうりょくぶそく /冷却能力不足/
れいきゃくふう /冷却風/
れいきゃくぶ /冷却部/
れいきゃくぶぶん /冷却部分/
れいきゃくほう /冷却法/
れいきゃくほうほう /冷却方法/
れいきゃくよう /冷却用/
れいきゅう /霊柩/
れいきゅうしゃ /霊柩車/
れいきん /礼金/
れいぎ /礼儀/
れいぎさほう /礼儀作法/
れいく /麗句/
れいぐう /冷遇/
れいけい /令閨/
れいけつ /冷血/
れいけつかん /冷血漢/
れいけつどうぶつ /冷血動物/
れいけん /霊験/
れいげつ /例月/
れいげん /冷厳/霊験/冷源/霊言/
れいげんしゅう /霊言集/
れいげんどうし /霊幻道士/
れいこ /玲子/麗子/礼子/祈子/令子/玲香/怜子/レイコ/
れいこう /励行/
れいこく /冷酷/
れいこん /霊魂/
れいさい /零細/
れいさいきぎょう /零細企業/
れいさいけいえい /零細経営/
れいし /霊視/
れいしき /礼式/零式/
れいしきせんとうき /零式戦闘機/
れいしきゆそうき /零式輸送機/
れいしゅ /冷酒/
れいしょ /隷書/
れいしょう /例証/冷笑/醴漿/
れいしょく /令色/
れいしん /励振/
れいしんりょく /励振力/
れいじ /玲二/例示/零時/礼仁/怜二/玲司/零士/禮二/零次/
れいじか /例示化/
れいじゅう /隷従/霊獣/
れいじょう /令嬢/令状/礼状/霊場/
れいじろう /令二朗/霊次郎/礼二郎/
れいじん /麗人/
れいすい /冷水/
れいすいき /冷水機/冷水器/
れいすいよう /冷水用/
れいず /例図/
れいせい /冷静/冷製/
れいせいちんちゃく /冷静沈着/
れいせつ /礼節/
れいせん /冷戦/零戦/零戰/
れいせんか /冷戦下/
れいせんご /冷戦後/
れいせんしゅうけつ /冷戦終結/
れいぜん /冷然/霊前/
れいそう /礼装/
れいそく /令息/
れいぞう /冷蔵/
れいぞうこ /冷蔵庫/冷藏庫/
れいぞうこよう /冷蔵庫用/
れいぞうしつ /冷蔵室/
れいぞうのうりょく /冷蔵能力/
れいぞく /隷属/隸屬/
れいたい /冷帯/霊体/
れいたん /冷淡/
れいだい /例題/
れいだいていど /例題程度/
れいだいよう /例題用/
れいだんぼう /冷暖房/
れいだんぼうちょうせつ /冷暖房調節/
れいだんぼうひ /冷暖房費/
れいちょうけん /霊長研/
れいちょうるい /霊長類/
れいっ /(_o_)/
れいてき /霊的/
れいてつ /冷徹/
れいてん /零点/
れいとう /冷凍/
れいとうかいじゅう /冷凍怪獣/
れいとうき /冷凍機/
れいとうぎょうざ /冷凍餃子/
れいとうこ /冷凍庫/
れいとうご /冷凍後/
れいとうしつ /冷凍室/
れいとうしょくひん /冷凍食品/
れいとうひん /冷凍品/
れいとうほぞん /冷凍保存/
れいとうほぞんほうほう /冷凍保存方法/
れいとうもの /冷凍物/
れいとうれいぞうこ /冷凍冷蔵庫/
れいとねりあもく /レイトネリア目/Leitneriales/
れいど /零度/
れいな /玲奈/麗奈/伶奈/レイナ/
れいにゅう /戻入/
れいねつ /冷熱/
れいねん /例年/
れいねんいじょう /例年以上/
れいの /例の/
れいのう /霊能/
れいのうしゃ /霊能者/
れいのうりょく /霊能力/
れいのうりょくしゃ /霊能力者/
れいはい /礼拝/
れいはいじ /礼拝時/
れいはいちゅう /礼拝中/
れいはいどう /礼拝堂/
れいはいび /礼拝日/
れいばい /霊媒/冷媒/
れいびょう /霊廟/
れいふう /冷風/
れいふうき /冷風機/
れいふうせん /冷風扇/
れいふうのうりょく /冷風能力/
れいふく /礼服/
れいふじん /令夫人/
れいぶん /例文/麗文/
れいぶんしゅう /例文集/
れいぶんみゃくもでる /例文脈モデル/
れいほう /礼法/礼砲/
れいぼう /冷房/麗貌/
れいぼうか /冷房化/
れいぼうかいぞう /冷房改造/
れいぼうかりつ /冷房化率/
れいぼうきかん /冷房期間/
れいぼうしゃ /冷房車/
れいぼうじゅよう /冷房需要/
れいぼうせつび /冷房設備/
れいぼうそうさき /冷房操作器/
れいぼうちゅう /冷房中/
れいぼうのうりょく /冷房能力/
れいぼうよう /冷房用/
れいぼうりつ /冷房率/
れいみ /麗美/
れいめい /黎明/令名/
れいめいき /黎明期/
れいめん /冷麺/
れいや /麗也/
れいやく /霊薬/
れいよう /羚羊/
れいようしゅ /冷用酒/
れいらく /零落/
れいり /伶俐/
れいりょう /冷涼/
れいりょく /霊力/
れいろう /玲瓏/
れおな /玲央名/玲於奈/
れき /歴/暦/檪/櫪/瀝/癧/礫/轢/轣/靂/
れきがん /礫岩/
れきげつ /暦月/
れきし /歴史/轢死/
れきしか /歴史家/
れきしかん /歴史観/歴史館/
れきしがく /歴史学/
れきしがっか /歴史学科/
れきしきょうかしょ /歴史教科書/
れきししょ /歴史書/
れきしじだい /歴史時代/
れきしじょう /歴史上/
れきしじんぶつ /歴史人物/
れきしすいり /歴史推理/
れきしてき /歴史的/
れきしてきいち /歴史的位置/
れきしてきいみ /歴史的意味/
れきしてきかち /歴史的価値/
れきしてきかてい /歴史的過程/
れきしてきけいい /歴史的経緯/
れきしてきけんち /歴史的見地/
れきしてきげんかい /歴史的限界/
れきしてきこうさつ /歴史的考察/
れきしてきこんきょ /歴史的根拠/
れきしてきしゅんかん /歴史的瞬間/
れきしてきじけん /歴史的事件/
れきしてきじじつ /歴史的事実/
れきしてきじじょう /歴史的事情/
れきしてきじょうけん /歴史的条件/
れきしてきせいやく /歴史的制約/
れきしてきちしき /歴史的知識/
れきしてきつづり /歴史的綴/歴史的綴り/
れきしてきできごと /歴史的出来事/
れきしてきはいけい /歴史的背景/
れきしてきはってん /歴史的発展/
れきしてきぶんけん /歴史的文献/
れきしてきへんせん /歴史的変遷/
れきしてきめいば /歴史的名馬/
れきしてきりゆう /歴史的理由/
れきしどくほん /歴史読本/
れきしはいけい /歴史背景/
れきしはっけん /歴史発見/
れきしもの /歴史物/
れきしもんだい /歴史問題/
れきしりかい /歴史理解/
れきじつ /暦日/
れきせい /瀝青/
れきせん /歴戦/
れきぜん /歴然/
れきだい /歴代/
れきだいしょうきんじょおう /歴代賞金女王/
れきだいせいふ /歴代政府/
れきだいよこづな /歴代横綱/
れきにん /歴任/
れきねん /歴年/
れきねんれい /暦年齢/
れきはく /歴博/
れきひょう /暦表/
れきひょうじ /暦表時/
れきぶ /暦部/
れきほう /歴訪/暦法/
れきほん /暦本/
れきれき /歴々/
れぎゅらー /レギュラー/
れくいえむ /レクイエム/
れくちゃー /レクチャー/
れこーだー /レコーダー/
れこーでぃんぐ /レコーディング/
れこーど /レコード/
れこーどや /レコード屋/
れしーと /レシート/
れじ /レジ/
れじーむ /レジーム/
れじゃー /レジャー/
れじゅめ /レジュメ/
れすちおもく /レスチオ目/Restionales/
れすとらん /レストラン/
れすぽんす /レスポンス/
れすりんぐ /レスリング/
れせぷしょん /レセプション/
れたー /レター/
れち /裂/
れっか /劣化/烈火/
れっかい /裂開/
れっかいか /裂開果/
れっき /列記/
れっきょ /列挙/
れっきょう /列強/
れっきょがた /列挙型/
れっこく /列国/
れっし /列子/
れっしゃ /列車/
れっしゃあいしょう /列車愛称/
れっしゃいがい /列車以外/
れっしゃいどう /列車移動/
れっしゃうんこう /列車運行/
れっしゃうんてんせいぎょ /列車運転制御/
れっしゃかんかく /列車間隔/
れっしゃぐん /列車群/
れっしゃしきべつしんごう /列車識別信号/
れっしゃしゃしん /列車写真/
れっしゃしゅたい /列車主体/
れっしゃしゅべつ /列車種別/
れっしゃしょくどう /列車食堂/
れっしゃしょくどうしゃ /列車食堂車/
れっしゃせっきん /列車接近/
れっしゃどうよう /列車同様/
れっしゃない /列車内/
れっしゃばんごう /列車番号/
れっしゃばんごうじゅん /列車番号順/
れっしゃへんせい /列車編成/
れっしゃへんせいひょう /列車編成表/
れっしゃほう /列車砲/
れっしゃほんすう /列車本数/
れっしゃみつど /列車密度/
れっしゃむせん /列車無線/
れっしゃめい /列車名/
れっしゃりょうきん /列車料金/
れっしょう /裂傷/
れっしん /烈震/
れっせい /劣性/劣勢/列聖/冽清/
れっせいいでん /劣性遺伝/
れっせいいでんし /劣性遺伝子/
れっせいぎゃくてん /劣勢逆転/
れっせき /列席/
れっせきしゃ /列席者/
れっちゅう /列柱/
れっとう /劣等/列島/
れっとうかん /劣等感/
れっとうじゅうだん /列島縦断/
れっとうせい /劣等生/
れっとうてんびょう /列島点描/
れっど /レッド/
れっぱ /裂破/
れっぱく /裂帛/
れっぴんかん /列品館/
れっぷう /烈風/
れっぺん /裂片/
れつ /列/裂/烈/劣/冽/洌/
れつ> /劣/
れつあく /劣悪/
れつあくしゃ /劣悪者/
れつかほうせい /劣加法性/
れつかほうてき /劣加法的/
れつくうかん /列空間/
れつけっていけい /劣決定系/
れつご /劣後/
れつじつ /烈日/
れつじょう /劣情/
れつたんい /列単位/
れつでん /列伝/
れつなみ /列並/
れつばんごう /列番号/
れつべくとる /列ベクトル/
れつめ /列目/
れつりろん /列理論/
れつれつ /冽冽/
れとると /レトルト/
れな /レナ/玲奈/
ればー /レバー/
ればのん /レバノン/
れびゅー /レビュー/
れぶぇる /レヴェル/
れぶん /礼文/
れぶんとう /礼文島/
れべっか /レベッカ/
れべる /レベル/
れべる# /レベル#1/
れぽーと /レポート/
れみ /礼美/
れもねーど /レモネード/
れもん /レモン/檸檬/
れん /連/恋/蓮/練/聯/攣/憐/廉/簾/煉/漣/鎌/匳/嗹/奩/戀/斂/濂/瀲/縺/聨/臠/輦/鏈/錬/
れんあい /恋愛/
れんあいえいが /恋愛映画/
れんあいかん /恋愛観/
れんあいかんけい /恋愛関係/
れんあいかんじょう /恋愛感情/
れんあいげきじょう /恋愛劇場/
れんあいじょうたい /恋愛状態/
れんあいたいしょう /恋愛対象/
れんあいばなし /恋愛話/
れんあいべた /恋愛下手/
れんあいまんが /恋愛漫画/
れんあいろん /恋愛論/
れんおんほうそく /連音法則/
れんか /廉価/連歌/簾価/
れんかばん /廉価版/廉価盤/
れんかばんおんげん /廉価版音源/
れんかん /聯関/連関/連環/
れんが /連歌/煉瓦/
れんき /連記/練気/
れんきゅう /連休/
れんきゅうあけ /連休明け/連休明/
れんきゅうきかん /連休期間/
れんきゅうこうはん /連休後半/
れんきゅうちゅう /連休中/
れんきゅうまえ /連休前/
れんきょ /蓮炬/
れんきん /錬金/
れんきんじゅつ /錬金術/
れんきんじゅつし /錬金術師/
れんぐん /連軍/
れんけい /連携/連係/聯係/連系/
れんけいこうげき /連係攻撃/
れんけいじ /連係時/
れんけいわざ /連携技/
れんけつ /連結/
れんけついち /連結位置/
れんけつかのう /連結可能/
れんけつき /連結器/連結機/
れんけつさぎょう /連結作業/
れんけつし /連結子/
れんけつせい /連結性/
れんけつせいぶん /連結成分/
れんけつぶぶん /連結部分/
れんけつめん /連結面/
れんげ /蓮華/
れんげおうじょう /蓮華往生/
れんげおんせん /蓮華温泉/
れんげん /連言/∧/
れんげんけい /連言形/
れんげんし /連言肢/
れんこ /連呼/
れんこう /連行/連衡/簾鉤/攣拘/
れんこうあし /練行足/
れんこん /蓮根/
れんご /連語/
れんごう /連合/聯合/
れんごうおうこく /連合王国/
れんごうかい /連合会/
れんごうかんたい /連合艦隊/聯合艦隊/
れんごうきこう /連合機構/
れんごうぐん /連合軍/
れんごうこく /連合国/
れんごうこくがわ /連合国側/
れんごうこっか /連合国家/
れんごうさくひん /連合作品/
れんごうたい /連合体/
れんごうてき /連合的/
れんごうや /連合野/
れんごく /煉獄/
れんさ /連鎖/連銷/
れんさい /連載/
れんさいかいし /連載開始/
れんさいかいしじ /連載開始時/
れんさいかいしまえ /連載開始前/
れんさいかいすう /連載回数/
れんさいきじ /連載記事/
れんさいきゅうし /連載休止/
れんさいけいさいじ /連載掲載時/
れんさいけいしき /連載形式/
れんさいさいかい /連載再開/
れんさいさくひん /連載作品/
れんさいさっか /連載作家/
れんさいし /連載誌/
れんさいしゅうりょう /連載終了/
れんさいしゅうりょうご /連載終了後/
れんさいじ /連載時/
れんさいだんねん /連載断念/
れんさいちゅう /連載中/
れんさいちゅうし /連載中止/
れんさいちゅうだん /連載中断/
れんさいとうしょ /連載当初/
れんさいとちゅう /連載途中/
れんさいまんが /連載漫画/
れんさく /連作/
れんさくかきょく /連作歌曲/
れんさくしゅう /連作集/
れんさくたんぺん /連作短篇/連作短編/
れんさくたんぺんしゅう /連作短編集/
れんさけいろ /連鎖経路/
れんさすう /連鎖数/
れんさてき /連鎖的/
れんさはんのう /連鎖反応/
れんさはんばい /連鎖販売/
れんさはんばいとりひき /連鎖販売取引/
れんざ /連座/
れんざせいきょうか /連座制強化/
れんざぶろう /錬三郎/
れんざん /連山/連産/
れんしゃ /連射/連写/
れんしゃおん /連射音/
れんしゃしき /連射式/
れんしゃたいおう /連写対応/
れんしゃりょく /連射力/
れんしゅ /連取/
れんしゅう /練習/
れんしゅうあいて /練習相手/
れんしゅうかい /練習会/
れんしゅうかいすう /練習回数/
れんしゅうかだい /練習課題/
れんしゅうかん /練習艦/
れんしゅうき /練習機/
れんしゅうきかん /練習期間/
れんしゅうきょく /練習曲/
れんしゅうきょくさくひん /練習曲作品/
れんしゅうこうかい /練習航海/
れんしゅうしだい /練習次第/
れんしゅうしゃ /練習車/
れんしゅうしゃめん /練習斜面/
れんしゅうじ /練習時/
れんしゅうじあい /練習試合/
れんしゅうじかん /練習時間/
れんしゅうじょ /練習所/
れんしゅうじょう /練習場/
れんしゅうせい /練習生/
れんしゅうせん /練習船/
れんしゅうそうこう /練習走行/
れんしゅうたいせい /練習体制/
れんしゅうだい /練習台/
れんしゅうちゅう /練習中/
れんしゅうちょう /練習帳/
れんしゅうなかま /練習仲間/
れんしゅうばしょ /練習場所/
れんしゅうばんごう /練習番号/
れんしゅうび /練習日/
れんしゅうふうけい /練習風景/
れんしゅうぶそく /練習不足/
れんしゅうほう /練習法/
れんしゅうほうほう /練習方法/
れんしゅうまえ /練習前/
れんしゅうもんだい /練習問題/
れんしゅうよう /練習用/
れんしゅうようぐ /練習用具/
れんしゅうりょう /練習量/
れんしゅく /攣縮/
れんしょ /連署/
れんしょう /連勝/
れんしょうきねん /連勝記念/
れんしょうきろく /連勝記録/
れんしょうご /連勝後/
れんしょうしき /連勝式/
れんしょうたんしき /連勝単式/
れんしょうちゅう /連勝中/
れんしょうふくしき /連勝複式/
れんじ /レンジ/櫺/蓮司/
れんじく /連軸/
れんじつ /連日/
れんじつほうそう /連日放送/
れんじゃく /連尺/連雀/
れんじゅ /連珠/
れんじょ /連署/
れんじょう /連城/連声/
れんすうじ /連数字/
れんせい /錬成/連星/連製/連成/
れんせいけい /連星系/連成系/
れんせいちゅうせいしせい /連星中性子星/
れんせつ /連接/
れんせつし /連接子/
れんせつしゃ /連接車/
れんせつぶ /連接部/
れんせん /連戦/
れんせんちゅう /連戦中/
れんせんれんしょう /連戦連勝/
れんそう /連想/連奏/連装/聯想/
れんそうがくしゅう /連想学習/
れんそうきおく /連想記憶/
れんそうきおくじゅつ /連想記憶術/
れんそうしき /連想式/
れんそうしゅぎ /連想主義/
れんそうしゅぎしゃ /連想主義者/
れんそうしゅぎしゃこうぞう /連想主義者構造/
れんそうてき /連想的/
れんそうはいれつ /連想配列/
れんそうらむ /連想ＲＡＭ/
れんそうりょく /連想力/
れんぞく /連続/連續/
れんぞくうんてん /連続運転/
れんぞくおうて /連続王手/
れんぞくおんせい /連続音声/
れんぞくかいさい /連続開催/
れんぞくかいてん /連続回転/
れんぞくかいほう /連続解放/
れんぞくかんすう /連続関数/連続函数/
れんぞくかんとうきろく /連続完投記録/
れんぞくかんぷう /連続完封/
れんぞくがぞう /連続画像/
れんぞくくうかん /連続空間/
れんぞくけい /連続系/
れんぞくけいさい /連続掲載/
れんぞくこ /連続弧/
れんぞくこうげき /連続攻撃/
れんぞくこうそくそうこう /連続高速走行/
れんぞくさいせい /連続再生/
れんぞくさいせいじかん /連続再生時間/
れんぞくさつえい /連続撮影/
れんぞくさつえいじかん /連続撮影時間/
れんぞくさつじん /連続殺人/
れんぞくさつじんじけん /連続殺人事件/
れんぞくさつじんはん /連続殺人犯/
れんぞくさんしん /連続三振/
れんぞくし /連続紙/
れんぞくしあいしゅつじょう /連続試合出場/
れんぞくしき /連続式/
れんぞくしゃげき /連続射撃/
れんぞくしゃしん /連続写真/
れんぞくしゃぞう /連続写像/
れんぞくしゅうり /連続修理/
れんぞくじっすうち /連続実数値/
れんぞくじゅうでん /連続充電/
れんぞくじょうしゃけん /連続乗車券/
れんぞくせい /連続性/
れんぞくそうしん /連続送信/
れんぞくそく /連続束/
れんぞくたい /連続体/
れんぞくたいかせつ /連続体仮説/
れんぞくたいりょくがく /連続体力学/
れんぞくだ /連続打/
れんぞくだん /連続弾/
れんぞくち /連続値/
れんぞくていしゃ /連続停車/
れんぞくてき /連続的/
れんぞくとうろんかい /連続討論会/
れんぞくとくてん /連続得点/
れんぞくどうさ /連続動作/
れんぞくはっこう /連続発行/
れんぞくばんぐみ /連続番組/
れんぞくふか /連続負荷/
れんぞくまっぴんぐ /連続マッピング/
れんぞくもの /連続もの/
れんぞくゆうぎ /連続遊技/
れんぞくゆうしょう /連続優勝/
れんぞくようし /連続用紙/
れんぞくりったいこうさ /連続立体交差/
れんぞくりょう /連続量/
れんぞくりょういき /連続領域/
れんぞくろくがじかん /連続録画時間/
れんぞくわざ /連続技/
れんたい /連体/連帯/連隊/連対/聯隊/聨隊/
れんたいかん /連帯感/
れんたいきぼ /連隊規模/
れんたいきろく /連対記録/
れんたいけい /連体形/
れんたいし /連体詞/
れんたいじっせき /連対実績/
れんたいちょう /連隊長/
れんたいほしょうにん /連帯保証人/
れんたいりつ /連対率/連体率/
れんたつ /練達/
れんたる /レンタル/
れんたん /連単/練炭/煉炭/
れんだ /連打/
れんだく /連濁/
れんだん /連弾/
れんちゃん /連荘/連チャン/
れんちゅう /連中/
れんちゅうたち /連中達/
れんちょう /連長/
れんちょく /廉直/
れんとう /連闘/連騰/連投/
れんとげん /レントゲン/
れんど /練度/
れんどう /連動/
れんどうかのう /連動可能/
れんどうしき /連動式/
れんどら /連ドラ/
れんにゅう /練乳/煉乳/
れんねん /連年/
れんばい /廉売/
れんばく /恋縛/
れんばん /連番/
れんばんさんしょう /連番参照/
れんばんしていせき /連番指定席/
れんぱ /連破/連覇/
れんぱい /連敗/
れんぱいきろく /連敗記録/
れんぱいちゅう /連敗中/
れんぱく /連泊/練帛/
れんぱたっせい /連覇達成/
れんぱちゅう /連覇中/
れんぱつ /連発/
れんびん /憐愍/憐憫/
れんふく /連複/
れんふくしき /連複式/
れんぶんすう /連分数/
れんぶんすうぶんかい /連分数分解/
れんぶんせつ /連文節/
れんぶんせつへんかん /連文節変換/
れんぷ /連符/
れんぺい /練兵/錬兵/
れんほう /蓮舫/連舫/
れんぼ /恋慕/
れんぼう /連坊/
れんぼうこうじ /連坊小路/
れんぽう /連邦/連峰/聯邦/
れんぽうかいぎ /連邦会議/
れんぽうがわ /連邦側/
れんぽうきょうわこく /連邦共和国/
れんぽうぐん /連邦軍/
れんぽうぐんしょうこう /連邦軍将校/
れんぽうこっか /連邦国家/
れんぽうさいばんしょ /連邦裁判所/
れんぽうせいふ /連邦政府/
れんぽうせいふきょく /連邦政府局/
れんま /錬磨/練磨/
れんめい /連盟/連名/聯盟/
れんめいしゃ /連名者/
れんめん /連綿/
れんや /連夜/
れんよう /連用/
れんようけい /連用形/
れんらく /連絡/聯絡/
れんらくいいん /連絡委員/
れんらくいん /連絡員/
れんらくえき /連絡駅/
れんらくかい /連絡会/
れんらくかいぎ /連絡会議/
れんらくかのう /連絡可能/
れんらくがかり /連絡係/
れんらくきっぷ /連絡切符/
れんらくきゅうこう /連絡急行/
れんらくきょう /連絡橋/
れんらくぐち /連絡口/
れんらくさ /連絡差/
れんらくさき /連絡先/
れんらくさきしょざいち /連絡先所在地/
れんらくさきじゅうしょ /連絡先住所/
れんらくさきめいき /連絡先明記/
れんらくしゃ /連絡者/
れんらくしゃめい /連絡者名/
れんらくしゅうはすう /連絡周波数/
れんらくしゅだん /連絡手段/
れんらくしょ /連絡書/連絡所/
れんらくじ /連絡時/
れんらくじこう /連絡事項/
れんらくじょ /連絡所/
れんらくずみ /連絡済み/
れんらくせん /連絡船/連絡線/
れんらくせんはっちゃくじょ /連絡船発着所/
れんらくたんとうしゃ /連絡担当者/
れんらくちょう /連絡帳/
れんらくつうろ /連絡通路/
れんらくてつどう /連絡鉄道/
れんらくどう /連絡道/
れんらくひょう /連絡票/
れんらくぶんしょ /連絡文書/
れんらくほうほう /連絡方法/
れんらくもう /連絡網/
れんらくよう /連絡用/
れんらくようむせん /連絡用無線/
れんらくらん /連絡欄/
れんりつ /連立/聯立/
れんりついちじほうていしき /連立一次方程式/
れんりつせいけん /連立政権/
れんりつほうていしき /連立方程式/
れんれん /攣攣/恋恋/恋々/
ろ /路/露/呂/魯/櫓/炉/賂/盧/鷺/廬/枦/櫚/滷/瀘/爐/絽/臚/艪/輅/轤/顱/驢/髏/鹵/蘆/櫨/蕗/
ろー /ρ/
ろーかる /ローカル/
ろーず /ローズ/
ろーそん /ローソン/
ろーとせいやく /ロート製薬/
ろーとる /老頭児/
ろーど /ロード/
ろーま /ローマ/羅馬/
ろーまじ /ローマ字/
ろーん /ローン/
ろあく /露悪/
ろう /郎/朗/老/浪/蝋/牢/狼/労/聾/楼/篭/漏/廊/弄/婁/榔/露/瘻/癆/僂/勞/咾/哢/壟/實/撈/朖/朧/柆/槞/樓/潦/焜/琅/瑯/瓏/籠/簍/粮/臘/臈/薐/蘢/螂/螻/褸/鑞/陋/隴/縷/滝/糧/
ろうあ /聾唖/
ろうえい /漏洩/朗詠/
ろうえいでんぱ /漏洩電波/
ろうえき /労役/
ろうえん /狼煙/
ろうおく /陋屋/
ろうおん /漏音/
ろうか /廊下/老化/蝋花/
ろうかい /老獪/
ろうかがわ /廊下側/
ろうかく /楼閣/
ろうかげんしょう /老化現象/
ろうがい /老害/
ろうがっこう /聾学校/
ろうがん /老眼/蝋丸/
ろうきほう /労基法/
ろうきゅう /老朽/篭球/籠球/
ろうきゅうか /老朽化/
ろうきょ /籠居/蝋炬/
ろうきょう /老境/
ろうきょうじゅ /老教授/
ろうきょく /浪曲/
ろうきん /労金/
ろうく /労苦/
ろうくみ /労組/
ろうこ /牢固/
ろうこう /漏光/陋巷/老公/
ろうこうたいさく /漏光対策/
ろうご /老後/
ろうごく /牢獄/
ろうさい /労災/
ろうさく /労作/
ろうし /労使/浪士/老子/老師/
ろうしかん /労使間/
ろうしつ /狼疾/
ろうしふんそう /労使紛争/
ろうしゃ /聾者/
ろうしゅ /蝋珠/
ろうしゅう /老醜/陋習/
ろうしゅつ /漏出/
ろうしゅん /老春/
ろうしょう /労相/老将/
ろうしんし /老紳士/
ろうじゃくだんじょ /老若男女/
ろうじゅう /老中/
ろうじゅく /老熟/
ろうじょ /老女/
ろうじょう /篭城/
ろうじん /老人/
ろうじんいりょう /老人医療/
ろうじんいりょうひ /老人医療費/
ろうじんえいが /老人映画/
ろうじんかい /老人会/
ろうじんご /老人語/
ろうじんしせつ /老人施設/
ろうじんせい /老人性/
ろうじんせんよう /老人専用/
ろうじんはん /老人斑/
ろうじんほけん /老人保健/
ろうすい /漏水/老衰/
ろうすいし /老衰死/
ろうせい /老成/労政/
ろうせいぶ /労政部/
ろうせつ /漏洩/漏泄/
ろうぜき /狼藉/
ろうそ /労組/
ろうそうしそう /老荘思想/
ろうそく /蝋燭/ロウソク/
ろうたい /老体/
ろうたいか /老大家/
ろうちん /労賃/
ろうていとく /老提督/
ろうでん /漏電/
ろうと /漏斗/
ろうとう /郎党/蝋灯/
ろうとじょう /漏斗状/
ろうどう /労働/労動/
ろうどういよく /労働意欲/
ろうどううんどう /労働運動/
ろうどうかんきょう /労働環境/
ろうどうきじゅんほう /労働基準法/
ろうどうきょうか /労働強化/
ろうどうきょうやく /労働協約/
ろうどうくみあい /労働組合/
ろうどうけいやく /労働契約/
ろうどうしゃ /労働者/
ろうどうしゅうにゅう /労働収入/
ろうどうしょう /労働省;2001年1月の中央省庁再編で厚生労働省に再編された/
ろうどうじかん /労働時間/
ろうどうじょう /労働上/
ろうどうじょうけん /労働条件/
ろうどうそうぎ /労働争議/
ろうどうぶんぱいりつ /労働分配率/
ろうどうほう /労働法/
ろうどうほうしょう /労働報償/
ろうどうりょう /労働量/
ろうどうりょく /労働力/
ろうどうりんり /労働倫理/
ろうどく /朗読/
ろうなぬし /牢名主/
ろうにゃく /老若/
ろうにゃくなんにょ /老若男女/
ろうにん /浪人/
ろうにんぎょう /蝋人形/
ろうにんじだい /浪人時代/
ろうにんせい /浪人生/
ろうにんせいかつ /浪人生活/
ろうにんせいじだい /浪人生時代/
ろうにんちゅう /浪人中/
ろうねん /老年/
ろうねんき /老年期/
ろうはい /老廃/
ろうはいぶつ /老廃物/
ろうば /老婆/
ろうばい /狼狽/
ろうばいか /ロウバイ科/Calycanthaceae/
ろうばしん /老婆心/
ろうひ /浪費/
ろうふうふ /老夫婦/
ろうふじん /老婦人/
ろうへい /老兵/
ろうほう /朗報/
ろうぼく /老木/
ろうまん /浪漫/
ろうむ /労務/
ろうむしゃ /労務者/
ろうむひ /労務費/
ろうめ /浪目/
ろうめいじん /老名人/
ろうもう /老耄/
ろうや /牢屋/
ろうらく /篭絡/
ろうらんどう /楼蘭堂/
ろうりょく /労力/
ろうりょくてき /労力的/
ろうるい /蝋涙/
ろうれい /老齢/
ろうれいか /老齢化/
ろうれいしゃ /老齢者/
ろうれつ /陋劣/
ろうれん /労連/老練/
ろうろう /朗朗/朗々/
ろうわん /六萬/
ろえい /露営/
ろおわん /六萬/
ろか /濾過/芦花/
ろかき /濾過器/
ろかく /鹵獲/
ろかこうえん /芦花公園/
ろかそうち /濾過装置/
ろかた /路肩/
ろかたそうこう /路肩走行/
ろかたちゅうしゃ /路肩駐車/
ろかたはば /路肩幅/
ろく /録/六/緑/禄/肋/麓/６/漉/淕/碌/祿/轆/勒/戮/鹿/
ろくおん /録音/鹿苑/
ろくおんかのう /録音可能/
ろくおんかのうじかん /録音可能時間/
ろくおんがわ /録音側/
ろくおんき /録音機/
ろくおんきざい /録音機材/
ろくおんきのう /録音機能/
ろくおんぎじゅつ /録音技術/
ろくおんぎじゅつしゃ /録音技術者/
ろくおんさいせい /録音再生/
ろくおんじ /録音時/
ろくおんじょうたい /録音状態/
ろくおんずみ /録音済/
ろくおんちゅう /録音中/
ろくおんないよう /録音内容/
ろくおんねん /録音年/
ろくおんばん /録音盤/
ろくおんひょう /録音評/
ろくおんへんしゅうきき /録音編集機器/
ろくおんもと /録音元/
ろくおんもの /録音物/
ろくおんよう /録音用/
ろくが /録画/
ろくがかいしじこく /録画開始時刻/
ろくがきのう /録画機能/
ろくがぎじゅつ /録画技術/
ろくがさいせい /録画再生/
ろくがしっぱい /録画失敗/
ろくがしゅうりょうじこく /録画終了時刻/
ろくがじかん /録画時間/
ろくがじてん /録画時点/
ろくがじょうほう /録画情報/
ろくがずみ /録画済み/
ろくがたいしょう /録画対象/
ろくがちゅう /録画中/
ろくがちゅうけい /録画中継/
ろくがつ /６月/六月/6月/水無月/
ろくがどり /録画撮り/
ろくがふかのう /録画不可能/
ろくがぶ /録画部/
ろくがほうしき /録画方式/
ろくがもの /録画物/
ろくがよやく /録画予約/
ろくがよやくほうしき /録画予約方式/
ろくがりつ /録画率/
ろくごう /麓郷/六郷/六合/
ろくごうざきとうだい /禄剛崎灯台/
ろくごうせん /六号線/
ろくさい /録再/
ろくさいせい /録再生/
ろくさいどくりつ /録再独立/
ろくさぶろう /六三郎/
ろくさわ /六沢/
ろくざい /肋材/
ろくしゃく /六尺/
ろくしょう /六章/緑青/
ろくしんがったい /六神合体/
ろくしんたい /六神体/
ろくじ /6時/
ろくじぞう /六地蔵/
ろくじっさい /六十歳/
ろくじっぴき /六十匹/
ろくじゅう /六十/
ろくじゅうさんじょう /六三条/
ろくじゅうそう /六重奏/
ろくじゅっさい /六十歳/
ろくじゅっぴき /六十匹/
ろくじょう /六畳/六条/
ろくすけ /六輔/
ろくせい /鹿西/
ろくせんまい /六千枚/
ろくぞう /六蔵/
ろくたま /六玉/
ろくたろう /六太郎/
ろくたんだ /六反田/
ろくだいがく /六大学/
ろくだん /六段/
ろくだんぐみ /六段組/
ろくとく /六徳;人が守るべき六つの徳。「りくとく」とも/
ろくどう /六道/
ろくに /陸に/碌に/
ろくにん /六人/
ろくねん /六年/
ろくのへ /六戸/
ろくば /六馬/
ろくばん /六番/
ろくばんちょう /六番町/
ろくばんめ /六番目/
ろくぶんぎ /六分儀/
ろくべえ /六兵衛/
ろくまく /肋膜/
ろくめい /六名/
ろくめいかん /鹿鳴館/
ろくめんたい /６面体/
ろくや /六哉/
ろくよう /六曜/
ろくりょうへんせい /六両編成/
ろくれん /６連/
ろくろ /轆轤/
ろくろう /六郎/
ろぐ /ログ/
ろぐいん /ログイン/
ろぐいんめい /ログイン名/
ろけい /炉型/
ろけっと /ロケット/
ろけん /露見/
ろこ /ロコ/路子/
ろこう /露光/炉工/
ろこうき /露光機/
ろこうきょう /盧溝橋/
ろこうきょうじけん /盧溝橋事件/
ろこうじかん /露光時間/
ろこうびょうすう /露光秒数/
ろこうまど /露光窓/
ろこうりょう /露光量/
ろこつ /露骨/
ろご /ロゴ/
ろさんじん /魯山人/
ろざん /廬山/
ろし /濾紙/ろ紙/
ろしあ /ロシア/露西亜/
ろしあご /ロシア語/
ろしあじん /ロシア人/
ろしゅつ /露出/
ろしゅつかた /露出過多/
ろしゅつかんけい /露出関係/
ろしゅつきょう /露出狂/
ろしゅつきょようど /露出許容度/
ろしゅつけい /露出計/露出系/
ろしゅつけいないぞう /露出計内蔵/
ろしゅつじかん /露出時間/
ろしゅつせってい /露出設定/
ろしゅつそうさきのう /露出操作機能/
ろしゅつち /露出値/
ろしゅつど /露出度/
ろしゅつばいすう /露出倍数/
ろしゅつばいすうほせい /露出倍数補正/
ろしゅつぶそく /露出不足/
ろしゅつほせい /露出補正/
ろしゅつれんどう /露出連動/
ろしん /炉心/
ろしんけいさん /炉心計算/
ろしんふきん /炉心付近/
ろじ /路地/露地/
ろじうら /路地裏/
ろじょう /路上/
ろじょうかんさつ /路上観察/
ろじょうかんさつがく /路上観察学/
ろじょうかんさつがっかい /路上観察学会/
ろじょうきょうしゅう /路上教習/
ろじょうちゅうしゃ /路上駐車/
ろじょうちゅうしゃかのう /路上駐車可能/
ろじょうれんしゅう /路上練習/
ろじん /魯迅/
ろすい /呂翠/
ろせん /路線/
ろせんいがい /路線以外/
ろせんか /路線価/
ろせんかくにん /路線確認/
ろせんげんてい /路線限定/
ろせんしゃ /路線車/
ろせんしようりょう /路線使用料/
ろせんず /路線図/
ろせんずしき /路線図式/
ろせんせいび /路線整備/
ろせんはんい /路線範囲/
ろせんばんごう /路線番号/
ろせんへんこう /路線変更/
ろせんめい /路線名/
ろせんめいしょう /路線名称/
ろせんもう /路線網/
ろそくたい /路側帯/
ろそくたいそうこう /路側帯走行/
ろちゅう /路駐/
ろちょう /路長/
ろっかー /ロッカー/
ろっかく /六角/
ろっかくばし /六角橋/
ろっかくや /六角家/
ろっかしょむら /六ヶ所村/
ろっかっけい /六角形/
ろっかん /肋間/六巻/
ろっかんしんけいつう /肋間神経痛/
ろっきとう /六気筒/
ろっきゃく /六脚/
ろっく /ロック/
ろっこう /六甲/六興/
ろっこうおろし /六甲颪/
ろっこうさん /六甲山/
ろっこうさんけい /六甲山系/
ろっこうさんしゅうへん /六甲山周辺/
ろっこうさんじょう /六甲山上/
ろっこうだい /六甲台/
ろっこうみち /六甲道/
ろっこつ /肋骨/
ろっこん /六根/
ろっこんしょうじょう /六根清浄/
ろっぴき /六匹/
ろっぷ /六腑/
ろっぺい /六平/
ろっぽう /六法/六方/
ろっぽうぜんしょ /六法全書/
ろっぽん /六本/
ろっぽんぎ /六本木/
ろっぽんぎこうえん /六本木公演/
ろっぽんぎしんじゅう /六本木心中/
ろっぽんぎほうめん /六本木方面/
ろっぽんまつ /六本松/
ろてい /露呈/
ろてき /蘆荻/
ろてん /露天/露店/
ろてんぶろ /露天風呂/
ろとう /路頭/露頭/
ろない /炉内/
ろねつ /炉熱/
ろはば /路幅/
ろば /驢馬/ロバ/
ろばた /炉端/爐端/
ろばん /路盤/
ろばんこうじ /路盤工事/
ろぶすたー /ロブスター/
ろぶつ /炉物/
ろぶつり /炉物理/
ろぼう /路傍/
ろぼっと /ロボット/
ろまん /浪漫/
ろまんてぃしずむ /ロマンティシズム/
ろまんは /ロマン派/
ろまんひこう /浪漫飛行/
ろみ /路美/
ろめん /路面/
ろめんおんど /路面温度/
ろめんじょうきょう /路面状況/
ろめんじょうたい /路面状態/
ろめんでんしゃ /路面電車/
ろめんでんしゃよう /路面電車用/
ろめんひょうじよう /路面表示用/
ろめんぶぶん /路面部分/
ろめんよう /路面用/
ろもう /路網/
ろゆう /芦有/
ろりこん /ロリコン/
ろれつ /呂律/
ろん /論/侖/堽/崙/崘/栄/
ろんかく /論客/
ろんがい /論外/
ろんきゃく /論客/
ろんきゅう /論及/論究/
ろんきょ /論拠/
ろんぎ /論議/
ろんこう /論考/
ろんこく /論告/
ろんご /論語/
ろんし /論旨/
ろんしいっかん /論旨一貫/
ろんしゃ /論者/
ろんしゅう /論集/
ろんしょう /論証/
ろんしょうかのう /論証可能/
ろんしょうしえん /論証支援/
ろんしょうもんだい /論証問題/
ろんじゅつ /論述/
ろんじん /論陣/
ろんせつ /論説/
ろんせつぶん /論説文/
ろんせん /論戦/
ろんそう /論争/論爭/
ろんそうあいて /論争相手/
ろんそうかてい /論争過程/
ろんそうし /論争史/
ろんそうちゅう /論争中/
ろんだい /論題/
ろんだん /論壇/
ろんちょう /論調/
ろんてき /論敵/論的/
ろんてん /論点/
ろんどん /倫敦/
ろんばく /論駁/
ろんぱ /論破/
ろんひょう /論評/
ろんぴょう /論評/
ろんぶん /論文/
ろんぶんか /論文化/
ろんぶんけいしき /論文形式/
ろんぶんげんこう /論文原稿/
ろんぶんこうえん /論文講演/
ろんぶんさくせい /論文作成/
ろんぶんし /論文誌/
ろんぶんしっぴつ /論文執筆/
ろんぶんしどう /論文指導/
ろんぶんしゅう /論文集/
ろんぶんしゅたい /論文主体/
ろんぶんしょう /論文賞/
ろんぶんしょうかい /論文紹介/
ろんぶんしょうじゅしょう /論文賞受賞/
ろんぶんしりょうだい /論文資料代/
ろんぶんしんさ /論文審査/
ろんぶんすう /論文数/
ろんぶんせんしゅう /論文選集/
ろんぶんだいめい /論文題名/
ろんぶんちゅう /論文中/
ろんぶんちょう /論文調/
ろんぶんていしゅつ /論文提出/
ろんぶんとうこう /論文投稿/
ろんぶんなど /論文等/
ろんぶんはかせ /論文博士/
ろんぶんはくし /論文博士/
ろんぶんはっぴょう /論文発表/
ろんぶんはっぴょうしゃ /論文発表者/
ろんぶんひっしゃ /論文筆者/
ろんぶんぼしゅう /論文募集/
ろんぶんめい /論文名/
ろんぶんようし /論文要旨/
ろんほうら /栄和了/
ろんぽう /論法/
ろんり /論理/
ろんりえんざん /論理演算/
ろんりえんざんし /論理演算子/
ろんりか /論理化/
ろんりかいぎ /論理会議/
ろんりかいそう /論理階層/
ろんりかいろ /論理回路/
ろんりかいろこうせい /論理回路構成/
ろんりかいろず /論理回路図/
ろんりかん /論理感/
ろんりかんすう /論理関数/
ろんりかんすうしょり /論理関数処理/
ろんりがく /論理学/
ろんりがくしゃ /論理学者/
ろんりがくてき /論理学的/
ろんりがた /論理型/
ろんりがたげんご /論理型言語/
ろんりがめん /論理画面/
ろんりきごう /論理記号/
ろんりきのう /論理機能/
ろんりきばん /論理機番/
ろんりけい /論理系/
ろんりけいさん /論理計算/
ろんりけいていぎぶ /論理系定義部/
ろんりけつごうし /論理結合子/
ろんりこうぞう /論理構造/
ろんりこうぞうじょう /論理構造上/
ろんりごうせい /論理合成/
ろんりざひょう /論理座標/
ろんりしき /論理式/
ろんりしきちゅう /論理式中/
ろんりしゅぎ /論理主義/
ろんりじかん /論理時間/
ろんりじゅうし /論理重視/
ろんりじょう /論理上/
ろんりせい /論理性/
ろんりせいじゅうし /論理性重視/
ろんりせき /論理積/
ろんりせっけい /論理設計/
ろんりそうさ /論理操作/
ろんりそうち /論理装置/
ろんりそうちめい /論理装置名/
ろんりそし /論理素子/
ろんりたいけい /論理体系/
ろんりだんかい /論理段階/
ろんりち /論理値/
ろんりていすう /論理定数/
ろんりてき /論理的/
ろんりてきかてい /論理的過程/
ろんりてききけつ /論理的帰結/
ろんりてききごう /論理的記号/
ろんりてききのう /論理的機能/
ろんりてきけってん /論理的欠点/
ろんりてきこうり /論理的公理/
ろんりてきこんきょ /論理的根拠/
ろんりてきしこう /論理的思考/
ろんりてきしこうりょく /論理的思考力/
ろんりてきしょうめい /論理的証明/
ろんりてきしょり /論理的処理/
ろんりてきせいごうせい /論理的整合性/
ろんりてきそしき /論理的組織/
ろんりてきたんきゅう /論理的探求/
ろんりてきはんだん /論理的判断/
ろんりてきむじゅん /論理的矛盾/
ろんりてきりかい /論理的理解/
ろんりてんかい /論理展開/
ろんりてんかいりょく /論理展開力/
ろんりへんすう /論理変数/
ろんりむじゅん /論理矛盾/
ろんりめい /論理名/
ろんりめいだい /論理命題/
ろんりゆうせん /論理優先/
ろんりわ /論理和/
わ /和/話/輪/倭/羽/我/把/環/杷/琶/啝/萵/吾/
わーく /ワーク/
わーくすてーしょん /ワークステーション/
わーどぷろせっさ /ワードプロセッサ/
わーぷ /ワープ/
わーぷろ /ワープロ/
わーるど /ワールド/
わーるどかっぷ /Ｗ杯/
わい /歪/隈/賄/猥/矮/淮/薈/
わいあ /ワイア/
わいおく /矮屋/
わいか /猥歌/
わいきょく /歪曲/
わいきょくしゅうさ /歪曲収差/
わいく /矮躯/
わいざつ /猥雑/
わいしかんぎ /矮子看戯/
わいしゃつ /ワイシャツ/
わいしょう /矮小/
わいしょうか /矮小化/
わいせい /矮星/
わいせつ /猥褻/
わいせつぶんしょ /猥褻文書/
わいだん /猥談/
わいど /ワイド/歪度/
わいばら /莪原/
わいぱー /ワイパー/
わいほん /猥本/
わいや /ワイヤ/
わいやー /ワイヤー/
わいろ /賄賂/
わいろう /矮陋/
わいん /ワイン/
わう /往/横/王/黄/皇/
わえい /和英/
わえいじしょ /和英辞書/
わえいじてん /和英辞典/
わおうぶんかん /和欧文間/
わおん /和音/
わおんにんしき /和音認識/
わおんれんけつ /和音連結/
わか /若/和歌/
わかい /和賀井/和解/若井/
わかいずみ /和解済/
わかいろ /若色/
わかうらしゅうへん /和歌浦周辺/
わかお /稚郎/
わかおくさま /若奥様/
わかき /若木/
わかぎ /若木/
わかくさ /若草/
わかくさいろ /若草色/
わかくさものがたり /若草物語/
わかくわ /若桑/
わかげ /若気/
わかこ /和歌子/和佳子/
わかさ /若狭/若佐/
わかさき /若桜木/
わかさだに /若狭谷/
わかさと /若里/
わかしおこくたい /若潮国体/
わかしま /若島/
わかしまづ /若嶋津/
わかしゅ /若衆/
わかしゅう /若衆/
わかしょうよう /若翔洋/
わかじし /若獅子/
わかすぎ /若杉/
わかせ /若瀬/
わかせがわ /若瀬川/
わかぞう /若造/若僧/
わかた /若田/
わかたか /若貴/
わかたに /若谷/
わかたべ /若田部/
わかだいしょう /若大将/
わかだんな /若旦那/
わかちがき /わかち書き/
わかつき /若月/若槻/
わかて /若手/
わかてかい /若手会/
わかてがいやしゅ /若手外野手/
わかてきし /若手棋士/
わかてけんきゅうしゃ /若手研究者/
わかてげいにん /若手芸人/
わかてさっか /若手作家/
わかてせんしゅ /若手選手/
わかてたいけつ /若手対決/
わかてたんとう /若手担当/
わかてちゅうしん /若手中心/
わかてぶつりや /若手物理屋/
わかと /若戸/
わかとおおはし /若戸大橋/
わかとの /若殿/
わかどしより /若年寄/
わかどり /若鶏/
わかな /若菜/
わかのはな /若乃花/若ノ花/
わかはげ /若禿/
わかはなだ /若花田/
わかはら /若原/
わかば /若葉/
わかばだい /若葉台/
わかばちょう /若葉町/
わかばまーく /若葉マーク/
わかばやし /若林/
わかばやしく /若林区/
わかふうふ /若夫婦/
わかまつ /若松/
わかまつく /若松区/
わかまつしでん /若松市電/
わかまつちょう /若松町/
わかまつつうしょう /若松通商/
わかみ /若美/
わかみや /若宮/
わかむら /若村/
わかむらさき /若紫/
わかめ /若布/若芽/
わかもとせいやく /わかもと製薬/
わかもの /若者/
わかものことば /若者言葉/
わかものたち /若者達/
わかものむき /若者向/
わかものやく /若者役/
わかもり /若森/
わかやく /若役/
わかやなぎ /若柳/
わかやなぎちょう /若柳町/
わかやま /和歌山/若山/
わかやまかん /和歌山間/
わかやまけん /和歌山県/
わかやまけんちょう /和歌山県庁/
わかやまし /和歌山市/
わかやません /和歌山線/
わかやませんごじょう /和歌山線五条/
わかやまだい /和歌山大/
わかやまだいがく /和歌山大学/
わかやまてつどう /和歌山鉄道/
わかやまほうめん /和歌山方面/
わかれ /別れ/
わかれみち /別れ道/
わかれめ /分かれ目/
わかん /和漢/
わかんたいしょうひょう /和漢対照表/
わかんろうえいしゅう /和漢朗詠集/
わが /我/和賀/
わがくに /我が国/わが国/我が國/
わがこ /吾子/
わがこと /我がこと/
わがことながら /我がことながら/
わがし /和菓子/
わがしゃ /我社/我が社/
わがしや /和菓子屋/
わがしよう /和菓子用/
わがっき /和楽器/
わがつま /我妻/
わがな /我名/
わがはい /我輩/吾輩/
わがまま /我儘/我がまま/我侭/
わがみ /我が身/我身/
わがや /我が家/我家/
わき /脇/和気/和紀/腋/和氣/
わきあいあい /和気合い合い/和気藹藹/
わきが /腋臭/
わきげ /脇毛/腋毛/
わきこ /和貴子/
わきさか /脇坂/
わきすじ /脇筋/
わきた /脇田/
わきのさわ /脇野沢/
わきはま /脇浜/
わきはまちょう /脇浜町/
わきばら /脇腹/わき腹/
わきみ /わき見/脇見/
わきみうんてん /脇見運転/
わきみち /脇道/
わきむら /脇村/
わきめ /脇目/
わきもと /脇本/
わきや /脇谷/
わきやく /脇役/
わきやま /脇山/
わきん /和巾/和金/
わぎ /和議/和木/
わぎゅう /和牛/
わぎょう /ワ行/
わぎり /輪切り/
わく /枠/惑/或/
わくい /和久井/涌井/
わくいり /枠入り/
わくおち /枠落/
わくがい /枠外/
わくきん /枠金/
わくぐみ /枠組/枠組み/
わくじゅん /枠順/
わくじゅんかくてい /枠順確定/
わくじゅんはっぴょう /枠順発表/
わくせい /惑星/枠制/
わくせいかん /惑星間/
わくせいかんじん /惑星間塵/
わくせいけい /惑星系/
わくせいたんさき /惑星探査機/
わくせいめい /惑星名/
わくせん /枠線/
わくた /和久田/
わくだ /和久田/
わくちん /ワクチン/
わくない /枠内/
わくなし /枠無し/
わくばん /枠番/
わくべつ /湧別/
わくや /涌谷/
わくら /和倉/
わくらおんせん /和倉温泉/
わくり /和栗/和久利/
わくれん /枠連/
わけ /訳/和気/理由/譯/分け/分/
わけい /和敬/
わけかた /分け方/
わけべ /分部/
わけめ /分け目/
わげい /話芸/
わこう /和光/若生/倭寇/和孝/和寇/和幸/
わこうし /和光市/
わこうしふきん /和光市付近/
わこうしょうけん /和光証券/
わこうど /若人/
わこうどう /和光堂/
わこうまえ /和光前/
わこく /倭国/
わこんようさいてき /和魂洋才的/
わご /和語/
わごう /和合/
わごむ /輪ゴム/
わごん /ワゴン/
わごんしゃ /ワゴン車/
わさい /和裁/
わさび /山葵/
わさんぼん /和三盆/
わざ /技/業/伎/術/
わざせん /技戦/
わざと /態と/
わざら /和皿/
わざわ /和沢/
わざわい /災い/災/禍/
わし /鷲/儂/和紙/
わしお /鷲尾/
わしか /鷲家;姓/
わしき /和式/
わしさか /鷲坂/
わしつ /和室/
わしつちゅうしん /和室中心/
わしづ /鷲津/
わしづかみ /鷲掴み/
わしのぎ /鷲之樹/
わしま /和島/
わしみ /鷲見/
わしみや /鷲宮/
わしゃ /話者/
わしゃかん /話者間/
わしゃすう /話者数/
わしゃてきおう /話者適応/
わしゃどうてい /話者同定/
わしゃない /話者内/
わしゃにんしき /話者認識/
わしゅうごう /和集合/∪/
わしゅうざん /鷲羽山/
わしょ /和書/
わしょく /和食/
わしょくどう /和食堂/
わしょっき /和食器/
わしんとん /華盛頓/
わじ /和字/
わじき /鷲敷/
わじま /和嶋/輪島/和島/
わじゅつ /話術/
わじん /倭人/
わじんでん /倭人伝/
わすう /話数/
わすれ /忘れ/
わすれなぐさ /勿忘草/
わすれもの /忘れ物/
わせ /早稲/早生/
わせい /和声/和製/話声/和生/
わせいえいご /和製英語/
わせいか /和声化/
わせいがく /和声学/
わせいしんこう /和声進行/
わせいしんこうじょう /和声進行上/
わせいじゅつご /和製術語/
わせいてき /和声的/
わせいほう /和声法/
わせいや /和声屋/
わせいりろん /和声理論/
わせき /和積/
わせだ /早稲田/
わせだおうぶつ /早稲田応物/
わせだきかい /早稲田機械/
わせだぐち /早稲田口/
わせだこうけん /早稲田工研/
わせだこしょがい /早稲田古書街/
わせださい /早稲田祭/
わせだじん /早稲田陣/
わせだだい /早稲田大/
わせだだいがく /早稲田大学/
わせだだいがくあて /早稲田大学宛/
わせだだいがくかん /早稲田大学間/
わせだぶつり /早稲田物理/
わせだほうこう /早稲田方向/
わせだりこう /早稲田理工/
わそう /和装/
わぞく /倭族/
わた /渡/綿/棉/緜/
わたかべ /渡壁/
わたがし /棉菓子/
わたくし /私/
わたくしあて /私宛/
わたくしぎ /私儀/
わたくしごと /私事/
わたくしども /私共/
わたげ /綿毛/
わたごみ /綿ゴミ/
わたし /私/渡し/
わたしあて /私宛/
わたしいがい /私以外/
わたしかた /渡し方/
わたしこじん /私個人/
わたしこみ /渡し込み/
わたしじしん /私自身/
わたしたち /私達/私たち/私逹/
わたしたちあて /私達宛/
わたしども /私供/
わたしの /私の/
わたしひとり /私一人/
わたしぶね /渡し船/渡船/
わたしゃ /私ゃ/
わたしら /私等/
わたしりゅう /私流/
わたせ /渡瀬/綿瀬/
わたたに /綿谷/
わただ /和多田/
わたなべ /渡辺/渡邊/渡部/渡邉/
わたなべじゅんいち /渡辺淳一/
わたぬき /綿貫/
わたのは /渡波/
わたびき /綿引/
わたべ /渡部/
わたむら /綿村/
わたもり /渡森/
わたや /渡谷/
わたらい /度会/
わたり /亘理/渡/亘/
わたりぐん /亘理郡/
わたりちょう /亘理町/
わたりどり /渡り鳥/
わたる /渉/航/弥/渡/亘/亙/道/
わだ /和田/
わだい /話題/
わだいげんてい /話題限定/
わだいこ /和太鼓/
わだいこうかん /話題交換/
わだいさく /話題作/
わだいじたい /話題自体/
わだいせい /話題性/
わだいそうぜん /話題騒然/
わだいていきょう /話題提供/
わだいていきょうしゃ /話題提供者/
わだいぬし /話題主/
わだいふっとう /話題沸騰/
わだいふっとうちゅう /話題沸騰中/
わだいまんさい /話題満載/
わだけん /和田研/
わだち /轍/和達/
わだつみ /海童/海神/
わだやま /和田山/
わち /和智/和知/
わちゅう /話中/
わっかない /稚内/
わっかないえき /稚内駅/
わっかないかん /稚内間/
わっかないこうえん /稚内公園/
わっかないしない /稚内市内/
わっさむ /和寒/
わっと /ワット/
わづか /和束/
わて /和手/
わていしょく /和定食/
わどくじてん /和独辞典/
わどまり /和泊/
わどめ /輪止め/
わな /罠/
わに /鰐/和邇/
わにがわ /鰐皮/
わにぐち /鰐口/
わにりょうり /鰐料理/
わのうち /輪之内/
わび /侘/詫/佗/
わびじょう /詫状/
わびずまい /佗び住まい/佗住い/
わふう /和風/
わふうきっさ /和風喫茶/
わふく /和服/
わふつ /和仏/
わぶん /和文/
わぶんだいもく /和文題目/
わぶんつうわひょう /和文通話表/
わぶんでんしん /和文電信/
わぶんもじ /和文文字/
わぶんろんぶん /和文論文/
わへい /和平/
わへいかいぎ /和平会議/
わへいこうしょう /和平交渉/
わへいすいしんは /和平推進派/
わほう /話法/
わぼうちょう /和包丁/
わぼく /和睦/
わめい /和名/
わやく /和訳/
わやくぶん /和訳文/
わよう /和洋/
わようくだん /和洋九段/
わようじょし /和洋女子/
わようじょしだい /和洋女子大/
わようせっちゅう /和洋折衷/
わら /原/藁/稿/和良/
わらい /（笑）/笑い/笑/(笑)/
わらいかた /笑い方/
わらいがお /笑い顔/
わらいごえ /笑い声/
わらいばなし /笑い話/
わらいもの /笑い者/
わらがい /藁谷/
わらし /童/
わらしや /藁谷/
わらじ /草鞋/鞋/
わらじばき /草鞋履/
わらばんし /藁半紙/
わらび /蕨/
わらべ /童/
わらべうた /童歌/
わらわ /妾/童/
わり /割/割り/
わりあい /割合/
わりあて /割り当て/割当/割当て/
わりあてかのう /割当て可能/
わりあてせい /割当制/
わりいん /割印/割り印/
わりかた /割方/
わりかん /割り勘/割勘/
わりこみ /割り込み/割込み/割込/
わりこみじ /割り込み時/
わりざん /割り算/割算/
わりした /割下/
わりだか /割高/
わりだかうんちん /割高運賃/
わりだかかん /割高感/
わりだかりょうきん /割高料金/
わりだし /割り出し/割出し/
わりつけ /割付/割り付け/割付け/
わりつけがく /割付額/
わりばし /割箸/割り箸/
わりびき /割引/割り引き/
わりびきうんちん /割引運賃/
わりびきかかく /割引価格/
わりびききっぷ /割引切符/
わりびきけん /割引券/
わりびきこうくうけん /割引航空券/
わりびきさい /割引債/
わりびきしょう /割引証/
わりびきせいど /割引制度/
わりびきちょうせいがく /割引調整額/
わりびきはんばい /割引販売/
わりびきりつ /割引率/
わりびきりょうきん /割引料金/
わりふり /割り振り/
わりまえ /割前/
わりまし /割増/割増し/
わりましうんちん /割増運賃/
わりましきん /割増金/
わりもどし /割戻し/
わりやす /割安/
わりやすかん /割安感/
わる /悪/÷/惡/
わるお /悪男/
わるがき /悪餓鬼/
わるぎ /悪気/
わるくち /悪口/
わるぐち /悪口/
わるさ /悪さ/
わるじえ /悪知恵/
わるだくみ /悪巧み/
わるだま /悪玉/
わるぢえ /悪知恵/
わるもの /悪者/
わるものだんたい /悪者団体/
わるやく /悪役/
われ /我/吾/
われき /和暦/
われさき /我先/
われながら /我ながら/
われめ /割れ目/
われもの /割れ物/
われら /我等/我ら/我們/
われわれ /我々/我我/
わん /湾/腕/碗/椀/萬/弯/王/万/彎/灣/綰/豌/
わんがい /湾外/
わんがた /碗型/
わんがん /湾岸/
わんがんかいはつ /湾岸開発/
わんがんしょこく /湾岸諸国/
わんがんせん /湾岸線/
わんがんせんそう /湾岸戦争/
わんがんせんそうじ /湾岸戦争時/
わんがんふんそう /湾岸紛争/
わんきょく /湾曲/弯曲/彎曲/
わんしょう /腕章/
わんじょう /椀状/
わんたん /ワンタン/雲呑/
わんちゃい /湾仔/
わんない /湾内/
わんにゅう /湾入/彎入/
わんぱい /王牌/
わんぱく /腕白/
わんりゅう /湾流/
わんりょく /腕力/
わんりょくは /腕力派/
を /小/悪/惡/緒/雄/男/牡/尾/汚/
をう /翁/
をんな /女/
ウィ /ヰ/
ウェ /ヱ/
カラ /〜/
テン /・/
